@@ -20,15 +20,6 @@ function usage () {
     echo ""
 }
 
-function validate_ccnet_conf_dir () {
-    if [[ ! -d ${default_ccnet_conf_dir} ]]; then
-        echo "Error: there is no ccnet config directory."
-        echo "Have you run setup-seafile.sh before this?"
-        echo ""
-        exit -1;
-    fi
-}
-
 function validate_seafile_data_dir () {
     if [[ ! -d ${default_seafile_data_dir} ]]; then
         echo "Error: there is no seafile server data directory."
@@ -39,7 +30,6 @@ function validate_seafile_data_dir () {
 }
 
 function run_seaf_fsck () {
-    validate_ccnet_conf_dir;
     validate_seafile_data_dir;
 
     echo "Starting seaf-fsck, please wait ..."
