@@ -22,10 +22,10 @@ class ConfirmRestoreRepo extends Component {
       btnDisabled: true
     });
     this.props.restoreRepo();
-  }
+  };
 
   render() {
-    const {formActionURL, csrfToken, toggle} = this.props;
+    const { toggle } = this.props;
     return (
       <Modal centered={true} isOpen={true} toggle={toggle}>
         <ModalHeader toggle={toggle}>{gettext('Restore Library')}</ModalHeader>
