@@ -1,9 +1,10 @@
 import React, { Fragment } from 'react';
 import PropTypes from 'prop-types';
-import MD5 from 'MD5';
-import { UncontrolledTooltip } from 'reactstrap';
+import MediaQuery from 'react-responsive';
+import { v4 as uuidv4 } from 'uuid';
+import moment from 'moment';
 import { Dropdown, DropdownToggle, DropdownItem } from 'reactstrap';
-import { gettext, siteRoot, mediaUrl, username } from '../../utils/constants';
+import { gettext, siteRoot, mediaUrl, username, useGoFileserver, fileServerRoot } from '../../utils/constants';
 import { Utils } from '../../utils/utils';
 import { seafileAPI } from '../../utils/seafile-api';
 import URLDecorator from '../../utils/url-decorator';
@@ -15,10 +16,12 @@ import CopyDirentDialog from '../dialog/copy-dirent-dialog';
 import ShareDialog from '../dialog/share-dialog';
 import ZipDownloadDialog from '../dialog/zip-download-dialog';
 import EditFileTagDialog from '../dialog/edit-filetag-dialog';
+import EditFileTagPopover from '../popover/edit-filetag-popover';
 import LibSubFolderPermissionDialog from '../dialog/lib-sub-folder-permission-dialog';
+import toaster from '../toast';
+import FileTag from './file-tag';
 
 import '../../css/dirent-list-item.css';
-import toaster from '../toast';
 
 const propTypes = {
   path: PropTypes.string.isRequired,
@@ -34,6 +37,7 @@ const propTypes = {
   onItemRename: PropTypes.func.isRequired,
   onItemMove: PropTypes.func.isRequired,
   onItemCopy: PropTypes.func.isRequired,
+  onItemConvert: PropTypes.func.isRequired,
   onDirentClick: PropTypes.func.isRequired,
   updateDirent: PropTypes.func.isRequired,
   showImagePopup: PropTypes.func.isRequired,
@@ -52,12 +56,26 @@ const propTypes = {
   showDirentDetail: PropTypes.func.isRequired,
   onItemsMove: PropTypes.func.isRequired,
   onShowDirentsDraggablePreview: PropTypes.func,
+  loadDirentList: PropTypes.func,
 };
 
 class DirentListItem extends React.Component {
 
   constructor(props) {
     super(props);
+
+    const { dirent } = this.props;
+    const { isCustomPermission, customPermission } = Utils.getUserPermission(dirent.permission);
+    this.isCustomPermission = isCustomPermission;
+    this.customPermission = customPermission;
+    this.canPreview = true;
+    this.canDrag = dirent.permission === 'rw';
+    if (isCustomPermission) {
+      const { preview, modify } = customPermission.permission;
+      this.canPreview = preview || modify;
+      this.canDrag = modify;
+    }
+
     this.state = {
       isOperationShow: false,
       highlight: false,
@@ -66,6 +84,7 @@ class DirentListItem extends React.Component {
       isCopyDialogShow: false,
       isShareDialogShow: false,
       isMutipleOperation: false,
+      canDrag: this.canDrag,
       isShowTagTooltip: false,
       isDragTipShow: false,
       isDropTipshow: false,
@@ -73,9 +92,10 @@ class DirentListItem extends React.Component {
       isPermissionDialogOpen: false,
       isOpMenuOpen: false // for mobile
     };
+    this.tagListTitleID = `tag-list-title-${uuidv4()}`;
   }
 
-  componentWillReceiveProps(nextProps) {
+  UNSAFE_componentWillReceiveProps(nextProps) {
     if (nextProps.isItemFreezed !== this.props.isItemFreezed && !nextProps.isItemFreezed) {
       this.setState({
         highlight: false,
@@ -92,7 +112,7 @@ class DirentListItem extends React.Component {
     this.setState({
       isOpMenuOpen: !this.state.isOpMenuOpen
     });
-  }
+  };
 
   //UI Interactive
   onMouseEnter = () => {
@@ -102,8 +122,10 @@ class DirentListItem extends React.Component {
         isOperationShow: true,
       });
     }
-    this.setState({isDragTipShow: true});
-  }
+    if (this.state.canDrag) {
+      this.setState({isDragTipShow: true});
+    }
+  };
 
   onMouseOver = () => {
     if (!this.props.isItemFreezed) {
@@ -112,8 +134,10 @@ class DirentListItem extends React.Component {
         isOperationShow: true,
       });
     }
-    this.setState({isDragTipShow: true});
-  }
+    if (this.state.canDrag) {
+      this.setState({isDragTipShow: true});
+    }
+  };
 
   onMouseLeave = () => {
     if (!this.props.isItemFreezed) {
@@ -123,7 +147,7 @@ class DirentListItem extends React.Component {
       });
     }
     this.setState({isDragTipShow: false});
-  }
+  };
 
   unfreezeItem = () => {
     this.setState({
@@ -131,18 +155,20 @@ class DirentListItem extends React.Component {
       isOperationShow: false,
     });
     this.props.unfreezeItem();
-  }
+  };
 
   //buiness handler
   onItemSelected = () => {
     this.props.onItemSelected(this.props.dirent);
-  }
+  };
 
-  onItemStarred = () => {
+  onItemStarred = (e) => {
     let dirent = this.props.dirent;
     let repoID = this.props.repoID;
     let filePath = this.getDirentPath(dirent);
 
+    e.preventDefault();
+
     if (dirent.starred) {
       seafileAPI.unstarItem(repoID, filePath).then(() => {
         this.props.updateDirent(this.props.dirent, 'starred', false);
@@ -158,7 +184,7 @@ class DirentListItem extends React.Component {
         toaster.danger(errMessage);
       });
     }
-  }
+  };
 
   // on '<tr>'
   onDirentClick = (e) => {
@@ -167,7 +193,7 @@ class DirentListItem extends React.Component {
     if (e.target.tagName == 'TD') {
       this.props.onDirentClick(this.props.dirent);
     }
-  }
+  };
 
   onItemClick = (e) => {
     e.preventDefault();
@@ -175,31 +201,43 @@ class DirentListItem extends React.Component {
     if (this.state.isRenameing) {
       return;
     }
+
+    if (dirent.isDir()) {
+      this.props.onItemClick(dirent);
+      return;
+    }
+
+    if (!this.canPreview) {
+      return;
+    }
+
     if (Utils.imageCheck(dirent.name)) {
       this.props.showImagePopup(dirent);
     } else {
       this.props.onItemClick(dirent);
     }
-  }
+  };
 
   onItemDelete = (e) => {
+    e.preventDefault();
     e.nativeEvent.stopImmediatePropagation(); //for document event
     this.props.onItemDelete(this.props.dirent);
-  }
+  };
 
   onItemShare = (e) => {
+    e.preventDefault();
     e.nativeEvent.stopImmediatePropagation(); //for document event
     this.setState({isShareDialogShow: !this.state.isShareDialogShow});
-  }
+  };
 
   closeSharedDialog = () => {
     this.setState({isShareDialogShow: !this.state.isShareDialogShow});
-  }
+  };
 
   onMobileMenuItemClick = (e) => {
     const operation = e.target.getAttribute('data-op');
     this.onMenuItemClick(operation, e);
-  }
+  };
 
   onMenuItemClick = (operation, event) => {
     switch(operation) {
@@ -233,9 +271,20 @@ class DirentListItem extends React.Component {
       case 'Lock':
         this.onLockItem();
         break;
-      case 'Comment':
-        this.props.onDirentClick(this.props.dirent);
-        this.props.showDirentDetail('comments');
+      case 'Freeze Document':
+        this.onFreezeDocument();
+        break;
+      case 'Convert to Markdown':
+        this.onItemConvert(event, 'markdown');
+        break;
+      case 'Convert to sdoc':
+        this.onItemConvert(event, 'sdoc');
+        break;
+      case 'Mark as draft':
+        this.onMarkAsDraft();
+        break;
+      case 'Unmark as draft':
+        this.onUnmarkAsDraft();
         break;
       case 'History':
         this.onHistory();
@@ -243,54 +292,71 @@ class DirentListItem extends React.Component {
       case 'Access Log':
         this.onAccessLog();
         break;
+      case 'Properties':
+        this.props.onDirentClick(this.props.dirent);
+        this.props.showDirentDetail('info');
+        break;
       case 'Open via Client':
         this.onOpenViaClient();
         break;
+      case 'Convert with ONLYOFFICE':
+        this.onConvertWithONLYOFFICE();
+        break;
       default:
         break;
     }
-  }
+  };
+
+  onItemConvert = (e, dstType)=> {
+    e.preventDefault();
+    e.nativeEvent.stopImmediatePropagation(); //for document event
+    this.props.onItemConvert(this.props.dirent, dstType);
+  };
 
   onEditFileTagToggle = () => {
     this.setState({
       isEditFileTagShow: !this.state.isEditFileTagShow
     });
-  }
+  };
 
   onFileTagChanged = () => {
     let direntPath = this.getDirentPath(this.props.dirent);
     this.props.onFileTagChanged(this.props.dirent, direntPath);
-  }
+  };
 
   onItemRenameToggle = () => {
     this.props.onItemRenameToggle(this.props.dirent);
     this.setState({
       isOperationShow: false,
       isRenameing: true,
+      canDrag: false
     });
-  }
+  };
 
   onRenameConfirm = (newName) => {
     this.props.onItemRename(this.props.dirent, newName);
     this.onRenameCancel();
-  }
+  };
 
   onRenameCancel = () => {
-    this.setState({isRenameing: false});
+    this.setState({
+      isRenameing: false,
+      canDrag: this.canDrag // set it back to the initial value
+    });
     this.unfreezeItem();
-  }
+  };
 
   onItemMoveToggle = () => {
     this.setState({isMoveDialogShow: !this.state.isMoveDialogShow});
-  }
+  };
 
   onItemCopyToggle = () => {
     this.setState({isCopyDialogShow: !this.state.isCopyDialogShow});
-  }
+  };
 
   onPermissionItem = () => {
     this.setState({isPermissionDialogOpen: !this.state.isPermissionDialogOpen});
-  }
+  };
 
   onLockItem = () => {
     let repoID = this.props.repoID;
@@ -304,7 +370,22 @@ class DirentListItem extends React.Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
+
+  onFreezeDocument = () => {
+    let repoID = this.props.repoID;
+    let filePath = this.getDirentPath(this.props.dirent);
+    seafileAPI.lockfile(repoID, filePath, -1).then(() => {
+      this.props.updateDirent(this.props.dirent, 'is_freezed', true);
+      this.props.updateDirent(this.props.dirent, 'is_locked', true);
+      this.props.updateDirent(this.props.dirent, 'locked_by_me', true);
+      let lockName = username.split('@');
+      this.props.updateDirent(this.props.dirent, 'lock_owner_name', lockName[0]);
+    }).catch(error => {
+      let errMessage = Utils.getErrorMsg(error);
+      toaster.danger(errMessage);
+    });
+  };
 
   onUnlockItem = () => {
     let repoID = this.props.repoID;
@@ -317,65 +398,112 @@ class DirentListItem extends React.Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
+
+  onMarkAsDraft = () => {
+    let repoID = this.props.repoID;
+    let filePath = this.getDirentPath(this.props.dirent);
+    seafileAPI.sdocMarkAsDraft(repoID, filePath).then((res) => {
+      this.props.updateDirent(this.props.dirent, 'is_sdoc_draft', true);
+    }).catch(error => {
+      let errMessage = Utils.getErrorMsg(error);
+      toaster.danger(errMessage);
+    });
+  };
+
+  onUnmarkAsDraft = () => {
+    let repoID = this.props.repoID;
+    let filePath = this.getDirentPath(this.props.dirent);
+    seafileAPI.sdocUnmarkAsDraft(repoID, filePath).then((res) => {
+      this.props.updateDirent(this.props.dirent, 'is_sdoc_draft', false);
+    }).catch(error => {
+      let errMessage = Utils.getErrorMsg(error);
+      toaster.danger(errMessage);
+    });
+  };
 
   onHistory = () => {
     let repoID = this.props.repoID;
     let filePath = this.getDirentPath(this.props.dirent);
     let url = URLDecorator.getUrl({type: 'file_revisions', repoID: repoID, filePath: filePath});
     location.href = url;
-  }
+  };
 
   onAccessLog = () => {
     let filePath = this.getDirentPath(this.props.dirent);
     let path = siteRoot + 'repo/file-access/' + this.props.repoID + '/?p=' + encodeURIComponent(filePath) ;
     window.open(path);
-  }
+  };
 
   onOpenViaClient = () => {
     let repoID = this.props.repoID;
     let filePath = this.getDirentPath(this.props.dirent);
     let url = URLDecorator.getUrl({type: 'open_via_client', repoID: repoID, filePath: filePath});
     location.href = url;
-  }
+  };
+
+  onConvertWithONLYOFFICE = ()=> {
+    let repoID = this.props.repoID;
+    let filePath = this.getDirentPath(this.props.dirent);
+    seafileAPI.onlyofficeConvert(repoID, filePath).then(res => {
+      this.props.loadDirentList(res.data.parent_dir);
+    }).catch(error => {
+      let errMessage = Utils.getErrorMsg(error);
+      toaster.danger(errMessage);
+    });
+  };
 
   onItemDownload = (e) => {
+    e.preventDefault();
     e.nativeEvent.stopImmediatePropagation();
     let dirent = this.props.dirent;
     let repoID = this.props.repoID;
     let direntPath = this.getDirentPath(dirent);
     if (dirent.type === 'dir') {
-      this.setState({
-        isZipDialogOpen: true
-      });
+      if (!useGoFileserver) {
+        this.setState({
+          isZipDialogOpen: true
+        });
+      } else {
+        seafileAPI.zipDownload(repoID, this.props.path, this.props.dirent.name).then((res) => {
+          const zipToken = res.data['zip_token'];
+          location.href = `${fileServerRoot}zip/${zipToken}`;
+        }).catch((error) => {
+          let errorMsg = Utils.getErrorMsg(error);
+          this.setState({
+            isLoading: false,
+            errorMsg: errorMsg
+          });
+        });
+      }
     } else {
       let url = URLDecorator.getUrl({type: 'download_file_url', repoID: repoID, filePath: direntPath});
       location.href = url;
     }
-  }
+  };
 
   closeZipDialog = () => {
     this.setState({
       isZipDialogOpen: false
     });
-  }
+  };
 
   getDirentPath = (dirent) => {
     let path = this.props.path;
     return path === '/' ? path + dirent.name : path + '/' + dirent.name;
-  }
+  };
 
   onTagTooltipToggle = (e) => {
     e.stopPropagation();
     this.setState({isShowTagTooltip: !this.state.isShowTagTooltip});
-  }
+  };
 
   onItemMove = (destRepo, dirent, selectedPath, currentPath) => {
     this.props.onItemMove(destRepo, dirent, selectedPath, currentPath);
-  }
+  };
 
   onItemDragStart = (e) => {
-    if (Utils.isIEBrower()) {
+    if (Utils.isIEBrower() || !this.state.canDrag) {
       return false;
     }
     e.dataTransfer.effectAllowed = 'move';
@@ -402,20 +530,20 @@ class DirentListItem extends React.Component {
     dragStartItemData = JSON.stringify(dragStartItemData);
 
     e.dataTransfer.setData('applicaiton/drag-item-info', dragStartItemData);
-  }
+  };
 
   onItemDragEnter = (e) => {
-    if (Utils.isIEBrower()) {
+    if (Utils.isIEBrower() || !this.state.canDrag) {
       return false;
     }
     if (this.props.dirent.type === 'dir') {
       e.stopPropagation();
       this.setState({isDropTipshow: true});
     }
-  }
+  };
 
   onItemDragOver = (e) => {
-    if (Utils.isIEBrower()) {
+    if (Utils.isIEBrower() || !this.state.canDrag) {
       return false;
     }
     if (e.dataTransfer.dropEffect === 'copy') {
@@ -423,10 +551,10 @@ class DirentListItem extends React.Component {
     }
     e.preventDefault();
     e.dataTransfer.dropEffect = 'move';
-  }
+  };
 
   onItemDragLeave = (e) => {
-    if (Utils.isIEBrower()) {
+    if (Utils.isIEBrower() || !this.state.canDrag) {
       return false;
     }
 
@@ -434,10 +562,10 @@ class DirentListItem extends React.Component {
       e.stopPropagation();
     }
     this.setState({isDropTipshow: false});
-  }
+  };
 
   onItemDragDrop = (e) => {
-    if (Utils.isIEBrower()) {
+    if (Utils.isIEBrower() || !this.state.canDrag) {
       return false;
     }
     this.setState({isDropTipshow: false});
@@ -484,19 +612,27 @@ class DirentListItem extends React.Component {
 
     let selectedPath = Utils.joinPath(this.props.path, this.props.dirent.name);
     this.onItemMove(this.props.currentRepoInfo, nodeDirent, selectedPath, nodeParentPath);
-  }
+  };
 
   onItemMouseDown = (event) => {
     this.props.onItemMouseDown(event);
-  }
+  };
 
   onItemContextMenu = (event) => {
     let dirent = this.props.dirent;
     this.props.onItemContextMenu(event, dirent);
-  }
+  };
 
   renderItemOperation = () => {
     let { dirent, currentRepoInfo, selectedDirentList } = this.props;
+    let canDownload = true;
+    let canDelete = true;
+    const { isCustomPermission, customPermission } = this;
+    if (isCustomPermission) {
+      const { permission } = customPermission;
+      canDownload = permission.download;
+      canDelete = permission.delete;
+    }
 
     // https://dev.seafile.com/seahub/lib/d6f300e7-bb2b-4722-b83e-cf45e370bfbc/file/seaf-server%20%E5%8A%9F%E8%83%BD%E8%AE%BE%E8%AE%A1/%E6%9D%83%E9%99%90%E7%9B%B8%E5%85%B3/%E8%B5%84%E6%96%99%E5%BA%93%E6%9D%83%E9%99%90%E8%A7%84%E8%8C%83.md
     let showShareBtn = Utils.isHasPermissionToShare(currentRepoInfo, dirent.permission, dirent);
@@ -507,75 +643,55 @@ class DirentListItem extends React.Component {
           <Fragment>
             {this.state.isOperationShow && !dirent.isSelected &&
               <div className="operations">
-                <ul className="operation-group">
-                  {(dirent.permission === 'rw' || dirent.permission === 'r') && (
-                    <li className="operation-group-item">
-                      <i className="op-icon sf2-icon-download" title={gettext('Download')} onClick={this.onItemDownload}></i>
-                    </li>
-                  )}
-                  {showShareBtn && (
-                    <li className="operation-group-item">
-                      <i className="op-icon sf2-icon-share" title={gettext('Share')} onClick={this.onItemShare}></i>
-                    </li>
-                  )}
-                  {dirent.permission === 'rw' && (
-                    <li className="operation-group-item">
-                      <i className="op-icon sf2-icon-delete" title={gettext('Delete')} onClick={this.onItemDelete}></i>
-                    </li>
-                  )}
-                  <li className="operation-group-item">
-                    <ItemDropdownMenu
-                      item={this.props.dirent}
-                      toggleClass={'sf2-icon-caret-down'}
-                      isHandleContextMenuEvent={true}
-                      getMenuList={this.props.getDirentItemMenuList}
-                      onMenuItemClick={this.onMenuItemClick}
-                      unfreezeItem={this.unfreezeItem}
-                      freezeItem={this.props.freezeItem}
-                    />
-                  </li>
-                </ul>
+                {(dirent.permission === 'rw' || dirent.permission === 'r' || (isCustomPermission && canDownload)) && (
+                  <a href="#" className="op-icon sf2-icon-download" title={gettext('Download')} role="button" aria-label={gettext('Download')} onClick={this.onItemDownload}></a>
+                )}
+                {showShareBtn && (
+                  <a href="#" className="op-icon sf2-icon-share" title={gettext('Share')} role="button" aria-label={gettext('Share')} onClick={this.onItemShare}></a>
+                )}
+                {(dirent.permission === 'rw' || dirent.permission === 'cloud-edit' || (isCustomPermission && canDelete)) && (
+                  <a href="#" className="op-icon sf2-icon-delete" title={gettext('Delete')} role="button" aria-label={gettext('Delete')} onClick={this.onItemDelete}></a>
+                )}
+                <ItemDropdownMenu
+                  item={this.props.dirent}
+                  toggleClass={'sf2-icon-caret-down'}
+                  isHandleContextMenuEvent={true}
+                  getMenuList={this.props.getDirentItemMenuList}
+                  onMenuItemClick={this.onMenuItemClick}
+                  unfreezeItem={this.unfreezeItem}
+                  freezeItem={this.props.freezeItem}
+                />
               </div>
             }
           </Fragment> :
           <Fragment>
             {this.state.isOperationShow &&
               <div className="operations">
-                <ul className="operation-group">
-                  {(dirent.permission === 'rw' || dirent.permission === 'r') && (
-                    <li className="operation-group-item">
-                      <i className="op-icon sf2-icon-download" title={gettext('Download')} onClick={this.onItemDownload}></i>
-                    </li>
-                  )}
-                  {showShareBtn && (
-                    <li className="operation-group-item">
-                      <i className="op-icon sf2-icon-share" title={gettext('Share')} onClick={this.onItemShare}></i>
-                    </li>
-                  )}
-                  {dirent.permission === 'rw' && (
-                    <li className="operation-group-item">
-                      <i className="op-icon sf2-icon-delete" title={gettext('Delete')} onClick={this.onItemDelete}></i>
-                    </li>
-                  )}
-                  <li className="operation-group-item">
-                    <ItemDropdownMenu
-                      item={this.props.dirent}
-                      toggleClass={'sf2-icon-caret-down'}
-                      isHandleContextMenuEvent={true}
-                      getMenuList={this.props.getDirentItemMenuList}
-                      onMenuItemClick={this.onMenuItemClick}
-                      unfreezeItem={this.unfreezeItem}
-                      freezeItem={this.props.freezeItem}
-                    />
-                  </li>
-                </ul>
+                {(dirent.permission === 'rw' || dirent.permission === 'r' || (isCustomPermission && canDownload)) && (
+                  <a href="#" className="op-icon sf2-icon-download" title={gettext('Download')} role="button" aria-label={gettext('Download')} onClick={this.onItemDownload}></a>
+                )}
+                {showShareBtn && (
+                  <a href="#" className="op-icon sf2-icon-share" title={gettext('Share')} role="button" aria-label={gettext('Share')} onClick={this.onItemShare}></a>
+                )}
+                {(dirent.permission === 'rw' || dirent.permission === 'cloud-edit' || (isCustomPermission && canDelete)) && (
+                  <a href="#" className="op-icon sf2-icon-delete" title={gettext('Delete')} role="button" aria-label={gettext('Delete')} onClick={this.onItemDelete}></a>
+                )}
+                <ItemDropdownMenu
+                  item={this.props.dirent}
+                  toggleClass={'sf2-icon-caret-down'}
+                  isHandleContextMenuEvent={true}
+                  getMenuList={this.props.getDirentItemMenuList}
+                  onMenuItemClick={this.onMenuItemClick}
+                  unfreezeItem={this.unfreezeItem}
+                  freezeItem={this.props.freezeItem}
+                />
               </div>
             }
           </Fragment>
         }
       </Fragment>
     );
-  }
+  };
 
   render() {
     let { path, dirent, activeDirent } = this.props;
@@ -585,12 +701,8 @@ class DirentListItem extends React.Component {
       dirHref = siteRoot + 'library/' + this.props.repoID + '/' + this.props.currentRepoInfo.repo_name + Utils.encodePath(direntPath);
     }
     let fileHref = siteRoot + 'lib/' + this.props.repoID + '/file' + Utils.encodePath(direntPath);
-
-    let toolTipID = '';
-    let tagTitle = '';
-    if (dirent.file_tags && dirent.file_tags.length > 0) {
-      toolTipID = MD5(dirent.name).slice(0, 7);
-      tagTitle = dirent.file_tags.map(item => item.name).join(' ');
+    if (dirent.is_sdoc_revision && dirent.revision_id) {
+      fileHref = siteRoot + 'lib/' + this.props.repoID + '/revisions/' + dirent.revision_id + '/';
     }
 
     let iconUrl = Utils.getDirentIcon(dirent);
@@ -600,13 +712,18 @@ class DirentListItem extends React.Component {
     trClass += (activeDirent && activeDirent.name === dirent.name)  ? 'tr-active' : '';
     trClass += dirent.isSelected? 'tr-active' : '';
 
-    let lockedInfo = gettext('locked by {name}').replace('{name}', dirent.lock_owner_name);
+    let lockedInfo = dirent.is_freezed ? gettext('Frozen by {name}'): gettext('locked by {name}');
+    lockedInfo = lockedInfo.replace('{name}', dirent.lock_owner_name);
 
     const isDesktop = Utils.isDesktop();
+    const { canDrag } = this.state;
+    const lockedImageUrl = `${mediaUrl}img/file-${dirent.is_freezed ? 'freezed' : 'locked'}-32.png`;
+    const lockedMessage = dirent.is_freezed ? gettext('freezed') : gettext('locked');
     const desktopItem = (
       <tr
         className={trClass}
-        draggable="true"
+        draggable={canDrag}
+        onFocus={this.onMouseEnter}
         onMouseEnter={this.onMouseEnter}
         onMouseOver={this.onMouseOver}
         onMouseLeave={this.onMouseLeave}
@@ -623,63 +740,76 @@ class DirentListItem extends React.Component {
           <input type="checkbox" className="vam" onChange={this.onItemSelected} checked={dirent.isSelected}/>
         </td>
         <td className="pl10">
-          {dirent.starred !== undefined && !dirent.starred && <i className="far fa-star star-empty cursor-pointer" onClick={this.onItemStarred}></i>}
-          {dirent.starred !== undefined && dirent.starred && <i className="fas fa-star cursor-pointer" onClick={this.onItemStarred}></i>}
+          {dirent.starred !== undefined &&
+          <a href="#" role="button" aria-label={dirent.starred ? gettext('Unstar') : gettext('Star')} onClick={this.onItemStarred}>
+            <i className={`fa-star ${dirent.starred ? 'fas' : 'far star-empty'}`}></i>
+          </a>
+          }
         </td>
         <td className="pl10">
           <div className="dir-icon">
-            {dirent.encoded_thumbnail_src ?
+            {(this.canPreview && dirent.encoded_thumbnail_src) ?
               <img ref='drag_icon' src={`${siteRoot}${dirent.encoded_thumbnail_src}`} className="thumbnail cursor-pointer" onClick={this.onItemClick} alt="" /> :
               <img ref='drag_icon' src={iconUrl} width="24" alt='' />
             }
-            {dirent.is_locked && <img className="locked" src={mediaUrl + 'img/file-locked-32.png'} alt={gettext('locked')} title={lockedInfo}/>}
+            {dirent.is_locked && <img className="locked" src={lockedImageUrl} alt={lockedMessage} title={lockedInfo}/>}
             <div ref="empty_content" style={{position: 'absolute', width: '1px', height: '1px'}}></div>
           </div>
         </td>
         <td className="name">
-          {this.state.isRenameing ?
-            <Rename hasSuffix={dirent.type !== 'dir'} name={dirent.name} onRenameConfirm={this.onRenameConfirm} onRenameCancel={this.onRenameCancel} /> :
-            <a href={dirent.type === 'dir' ? dirHref : fileHref} onClick={this.onItemClick}>{dirent.name}</a>
-          }
+          {this.state.isRenameing && <Rename hasSuffix={dirent.type !== 'dir'} name={dirent.name} onRenameConfirm={this.onRenameConfirm} onRenameCancel={this.onRenameCancel} />}
+          {!this.state.isRenameing && (
+            <Fragment>
+              {(!dirent.isDir() && !this.canPreview) ?
+                <a className="sf-link" onClick={this.onItemClick}>{dirent.name}</a> :
+                <a href={dirent.type === 'dir' ? dirHref : fileHref} onClick={this.onItemClick}>{dirent.name}</a>
+              }
+              {/*(Utils.isSdocFile(dirent.name) && dirent.is_sdoc_draft) &&
+                <span className="dirent-sdoc-draft-identifier">{gettext('Draft')}</span>
+              */}
+            </Fragment>
+          )}
         </td>
         <td className="tag-list-title">
           {(dirent.type !== 'dir' && dirent.file_tags && dirent.file_tags.length > 0) && (
-            <Fragment>
-              <div id={`tag-list-title-${toolTipID}`} className="dirent-item tag-list tag-list-stacked">
-                {dirent.file_tags.map((fileTag, index) => {
-                  let length = dirent.file_tags.length;
-                  return (
-                    <span className="file-tag" key={fileTag.id} style={{zIndex:length - index, backgroundColor:fileTag.color}}></span>
-                  );
-                })}
-              </div>
-              <UncontrolledTooltip target={`tag-list-title-${toolTipID}`} placement="bottom">
-                {tagTitle}
-              </UncontrolledTooltip>
-            </Fragment>
+            <div id={this.tagListTitleID} className="dirent-item tag-list tag-list-stacked">
+              {dirent.file_tags.map((fileTag, index) => {
+                return (
+                  <FileTag fileTag={fileTag} length={dirent.file_tags.length} key={index} index={index}/>
+                );
+              })}
+            </div>
+          )}
+          {(dirent.type !== 'dir' && (!dirent.file_tags || dirent.file_tags.length == 0)) && (
+            <div id={this.tagListTitleID} className="dirent-item tag-list tag-list-stacked"></div>
           )}
         </td>
         <td className="operation">{this.renderItemOperation()}</td>
         <td className="file-size">{dirent.size && dirent.size}</td>
-        <td className="last-update">{dirent.mtime_relative}</td>
+        <td className="last-update" title={moment.unix(dirent.mtime).format('llll')}>{dirent.mtime_relative}</td>
       </tr>
     );
     const mobileItem = (
       <tr>
         <td onClick={this.onItemClick}>
           <div className="dir-icon">
-            {dirent.encoded_thumbnail_src ?
+            {(this.canPreview && dirent.encoded_thumbnail_src) ?
               <img src={`${siteRoot}${dirent.encoded_thumbnail_src}`} className="thumbnail cursor-pointer" alt="" /> :
               <img src={iconUrl} width="24" alt="" />
             }
-            {dirent.is_locked && <img className="locked" src={mediaUrl + 'img/file-locked-32.png'} alt={gettext('locked')} title={lockedInfo}/>}
+            {dirent.is_locked && <img className="locked" src={lockedImageUrl} alt={lockedMessage} title={lockedInfo}/>}
           </div>
         </td>
         <td onClick={this.onItemClick}>
-          {this.state.isRenameing ?
-            <Rename hasSuffix={dirent.type !== 'dir'} name={dirent.name} onRenameConfirm={this.onRenameConfirm} onRenameCancel={this.onRenameCancel} /> :
-            <a href={dirent.type === 'dir' ? dirHref : fileHref}>{dirent.name}</a>
-          }
+          {this.state.isRenameing && <Rename hasSuffix={dirent.type !== 'dir'} name={dirent.name} onRenameConfirm={this.onRenameConfirm} onRenameCancel={this.onRenameCancel} /> }
+          {!this.state.isRenameing && (
+            <Fragment>
+              {(!dirent.isDir() && !this.canPreview) ?
+                <a className="sf-link">{dirent.name}</a> :
+                <a href={dirent.type === 'dir' ? dirHref : fileHref}>{dirent.name}</a>
+              }
+            </Fragment>
+          )}
           <br />
           {dirent.size && <span className="item-meta-info">{dirent.size}</span>}
           <span className="item-meta-info">{dirent.mtime_relative}</span>
@@ -703,6 +833,8 @@ class DirentListItem extends React.Component {
                     return (
                       <DropdownItem className="mobile-menu-item" key={index} data-op={item.key} onClick={this.onMobileMenuItemClick}>{item.value}</DropdownItem>
                     );
+                  } else {
+                    return null;
                   }
                 })}
               </div>
@@ -741,15 +873,30 @@ class DirentListItem extends React.Component {
             />
           </ModalPortal>
         }
-        {this.state.isEditFileTagShow &&
-          <EditFileTagDialog
-            repoID={this.props.repoID}
-            fileTagList={dirent.file_tags}
-            filePath={direntPath}
-            toggleCancel={this.onEditFileTagToggle}
-            onFileTagChanged={this.onFileTagChanged}
-          />
-        }
+        <MediaQuery query="(min-width: 768px)">
+          {this.state.isEditFileTagShow &&
+            <EditFileTagPopover
+              repoID={this.props.repoID}
+              fileTagList={dirent.file_tags}
+              filePath={direntPath}
+              toggleCancel={this.onEditFileTagToggle}
+              onFileTagChanged={this.onFileTagChanged}
+              target={this.tagListTitleID}
+              isEditFileTagShow={this.state.isEditFileTagShow}
+            />
+          }
+        </MediaQuery>
+        <MediaQuery query="(max-width: 767.8px)">
+          {this.state.isEditFileTagShow &&
+            <EditFileTagDialog
+              repoID={this.props.repoID}
+              fileTagList={dirent.file_tags}
+              filePath={direntPath}
+              toggleCancel={this.onEditFileTagToggle}
+              onFileTagChanged={this.onFileTagChanged}
+            />
+          }
+        </MediaQuery>
         {this.state.isZipDialogOpen &&
           <ModalPortal>
             <ZipDownloadDialog
