@@ -3,7 +3,8 @@ import PropTypes from 'prop-types';
 import { mediaUrl } from '../utils/constants';
 
 const propTypes = {
-  forDialog: PropTypes.bool
+  forDialog: PropTypes.bool,
+  children: PropTypes.any,
 };
 
 class EmptyTip extends React.Component {
