@@ -26,10 +26,15 @@ const propTypes = {
   dragAndDrop: PropTypes.bool.isRequired,
   path: PropTypes.string.isRequired,
   onFileUploadSuccess: PropTypes.func.isRequired,
+  isCustomPermission: PropTypes.bool,
 };
 
 class FileUploader extends React.Component {
 
+  static defaultProps = {
+    isCustomPermission: false
+  };
+
   constructor(props) {
     super(props);
     this.state = {
@@ -91,7 +96,7 @@ class FileUploader extends React.Component {
     if (this.props.dragAndDrop === true) {
       this.resumable.disableDropOnDocument();
     }
-  }
+  };
 
   onbeforeunload = () => {
     if (window.uploader &&
@@ -99,7 +104,7 @@ class FileUploader extends React.Component {
         window.uploader.totalProgress !== 100) {
       return '';
     }
-  }
+  };
 
   bindCallbackHandler = () => {
     let { minFileSizeErrorCallback, fileTypeErrorCallback } = this.props;
@@ -120,7 +125,7 @@ class FileUploader extends React.Component {
       this.resumable.opts.fileTypeErrorCallback = this.props.fileTypeErrorCallback;
     }
 
-  }
+  };
 
   bindEventHandler = () => {
     this.resumable.on('chunkingComplete', this.onChunkingComplete.bind(this));
@@ -137,20 +142,20 @@ class FileUploader extends React.Component {
     this.resumable.on('beforeCancel', this.onBeforeCancel.bind(this));
     this.resumable.on('cancel', this.onCancel.bind(this));
     this.resumable.on('dragstart', this.onDragStart.bind(this));
-  }
+  };
 
   maxFilesErrorCallback = (files, errorCount) => {
     let maxFiles = maxNumberOfFilesForFileupload;
     let message = gettext('Please upload no more than {maxFiles} files at a time.');
     message = message.replace('{maxFiles}', maxFiles);
     toaster.danger(message);
-  }
+  };
 
   maxFileSizeErrorCallback = (file) => {
     let { forbidUploadFileList } = this.state;
     forbidUploadFileList.push(file);
     this.setState({forbidUploadFileList: forbidUploadFileList});
-  }
+  };
 
   onChunkingComplete = (resumableFile) => {
 
@@ -178,18 +183,21 @@ class FileUploader extends React.Component {
         relative_path: relative_path
       };
     }
-  }
+  };
 
   onFileAdded = (resumableFile, files) => {
+    const { isCustomPermission } = this.props;
     let isFile = resumableFile.fileName === resumableFile.relativePath;
     // uploading is file and only upload one file
     if (isFile && files.length === 1) {
       let hasRepetition = false;
-      let direntList = this.props.direntList;
-      for (let i = 0; i < direntList.length; i++) {
-        if (direntList[i].type === 'file' && direntList[i].name === resumableFile.fileName) {
-          hasRepetition = true;
-          break;
+      if (!isCustomPermission) {
+        let direntList = this.props.direntList;
+        for (let i = 0; i < direntList.length; i++) {
+          if (direntList[i].type === 'file' && direntList[i].name === resumableFile.fileName) {
+            hasRepetition = true;
+            break;
+          }
         }
       }
       if (hasRepetition) {
@@ -222,7 +230,7 @@ class FileUploader extends React.Component {
         });
       }
     }
-  }
+  };
 
   resumableUpload = (resumableFile) => {
     let { repoID, path } = this.props;
@@ -236,7 +244,7 @@ class FileUploader extends React.Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   filesAddedComplete = (resumable, files) => {
     let { forbidUploadFileList } = this.state;
@@ -246,7 +254,7 @@ class FileUploader extends React.Component {
         totalProgress: 100
       });
     }
-  }
+  };
 
   setUploadFileList = () => {
     let uploadFileList = this.resumable.files;
@@ -255,7 +263,7 @@ class FileUploader extends React.Component {
       isUploadProgressDialogShow: true,
     });
     Utils.registerGlobalVariable('uploader', 'isUploadProgressDialogShow', true);
-  }
+  };
 
   onFileProgress = (resumableFile) => {
     let uploadBitrate = this.getBitrate();
@@ -274,7 +282,7 @@ class FileUploader extends React.Component {
       uploadBitrate: uploadBitrate,
       uploadFileList: uploadFileList
     });
-  }
+  };
 
   getBitrate = () => {
     let loaded = 0;
@@ -304,13 +312,13 @@ class FileUploader extends React.Component {
     this.loaded = loaded;
 
     return uploadBitrate;
-  }
+  };
 
   onProgress = () => {
     let progress = Math.round(this.resumable.progress() * 100);
     this.setState({totalProgress: progress});
     Utils.registerGlobalVariable('uploader', 'totalProgress', progress);
-  }
+  };
 
   onFileUploadSuccess = (resumableFile, message) => {
     let formData = resumableFile.formData;
@@ -386,7 +394,7 @@ class FileUploader extends React.Component {
       return item;
     });
     this.setState({uploadFileList: uploadFileList});
-  }
+  };
 
   getFileServerErrorMessage = (key) => {
     const errorMessage = {
@@ -396,9 +404,9 @@ class FileUploader extends React.Component {
       'File size is too large.': gettext('File size is too large.'),        // 442
       'Out of quota.': gettext('Out of quota.'),                            // 443
       'Internal error.': gettext('Internal Server Error'),                  // 500
-    }
+    };
     return errorMessage[key] || key;
-  }
+  };
 
   onFileError = (resumableFile, message) => {
     let error = '';
@@ -425,37 +433,37 @@ class FileUploader extends React.Component {
       uploadFileList: uploadFileList
     });
 
-  }
+  };
 
   onComplete = () => {
     this.notifiedFolders = [];
     // reset upload link loaded
     this.isUploadLinkLoaded = false;
     this.setState({allFilesUploaded: true});
-  }
+  };
 
   onPause = () => {
 
-  }
+  };
 
   onError = (message) => {
     // reset upload link loaded
     this.isUploadLinkLoaded = false;
     // After the error, the user can switch windows
     Utils.registerGlobalVariable('uploader', 'totalProgress', 100);
-  }
+  };
 
   onFileRetry = () => {
     // todo, cancel upload file, uploded again;
-  }
+  };
 
   onBeforeCancel = () => {
     // todo, giving a pop message ?
-  }
+  };
 
   onCancel = () => {
 
-  }
+  };
 
   setHeaders = (resumableFile, resumable) => {
     let offset = resumable.offset;
@@ -475,37 +483,37 @@ class FileUploader extends React.Component {
     };
 
     return headers;
-  }
+  };
 
   setQuery = (resumableFile) => {
     let formData = resumableFile.formData;
     return formData;
-  }
+  };
 
   generateUniqueIdentifier = (file) => {
     let relativePath = file.webkitRelativePath||file.relativePath||file.fileName||file.name;
     return MD5(relativePath + new Date()) + relativePath;
-  }
+  };
 
   onClick = (e) => {
     e.nativeEvent.stopImmediatePropagation();
     e.stopPropagation();
-  }
+  };
 
   onFileUpload = () => {
     this.uploadInput.current.removeAttribute('webkitdirectory');
 
     this.uploadInput.current.click();
-  }
+  };
 
   onFolderUpload = () => {
     this.uploadInput.current.setAttribute('webkitdirectory', 'webkitdirectory');
     this.uploadInput.current.click();
-  }
+  };
 
   onDragStart = () => {
     this.uploadInput.current.setAttribute('webkitdirectory', 'webkitdirectory');
-  }
+  };
 
   onCloseUploadDialog = () => {
     this.loaded = 0;
@@ -514,7 +522,7 @@ class FileUploader extends React.Component {
     this.isUploadLinkLoaded = false;
     this.setState({isUploadProgressDialogShow: false, uploadFileList: [], forbidUploadFileList: []});
     Utils.registerGlobalVariable('uploader', 'isUploadProgressDialogShow', false);
-  }
+  };
 
   onUploadCancel = (uploadingItem) => {
 
@@ -535,7 +543,7 @@ class FileUploader extends React.Component {
     }
 
     this.setState({uploadFileList: uploadFileList});
-  }
+  };
 
   onCancelAllUploading = () => {
     let uploadFileList = this.state.uploadFileList.filter(item => {
@@ -555,7 +563,7 @@ class FileUploader extends React.Component {
     });
     // reset upload link loaded
     this.isUploadLinkLoaded = false;
-  }
+  };
 
   onUploadRetry = (resumableFile) => {
 
@@ -581,7 +589,7 @@ class FileUploader extends React.Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   onUploadRetryAll = () => {
 
@@ -602,7 +610,7 @@ class FileUploader extends React.Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   retryUploadFile = (resumableFile) => {
     let { repoID, path } = this.props;
@@ -634,7 +642,7 @@ class FileUploader extends React.Component {
       firedRetry = true;
     });
 
-  }
+  };
 
   replaceRepetitionFile = () => {
     let { repoID, path } = this.props;
@@ -651,7 +659,7 @@ class FileUploader extends React.Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   uploadFile = () => {
     let resumableFile = this.resumable.files[this.resumable.files.length - 1];
@@ -671,12 +679,12 @@ class FileUploader extends React.Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   cancelFileUpload = () => {
     this.resumable.files.pop(); //delete latest file；
     this.setState({isUploadRemindDialogShow: false});
-  }
+  };
 
   render() {
     return (
