@@ -2,21 +2,23 @@ import React, { Fragment } from 'react';
 import PropTypes from 'prop-types';
 import moment from 'moment';
 import { Dropdown, DropdownMenu, DropdownToggle, DropdownItem } from 'reactstrap';
-import { Link, navigate } from '@reach/router';
+import { Link, navigate } from '@gatsbyjs/reach-router';
 import { Utils } from '../../utils/utils';
-import { gettext, siteRoot, isPro, username, folderPermEnabled, isSystemStaff, enableResetEncryptedRepoPassword, isEmailConfigured } from '../../utils/constants';
+import { gettext, siteRoot, isPro, username, folderPermEnabled, isSystemStaff, enableResetEncryptedRepoPassword, isEmailConfigured, enableRepoAutoDel } from '../../utils/constants';
 import ModalPortal from '../../components/modal-portal';
 import ShareDialog from '../../components/dialog/share-dialog';
 import LibSubFolderPermissionDialog from '../../components/dialog/lib-sub-folder-permission-dialog';
 import DeleteRepoDialog from '../../components/dialog/delete-repo-dialog';
 import ChangeRepoPasswordDialog from '../../components/dialog/change-repo-password-dialog';
 import ResetEncryptedRepoPasswordDialog from '../../components/dialog/reset-encrypted-repo-password-dialog';
+import LibOldFilesAutoDelDialog from '../../components/dialog/lib-old-files-auto-del-dialog';
 import Rename from '../rename';
 import { seafileAPI } from '../../utils/seafile-api';
 import LibHistorySettingDialog from '../dialog/lib-history-setting-dialog';
 import toaster from '../toast';
 import RepoAPITokenDialog from '../dialog/repo-api-token-dialog';
-import RepoShareUploadLinksDialog from '../dialog/repo-share-upload-links-dialog';
+import RepoShareAdminDialog from '../dialog/repo-share-admin-dialog';
+import RepoMonitoredIcon from '../../components/repo-monitored-icon';
 
 const propTypes = {
   currentGroup: PropTypes.object,
@@ -29,6 +31,7 @@ const propTypes = {
   onItemDetails: PropTypes.func,
   onItemRename: PropTypes.func,
   onItemDelete: PropTypes.func,
+  onMonitorRepo: PropTypes.func
 };
 
 class SharedRepoListItem extends React.Component {
@@ -39,6 +42,7 @@ class SharedRepoListItem extends React.Component {
       highlight: false,
       isOperationShow: false,
       isItemMenuShow: false,
+      isAdvancedMenuShown: false,
       isShowSharedDialog: false,
       isRenaming: false,
       isStarred: this.props.repo.starred,
@@ -46,10 +50,11 @@ class SharedRepoListItem extends React.Component {
       isHistorySettingDialogShow: false,
       isDeleteDialogShow: false,
       isAPITokenDialogShow: false,
-      isRepoShareUploadLinksDialogOpen: false,
+      isRepoShareAdminDialogOpen: false,
       isRepoDeleted: false,
       isChangePasswordDialogShow: false,
-      isResetPasswordDialogShow: false
+      isResetPasswordDialogShow: false,
+      isOldFilesAutoDelDialogOpen: false,
     };
     this.isDeparementOnwerGroupMember = false;
   }
@@ -61,7 +66,7 @@ class SharedRepoListItem extends React.Component {
         isOperationShow: true,
       });
     }
-  }
+  };
 
   onMouseOver = () => {
     if (!this.props.isItemFreezed) {
@@ -70,7 +75,7 @@ class SharedRepoListItem extends React.Component {
         isOperationShow: true,
       });
     }
-  }
+  };
 
   onMouseLeave = () => {
     if (!this.props.isItemFreezed) {
@@ -79,11 +84,17 @@ class SharedRepoListItem extends React.Component {
         isOperationShow: false,
       });
     }
-  }
+  };
 
   clickOperationMenuToggle = (e) => {
     this.toggleOperationMenu(e);
-  }
+  };
+
+  onDropdownToggleKeyDown = (e) => {
+    if (e.key == 'Enter' || e.key == 'Space') {
+      this.clickOperationMenuToggle(e);
+    }
+  };
 
   toggleOperationMenu = (e) => {
     let dataset = e.target ? e.target.dataset : null;
@@ -106,7 +117,26 @@ class SharedRepoListItem extends React.Component {
         }
       }
     );
-  }
+  };
+
+  toggleAdvancedMenuShown = (e) => {
+    this.setState({ isAdvancedMenuShown: true });
+  };
+
+  toggleAdvancedMenu = (e) => {
+    e.stopPropagation();
+    this.setState({ isAdvancedMenuShown: !this.state.isAdvancedMenuShown }, () => {
+      this.toggleOperationMenu(e);
+    });
+  };
+
+  onDropDownMouseMove = (e) => {
+    if (this.state.isAdvancedMenuShown && e.target && e.target.className === 'dropdown-item') {
+      this.setState({
+        isAdvancedMenuShown: false
+      });
+    }
+  };
 
   getRepoComputeParams = () => {
     let repo = this.props.repo;
@@ -116,7 +146,13 @@ class SharedRepoListItem extends React.Component {
     let libPath = `${siteRoot}library/${repo.repo_id}/${Utils.encodePath(repo.repo_name)}/`;
 
     return { iconUrl, iconTitle, libPath };
-  }
+  };
+
+  onMenuItemKeyDown = (e) => {
+    if (e.key == 'Enter' || e.key == 'Space') {
+      this.onMenuItemClick(e);
+    }
+  };
 
   onMenuItemClick = (e) => {
     let operation = e.target.dataset.toggle;
@@ -142,8 +178,8 @@ class SharedRepoListItem extends React.Component {
       case 'API Token':
         this.onAPITokenToggle();
         break;
-      case 'Share Links Admin':
-        this.toggleRepoShareUploadLinksDialog();
+      case 'Share Admin':
+        this.toggleRepoShareAdminDialog();
         break;
       case 'Change Password':
         this.onChangePasswordToggle();
@@ -151,10 +187,38 @@ class SharedRepoListItem extends React.Component {
       case 'Reset Password':
         this.onResetPasswordToggle();
         break;
-      default:
+      case 'Watch File Changes':
+        this.watchFileChanges();
         break;
+      case 'Unwatch File Changes':
+        this.unwatchFileChanges();
+        break;
+      case 'Old Files Auto Delete':
+        this.toggleOldFilesAutoDelDialog();
+        break;
+      // no default
     }
-  }
+  };
+
+  watchFileChanges = () => {
+    const { repo } = this.props;
+    seafileAPI.monitorRepo(repo.repo_id).then(() => {
+      this.props.onMonitorRepo(repo, true);
+    }).catch(error => {
+      let errMessage = Utils.getErrorMsg(error);
+      toaster.danger(errMessage);
+    });
+  };
+
+  unwatchFileChanges = () => {
+    const { repo } = this.props;
+    seafileAPI.unMonitorRepo(repo.repo_id).then(() => {
+      this.props.onMonitorRepo(repo, false);
+    }).catch(error => {
+      let errMessage = Utils.getErrorMsg(error);
+      toaster.danger(errMessage);
+    });
+  };
 
   onItemRenameToggle = () => {
     this.props.onFreezedItem();
@@ -162,41 +226,44 @@ class SharedRepoListItem extends React.Component {
       isRenaming: !this.state.isRenaming,
       isOperationShow: !this.state.isOperationShow
     });
-  }
+  };
 
   onRenameConfirm = (name) => {
     this.props.onItemRename(this.props.repo, name);
     this.onRenameCancel();
-  }
+  };
 
   onRenameCancel = () => {
     this.props.onUnfreezedItem();
     this.setState({isRenaming: !this.state.isRenaming});
-  }
+  };
 
   onItemFolderPermissionToggle = () => {
     this.setState({isFolderPermissionDialogOpen: !this.state.isFolderPermissionDialogOpen});
-  }
+  };
 
   onHistorySettingToggle = () => {
     this.setState({isHistorySettingDialogShow: !this.state.isHistorySettingDialogShow});
-  }
+  };
 
   onItemDetails = () => {
     this.props.onItemDetails(this.props.repo);
-  }
+  };
 
-  onItemShare = () => {
+  onItemShare = (e) => {
+    e.preventDefault();
     this.setState({isShowSharedDialog: true});
-  }
+  };
 
-  onItemUnshare = () => {
+  onItemUnshare = (e) => {
+    e.preventDefault();
     this.props.onItemUnshare(this.props.repo);
-  }
+  };
 
-  onItemDeleteToggle = () => {
+  onItemDeleteToggle = (e) => {
+    e.preventDefault();
     this.setState({isDeleteDialogShow: !this.state.isDeleteDialogShow});
-  }
+  };
 
   onItemDelete = () => {
     const { currentGroup, repo } = this.props;
@@ -227,27 +294,31 @@ class SharedRepoListItem extends React.Component {
 
       this.setState({isRepoDeleted: false});
     });
-  }
+  };
 
   toggleShareDialog = () => {
     this.setState({isShowSharedDialog: false});
-  }
+  };
 
-  toggleRepoShareUploadLinksDialog = () => {
-    this.setState({isRepoShareUploadLinksDialogOpen: !this.state.isRepoShareUploadLinksDialogOpen});
-  }
+  toggleRepoShareAdminDialog = () => {
+    this.setState({isRepoShareAdminDialogOpen: !this.state.isRepoShareAdminDialogOpen});
+  };
+
+  toggleOldFilesAutoDelDialog = () => {
+    this.setState({isOldFilesAutoDelDialogOpen: !this.state.isOldFilesAutoDelDialogOpen});
+  };
 
   onAPITokenToggle = () => {
     this.setState({isAPITokenDialogShow: !this.state.isAPITokenDialogShow});
-  }
+  };
 
   onChangePasswordToggle = () => {
     this.setState({isChangePasswordDialogShow: !this.state.isChangePasswordDialogShow});
-  }
+  };
 
   onResetPasswordToggle = () => {
     this.setState({isResetPasswordDialogShow: !this.state.isResetPasswordDialogShow});
-  }
+  };
 
   translateMenuItem = (menuItem) => {
     let translateResult = '';
@@ -270,8 +341,8 @@ class SharedRepoListItem extends React.Component {
       case 'History Setting':
         translateResult = gettext('History Setting');
         break;
-      case 'Share Links Admin':
-        translateResult = gettext('Share Links Admin');
+      case 'Share Admin':
+        translateResult = gettext('Share Admin');
         break;
       case 'Change Password':
         translateResult = gettext('Change Password');
@@ -279,14 +350,35 @@ class SharedRepoListItem extends React.Component {
       case 'Reset Password':
         translateResult = gettext('Reset Password');
         break;
+      case 'Watch File Changes':
+        translateResult = gettext('Watch File Changes');
+        break;
+      case 'Unwatch File Changes':
+        translateResult = gettext('Unwatch File Changes');
+        break;
+      case 'Old Files Auto Delete':
+        translateResult = gettext('Auto Deletion Setting');
+        break;
       case 'API Token':
         translateResult = 'API Token'; // translation is not needed here
         break;
+      case 'Advanced':
+        translateResult = gettext('Advanced');
+        break;
       default:
         break;
     }
     return translateResult;
-  }
+  };
+
+  getAdvancedOperations = () => {
+    const operations = [];
+    operations.push('API Token');
+    if (enableRepoAutoDel) {
+      operations.push('Old Files Auto Delete');
+    }
+    return operations;
+  };
 
   generatorOperations = () => {
     let { repo, currentGroup } = this.props;
@@ -304,14 +396,22 @@ class SharedRepoListItem extends React.Component {
             if (folderPermEnabled) {
               operations.push('Folder Permission');
             }
-            operations.push('Share Links Admin');
+            operations.push('Share Admin', 'Divider');
             if (repo.encrypted) {
               operations.push('Change Password');
             }
             if (repo.encrypted && enableResetEncryptedRepoPassword && isEmailConfigured) {
               operations.push('Reset Password');
             }
-            operations.push('History Setting', 'API Token', 'Details');
+            if (repo.permission == 'r' || repo.permission == 'rw') {
+              const monitorOp = repo.monitored ? 'Unwatch File Changes' : 'Watch File Changes';
+              operations.push(monitorOp);
+            }
+            operations.push('Divider', 'History Setting', 'Details');
+            if (Utils.isDesktop()) {
+              operations.push('Advanced');
+            }
+            return operations;
           } else {
             operations.push('Unshare');
           }
@@ -324,6 +424,10 @@ class SharedRepoListItem extends React.Component {
           operations.push('Unshare');
         }
       }
+      if (repo.permission == 'r' || repo.permission == 'rw') {
+        const monitorOp = repo.monitored ? 'Unwatch File Changes' : 'Watch File Changes';
+        operations.push(monitorOp);
+      }
     } else {
       if (isRepoOwner) {
         operations.push('Share');
@@ -333,7 +437,7 @@ class SharedRepoListItem extends React.Component {
       }
     }
     return operations;
-  }
+  };
 
   generatorMobileMenu = () => {
     let operations = [];
@@ -375,7 +479,7 @@ class SharedRepoListItem extends React.Component {
         </div>
       </Dropdown>
     );
-  }
+  };
 
   generatorPCMenu = () => {
     let operations = [];
@@ -385,60 +489,114 @@ class SharedRepoListItem extends React.Component {
         operations.push('Unshare');
       }
     } else {
-      // scene one: (Share, Delete, itemToggle and other operations);
-      // scene two: (Share, Unshare), (Share), (Unshare)
       operations = this.generatorOperations();
     }
-    const shareOperation   = <a href="#" className="op-icon sf2-icon-share" title={gettext('Share')} onClick={this.onItemShare}></a>;
-    const unshareOperation = <a href="#" className="op-icon sf2-icon-x3" title={gettext('Unshare')} onClick={this.onItemUnshare}></a>;
-    const deleteOperation  = <a href="#" className="op-icon sf2-icon-delete" title={gettext('Delete')} onClick={this.onItemDeleteToggle}></a>;
+    const shareOperation   = <a href="#" className="op-icon sf2-icon-share" title={gettext('Share')} role="button" aria-label={gettext('Share')} onClick={this.onItemShare}></a>;
+    const unshareOperation = <a href="#" className="op-icon sf2-icon-x3" title={gettext('Unshare')} role="button" aria-label={gettext('Unshare')} onClick={this.onItemUnshare}></a>;
+    const deleteOperation  = <a href="#" className="op-icon sf2-icon-delete" title={gettext('Delete')} role="button" aria-label={gettext('Delete')} onClick={this.onItemDeleteToggle}></a>;
 
     if (this.isDeparementOnwerGroupMember) {
+      const advancedOperations = this.getAdvancedOperations();
       return (
         <Fragment>
           {shareOperation}
           {deleteOperation}
           <Dropdown isOpen={this.state.isItemMenuShow} toggle={this.toggleOperationMenu}>
             <DropdownToggle
-              tag="i"
-              className="sf-dropdown-toggle sf2-icon-caret-down"
+              className="sf-dropdown-toggle sf2-icon-caret-down border-0 p-0"
               title={gettext('More Operations')}
               data-toggle="dropdown"
               aria-expanded={this.state.isItemMenuShow}
+              aria-haspopup={true}
+              style={{'minWidth': '0'}}
               onClick={this.clickOperationMenuToggle}
+              onKeyDown={this.onDropdownToggleKeyDown}
             />
-            <DropdownMenu>
-              {operations.map((item, index) => {
-                return <DropdownItem key={index} data-toggle={item} onClick={this.onMenuItemClick}>{this.translateMenuItem(item)}</DropdownItem>;
+            <DropdownMenu onMouseMove={this.onDropDownMouseMove}>
+              {operations.map((item, index)=> {
+                if (item == 'Divider') {
+                  return <DropdownItem key={index} divider />;
+                } else if (item == 'Advanced') {
+                  return (
+                    <Dropdown
+                      key={index}
+                      direction="right"
+                      className="w-100"
+                      isOpen={this.state.isAdvancedMenuShown}
+                      toggle={this.toggleAdvancedMenu}
+                      onMouseMove={(e) => {e.stopPropagation();}}
+                    >
+                      <DropdownToggle
+                        caret
+                        className="dropdown-item font-weight-normal rounded-0 d-flex justify-content-between align-items-center pr-2"
+                        onMouseEnter={this.toggleAdvancedMenuShown}
+                      >
+                        {this.translateMenuItem(item)}
+                      </DropdownToggle>
+                      <DropdownMenu>
+                        {advancedOperations.map((item, index)=> {
+                          return (<DropdownItem key={index} data-toggle={item} onClick={this.onMenuItemClick} onKeyDown={this.onMenuItemKeyDown}>{this.translateMenuItem(item)}</DropdownItem>);
+                        })}
+                      </DropdownMenu>
+                    </Dropdown>
+                  );
+                } else {
+                  return (<DropdownItem key={index} data-toggle={item} onClick={this.onMenuItemClick} onKeyDown={this.onMenuItemKeyDown}>{this.translateMenuItem(item)}</DropdownItem>);
+                }
               })}
             </DropdownMenu>
           </Dropdown>
         </Fragment>
       );
     } else {
-      if (operations.length == 2) {
-        return (
-          <Fragment>
-            {shareOperation}
-            {unshareOperation}
-          </Fragment>
-        );
-      }
-      if (operations.length == 1 && operations[0] === 'Share') {
-        return shareOperation;
-      }
-
-      if (operations.length == 1 && operations[0] === 'Unshare') {
-        return unshareOperation;
-      }
+      return (
+        <Fragment>
+          {operations.map(item => {
+            switch (item) {
+              case 'Share':
+                return <Fragment key={item}>{shareOperation}</Fragment>;
+              case 'Unshare':
+                return <Fragment key={item}>{unshareOperation}</Fragment>;
+              case 'Watch File Changes':
+              case 'Unwatch File Changes':
+                return (
+                  <Dropdown isOpen={this.state.isItemMenuShow} toggle={this.toggleOperationMenu} key={item}>
+                    <DropdownToggle
+                      className="sf-dropdown-toggle sf2-icon-caret-down border-0 p-0"
+                      title={gettext('More Operations')}
+                      data-toggle="dropdown"
+                      aria-expanded={this.state.isItemMenuShow}
+                      aria-haspopup={true}
+                      style={{'minWidth': '0'}}
+                      onClick={this.clickOperationMenuToggle}
+                      onKeyDown={this.onDropdownToggleKeyDown}
+                    />
+                    <DropdownMenu>
+                      {[item].map((item, index) => {
+                        return <DropdownItem key={index} data-toggle={item} onClick={this.onMenuItemClick} onKeyDown={this.onMenuItemKeyDown}>{this.translateMenuItem(item)}</DropdownItem>;
+                      })}
+                    </DropdownMenu>
+                  </Dropdown>
+                );
+              // no default
+              default:
+                return null;
+            }
+          })}
+        </Fragment>
+      );
     }
-    return null;
-  }
+  };
 
-  onStarRepo = () => {
+  onToggleStarRepo = (e) => {
+    e.preventDefault();
+    const { repo_name: repoName } = this.props.repo;
     if (this.state.isStarred) {
       seafileAPI.unstarItem(this.props.repo.repo_id, '/').then(() => {
         this.setState({isStarred: !this.state.isStarred});
+        const msg = gettext('Successfully unstarred {library_name_placeholder}.')
+          .replace('{library_name_placeholder}', repoName);
+        toaster.success(msg);
       }).catch(error => {
         let errMessage = Utils.getErrorMsg(error);
         toaster.danger(errMessage);
@@ -446,28 +604,35 @@ class SharedRepoListItem extends React.Component {
     } else {
       seafileAPI.starItem(this.props.repo.repo_id, '/').then(() => {
         this.setState({isStarred: !this.state.isStarred});
+        const msg = gettext('Successfully starred {library_name_placeholder}.')
+          .replace('{library_name_placeholder}', repoName);
+        toaster.success(msg);
       }).catch(error => {
         let errMessage = Utils.getErrorMsg(error);
         toaster.danger(errMessage);
       });
     }
-  }
+  };
 
   renderPCUI = () => {
     let { iconUrl, iconTitle, libPath } = this.getRepoComputeParams();
     let { repo } = this.props;
     return (
       <Fragment>
-        <tr className={this.state.highlight ? 'tr-highlight' : ''} onMouseEnter={this.onMouseEnter} onMouseOver={this.onMouseOver} onMouseLeave={this.onMouseLeave}>
+        <tr className={this.state.highlight ? 'tr-highlight' : ''} onMouseEnter={this.onMouseEnter} onMouseOver={this.onMouseOver} onMouseLeave={this.onMouseLeave} onFocus={this.onMouseEnter}>
           <td className="text-center">
-            {!this.state.isStarred && <i className="far fa-star star-empty cursor-pointer" onClick={this.onStarRepo}></i>}
-            {this.state.isStarred && <i className="fas fa-star cursor-pointer" onClick={this.onStarRepo}></i>}
+            <a href="#" role="button" aria-label={this.state.isStarred ? gettext('Unstar') : gettext('Star')} onClick={this.onToggleStarRepo}>
+              <i className={`fa-star ${this.state.isStarred ? 'fas' : 'far star-empty'}`}></i>
+            </a>
           </td>
           <td><img src={iconUrl} title={iconTitle} alt={iconTitle} width="24" /></td>
           <td>
             {this.state.isRenaming ?
-              <Rename  name={repo.repo_name} onRenameConfirm={this.onRenameConfirm} onRenameCancel={this.onRenameCancel}/> :
-              <Link to={libPath}>{repo.repo_name}</Link>
+              <Rename name={repo.repo_name} onRenameConfirm={this.onRenameConfirm} onRenameCancel={this.onRenameCancel}/> :
+              <Fragment>
+                <Link to={libPath}>{repo.repo_name}</Link>
+                {repo.monitored && <RepoMonitoredIcon repoID={repo.repo_id} />}
+              </Fragment>
             }
           </td>
           <td>{this.state.isOperationShow && this.generatorPCMenu()}</td>
@@ -477,14 +642,14 @@ class SharedRepoListItem extends React.Component {
         </tr>
       </Fragment>
     );
-  }
+  };
 
   visitRepo = () => {
     if (!this.state.isRenaming) {
       navigate(this.repoURL);
     }
-  }
-  
+  };
+
   renderMobileUI = () => {
     let { iconUrl, iconTitle, libPath } = this.getRepoComputeParams();
     let { repo } = this.props;
@@ -496,7 +661,10 @@ class SharedRepoListItem extends React.Component {
           <td onClick={this.visitRepo}>
             {this.state.isRenaming ?
               <Rename name={repo.repo_name} onRenameConfirm={this.onRenameConfirm} onRenameCancel={this.onRenameCancel} /> :
-              <Link to={libPath}>{repo.repo_name}</Link>
+              <Fragment>
+                <Link to={libPath}>{repo.repo_name}</Link>
+                {repo.monitored && <RepoMonitoredIcon repoID={repo.repo_id} />}
+              </Fragment>
             }
             <br />
             <span className="item-meta-info" title={repo.owner_contact_email}>{repo.owner_name}</span>
@@ -507,7 +675,7 @@ class SharedRepoListItem extends React.Component {
         </tr>
       </Fragment>
     );
-  }
+  };
 
   render() {
     let { repo } = this.props;
@@ -568,11 +736,11 @@ class SharedRepoListItem extends React.Component {
             />
           </ModalPortal>
         )}
-        {this.state.isRepoShareUploadLinksDialogOpen && (
+        {this.state.isRepoShareAdminDialogOpen && (
           <ModalPortal>
-            <RepoShareUploadLinksDialog
+            <RepoShareAdminDialog
               repo={repo}
-              toggleDialog={this.toggleRepoShareUploadLinksDialog}
+              toggleDialog={this.toggleRepoShareAdminDialog}
             />
           </ModalPortal>
         )}
@@ -593,6 +761,15 @@ class SharedRepoListItem extends React.Component {
             />
           </ModalPortal>
         )}
+        {this.state.isOldFilesAutoDelDialogOpen && (
+          <ModalPortal>
+            <LibOldFilesAutoDelDialog
+              repoID={repo.repo_id}
+              toggleDialog={this.toggleOldFilesAutoDelDialog}
+            />
+          </ModalPortal>
+        )}
+
       </Fragment>
     );
   }
