@@ -1,6 +1,6 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import { processor } from '@seafile/seafile-editor/dist/utils/seafile-markdown2html';
+import { processor } from '@seafile/seafile-editor';
 import Loading from './loading';
 
 const propTypes = {
@@ -30,7 +30,7 @@ class TermsPreviewWidget extends React.Component {
     }
   }
 
-  componentWillReceiveProps(nextProps) {
+  UNSAFE_componentWillReceiveProps(nextProps) {
     let mdFile = nextProps.content;
     this.formatterLongTextValue(mdFile);
   }
@@ -43,7 +43,7 @@ class TermsPreviewWidget extends React.Component {
         innerHtml: innerHtml
       });
     });
-  }
+  };
 
   render() {
     if (this.state.isFormatValue) {
