@@ -1,7 +1,8 @@
 import React from 'react';
 import PropTypes from 'prop-types';
-import { isPro, gettext, showLogoutIcon } from '../../utils/constants';
+import { isPro, gettext, showLogoutIcon, enableSeafileAI } from '../../utils/constants';
 import Search from '../search/search';
+import AISearch from '../search/ai-search';
 import SearchByName from '../search/search-by-name';
 import Notification from '../common/notification';
 import Account from '../common/account';
@@ -17,23 +18,44 @@ const propTypes = {
 
 class CommonToolbar extends React.Component {
 
+  renderSearch = () => {
+    const { repoID, repoName, isLibView, searchPlaceholder } = this.props;
+    const placeholder = searchPlaceholder || gettext('Search files');
+
+    if (isPro) {
+      if (enableSeafileAI && isLibView) {
+        return (
+          <AISearch
+            repoID={repoID}
+            placeholder={placeholder}
+            onSearchedClick={this.props.onSearchedClick}
+            repoName={repoName}
+          />
+        );
+      } else {
+        return (
+          <Search
+            repoID={repoID}
+            placeholder={placeholder}
+            onSearchedClick={this.props.onSearchedClick}
+            isPublic={false}
+          />
+        );
+      }
+    } else {
+      if (isLibView) {
+        return (
+          <SearchByName repoID={repoID} repoName={repoName} />
+        );
+      }
+      return null;
+    }
+  };
+
   render() {
-    let searchPlaceholder = this.props.searchPlaceholder || gettext('Search Files');
     return (
       <div className="common-toolbar">
-        {isPro && (
-          <Search
-            repoID={this.props.repoID}
-            placeholder={searchPlaceholder}
-            onSearchedClick={this.props.onSearchedClick}
-          />
-        )}
-        {this.props.isLibView && !isPro &&
-          <SearchByName
-            repoID={this.props.repoID}
-            repoName={this.props.repoName}
-          />
-        }
+        {this.renderSearch()}
         <Notification />
         <Account />
         {showLogoutIcon && (<Logout />)}
