@@ -1,5 +1,5 @@
 import React from 'react';
-import ReactDOM from 'react-dom';
+import ReactDom from 'react-dom';
 import FileView from './components/file-view/file-view';
 import FileViewTip from './components/file-view/file-view-tip';
 import Image from './components/file-content-view/image';
@@ -24,7 +24,7 @@ class InnerFileView extends React.Component {
     let content;
     switch (fileType) {
       case 'Image':
-        content = <Image tip={<FileViewTip />} canUseThumbnail={true} />;
+        content = <Image tip={<FileViewTip />} />;
         break;
       case 'XMind':
         content = <Image tip={<FileViewTip />} />;
@@ -41,6 +41,8 @@ class InnerFileView extends React.Component {
       case 'Audio':
         content = <Audio />;
         break;
+      default:
+        break;
     }
 
     return (
@@ -49,7 +51,4 @@ class InnerFileView extends React.Component {
   }
 }
 
-ReactDOM.render (
-  <InnerFileView />,
-  document.getElementById('wrapper')
-);
+ReactDom.render(<InnerFileView />, document.getElementById('wrapper'));
