@@ -1,13 +1,13 @@
 import React, { Fragment } from 'react';
 import PropTypes from 'prop-types';
 import moment from 'moment';
-import { Link } from '@reach/router';
+import { Link } from '@gatsbyjs/reach-router';
 import { seafileAPI } from '../../utils/seafile-api';
-import { Utils } from '../../utils/utils.js';
+import { Utils } from '../../utils/utils';
 import toaster from '../../components/toast';
 import MainPanelTopbar from './main-panel-topbar';
 import ModalPortal from '../../components/modal-portal';
-import RoleEditor from '../../components/select-editor/role-editor';
+import RoleSelector from '../../components/single-selector';
 import AddDepartDialog from '../../components/dialog/org-add-department-dialog';
 import AddMemberDialog from '../../components/dialog/org-add-member-dialog';
 import DeleteMemberDialog from '../../components/dialog/org-delete-member-dialog';
@@ -15,6 +15,8 @@ import AddRepoDialog from '../../components/dialog/org-add-repo-dialog';
 import DeleteRepoDialog from '../../components/dialog/org-delete-repo-dialog';
 import DeleteDepartDialog from '../../components/dialog/org-delete-department-dialog';
 import SetGroupQuotaDialog from '../../components/dialog/org-set-group-quota-dialog';
+import RenameDepartmentDialog from '../../components/dialog/org-rename-department-dialog';
+import OpMenu from '../../components/dialog/op-menu';
 import { serviceURL, siteRoot, gettext, orgID, lang } from '../../utils/constants';
 import '../../css/org-department-item.css';
 
@@ -27,6 +29,7 @@ class OrgDepartmentItem extends React.Component {
     this.state = {
       groupName: '',
       isItemFreezed: false,
+      isDepartFreezed: false,
       ancestorGroups: [],
       members: [],
       deletedMember: {},
@@ -51,7 +54,7 @@ class OrgDepartmentItem extends React.Component {
     this.listOrgMembers(groupID);
   }
 
-  componentWillReceiveProps(nextProps) {
+  UNSAFE_componentWillReceiveProps(nextProps) {
     if (this.props.groupID !== nextProps.groupID) {
       this.listOrgGroupRepo(nextProps.groupID);
       this.listOrgMembers(nextProps.groupID);
@@ -65,7 +68,7 @@ class OrgDepartmentItem extends React.Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   listOrgMembers = (groupID) => {
     seafileAPI.orgAdminListGroupInfo(orgID, groupID, true).then(res => {
@@ -79,7 +82,7 @@ class OrgDepartmentItem extends React.Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   listSubDepartGroups = (groupID) => {
     seafileAPI.orgAdminListGroupInfo(orgID, groupID, true).then(res => {
@@ -88,7 +91,7 @@ class OrgDepartmentItem extends React.Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   toggleCancel = () => {
     this.setState({
@@ -97,43 +100,62 @@ class OrgDepartmentItem extends React.Component {
       showDeleteDepartDialog: false,
       showSetGroupQuotaDialog: false,
     });
-  }
+  };
+
+  onFreezedDepart = () => {
+    this.setState({isDepartFreezed: true});
+  };
+
+  onUnfreezedDepart = () => {
+    this.setState({isDepartFreezed: false});
+  };
+
+  onDepartmentNameChanged = (dept) => {
+    this.setState({
+      groups: this.state.groups.map(item => {
+        if (item.id == dept.id) {
+          item.name = dept.name;
+        }
+        return item;
+      })
+    });
+  };
 
   onSubDepartChanged = () => {
     this.listSubDepartGroups(this.props.groupID);
-  }
+  };
 
   onRepoChanged = () => {
     this.listOrgGroupRepo(this.props.groupID);
-  }
+  };
 
   onMemberChanged = () => {
     this.listOrgMembers(this.props.groupID);
-  }
+  };
 
   toggleItemFreezed = (isFreezed) => {
     this.setState({ isItemFreezed: isFreezed });
-  }
+  };
 
   showDeleteMemberDialog = (member) => {
     this.setState({ showDeleteMemberDialog: true, deletedMember: member });
-  }
+  };
 
   showDeleteRepoDialog = (repo) => {
     this.setState({ showDeleteRepoDialog: true, deletedRepo: repo });
-  }
+  };
 
   toggleAddRepoDialog = () => {
     this.setState({ isShowAddRepoDialog: !this.state.isShowAddRepoDialog });
-  }
+  };
 
   toggleAddMemberDialog = () => {
     this.setState({ isShowAddMemberDialog: !this.state.isShowAddMemberDialog });
-  }
+  };
 
   toggleAddDepartDialog = () => {
     this.setState({ isShowAddDepartDialog: !this.state.isShowAddDepartDialog});
-  }
+  };
 
   showDeleteDepartDialog = (subGroup) => {
     this.setState({
@@ -141,14 +163,14 @@ class OrgDepartmentItem extends React.Component {
       subGroupID: subGroup.id,
       subGroupName: subGroup.name
     });
-  }
+  };
 
   showSetGroupQuotaDialog = (subGroupID) => {
     this.setState({
       showSetGroupQuotaDialog: true,
       subGroupID: subGroupID
     });
-  }
+  };
 
   render() {
     const { members, repos, groups } = this.state;
@@ -237,6 +259,10 @@ class OrgDepartmentItem extends React.Component {
                           <React.Fragment key={group.id}>
                             <GroupItem
                               group={group}
+                              isItemFreezed={this.state.isDepartFreezed}
+                              onFreezedItem={this.onFreezedDepart}
+                              onUnfreezedItem={this.onUnfreezedDepart}
+                              onDepartmentNameChanged={this.onDepartmentNameChanged}
                               showDeleteDepartDialog={this.showDeleteDepartDialog}
                               showSetGroupQuotaDialog={this.showSetGroupQuotaDialog}
                             />
@@ -370,28 +396,26 @@ class MemberItem extends React.Component {
   constructor(props) {
     super(props);
     this.state = {
-      highlight: false,
-      showRoleMenu: false,
+      highlight: false
     };
-    this.roles = ['Admin', 'Member'];
+    this.roleOptions = [
+      { value: 'Admin', text: gettext('Admin'), isSelected: false },
+      { value: 'Member', text: gettext('Member'), isSelected: false }
+    ];
   }
 
   onMouseEnter = () => {
     if (this.props.isItemFreezed) return;
     this.setState({ highlight: true });
-  }
+  };
 
   onMouseLeave = () => {
     if (this.props.isItemFreezed) return;
     this.setState({ highlight: false });
-  }
+  };
 
-  toggleMemberRoleMenu = () => {
-    this.setState({ showRoleMenu: !this.state.showRoleMenu });
-  }
-
-  onChangeUserRole = (role) => {
-    let isAdmin = role === 'Admin' ? true : false;
+  onChangeUserRole = (roleOption) => {
+    let isAdmin = roleOption.value === 'Admin' ? true : false;
     seafileAPI.orgAdminSetGroupMemberRole(orgID, this.props.groupID, this.props.member.email, isAdmin).then((res) => {
       this.props.onMemberChanged();
     }).catch(error => {
@@ -401,39 +425,43 @@ class MemberItem extends React.Component {
     this.setState({
       highlight: false,
     });
-  }
+  };
 
   render() {
     const member = this.props.member;
     const highlight = this.state.highlight;
     let memberLink = serviceURL + '/org/useradmin/info/' + member.email + '/';
     if (member.role === 'Owner') return null;
+
+    this.roleOptions = this.roleOptions.map(item => {
+      item.isSelected = item.value == member.role;
+      return item;
+    });
+    const currentSelectedOption = this.roleOptions.filter(item => item.isSelected)[0];
+
     return (
       <tr className={highlight ? 'tr-highlight' : ''} onMouseEnter={this.onMouseEnter} onMouseLeave={this.onMouseLeave}>
         <td><img src={member.avatar_url} alt="member-header" width="24" className="avatar"/></td>
         <td><a href={memberLink}>{member.name}</a></td>
         <td>
-          <RoleEditor
-            isTextMode={true}
-            isEditIconShow={highlight}
-            currentRole={member.role}
-            roles={this.roles}
-            onRoleChanged={this.onChangeUserRole}
+          <RoleSelector
+            isDropdownToggleShown={highlight}
+            currentSelectedOption={currentSelectedOption}
+            options={this.roleOptions}
+            selectOption={this.onChangeUserRole}
             toggleItemFreezed={this.props.toggleItemFreezed}
           />
         </td>
-        {!this.props.isItemFreezed ?
-          <td className="cursor-pointer text-center" onClick={this.props.showDeleteMemberDialog.bind(this, member)}>
-            <span className={`sf2-icon-x3 action-icon ${highlight ? '' : 'vh'}`} title="Delete"></span>
-          </td> : <td></td>
-        }
+        <td className="cursor-pointer text-center" onClick={this.props.showDeleteMemberDialog.bind(this, member)}>
+          <span className={`sf2-icon-x3 action-icon ${highlight ? '' : 'vh'}`} title="Delete"></span>
+        </td>
       </tr>
     );
   }
 }
 
 const MemberItemPropTypes = {
-  groupID: PropTypes.string.isRequired,
+  groupID: PropTypes.string,
   member: PropTypes.object.isRequired,
   isItemFreezed: PropTypes.bool.isRequired,
   onMemberChanged: PropTypes.func.isRequired,
@@ -454,11 +482,11 @@ class RepoItem extends React.Component {
 
   onMouseEnter = () => {
     this.setState({ highlight: true });
-  }
+  };
 
   onMouseLeave = () => {
     this.setState({ highlight: false });
-  }
+  };
 
   render() {
     const repo = this.props.repo;
@@ -490,33 +518,108 @@ class GroupItem extends React.Component {
     super(props);
     this.state = {
       highlight: false,
+      isOpIconShown: false,
+      isRenameDialogOpen: false,
     };
   }
 
   onMouseEnter = () => {
-    this.setState({ highlight: true });
-  }
+    if (!this.props.isItemFreezed) {
+      this.setState({
+        isOpIconShown: true,
+        highlight: true
+      });
+    }
+  };
 
   onMouseLeave = () => {
-    this.setState({ highlight: false });
-  }
+    if (!this.props.isItemFreezed) {
+      this.setState({
+        isOpIconShown: false,
+        highlight: false
+      });
+    }
+  };
+
+  translateOperations = (item) => {
+    let translateResult = '';
+    switch(item) {
+      case 'Rename':
+        translateResult = gettext('Rename');
+        break;
+      case 'Delete':
+        translateResult = gettext('Delete');
+        break;
+      default:
+        break;
+    }
+
+    return translateResult;
+  };
+
+  onMenuItemClick = (operation) => {
+    const { group } = this.props;
+    switch(operation) {
+      case 'Rename':
+        this.toggleRenameDialog();
+        break;
+      case 'Delete':
+        this.props.showDeleteDepartDialog(group);
+        break;
+      default:
+        break;
+    }
+  };
+
+  onUnfreezedItem = () => {
+    this.setState({
+      highlight: false,
+      isOpIconShow: false
+    });
+    this.props.onUnfreezedItem();
+  };
+
+  toggleRenameDialog = () => {
+    this.setState({
+      isRenameDialogOpen: !this.state.isRenameDialogOpen
+    });
+  };
 
   render() {
     const group = this.props.group;
-    const highlight = this.state.highlight;
+    const { highlight, isOpIconShown, isRenameDialogOpen } = this.state;
     const newHref = siteRoot+ 'org/departmentadmin/groups/' + group.id + '/';
     return (
-      <tr className={highlight ? 'tr-highlight' : ''} onMouseEnter={this.onMouseEnter} onMouseLeave={this.onMouseLeave}>
-        <td><Link to={newHref}>{group.name}</Link></td>
-        <td>{moment(group.created_at).fromNow()}</td>
-        <td onClick={this.props.showSetGroupQuotaDialog.bind(this, group.id)}>
-          {Utils.bytesToSize(group.quota)}{' '}
-          <span title="Edit Quota" className={`fa fa-pencil-alt attr-action-icon ${highlight ? '' : 'vh'}`}></span>
-        </td>
-        <td className="cursor-pointer text-center" onClick={this.props.showDeleteDepartDialog.bind(this, group)}>
-          <span className={`sf2-icon-delete action-icon ${highlight ? '' : 'vh'}`} title="Delete"></span>
-        </td>
-      </tr>
+      <Fragment>
+        <tr className={highlight ? 'tr-highlight' : ''} onMouseEnter={this.onMouseEnter} onMouseLeave={this.onMouseLeave}>
+          <td><Link to={newHref}>{group.name}</Link></td>
+          <td>{moment(group.created_at).fromNow()}</td>
+          <td onClick={this.props.showSetGroupQuotaDialog.bind(this, group.id)}>
+            {Utils.bytesToSize(group.quota)}{' '}
+            <span title="Edit Quota" className={`fa fa-pencil-alt attr-action-icon ${highlight ? '' : 'vh'}`}></span>
+          </td>
+          <td>
+            {isOpIconShown &&
+              <OpMenu
+                operations={['Rename', 'Delete']}
+                translateOperations={this.translateOperations}
+                onMenuItemClick={this.onMenuItemClick}
+                onFreezedItem={this.props.onFreezedItem}
+                onUnfreezedItem={this.onUnfreezedItem}
+              />
+            }
+          </td>
+        </tr>
+        {isRenameDialogOpen && (
+          <RenameDepartmentDialog
+            orgID={orgID}
+            groupID={group.id}
+            name={group.name}
+            toggle={this.toggleRenameDialog}
+            onDepartmentNameChanged={this.props.onDepartmentNameChanged}
+          />
+        )}
+      </Fragment>
     );
   }
 }
@@ -524,6 +627,10 @@ class GroupItem extends React.Component {
 const GroupItemPropTypes = {
   group: PropTypes.object.isRequired,
   groupID: PropTypes.string,
+  isItemFreezed: PropTypes.bool.isRequired,
+  onFreezedItem: PropTypes.func.isRequired,
+  onUnfreezedItem: PropTypes.func.isRequired,
+  onDepartmentNameChanged: PropTypes.func.isRequired,
   showSetGroupQuotaDialog: PropTypes.func.isRequired,
   showDeleteDepartDialog: PropTypes.func.isRequired,
   isSubdepartChanged: PropTypes.bool,
