@@ -1,5 +1,5 @@
 import React from 'react';
-import ReactDOM from 'react-dom';
+import ReactDom from 'react-dom';
 import CommonToolbar from '../../components/toolbar/common-toolbar';
 import Logo from '../../components/logo';
 import SearchViewPanel from './main-panel';
@@ -39,7 +39,4 @@ class SearchView extends React.Component {
   }
 }
 
-ReactDOM.render(
-  <SearchView/>,
-  document.getElementById('wrapper')
-);
+ReactDom.render(<SearchView />, document.getElementById('wrapper'));
