@@ -1,5 +1,5 @@
 import React, { Component, Fragment } from 'react';
-import { navigate } from '@reach/router';
+import { navigate } from '@gatsbyjs/reach-router';
 import { Button } from 'reactstrap';
 import PropTypes from 'prop-types';
 import { Utils } from '../../../utils/utils';
@@ -70,19 +70,19 @@ class Users extends Component {
 
   toggleImportUserDialog = () => {
     this.setState({isImportUserDialogOpen: !this.state.isImportUserDialogOpen});
-  }
+  };
 
   toggleAddUserDialog = () => {
     this.setState({isAddUserDialogOpen: !this.state.isAddUserDialogOpen});
-  }
+  };
 
   toggleBatchSetQuotaDialog = () => {
     this.setState({isBatchSetQuotaDialogOpen: !this.state.isBatchSetQuotaDialogOpen});
-  }
+  };
 
   toggleBatchDeleteUserDialog = () => {
     this.setState({isBatchDeleteUserDialogOpen: !this.state.isBatchDeleteUserDialogOpen});
-  }
+  };
 
   onUserSelected = (item) => {
     let hasUserSelected = false;
@@ -112,7 +112,7 @@ class Users extends Component {
       hasUserSelected: hasUserSelected,
       selectedUserList: selectedUserList,
     });
-  }
+  };
 
   toggleSelectAllUsers = () => {
     if (this.state.isAllUsersSelected) {
@@ -140,7 +140,7 @@ class Users extends Component {
         selectedUserList: users
       });
     }
-  }
+  };
 
   getUserList = () => {
   // get admins
@@ -158,7 +158,7 @@ class Users extends Component {
         errorMsg: Utils.getErrorMsg(error, true) // true: show login tip if 403
       });
     });
-  }
+  };
 
   getUsersListByPage = (page) => {
     const { perPage, sortBy, sortOrder } = this.state;
@@ -177,7 +177,7 @@ class Users extends Component {
         errorMsg: Utils.getErrorMsg(error, true) // true: show login tip if 403
       });
     });
-  }
+  };
 
   sortByQuotaUsage = () => {
     this.setState({
@@ -195,20 +195,22 @@ class Users extends Component {
       navigate(url.toString());
       this.getUsersListByPage(currentPage);
     });
-  }
+  };
 
-  deleteUser = (email) => {
+  deleteUser = (email, username) => {
     seafileAPI.sysAdminDeleteUser(email).then(res => {
       let newUserList = this.state.userList.filter(item => {
         return item.email != email;
       });
       this.setState({userList: newUserList});
-      toaster.success(gettext('Successfully deleted 1 item.'));
+      let msg = gettext('Deleted user %s');
+      msg = msg.replace('%s', username);
+      toaster.success(msg);
     }).catch((error) => {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   setUserQuotaInBatch = (quotaTotal) => {
     let emails = this.state.selectedUserList.map(user => {
@@ -216,7 +218,7 @@ class Users extends Component {
     });
     seafileAPI.sysAdminSetUserQuotaInBatch(emails, quotaTotal).then(res => {
       let userList = this.state.userList.map(item => {
-        res.data.success.map(resultUser => {
+        res.data.success.forEach(resultUser => {
           if (item.email == resultUser.email) {
             item.quota_total = resultUser.quota_total;
           }
@@ -228,7 +230,7 @@ class Users extends Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   deleteUserInBatch = () => {
     let emails = this.state.selectedUserList.map(user => {
@@ -253,7 +255,7 @@ class Users extends Component {
             .replace('{user_number_placeholder}', length);
         toaster.success(msg);
       }
-      res.data.failed.map(item => {
+      res.data.failed.forEach(item => {
         const msg = `${item.email}: ${item.error_msg}`;
         toaster.danger(msg);
       });
@@ -261,7 +263,7 @@ class Users extends Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   importUserInBatch = (file) => {
     toaster.notify(gettext('It may take some time, please wait.'));
@@ -277,7 +279,7 @@ class Users extends Component {
           userList: users.concat(this.state.userList)
         });
       }
-      res.data.failed.map(item => {
+      res.data.failed.forEach(item => {
         const msg = `${item.email}: ${item.error_msg}`;
         toaster.danger(msg);
       });
@@ -285,7 +287,7 @@ class Users extends Component {
       let errMsg = Utils.getErrorMsg(error);
       toaster.danger(errMsg);
     });
-  }
+  };
 
   addUser = (data) => {
     toaster.notify(gettext('It may take some time, please wait.'));
@@ -301,7 +303,7 @@ class Users extends Component {
       let errMsg = Utils.getErrorMsg(error);
       toaster.danger(errMsg);
     });
-  }
+  };
 
   resetPerPage = (perPage) => {
     this.setState({
@@ -309,7 +311,7 @@ class Users extends Component {
     }, () => {
       this.getUsersListByPage(1);
     });
-  }
+  };
 
   updateUser = (email, key, value) => {
     seafileAPI.sysAdminUpdateUser(email, key, value).then(res => {
@@ -327,7 +329,7 @@ class Users extends Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   updateAdminRole = (email, role) => {
     seafileAPI.sysAdminUpdateAdminRole(email, role).then(res => {
@@ -343,7 +345,7 @@ class Users extends Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   revokeAdmin = (email, name) => {
     seafileAPI.sysAdminUpdateUser(email, 'is_staff', false).then(res => {
@@ -358,7 +360,7 @@ class Users extends Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   getOperationsForAll = () => {
     const { isAdmin, isLDAPImported } = this.props;
@@ -379,7 +381,7 @@ class Users extends Component {
         <a className="btn btn-secondary operation-item" href={`${siteRoot}sys/useradmin/export-excel/`}>{gettext('Export Excel')}</a>
       </Fragment>
     );
-  }
+  };
 
   getCurrentNavItem = () => {
     const { isAdmin, isLDAPImported } = this.props;
@@ -390,11 +392,11 @@ class Users extends Component {
       item = 'ldap-imported';
     }
     return item;
-  }
+  };
 
   toggleBatchAddAdminDialog = () => {
     this.setState({isBatchAddAdminDialogOpen: !this.state.isBatchAddAdminDialogOpen});
-  }
+  };
 
   addAdminInBatch = (emails) => {
     seafileAPI.sysAdminAddAdminInBatch(emails).then(res => {
@@ -404,7 +406,7 @@ class Users extends Component {
       this.setState({
         userList: users.concat(this.state.userList)
       });
-      res.data.failed.map(item => {
+      res.data.failed.forEach(item => {
         const msg = `${item.email}: ${item.error_msg}`;
         toaster.danger(msg);
       });
@@ -412,7 +414,7 @@ class Users extends Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   getSearch = () => {
     if (this.props.isAdmin) {
@@ -423,11 +425,11 @@ class Users extends Component {
       placeholder={gettext('Search users')}
       submit={this.searchItems}
     />;
-  }
+  };
 
   searchItems = (keyword) => {
     navigate(`${siteRoot}sys/search-users/?query=${encodeURIComponent(keyword)}`);
-  }
+  };
 
   render() {
     const { isAdmin, isLDAPImported } = this.props;
@@ -441,7 +443,7 @@ class Users extends Component {
     } = this.state;
     return (
       <Fragment>
-        <MainPanelTopbar search={this.getSearch()}>
+        <MainPanelTopbar search={this.getSearch()} {...this.props}>
           {hasUserSelected ?
             <Fragment>
               <Button className="btn btn-secondary operation-item" onClick={this.toggleBatchSetQuotaDialog}>{gettext('Set Quota')}</Button>
