@@ -92,7 +92,7 @@ class FileUploader extends React.Component {
     if (this.props.dragAndDrop === true) {
       this.resumable.disableDropOnDocument();
     }
-  }
+  };
 
   onbeforeunload = () => {
     if (window.uploader &&
@@ -100,7 +100,7 @@ class FileUploader extends React.Component {
         window.uploader.totalProgress !== 100) {
       return '';
     }
-  }
+  };
 
   bindCallbackHandler = () => {
     let { minFileSizeErrorCallback, fileTypeErrorCallback } = this.props;
@@ -121,32 +121,33 @@ class FileUploader extends React.Component {
       this.resumable.opts.fileTypeErrorCallback = this.props.fileTypeErrorCallback;
     }
 
-  }
+  };
 
   bindEventHandler = () => {
     this.resumable.on('chunkingComplete', this.onChunkingComplete.bind(this));
     this.resumable.on('fileAdded', this.onFileAdded.bind(this));
     this.resumable.on('fileProgress', this.onFileProgress.bind(this));
     this.resumable.on('fileSuccess', this.onFileUploadSuccess.bind(this));
+    this.resumable.on('fileError', this.onFileError.bind(this));
+    this.resumable.on('uploadStart', this.onUploadStart.bind(this));
     this.resumable.on('progress', this.onProgress.bind(this));
     this.resumable.on('complete', this.onComplete.bind(this));
-    this.resumable.on('fileError', this.onFileError.bind(this));
     this.resumable.on('error', this.onError.bind(this));
     this.resumable.on('dragstart', this.onDragStart.bind(this));
-  }
+  };
 
   maxFilesErrorCallback = (files, errorCount) => {
     let maxFiles = maxNumberOfFilesForFileupload;
     let message = gettext('Please upload no more than {maxFiles} files at a time.');
     message = message.replace('{maxFiles}', maxFiles);
     toaster.danger(message);
-  }
+  };
 
   maxFileSizeErrorCallback = (file) => {
     let { forbidUploadFileList } = this.state;
     forbidUploadFileList.push(file);
     this.setState({forbidUploadFileList: forbidUploadFileList});
-  }
+  };
 
   onChunkingComplete = (resumableFile) => {
 
@@ -172,7 +173,7 @@ class FileUploader extends React.Component {
         relative_path: relative_path
       };
     }
-  }
+  };
 
   onFileAdded = (resumableFile, files) => {
     let isFile = resumableFile.fileName === resumableFile.relativePath;
@@ -215,7 +216,7 @@ class FileUploader extends React.Component {
         });
       }
     }
-  }
+  };
 
   resumableUpload = (resumableFile) => {
     let { repoID, path } = this.props;
@@ -229,7 +230,7 @@ class FileUploader extends React.Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   filesAddedComplete = (resumable, files) => {
     let { forbidUploadFileList } = this.state;
@@ -239,7 +240,7 @@ class FileUploader extends React.Component {
         totalProgress: 100
       });
     }
-  }
+  };
 
   setUploadFileList = () => {
     let uploadFileList = this.resumable.files;
@@ -248,7 +249,7 @@ class FileUploader extends React.Component {
       isUploadProgressDialogShow: true,
     });
     Utils.registerGlobalVariable('uploader', 'isUploadProgressDialogShow', true);
-  }
+  };
 
   onFileProgress = (resumableFile) => {
     let uploadBitrate = this.getBitrate();
@@ -267,7 +268,7 @@ class FileUploader extends React.Component {
       uploadBitrate: uploadBitrate,
       uploadFileList: uploadFileList
     });
-  }
+  };
 
   getBitrate = () => {
     let loaded = 0;
@@ -297,13 +298,19 @@ class FileUploader extends React.Component {
     this.loaded = loaded;
 
     return uploadBitrate;
-  }
+  };
+
+  // start uploading
+  onUploadStart = () => {
+    const message = gettext('File upload started');
+    toaster.notify(message);
+  };
 
   onProgress = () => {
     let progress = Math.round(this.resumable.progress() * 100);
     this.setState({totalProgress: progress});
     Utils.registerGlobalVariable('uploader', 'totalProgress', progress);
-  }
+  };
 
   onFileUploadSuccess = (resumableFile, message) => {
     let formData = resumableFile.formData;
@@ -379,7 +386,7 @@ class FileUploader extends React.Component {
       return item;
     });
     this.setState({uploadFileList: uploadFileList});
-  }
+  };
 
   onFileError = (resumableFile, message) => {
     let error = '';
@@ -411,22 +418,35 @@ class FileUploader extends React.Component {
       retryFileList: this.state.retryFileList,
       uploadFileList: uploadFileList
     });
-
-  }
+  };
 
   onComplete = () => {
+    if (!this.error) {
+      const message = gettext('All files uploaded');
+      toaster.success(message);
+    }
+    this.error = false; // reset it
+
     this.notifiedFolders = [];
     // reset upload link loaded
     this.isUploadLinkLoaded = false;
     this.setState({allFilesUploaded: true});
-  }
+  };
+
+  onError = (message, file) => {
+    let msg = gettext('Error');
+    if (file && file.fileName) {
+      msg = gettext('Failed to upload {file_name}.')
+        .replace('{file_name}', file.fileName);
+    }
+    toaster.danger(msg, {'id': 'file-error-msg'});
+    this.error = true;
 
-  onError = (message) => {
     // reset upload link loaded
     this.isUploadLinkLoaded = false;
     // After the error, the user can switch windows
     Utils.registerGlobalVariable('uploader', 'totalProgress', 100);
-  }
+  };
 
   setHeaders = (resumableFile, resumable) => {
     let offset = resumable.offset;
@@ -446,36 +466,36 @@ class FileUploader extends React.Component {
     };
 
     return headers;
-  }
+  };
 
   setQuery = (resumableFile) => {
     let formData = resumableFile.formData;
     return formData;
-  }
+  };
 
   generateUniqueIdentifier = (file) => {
     let relativePath = file.webkitRelativePath||file.relativePath||file.fileName||file.name;
     return MD5(relativePath + new Date()) + relativePath;
-  }
+  };
 
   onClick = (e) => {
     e.nativeEvent.stopImmediatePropagation();
     e.stopPropagation();
-  }
+  };
 
   onFileUpload = () => {
     this.uploadInput.current.removeAttribute('webkitdirectory');
     this.uploadInput.current.click();
-  }
+  };
 
   onFolderUpload = () => {
     this.uploadInput.current.setAttribute('webkitdirectory', 'webkitdirectory');
     this.uploadInput.current.click();
-  }
+  };
 
   onDragStart = () => {
     this.uploadInput.current.setAttribute('webkitdirectory', 'webkitdirectory');
-  }
+  };
 
   onCloseUploadDialog = () => {
     this.loaded = 0;
@@ -484,7 +504,7 @@ class FileUploader extends React.Component {
     this.isUploadLinkLoaded = false;
     this.setState({isUploadProgressDialogShow: false, uploadFileList: [], forbidUploadFileList: []});
     Utils.registerGlobalVariable('uploader', 'isUploadProgressDialogShow', false);
-  }
+  };
 
   onUploadCancel = (uploadingItem) => {
 
@@ -505,7 +525,7 @@ class FileUploader extends React.Component {
     }
 
     this.setState({uploadFileList: uploadFileList});
-  }
+  };
 
   onCancelAllUploading = () => {
     let uploadFileList = this.state.uploadFileList.filter(item => {
@@ -525,7 +545,7 @@ class FileUploader extends React.Component {
     });
     // reset upload link loaded
     this.isUploadLinkLoaded = false;
-  }
+  };
 
   onUploadRetry = (resumableFile) => {
     seafileAPI.sharedUploadLinkGetFileUploadUrl(this.props.token).then(res => {
@@ -549,7 +569,7 @@ class FileUploader extends React.Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   retryUploadFile = (resumableFile) => {
     let { repoID, path } = this.props;
@@ -581,7 +601,7 @@ class FileUploader extends React.Component {
       firedRetry = true;
     });
 
-  }
+  };
 
   replaceRepetitionFile = () => {
     let { repoID, path } = this.props;
@@ -597,11 +617,11 @@ class FileUploader extends React.Component {
       let errMessage = Utils.getErrorMsg(error);
       toaster.danger(errMessage);
     });
-  }
+  };
 
   cancelFileUpload = () => {
     this.resumable.files.pop(); //delete latest file；
-  }
+  };
 
   render() {
     return (
