@@ -1,9 +1,11 @@
 import React, { Fragment } from 'react';
-import ReactDOM from 'react-dom';
-import { Button, Dropdown, DropdownToggle, DropdownItem } from 'reactstrap';
+import PropTypes from 'prop-types';
+import MD5 from 'MD5';
+import ReactDom from 'react-dom';
+import { Button, Dropdown, DropdownToggle, DropdownItem, UncontrolledTooltip } from 'reactstrap';
 import moment from 'moment';
 import Account from './components/common/account';
-import { isPro, gettext, siteRoot, mediaUrl, logoPath, logoWidth, logoHeight, siteTitle, thumbnailSizeForOriginal } from './utils/constants';
+import { useGoFileserver, fileServerRoot, gettext, siteRoot, mediaUrl, logoPath, logoWidth, logoHeight, siteTitle, thumbnailSizeForOriginal } from './utils/constants';
 import { Utils } from './utils/utils';
 import { seafileAPI } from './utils/seafile-api';
 import Loading from './components/loading';
@@ -12,6 +14,10 @@ import ModalPortal from './components/modal-portal';
 import ZipDownloadDialog from './components/dialog/zip-download-dialog';
 import ImageDialog from './components/dialog/image-dialog';
 import FileUploader from './components/shared-link-file-uploader/file-uploader';
+import SaveSharedDirDialog from './components/dialog/save-shared-dir-dialog';
+import CopyMoveDirentProgressDialog from './components/dialog/copy-move-dirent-progress-dialog';
+import RepoInfoBar from './components/repo-info-bar';
+import RepoTag from './models/repo-tag';
 
 import './css/shared-dir-view.css';
 import './css/grid-view.css';
@@ -24,7 +30,7 @@ let {
   repoID, relativePath,
   mode, thumbnailSize, zipped,
   trafficOverLimit, canDownload,
-  noQuota, canUpload
+  noQuota, canUpload, enableVideoThumbnail
 } = window.shared.pageOptions;
 
 const showDownloadIcon = !trafficOverLimit && canDownload;
@@ -47,6 +53,17 @@ class SharedDirView extends React.Component {
       isZipDialogOpen: false,
       zipFolderPath: '',
 
+      usedRepoTags: [],
+      isRepoInfoBarShow: false,
+
+      isSaveSharedDirDialogShow: false,
+      itemsForSave: [],
+
+      asyncCopyMoveTaskId: '',
+      asyncOperationProgress: 0,
+      asyncOperatedFilesLength: 0,
+      isCopyMoveProgressDialogShow: false,
+
       isImagePopupOpen: false,
       imageItems: [],
       imageIndex: 0
@@ -78,6 +95,8 @@ class SharedDirView extends React.Component {
         errorMsg: errorMsg
       });
     });
+
+    this.getShareLinkRepoTags();
   }
 
   sortItems = (sortBy, sortOrder) => {
@@ -86,11 +105,14 @@ class SharedDirView extends React.Component {
       sortOrder: sortOrder,
       items: Utils.sortDirentsInSharedDir(this.state.items, sortBy, sortOrder)
     });
-  }
+  };
 
   getThumbnails = () => {
     let items = this.state.items.filter((item) => {
-      return !item.is_dir && Utils.imageCheck(item.file_name) && !item.encoded_thumbnail_src;
+      return !item.is_dir &&
+        (Utils.imageCheck(item.file_name) ||
+        (enableVideoThumbnail && Utils.videoCheck(item.file_name))) &&
+        !item.encoded_thumbnail_src;
     });
     if (items.length == 0) {
       return ;
@@ -116,7 +138,7 @@ class SharedDirView extends React.Component {
       });
     };
     getThumbnail(0);
-  }
+  };
 
   renderPath = () => {
     return (
@@ -125,33 +147,156 @@ class SharedDirView extends React.Component {
           if (index != zipped.length - 1) {
             return (
               <React.Fragment key={index}>
-                <a href={`?p=${encodeURIComponent(item.path)}&mode=${mode}`}>{item.name}</a>
+                <a href={`?p=${encodeURIComponent(item.path)}&mode=${mode}`} className="mx-1 ellipsis" title={item.name}>{item.name}</a>
                 <span> / </span>
               </React.Fragment>
             );
           }
+          return null;
         })
         }
-        {zipped[zipped.length - 1].name}
+        <span className="ml-1 ellipsis" title={zipped[zipped.length - 1].name}>{zipped[zipped.length - 1].name}</span>
       </React.Fragment>
     );
-  }
+  };
 
   zipDownloadFolder = (folderPath) => {
-    this.setState({
-      isZipDialogOpen: true,
-      zipFolderPath: folderPath
-    });
-  }
+    if (!useGoFileserver) {
+      this.setState({
+        isZipDialogOpen: true,
+        zipFolderPath: folderPath
+      });
+    }
+    else {
+      seafileAPI.getShareLinkZipTask(token, folderPath).then((res) => {
+        const zipToken = res.data['zip_token'];
+        location.href = `${fileServerRoot}zip/${zipToken}`;
+      }).catch((error) => {
+        let errorMsg = Utils.getErrorMsg(error);
+        this.setState({
+          isLoading: false,
+          errorMsg: errorMsg
+        });
+      });
+    }
+  };
 
   zipDownloadSelectedItems = () => {
+    if (!useGoFileserver) {
+      this.setState({
+        isZipDialogOpen: true,
+        zipFolderPath: relativePath,
+        selectedItems: this.state.items.filter(item => item.isSelected)
+          .map(item => item.file_name || item.folder_name)
+      });
+    }
+    else {
+      let target = this.state.items.filter(item => item.isSelected).map(item => item.file_name || item.folder_name);
+      seafileAPI.getShareLinkDirentsZipTask(token, relativePath, target).then((res) => {
+        const zipToken = res.data['zip_token'];
+        location.href = `${fileServerRoot}zip/${zipToken}`;
+      }).catch((error) => {
+        let errorMsg = Utils.getErrorMsg(error);
+        this.setState({
+          isLoading: false,
+          errorMsg: errorMsg
+        });
+      });
+    }
+  };
+
+  async getAsyncCopyMoveProgress() {
+    let { asyncCopyMoveTaskId } = this.state;
+    try {
+      let res = await seafileAPI.queryAsyncOperationProgress(asyncCopyMoveTaskId);
+      let data = res.data;
+      if (data.failed) {
+        let message = gettext('Failed to copy files to another library.');
+        toaster.danger(message);
+        this.setState({
+          asyncOperationProgress: 0,
+          isCopyMoveProgressDialogShow: false,
+        });
+        return;
+      }
+
+      if (data.successful) {
+        this.setState({
+          asyncOperationProgress: 0,
+          isCopyMoveProgressDialogShow: false,
+        });
+        let message = gettext('Successfully copied files to another library.');
+        toaster.success(message);
+        return;
+      }
+      // init state: total is 0
+      let asyncOperationProgress = !data.total ? 0 : parseInt((data.done/data.total * 100).toFixed(2));
+
+      this.getAsyncCopyMoveProgress();
+      this.setState({asyncOperationProgress: asyncOperationProgress});
+    } catch (error) {
+      this.setState({
+        asyncOperationProgress: 0,
+        isCopyMoveProgressDialogShow: false,
+      });
+    }
+  }
+
+  saveSelectedItems = () => {
     this.setState({
-      isZipDialogOpen: true,
-      zipFolderPath: relativePath,
-      selectedItems: this.state.items.filter(item => item.isSelected)
+      isSaveSharedDirDialogShow: true,
+      itemsForSave: this.state.items.filter(item => item.isSelected)
         .map(item => item.file_name || item.folder_name)
     });
-  }
+  };
+
+  saveAllItems = () => {
+    this.setState({
+      isSaveSharedDirDialogShow: true,
+      itemsForSave: this.state.items
+        .map(item => item.file_name || item.folder_name)
+    });
+  };
+
+  toggleSaveSharedDirCancel = () => {
+    this.setState({
+      isSaveSharedDirDialogShow: false,
+      itemsForSave: []
+    });
+  };
+
+  handleSaveSharedDir = (destRepoID, dstPath) => {
+
+    const itemsForSave = this.state.itemsForSave;
+
+    seafileAPI.saveSharedDir(destRepoID, dstPath, token, relativePath, itemsForSave).then((res) => {
+      this.setState({
+        isSaveSharedDirDialogShow: false,
+        itemsForSave: [],
+        isCopyMoveProgressDialogShow: true,
+        asyncCopyMoveTaskId: res.data.task_id,
+        asyncOperatedFilesLength: itemsForSave.length,
+      }, () => {
+        this.getAsyncCopyMoveProgress();
+      });
+    }).catch((error) => {
+      let errMessage = Utils.getErrorMsg(error);
+      this.setState({errMessage: errMessage});
+    });
+  };
+
+  onProgressDialogToggle = () => {
+    let { asyncOperationProgress } = this.state;
+    if (asyncOperationProgress !== 100) {
+      let taskId = this.state.asyncCopyMoveTaskId;
+      seafileAPI.cancelCopyMoveOperation(taskId);
+    }
+
+    this.setState({
+      asyncOperationProgress: 0,
+      isCopyMoveProgressDialogShow: false,
+    });
+  };
 
   closeZipDialog = () => {
     this.setState({
@@ -159,7 +304,7 @@ class SharedDirView extends React.Component {
       zipFolderPath: '',
       selectedItems: []
     });
-  }
+  };
 
   // for image popup
   prepareImageItem = (item) => {
@@ -180,7 +325,7 @@ class SharedDirView extends React.Component {
       'url': fileURL,
       'src': src
     };
-  }
+  };
 
   showImagePopup = (curItem) => {
     const items = this.state.items.filter((item) => {
@@ -195,27 +340,27 @@ class SharedDirView extends React.Component {
       imageItems: imageItems,
       imageIndex: items.indexOf(curItem)
     });
-  }
+  };
 
   closeImagePopup = () => {
     this.setState({
       isImagePopupOpen: false
     });
-  }
+  };
 
   moveToPrevImage = () => {
     const imageItemsLength = this.state.imageItems.length;
     this.setState((prevState) => ({
       imageIndex: (prevState.imageIndex + imageItemsLength - 1) % imageItemsLength
     }));
-  }
+  };
 
   moveToNextImage = () => {
     const imageItemsLength = this.state.imageItems.length;
     this.setState((prevState) => ({
       imageIndex: (prevState.imageIndex + 1) % imageItemsLength
     }));
-  }
+  };
 
   toggleAllSelected = () => {
     this.setState((prevState) => ({
@@ -225,7 +370,7 @@ class SharedDirView extends React.Component {
         return item;
       })
     }));
-  }
+  };
 
   toggleItemSelected = (targetItem, isSelected) => {
     this.setState({
@@ -240,12 +385,12 @@ class SharedDirView extends React.Component {
         isAllItemsSelected: !this.state.items.some(item => !item.isSelected)
       });
     });
-  }
+  };
 
   onUploadFile = (e) => {
     e.nativeEvent.stopImmediatePropagation();
     this.uploader.onFileUpload();
-  }
+  };
 
   onFileUploadSuccess = (direntObject) => {
     const { name, size } = direntObject;
@@ -263,7 +408,26 @@ class SharedDirView extends React.Component {
     items.splice(folderItems.length, 0, newItem);
     this.setState({items: items});
     seafileAPI.shareLinksUploadDone(token, Utils.joinPath(dirPath, name));
-  }
+  };
+
+  getShareLinkRepoTags = () => {
+    seafileAPI.getShareLinkRepoTags(token).then(res => {
+      let usedRepoTags = [];
+      res.data.repo_tags.forEach(item => {
+        let usedRepoTag = new RepoTag(item);
+        if (usedRepoTag.fileCount > 0) {
+          usedRepoTags.push(usedRepoTag);
+        }
+      });
+      this.setState({usedRepoTags: usedRepoTags});
+      if (usedRepoTags.length != 0 && relativePath == '/') {
+        this.setState({isRepoInfoBarShow: true});
+      }
+    }).catch(error => {
+      let errMessage = Utils.getErrorMsg(error);
+      toaster.danger(errMessage);
+    });
+  };
 
   render() {
     const isDesktop = Utils.isDesktop();
@@ -282,24 +446,46 @@ class SharedDirView extends React.Component {
               <h2 className="h3">{dirName}</h2>
               <p>{gettext('Shared by: ')}{sharedBy}</p>
               <div className="d-flex justify-content-between align-items-center op-bar">
-                <p className="m-0">{gettext('Current path: ')}{this.renderPath()}</p>
-                <div>
+                <p className="m-0 mr-4 ellipsis d-flex align-items-center"><span className="flex-none">{gettext('Current path: ')}</span>{this.renderPath()}</p>
+                <div className="flex-none">
                   {isDesktop &&
                   <div className="view-mode btn-group">
-                    <a href={`?p=${encodeURIComponent(relativePath)}&mode=list`} className={`${modeBaseClass} sf2-icon-list-view ${mode == 'list' ? 'current-mode' : ''}`} title={gettext('List')}></a>
-                    <a href={`?p=${encodeURIComponent(relativePath)}&mode=grid`} className={`${modeBaseClass} sf2-icon-grid-view ${mode == 'grid' ? 'current-mode' : ''}`} title={gettext('Grid')}></a>
+                    <a
+                      href={`?p=${encodeURIComponent(relativePath)}&mode=list`}
+                      className={`${modeBaseClass} sf2-icon-list-view ${mode == 'list' ? 'current-mode' : ''}`}
+                      title={gettext('List')}
+                      aria-label={gettext('List')}
+                    ></a>
+                    <a
+                      href={`?p=${encodeURIComponent(relativePath)}&mode=grid`}
+                      className={`${modeBaseClass} sf2-icon-grid-view ${mode == 'grid' ? 'current-mode' : ''}`}
+                      title={gettext('Grid')}
+                      aria-label={gettext('Grid')}
+                    ></a>
                   </div>
                   }
                   {canUpload && (
                     <Button disabled={noQuota}
                       title={noQuota ? gettext('The owner of this library has run out of space.') : ''}
-                      onClick={this.onUploadFile} className="ml-2 shared-dir-op-btn shared-dir-upload-btn">{gettext('Upload')}</Button>
+                      onClick={this.onUploadFile} className="ml-2 shared-dir-op-btn shared-dir-upload-btn"
+                    >{gettext('Upload')}</Button>
                   )}
                   {showDownloadIcon &&
                   <Fragment>
                     {this.state.items.some(item => item.isSelected) ?
-                      <Button color="success" onClick={this.zipDownloadSelectedItems} className="ml-2 shared-dir-op-btn">{gettext('ZIP Selected Items')}</Button> :
-                      <Button color="success" onClick={this.zipDownloadFolder.bind(this, relativePath)} className="ml-2 shared-dir-op-btn">{gettext('ZIP')}</Button>
+                      <Fragment>
+                        <Button color="success" onClick={this.zipDownloadSelectedItems} className="ml-2 shared-dir-op-btn">{gettext('ZIP Selected Items')}</Button>
+                        {(canDownload && loginUser && (loginUser !== sharedBy)) &&
+                        <Button color="success" onClick={this.saveSelectedItems} className="ml-2 shared-dir-op-btn">{gettext('Save Selected Items')}</Button>
+                        }
+                      </Fragment>
+                      :
+                      <Fragment>
+                        <Button color="success" onClick={this.zipDownloadFolder.bind(this, relativePath)} className="ml-2 shared-dir-op-btn">{gettext('ZIP')}</Button>
+                        {(canDownload && loginUser && (loginUser !== sharedBy)) &&
+                        <Button color="success" onClick={this.saveAllItems} className="ml-2 shared-dir-op-btn">{gettext('Save')}</Button>
+                        }
+                      </Fragment>
                     }
                   </Fragment>
                   }
@@ -310,12 +496,24 @@ class SharedDirView extends React.Component {
                   ref={uploader => this.uploader = uploader}
                   dragAndDrop={false}
                   token={token}
-                  path={dirPath === '/' ? dirPath : dirPath.replace(/\/+$/, "")}
-                  relativePath={relativePath === '/' ? relativePath : relativePath.replace(/\/+$/, "")}
+                  path={dirPath === '/' ? dirPath : dirPath.replace(/\/+$/, '')}
+                  relativePath={relativePath === '/' ? relativePath : relativePath.replace(/\/+$/, '')}
                   repoID={repoID}
                   onFileUploadSuccess={this.onFileUploadSuccess}
                 />
               )}
+
+              {this.state.isRepoInfoBarShow && (
+                <RepoInfoBar
+                  repoID={repoID}
+                  currentPath={'/'}
+                  usedRepoTags={this.state.usedRepoTags}
+                  shareLinkToken={token}
+                  enableFileDownload={showDownloadIcon}
+                  className="mx-0"
+                />
+              )}
+
               <Content
                 isDesktop={isDesktop}
                 isLoading={this.state.isLoading}
@@ -343,6 +541,23 @@ class SharedDirView extends React.Component {
           />
         </ModalPortal>
         }
+        {this.state.isSaveSharedDirDialogShow &&
+          <SaveSharedDirDialog
+            sharedToken={token}
+            parentDir={relativePath}
+            items={this.state.itemsForSave}
+            toggleCancel={this.toggleSaveSharedDirCancel}
+            handleSaveSharedDir={this.handleSaveSharedDir}
+          />
+        }
+        {this.state.isCopyMoveProgressDialogShow && (
+          <CopyMoveDirentProgressDialog
+            type='copy'
+            asyncOperatedFilesLength={this.state.asyncOperatedFilesLength}
+            asyncOperationProgress={this.state.asyncOperationProgress}
+            toggleDialog={this.onProgressDialogToggle}
+          />
+        )}
         {this.state.isImagePopupOpen &&
         <ModalPortal>
           <ImageDialog
@@ -370,21 +585,21 @@ class Content extends React.Component {
     const sortBy = 'name';
     const sortOrder = this.props.sortOrder == 'asc' ? 'desc' : 'asc';
     this.props.sortItems(sortBy, sortOrder);
-  }
+  };
 
   sortByTime = (e) => {
     e.preventDefault();
     const sortBy = 'time';
     const sortOrder = this.props.sortOrder == 'asc' ? 'desc' : 'asc';
     this.props.sortItems(sortBy, sortOrder);
-  }
+  };
 
   sortBySize = (e) => {
     e.preventDefault();
     const sortBy = 'size';
     const sortOrder = this.props.sortOrder == 'asc' ? 'desc' : 'asc';
     this.props.sortItems(sortBy, sortOrder);
-  }
+  };
 
   render() {
     const {
@@ -443,10 +658,11 @@ class Content extends React.Component {
             </th>
             }
             <th width="5%"></th>
-            <th width={showDownloadIcon ? '52%' : '55%'}><a className="d-block table-sort-op" href="#" onClick={this.sortByName}>{gettext('Name')} {sortBy == 'name' && sortIcon}</a></th>
+            <th width={showDownloadIcon ? '50%' : '53%'}><a className="d-block table-sort-op" href="#" onClick={this.sortByName}>{gettext('Name')} {sortBy == 'name' && sortIcon}</a></th>
+            <th width="8%"></th>
             <th width="14%"><a className="d-block table-sort-op" href="#" onClick={this.sortBySize}>{gettext('Size')} {sortBy == 'size' && sortIcon}</a></th>
-            <th width="16%"><a className="d-block table-sort-op" href="#" onClick={this.sortByTime}>{gettext('Last Update')} {sortBy == 'time' && sortIcon}</a></th>
-            <th width="10%"></th>
+            <th width="13%"><a className="d-block table-sort-op" href="#" onClick={this.sortByTime}>{gettext('Last Update')} {sortBy == 'time' && sortIcon}</a></th>
+            <th width="7%"></th>
           </tr>
         </thead>
         {tbody}
@@ -466,6 +682,21 @@ class Content extends React.Component {
   }
 }
 
+Content.propTypes = {
+  isDesktop: PropTypes.bool,
+  isLoading: PropTypes.bool,
+  isAllItemsSelected: PropTypes.bool,
+  errorMsg: PropTypes.string,
+  items: PropTypes.array,
+  sortItems: PropTypes.func,
+  sortBy: PropTypes.string,
+  sortOrder: PropTypes.string,
+  toggleAllSelected: PropTypes.func,
+  toggleItemSelected: PropTypes.func,
+  zipDownloadFolder: PropTypes.func,
+  showImagePopup: PropTypes.func,
+};
+
 class Item extends React.Component {
 
   constructor(props) {
@@ -478,20 +709,20 @@ class Item extends React.Component {
 
   toggleOpMenu = () => {
     this.setState({isOpMenuOpen: !this.state.isOpMenuOpen});
-  }
+  };
 
   handleMouseOver = () => {
     this.setState({isIconShown: true});
-  }
+  };
 
   handleMouseOut = () => {
     this.setState({isIconShown: false});
-  }
+  };
 
   zipDownloadFolder = (e) => {
     e.preventDefault();
     this.props.zipDownloadFolder.bind(this, this.props.item.folder_path)();
-  }
+  };
 
   handleFileClick = (e) => {
     const item = this.props.item;
@@ -501,19 +732,26 @@ class Item extends React.Component {
 
     e.preventDefault();
     this.props.showImagePopup(item);
-  }
+  };
 
   toggleItemSelected = (e) => {
     this.props.toggleItemSelected(this.props.item, e.target.checked);
-  }
+  };
 
   render() {
     const { item, isDesktop } = this.props;
     const { isIconShown } = this.state;
 
+    let toolTipID = '';
+    let tagTitle = '';
+    if (item.file_tags && item.file_tags.length > 0) {
+      toolTipID = MD5(item.file_name).slice(0, 7);
+      tagTitle = item.file_tags.map(item => item.tag_name).join(' ');
+    }
+
     if (item.is_dir) {
       return isDesktop ? (
-        <tr onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut}>
+        <tr onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut} onFocus={this.handleMouseOver}>
           {showDownloadIcon &&
             <td className="text-center">
               <input type="checkbox" checked={item.isSelected} onChange={this.toggleItemSelected} />
@@ -524,10 +762,11 @@ class Item extends React.Component {
             <a href={`?p=${encodeURIComponent(item.folder_path.substr(0, item.folder_path.length - 1))}&mode=${mode}`}>{item.folder_name}</a>
           </td>
           <td></td>
+          <td></td>
           <td title={moment(item.last_modified).format('llll')}>{moment(item.last_modified).fromNow()}</td>
           <td>
             {showDownloadIcon &&
-            <a className={`action-icon sf2-icon-download${isIconShown ? '' : ' invisible'}`} href="#" onClick={this.zipDownloadFolder} title={gettext('Download')} aria-label={gettext('Download')}>
+            <a role="button" className={`action-icon sf2-icon-download${isIconShown ? '' : ' invisible'}`} href="#" onClick={this.zipDownloadFolder} title={gettext('Download')} aria-label={gettext('Download')}>
             </a>
             }
           </td>
@@ -565,7 +804,7 @@ class Item extends React.Component {
       const fileURL = `${siteRoot}d/${token}/files/?p=${encodeURIComponent(item.file_path)}`;
       const thumbnailURL = item.encoded_thumbnail_src ? `${siteRoot}${item.encoded_thumbnail_src}` : '';
       return isDesktop ? (
-        <tr onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut}>
+        <tr onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut} onFocus={this.handleMouseOver}>
           {showDownloadIcon &&
             <td className="text-center">
               <input type="checkbox" checked={item.isSelected} onChange={this.toggleItemSelected} />
@@ -580,6 +819,23 @@ class Item extends React.Component {
           <td>
             <a href={fileURL} onClick={this.handleFileClick}>{item.file_name}</a>
           </td>
+          <td className="tag-list-title">
+            {(item.file_tags && item.file_tags.length > 0) && (
+              <Fragment>
+                <div id={`tag-list-title-${toolTipID}`} className="dirent-item tag-list tag-list-stacked">
+                  {item.file_tags.map((fileTag, index) => {
+                    let length = item.file_tags.length;
+                    return (
+                      <span className="file-tag" key={fileTag.file_tag_id} style={{zIndex:length - index, backgroundColor:fileTag.tag_color}}></span>
+                    );
+                  })}
+                </div>
+                <UncontrolledTooltip target={`tag-list-title-${toolTipID}`} placement="bottom">
+                  {tagTitle}
+                </UncontrolledTooltip>
+              </Fragment>
+            )}
+          </td>
           <td>{Utils.bytesToSize(item.size)}</td>
           <td title={moment(item.last_modified).format('llll')}>{moment(item.last_modified).fromNow()}</td>
           <td>
@@ -627,6 +883,18 @@ class Item extends React.Component {
   }
 }
 
+Item.propTypes = {
+  isDesktop: PropTypes.bool,
+  item: PropTypes.object,
+  sortItems: PropTypes.func,
+  sortBy: PropTypes.string,
+  sortOrder: PropTypes.string,
+  toggleAllSelected: PropTypes.func,
+  toggleItemSelected: PropTypes.func,
+  zipDownloadFolder: PropTypes.func,
+  showImagePopup: PropTypes.func,
+};
+
 class GridItem extends React.Component {
 
   constructor(props) {
@@ -638,16 +906,16 @@ class GridItem extends React.Component {
 
   handleMouseOver = () => {
     this.setState({isIconShown: true});
-  }
+  };
 
   handleMouseOut = () => {
     this.setState({isIconShown: false});
-  }
+  };
 
   zipDownloadFolder = (e) => {
     e.preventDefault();
     this.props.zipDownloadFolder.bind(this, this.props.item.folder_path)();
-  }
+  };
 
   handleFileClick = (e) => {
     const item = this.props.item;
@@ -657,7 +925,7 @@ class GridItem extends React.Component {
 
     e.preventDefault();
     this.props.showImagePopup(item);
-  }
+  };
 
   render() {
     const item = this.props.item;
@@ -666,13 +934,13 @@ class GridItem extends React.Component {
     if (item.is_dir) {
       const folderURL = `?p=${encodeURIComponent(item.folder_path.substr(0, item.folder_path.length - 1))}&mode=${mode}`;
       return (
-        <li className="grid-item" onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut}>
+        <li className="grid-item" onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut} onFocus={this.handleMouseOver}>
           <a href={folderURL} className="grid-file-img-link d-block">
             <img src={Utils.getFolderIconUrl(false, 192)} alt="" width="96" height="96" />
           </a>
           <a href={folderURL} className="grid-file-name grid-file-name-link">{item.folder_name}</a>
           {showDownloadIcon &&
-            <a className={`action-icon sf2-icon-download${isIconShown ? '' : ' invisible'}`} href="#" onClick={this.zipDownloadFolder} title={gettext('Download')} aria-label={gettext('Download')}>
+            <a role="button" className={`action-icon sf2-icon-download${isIconShown ? '' : ' invisible'}`} href="#" onClick={this.zipDownloadFolder} title={gettext('Download')} aria-label={gettext('Download')}>
             </a>
           }
         </li>
@@ -681,7 +949,7 @@ class GridItem extends React.Component {
       const fileURL = `${siteRoot}d/${token}/files/?p=${encodeURIComponent(item.file_path)}`;
       const thumbnailURL = item.encoded_thumbnail_src ? `${siteRoot}${item.encoded_thumbnail_src}` : '';
       return (
-        <li className="grid-item" onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut}>
+        <li className="grid-item" onMouseOver={this.handleMouseOver} onMouseOut={this.handleMouseOut} onFocus={this.handleMouseOver}>
           <a href={fileURL} className="grid-file-img-link d-block" onClick={this.handleFileClick}>
             {thumbnailURL ?
               <img className="thumbnail" src={thumbnailURL} alt="" /> :
@@ -699,7 +967,10 @@ class GridItem extends React.Component {
   }
 }
 
-ReactDOM.render(
-  <SharedDirView />,
-  document.getElementById('wrapper')
-);
+GridItem.propTypes = {
+  item: PropTypes.object,
+  zipDownloadFolder: PropTypes.func,
+  showImagePopup: PropTypes.func,
+};
+
+ReactDom.render(<SharedDirView />, document.getElementById('wrapper'));
