@@ -1,13 +1,14 @@
-import { mediaUrl, gettext, serviceURL, siteRoot, isPro, enableFileComment, fileAuditEnabled, canGenerateShareLink, canGenerateUploadLink, username, folderPermEnabled } from './constants';
-import { strChineseFirstPY } from './pinyin-by-unicode';
+import { mediaUrl, gettext, serviceURL, siteRoot, isPro, fileAuditEnabled, canGenerateShareLink, canGenerateUploadLink, shareLinkPasswordMinLength, username, folderPermEnabled, onlyofficeConverterExtensions, enableOnlyoffice, enableSeadoc } from './constants';
 import TextTranslation from './text-translation';
 import React from 'react';
 import toaster from '../components/toast';
 import PermissionDeniedTip from '../components/permission-denied-tip';
+import { compareTwoString } from './compare-two-string';
 
 export const Utils = {
 
   keyCodes:  {
+    enter: 13,
     esc:   27,
     space: 32,
     tab:   9,
@@ -86,7 +87,9 @@ export const Utils = {
     'mp3' : 'music.png',
     'oga' : 'music.png',
     'ogg' : 'music.png',
+    'wav' : 'music.png',
     'flac' : 'music.png',
+    'opus' : 'music.png',
     'aac' : 'music.png',
     'ac3' : 'music.png',
     'wma' : 'music.png',
@@ -101,7 +104,8 @@ export const Utils = {
     'ico' : 'pic.png',
 
     // default
-    'default' : 'file.png'
+    'default' : 'file.png',
+    'sdoc': 'sdoc.png',
   },
 
   // check if a file is an image
@@ -121,10 +125,17 @@ export const Utils = {
 
   getShareLinkPermissionList: function(itemType, permission, path, canEdit) {
     // itemType: library, dir, file
-    // permission: rw, r, admin, cloud-edit, preview
+    // permission: rw, r, admin, cloud-edit, preview, custom-*
 
     let permissionOptions = [];
 
+    const { isCustomPermission } = Utils.getUserPermission(permission);
+    if (isCustomPermission) {
+      permissionOptions.push('preview_download');
+      permissionOptions.push('preview_only');
+      return permissionOptions;
+    }
+
     if (permission == 'rw' || permission == 'admin' || permission == 'r') {
       permissionOptions.push('preview_download');
     }
@@ -228,9 +239,12 @@ export const Utils = {
     /*
      * @param title: gettext('...{placeholder}...')
      */
+    /*
     const targetStr = this.HTMLescape(operationTarget);
     const str = `<span class="op-target ellipsis ellipsis-op-target" title=${targetStr}>${targetStr}</span>`;
     return title.replace('{placeholder}', str);
+    */
+    return title.replace('{placeholder}', operationTarget);
   },
 
   getFileName: function(filePath) {
@@ -266,7 +280,7 @@ export const Utils = {
     if (path === '/') {
       return path;
     }
-    path = path[path.length - 1] !== '/' ? path : path.slice(0, path.length -2);
+    path = path[path.length - 1] !== '/' ? path : path.slice(0, path.length - 1);
     return path.slice(path.lastIndexOf('/') + 1);
   },
 
@@ -361,7 +375,7 @@ export const Utils = {
       if (dirent.permission && (dirent.permission === 'r' || dirent.permission === 'preview')) {
         readonly = true;
       }
-      return this.getFolderIconUrl(readonly, size);
+      return this.getFolderIconUrl(readonly, size, dirent.has_been_shared_out);
     } else {
       return this.getFileIconUrl(dirent.name, size);
     }
@@ -377,12 +391,12 @@ export const Utils = {
     }
   },
 
-  getFolderIconUrl: function(readonly = false, size) {
+  getFolderIconUrl: function(readonly = false, size, sharedOut) {
     if (!size) {
       size = Utils.isHiDPI() ? 48 : 24;
     }
     size = size > 24 ? 192 : 24;
-    return `${mediaUrl}img/folder${readonly ? '-read-only-' : '-'}${size}.png`;
+    return `${mediaUrl}img/folder${readonly ? '-read-only' : ''}${sharedOut ? '-shared-out' : ''}-${size}.png`;
   },
 
   getFileIconUrl: function(filename, size) {
@@ -454,23 +468,47 @@ export const Utils = {
     let list = [];
     const { SHARE, DOWNLOAD, DELETE, RENAME, MOVE, COPY, PERMISSION, OPEN_VIA_CLIENT } = TextTranslation;
     const permission = dirent.permission;
+    const { isCustomPermission, customPermission } = Utils.getUserPermission(permission);
 
     if (isContextmenu) {
       if (permission == 'rw' || permission == 'r') {
         list.push(DOWNLOAD);
       }
 
+      if (isCustomPermission && customPermission.permission.download) {
+        list.push(DOWNLOAD);
+      }
+
       if (Utils.isHasPermissionToShare(currentRepoInfo, permission, dirent)) {
         list.push(SHARE);
       }
 
-      if (permission == 'rw') {
+      if (permission == 'rw' || permission == 'cloud-edit') {
+        list.push(DELETE, 'Divider');
+      }
+
+      if (isCustomPermission && customPermission.permission.delete) {
         list.push(DELETE, 'Divider');
       }
     }
 
+    if (permission == 'rw' || permission == 'cloud-edit') {
+      list.push(RENAME, MOVE);
+    }
+
+    if (isCustomPermission && customPermission.permission.modify) {
+      list.push(RENAME, MOVE);
+    }
+
+    if (permission == 'rw' || permission == 'cloud-edit') {
+      list.push(COPY);
+    }
+
+    if (isCustomPermission && customPermission.permission.copy) {
+      list.push(COPY);
+    }
+
     if (permission == 'rw') {
-      list.push(RENAME, MOVE, COPY);
       if (folderPermEnabled  && ((isRepoOwner && currentRepoInfo.has_been_shared_out) || currentRepoInfo.is_admin)) {
         list.push('Divider', PERMISSION);
       }
@@ -481,54 +519,115 @@ export const Utils = {
       list.push(COPY);
     }
 
+    // if the last item of menuList is ‘Divider’, delete the last item
+    if (list[list.length - 1] === 'Divider') {
+      list.pop();
+    }
+
     return list;
   },
 
   getFileOperationList: function(isRepoOwner, currentRepoInfo, dirent, isContextmenu) {
     let list = [];
-    const { SHARE, DOWNLOAD, DELETE, RENAME, MOVE, COPY, TAGS, UNLOCK, LOCK,
-      COMMENT, HISTORY, ACCESS_LOG, OPEN_VIA_CLIENT } = TextTranslation;
+    const { SHARE, DOWNLOAD, DELETE, RENAME, MOVE, COPY, TAGS, UNLOCK, LOCK, FREEZE_DOCUMENT,
+      HISTORY, ACCESS_LOG, PROPERTIES, OPEN_VIA_CLIENT, ONLYOFFICE_CONVERT, CONVERT_TO_MARKDOWN, CONVERT_TO_SDOC } = TextTranslation;
     const permission = dirent.permission;
+    const { isCustomPermission, customPermission } = Utils.getUserPermission(permission);
 
     if (isContextmenu) {
       if (permission == 'rw' || permission == 'r') {
         list.push(DOWNLOAD);
       }
 
+      if (isCustomPermission && customPermission.permission.download) {
+        list.push(DOWNLOAD);
+      }
+
       if (Utils.isHasPermissionToShare(currentRepoInfo, permission, dirent)) {
         list.push(SHARE);
       }
 
-      if (permission == 'rw') {
+      if (permission == 'rw' || permission == 'cloud-edit') {
         if (!dirent.is_locked || (dirent.is_locked && dirent.locked_by_me)) {
           list.push(DELETE);
         }
+        list.push('Divider');
       }
 
-      list.push('Divider');
+      if (isCustomPermission && customPermission.permission.delete) {
+        if (!dirent.is_locked || (dirent.is_locked && dirent.locked_by_me)) {
+          list.push(DELETE);
+        }
+        list.push('Divider');
+      }
     }
 
-    if (permission == 'rw') {
+    if (permission == 'rw' || permission == 'cloud-edit') {
       if (!dirent.is_locked || (dirent.is_locked && dirent.locked_by_me)) {
         list.push(RENAME, MOVE);
       }
-      list.push(COPY, TAGS);
+    }
 
+    if (isCustomPermission && customPermission.permission.modify) {
+      if (!dirent.is_locked || (dirent.is_locked && dirent.locked_by_me)) {
+        list.push(RENAME, MOVE);
+      }
+    }
+
+    if (permission == 'rw' || permission == 'cloud-edit') {
+      list.push(COPY);
+    }
+
+    if (isCustomPermission) {
+      if (customPermission.permission.copy) {
+        list.push(COPY);
+      }
+    }
+
+    if (permission == 'rw') {
+      list.push(TAGS);
       if (isPro) {
         if (dirent.is_locked) {
           if (dirent.locked_by_me || dirent.lock_owner == 'OnlineOffice' || isRepoOwner || currentRepoInfo.is_admin) {
             list.push(UNLOCK);
           }
         } else {
-          list.push(LOCK);
+          if (!dirent.name.endsWith('.sdoc')) {
+            list.push(LOCK);
+          }
         }
       }
 
       list.push('Divider');
-      if (enableFileComment) {
-        list.push(COMMENT);
+
+      if (isPro && !dirent.is_locked && dirent.name.endsWith('.sdoc')) {
+        list.push(FREEZE_DOCUMENT);
       }
-      list.push(HISTORY);
+
+    }
+
+    if ((permission == 'rw' || permission == 'cloud-edit') && enableSeadoc) {
+      if (dirent.name.endsWith('.md')) {
+        list.push(CONVERT_TO_SDOC);
+      }
+
+      if (dirent.name.endsWith('.sdoc')) {
+        list.push(CONVERT_TO_MARKDOWN);
+      }
+    }
+
+    if (permission == 'rw') {
+      /*
+      if (Utils.isSdocFile(dirent.name)) {
+        if (dirent.is_sdoc_draft) {
+          list.push(UNMARK_AS_DRAFT);
+        } else {
+          list.push(MARK_AS_DRAFT);
+        }
+      }
+      */
+      list.push('Divider');
+      list.push(PROPERTIES, HISTORY);
       if (isPro && fileAuditEnabled) {
         list.push(ACCESS_LOG);
       }
@@ -539,15 +638,36 @@ export const Utils = {
       if (!currentRepoInfo.encrypted) {
         list.push(COPY);
       }
-      if (enableFileComment) {
-        list.push(COMMENT);
-      }
       list.push(HISTORY);
     }
 
+    if (permission == 'rw' && enableOnlyoffice &&
+      onlyofficeConverterExtensions.includes(this.getFileExtension(dirent.name, false))) {
+      list.push(ONLYOFFICE_CONVERT);
+    }
+
+    // if the last item of menuList is ‘Divider’, delete the last item
+    if (list[list.length - 1] === 'Divider') {
+      list.pop();
+    }
+
+    // Remove adjacent excess 'Divider'
+    for (let i = 0; i < list.length; i++) {
+      if (list[i] === 'Divider' && list[i + 1] === 'Divider') {
+        list.splice(i, 1);
+        i--;
+      }
+    }
+
     return list;
   },
 
+  getFileExtension: function (fileName, withoutDot) {
+    let parts = fileName.toLowerCase().split('.');
+
+    return withoutDot ? parts.pop() : '.' + parts.pop();
+  },
+
   getDirentOperationList: function(isRepoOwner, currentRepoInfo, dirent, isContextmenu) {
     return dirent.type == 'dir' ?
       Utils.getFolderOperationList(isRepoOwner, currentRepoInfo, dirent, isContextmenu) :
@@ -572,6 +692,9 @@ export const Utils = {
       case 'preview':
         title = gettext('Online Read-Only');
         break;
+      case 'invisible':
+        title = gettext('Invisible');
+        break;
     }
     return title;
   },
@@ -594,6 +717,9 @@ export const Utils = {
       case 'preview':
         title = gettext('User can only view files online via browser. Files can\'t be downloaded.');
         break;
+      case 'invisible':
+        title = gettext('User can not see this folder.');
+        break;
     }
     return title;
   },
@@ -720,12 +846,27 @@ export const Utils = {
     }
   },
 
+  isSdocFile: function(filePath) {
+    let index = filePath.lastIndexOf('.');
+    if (index === -1) {
+      return false;
+    } else {
+      let type = filePath.substring(index).toLowerCase();
+      if (type === '.sdoc') {
+        return true;
+      } else {
+        return false;
+      }
+    }
+  },
+
   isInternalFileLink: function(url, repoID) {
     var re = new RegExp(serviceURL + '/lib/' + repoID + '/file.*');
     return re.test(url);
   },
 
   isInternalMarkdownLink: function(url, repoID) {
+    // eslint-disable-next-line
     var re = new RegExp(serviceURL + '/lib/' + repoID + '.*\.md$');
     return re.test(url);
   },
@@ -736,6 +877,7 @@ export const Utils = {
   },
 
   getPathFromInternalMarkdownLink: function(url, repoID) {
+    // eslint-disable-next-line
     var re = new RegExp(serviceURL + '/lib/' + repoID + '/file' + '(.*\.md)');
     var array = re.exec(url);
     var path = decodeURIComponent(array[1]);
@@ -753,6 +895,7 @@ export const Utils = {
 
   isWikiInternalMarkdownLink: function(url, slug) {
     slug = encodeURIComponent(slug);
+    // eslint-disable-next-line
     var re = new RegExp(serviceURL + '/published/' + slug + '.*\.md$');
     return re.test(url);
   },
@@ -765,6 +908,7 @@ export const Utils = {
 
   getPathFromWikiInternalMarkdownLink: function(url, slug) {
     slug = encodeURIComponent(slug);
+    // eslint-disable-next-line
     var re = new RegExp(serviceURL + '/published/' + slug + '(.*\.md)');
     var array = re.exec(url);
     var path = array[1];
@@ -796,28 +940,7 @@ export const Utils = {
     // if wordA >= wordB, return 1
     // if wordA < wordB, return -1
 
-    var a_val, b_val,
-      a_uni = wordA.charCodeAt(0),
-      b_uni = wordB.charCodeAt(0);
-
-    if ((19968 < a_uni && a_uni < 40869) && (19968 < b_uni && b_uni < 40869)) {
-      // both are chinese words
-      a_val = strChineseFirstPY.charAt(a_uni - 19968).toLowerCase();
-      b_val = strChineseFirstPY.charAt(b_uni - 19968).toLowerCase();
-    } else if ((19968 < a_uni && a_uni < 40869) && !(19968 < b_uni && b_uni < 40869)) {
-      // a is chinese and b is english
-      return 1;
-    } else if (!(19968 < a_uni && a_uni < 40869) && (19968 < b_uni && b_uni < 40869)) {
-      // a is english and b is chinese
-      return -1;
-    } else {
-      // both are english words
-      a_val = wordA.toLowerCase();
-      b_val = wordB.toLowerCase();
-      return this.compareStrWithNumbersIn(a_val, b_val);
-    }
-
-    return a_val >= b_val ? 1 : -1;
+    return compareTwoString(wordA, wordB);
   },
 
   // compare two strings which may have digits in them
@@ -1074,13 +1197,12 @@ export const Utils = {
   },
 
   changeMarkdownNodes: function(nodes, fn) {
-    nodes.map((item) => {
+    nodes.forEach((item) => {
       fn(item);
       if (item.children && item.children.length > 0){
         Utils.changeMarkdownNodes(item.children, fn);
       }
     });
-
     return nodes;
   },
 
@@ -1094,22 +1216,25 @@ export const Utils = {
         mode = 'javascript';
         break;
       case 'c':
-        mode = 'text/x-csrc';
+        mode = 'c';
         break;
       case 'cpp':
-        mode = 'text/x-c++src';
-        break;
-      case 'java':
-        mode = 'text/x-java';
+        mode = 'cpp';
         break;
       case 'cs':
-        mode = 'text/x-csharp';
+        mode = 'csharp';
+        break;
+      case 'java':
+        mode = 'java';
         break;
       case 'mdf':
         mode = 'text/x-sql';
         break;
       case 'html':
-        mode = 'htmlmixed';
+        mode = 'html';
+        break;
+      case 'sh':
+        mode = 'shell';
         break;
       default:
         mode = suffix;
@@ -1224,12 +1349,34 @@ export const Utils = {
     }
   },
 
-  generatePassword: function(passwordLength) {
-    let possible = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789abcdefghijklmnopqrstuvwxyz0123456789';
-    let password = '';
-    for (let i = 0; i < passwordLength; i++) {
-      password += possible.charAt(Math.floor(Math.random() * possible.length));
+  generatePassword: function(length, hasNum=1, hasChar=1, hasSymbol=1) {
+
+    var password = '';
+
+    // 65~90：A~Z
+    password += String.fromCharCode(Math.floor((Math.random() * (90-65)) + 65));
+
+    // 97~122：a~z
+    password += String.fromCharCode(Math.floor((Math.random() * (122-97)) + 97));
+
+    // 48~57：0~9
+    password += String.fromCharCode(Math.floor((Math.random() * (57-48)) + 48));
+
+    // 33~47：!~/
+    password += String.fromCharCode(Math.floor((Math.random() * (47-33)) + 33));
+
+    // 33~47：!~/
+    // 48~57：0~9
+    // 58~64：:~@
+    // 65~90：A~Z
+    // 91~96：[~`
+    // 97~122：a~z
+    // 123~127：{~
+    for (var i = 0; i < length-4; i++) {
+      var num = Math.floor((Math.random() * (127-33)) + 33);
+      password += String.fromCharCode(num);
     }
+
     return password;
   },
 
@@ -1269,6 +1416,12 @@ export const Utils = {
    */
   isHasPermissionToShare: function(repoInfo, userDirPermission, dirent) {
 
+    const { isCustomPermission, customPermission } = Utils.getUserPermission(userDirPermission);
+    if (isCustomPermission) {
+      const { download_external_link } = customPermission.permission;
+      return download_external_link;
+    }
+
     let { is_admin: isAdmin, is_virtual: isVirtual, encrypted: repoEncrypted, owner_email: ownerEmail } = repoInfo;
     let isRepoOwner = ownerEmail === username;
 
@@ -1342,6 +1495,136 @@ export const Utils = {
 
   hasNextPage(curPage, perPage, totalCount) {
     return curPage * perPage < totalCount;
-  }
+  },
+
+  getStrengthLevel: function(pwd) {
+    const _this = this;
+    var num = 0;
+
+    if (pwd.length < shareLinkPasswordMinLength) {
+      return 0;
+    } else {
+      for (var i = 0; i < pwd.length; i++) {
+        // return the unicode
+        // bitwise OR
+        num |= _this.getCharMode(pwd.charCodeAt(i));
+      }
+      return _this.calculateBitwise(num);
+    }
+  },
+
+  getCharMode: function(n) {
+    if (n >= 48 && n <= 57) // nums
+      return 1;
+    if (n >= 65 && n <= 90) // uppers
+      return 2;
+    if (n >= 97 && n <= 122) // lowers
+      return 4;
+    else
+      return 8;
+  },
+
+  calculateBitwise: function(num) {
+    var level = 0;
+    for (var i = 0; i < 4; i++){
+      // bitwise AND
+      if (num&1) level++;
+      // Right logical shift
+      num>>>=1;
+    }
+    return level;
+  },
+
+  getSharedPermission: function(item) {
+    let permission = item.permission;
+    if (item.is_admin) {
+      permission = 'admin';
+    }
+    if (item.permission.startsWith('custom-')) {
+      permission = item.permission.slice(7);
+    }
+    return permission;
+  },
+
+  getUserPermission: function(userPerm) {
+    const { custom_permission } = window;
+    const common_permissions = ['rw', 'r', 'admin', 'cloud-edit', 'preview'];
+    // visit the shared repo(virtual repo) by custom permission
+    if (!custom_permission || common_permissions.indexOf(userPerm) > -1) {
+      return { isCustomPermission: false };
+    }
+    // userPerm is startsWith 'custom-'
+    if (custom_permission) {
+      const permissionId = custom_permission.id;
+      const userPermId = parseInt(userPerm.split('-')[1]);
+      if (permissionId === userPermId) {
+        return { isCustomPermission: true, customPermission: custom_permission };
+      }
+      // TODO user set custom permission on folder
+    }
+    return { isCustomPermission: false };
+  },
+
+  // for a11y
+  onKeyDown: function(e) {
+    if (e.key == 'Enter' || e.key == 'Space') {
+      e.target.click();
+    }
+  },
+
+  updateTabTitle: function(content) {
+    const title = document.getElementsByTagName('title')[0];
+    title.innerText = content;
+  },
+
+  generateHistoryURL: function(siteRoot, repoID, path) {
+    if (!siteRoot || !repoID || !path) return '';
+    return siteRoot + 'repo/file_revisions/' + repoID + '/?p=' + this.encodePath(path);
+  },
+
+  generateRevisionURL: function(siteRoot, repoID, path) {
+    if (!siteRoot || !repoID || !path) return '';
+    return siteRoot + 'repo/sdoc_revision/' + repoID + '/?p=' + this.encodePath(path);
+  },
+
+  generateRevisionsURL: function(siteRoot, repoID, path) {
+    if (!siteRoot || !repoID || !path) return '';
+    return siteRoot + 'repo/sdoc_revisions/' + repoID + '/?p=' + this.encodePath(path);
+  },
+
+  isFunction: function(functionToCheck) {
+    const getType = {};
+    return functionToCheck && getType.toString.call(functionToCheck) === '[object Function]';
+  },
+
+  getUrlSearches() {
+    const search = location.search;
+    let searchParams = {};
+    if (search.length === 0) {
+      return searchParams;
+    }
+    let allSearches = search.split('?')[1];
+    let allSearchesArr = allSearches.split('&');
+    allSearchesArr.forEach(item => {
+      let itemArr = item.split('=');
+      searchParams[itemArr[0]] = decodeURI(itemArr[1]);
+    });
+    return searchParams;
+  },
+
+  // If value is null, delete the search parameter; else, add or update the search parameter.
+  updateSearchParameter(key, value) {
+    const { origin, pathname } = location;
+    const searchParams = this.getUrlSearches();
+    searchParams[key] = value;
+    let newSearch = '?';
+    for (let key in searchParams) {
+      let value = searchParams[key];
+      if (value) {
+        newSearch = newSearch === '?' ? `?${key}=${value}` : `${newSearch}&${key}=${value}`;
+      }
+    }
+    history.replaceState(null, '', origin + pathname + newSearch);
+  },
 
 };
