@@ -1,13 +1,14 @@
 
 
-(function(globals) {
-
-  var django = globals.django || (globals.django = {});
+'use strict';
+{
+  const globals = this;
+  const django = globals.django || (globals.django = {});
 
   
   django.pluralidx = function(n) {
-    var v=(n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;
-    if (typeof(v) == 'boolean') {
+    const v = (n==1) ? 0 : (n>=2 && n<=4) ? 1 : 2;
+    if (typeof v === 'boolean') {
       return v ? 1 : 0;
     } else {
       return v;
@@ -19,10 +20,9 @@
 
   django.catalog = django.catalog || {};
   
-  var newcatalog = {
+  const newcatalog = {
     "%curr% of %total%": "%curr% z %total%",
     "(If left blank, owner will be admin)": "(Pokud je pr\u00e1zdn\u00e9, vlastn\u00edkem bude Admin)",
-    "(at least {passwordLength} characters)": "(nejm\u00e9n\u011b {passwordLength} znak\u016f)",
     "(at least {placeholder} characters)": "(nejm\u00e9n\u011b {placeholder} znak\u016f)",
     "(current notification)": "(aktu\u00e1ln\u00ed upozorn\u011bn\u00ed)",
     "(current version)": "(aktu\u00e1ln\u00ed verze)",
@@ -56,21 +56,18 @@
     "Add": "P\u0159idat",
     "Add Admin": "P\u0159idat spr\u00e1vce",
     "Add Admins": "P\u0159idat Administr\u00e1tory",
-    "Add File": "P\u0159idat soubor",
     "Add Institution": "P\u0159idat instituci",
     "Add Library": "P\u0159idat knihovnu",
     "Add Member": "P\u0159idat \u010dlena",
     "Add Organization": "P\u0159idat organizaci",
     "Add Terms and Conditions": "P\u0159idat pravidla a podm\u00ednky",
     "Add User": "P\u0159idat u\u017eivatele",
-    "Add a comment.": "P\u0159idat koment\u00e1\u0159.",
     "Add admin": "P\u0159idat Administr\u00e1tora",
     "Add auto expiration": "P\u0159idat automatickou expiraci",
     "Add group member": "P\u0159idat \u010dlena skupiny",
     "Add institution": "P\u0159idat instituci",
     "Add new notification": "P\u0159idat nov\u00e9 upozorn\u011bn\u00ed",
     "Add new reviewer": "P\u0159idat kontroln\u00edho u\u017eivatele",
-    "Add participants": "P\u0159idat \u00fa\u010dastn\u00edky",
     "Add password protection": "P\u0159idat ochranu heslem",
     "Add user": "P\u0159idat u\u017eivatele",
     "Added": "P\u0159id\u00e1no",
@@ -88,7 +85,6 @@
     "All Public Links": "V\u0161echny ve\u0159ejn\u00e9 odkazy",
     "All file types": "V\u0161echny typy soubor\u016f",
     "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Povolit registrace nov\u00fdm u\u017eivatel\u016fm. Od\u0161krtn\u011bte tuto polo\u017eku pro zak\u00e1z\u00e1n\u00ed vytv\u00e1\u0159en\u00ed nov\u00fdch u\u017eivatelsk\u00fdch \u00fa\u010dt\u016f.",
-    "Allow user to add organization libraries. Otherwise, only system admin can add organization libraries.": "Povolit u\u017eivatel\u016fm p\u0159id\u00e1vat knihovny organizace. V opa\u010dn\u00e9m p\u0159\u00edpad\u011b pouze syst\u00e9mov\u00fd administr\u00e1tor bude moci p\u0159id\u00e1vat knihovny organizace.",
     "Allow user to change library history settings": "Povolit u\u017eivatel\u016fm zm\u011bnu nastaven\u00ed historie knihovny",
     "Allow user to clean library trash": "Povolit u\u017eivateli vypr\u00e1zdnit ko\u0161 knihovny",
     "Allow user to create encrypted libraries": "Povolit u\u017eivatel\u016fm vytv\u00e1\u0159et \u0161ifrovan\u00e9 knihovny",
@@ -120,7 +116,6 @@
     "At server": "Na serveru",
     "Audio": "Audio",
     "Audit Admin": "Auditn\u00ed administr\u00e1tor",
-    "Author": "Autor",
     "Auto deletion": "Automatick\u00e9 maz\u00e1n\u00ed",
     "Automatically delete files that are not modified within certain days:": "Automaticky mazat soubory, kter\u00e9 nejsou zm\u011bn\u011bny b\u011bhem ur\u010dit\u00fdch dn\u00ed:",
     "Avatar": "Profilov\u00fd obr\u00e1zek",
@@ -138,7 +133,6 @@
     "By time descending": "Podle \u010dasu sestupn\u011b",
     "Can not copy directory %(src)s to its subdirectory %(des)s": "Nemohu zkop\u00edrovat adres\u00e1\u0159 %(src)s do podadres\u00e1\u0159e %(des)s",
     "Can not move directory %(src)s to its subdirectory %(des)s": "Nemohu p\u0159esunout adres\u00e1\u0159 %(src)s do podadres\u00e1\u0159e %(des)s",
-    "Can not select self as a related file.": "Nelze vybrat a t\u00edm odk\u00e1zat soubor s\u00e1m na sebe.",
     "Cancel": "Zru\u0161it",
     "Cancel All": "Zru\u0161it v\u0161e",
     "Canceled.": "Zru\u0161eno.",
@@ -157,8 +151,6 @@
     "Close": "Zav\u0159\u00edt",
     "Close (Esc)": "Zav\u0159\u00edt (Esc)",
     "Column": "Sloupec",
-    "Comment": "Koment\u00e1\u0159",
-    "Comments": "Koment\u00e1\u0159e",
     "Community Edition": "Komunitn\u00ed vyd\u00e1n\u00ed",
     "Confirm": "Potvrdit",
     "Confirm Password": "Potvrzen\u00ed hesla",
@@ -168,7 +160,6 @@
     "Contact Information": "Kontaktn\u00ed informace",
     "Contact information is required.": "Jsou po\u017eadov\u00e1ny kontaktn\u00ed informace",
     "Content Scan Records": "Z\u00e1znamy skenu obsahu",
-    "Contents": "Obsah",
     "Copy": "Kop\u00edrovat",
     "Copy selected item(s) to:": "Zkop\u00edrovat ozna\u010denou polo\u017eku(ky) do:",
     "Copy {num} items": "Kop\u00edrovat {num} polo\u017eek",
@@ -178,6 +169,7 @@
     "Copying file %(index)s of %(total)s": "Kop\u00edrov\u00e1n\u00ed souboru %(index)s ze %(total)s",
     "Copyright Infringement": "Poru\u0161en\u00ed autorsk\u00fdch pr\u00e1v",
     "Count": "Po\u010det",
+    "Create": "Vytvo\u0159it",
     "Create Group": "Vytvo\u0159it skupinu",
     "Create Library": "Vytvo\u0159it knihovnu",
     "Create Report": "Vy\u010distit report",
@@ -207,7 +199,6 @@
     "Date Invalid.": "Neplatn\u00fd datum",
     "Default": "V\u00fdchoz\u00ed",
     "Default Admin": "V\u00fdchoz\u00ed administr\u00e1tor",
-    "Default Size": "V\u00fdchoz\u00ed velikost",
     "Delete": "Smazat",
     "Delete Account": "Smazat \u00fa\u010det",
     "Delete Department": "Smazat odd\u011blen\u00ed",
@@ -242,8 +233,8 @@
     "Deleted user {user}": "U\u017eivatel {user} byl smaz\u00e1n",
     "Departments": "Odd\u011blen\u00ed",
     "Description": "Popis",
+    "Description is required": "Popis je povinn\u00fd",
     "Desktop": "Desktop",
-    "Detail": "Detail",
     "Details": "Detaily",
     "Device": "Za\u0159\u00edzen\u00ed",
     "Device Name": "Jm\u00e9no za\u0159\u00edzen\u00ed",
@@ -265,16 +256,12 @@
     "Download an example file": "St\u00e1hnout uk\u00e1zkov\u00fd soubor",
     "Download and upload": "St\u00e1hnout a nahr\u00e1t",
     "Draft": "Koncept",
-    "Draft has been deleted.": "N\u00e1vrh byl smaz\u00e1n.",
     "Draft is a way to let you collaborate with others on files. You can create a draft from a file, edit the draft and then ask for a review. The original file will be updated only after the draft has been reviewed.": "Koncept je zp\u016fsob, jak v\u00e1m umo\u017en\u00ed spolupracovat s ostatn\u00edmi na souborech. M\u016f\u017eete vytvo\u0159it koncept ze souboru, upravit koncept a pot\u00e9 po\u017e\u00e1dat o kontrolu. P\u016fvodn\u00ed soubor bude aktualizov\u00e1n a\u017e po revizi konceptu.",
     "Drafts": "N\u00e1vrhy",
     "Drag and drop files or folders here.": "Sem p\u0159et\u00e1hn\u011bte soubory nebo slo\u017eky.",
     "Edit": "Upravit",
-    "Edit Draft": "Upravit n\u00e1vrh",
     "Edit File": "Upravit soubor",
-    "Edit Tag": "Upravit \u0161t\u00edtek",
     "Edit failed": "Editace selhala.",
-    "Edit failed.": "Editace selhala.",
     "Edit labels": "Upravit \u0161t\u00edtky",
     "Edit on cloud and download": "Upravit v cloudu a st\u00e1hnout",
     "Edit on cloud only": "Upravit pouze na cloudu",
@@ -319,7 +306,6 @@
     "Failed to delete %(virus_file) from library %(library): %(error_msg)": "Nepoda\u0159ilo se odstranit %(virus_file) z knihovny %(library): %(error_msg)",
     "Failed to delete draft %(draft)s.": "Ne\u00fasp\u011b\u0161n\u011b smazan\u00fd n\u00e1vrh %(draft)s.",
     "Failed to delete {name}": "Chyba p\u0159i odstran\u011bn\u00ed {name}",
-    "Failed to delete {name} and other {n} items.": "Nepoda\u0159ilo se smazat {name} a {n} dal\u0161\u00edch polo\u017eek.",
     "Failed to delete {name}.": "Chyba p\u0159i odstran\u011bn\u00ed {name}.",
     "Failed to get update url": "Chyba p\u0159i z\u00edsk\u00e1v\u00e1n\u00ed url aktualizace",
     "Failed to get upload url": "Chyba p\u0159i z\u00edsk\u00e1v\u00e1n\u00ed url nahr\u00e1v\u00e1n\u00ed",
@@ -357,7 +343,6 @@
     "File is too small": "Soubor je p\u0159\u00edli\u017e mal\u00fd",
     "File size is too large.": "Velikost souboru je p\u0159\u00edli\u0161 velk\u00e1.",
     "File size should be smaller than {max_size_placeholder}.": "Velikost souboru by m\u011bla b\u00fdt men\u0161\u00ed ne\u017e {max_size_placeholder}.",
-    "File {file_link} has a new comment form user {author}.": "{author} p\u0159idal nov\u00fd koment\u00e1\u0159 k souboru {file_link}.",
     "Files": "Soubory",
     "Filetype not allowed": "Typ souboru nen\u00ed povolen",
     "Folder": "Slo\u017eka",
@@ -385,7 +370,6 @@
     "History Setting": "Nastaven\u00ed historie",
     "History Versions": "Historie verz\u00ed",
     "IP": "IP",
-    "If the share link is deleted, no one will be able to access it any more.": "Smaz\u00e1n\u00edm sd\u00edlec\u00edho odkazu bude v\u0161em odep\u0159en p\u0159\u00edstup.",
     "If turn on, the desktop clients will not be able to sync a folder outside the default Seafile folder.": "Pokud bude zapnut\u00e9, desktopov\u00ed klienti nebudou schopni synchronizovat slo\u017eky mimo v\u00fdchoz\u00ed Seafile slo\u017eku. ",
     "If you don't have any device with you, you can access your account using backup codes.": "Pokud nem\u00e1te u sebe \u017e\u00e1dn\u00e9 za\u0159\u00edzen\u00ed, m\u016f\u017eete p\u0159isupovat k Va\u0161emu \u00fa\u010dtu pomoc\u00ed z\u00e1lo\u017en\u00edch k\u00f3d\u016f.",
     "Ignore": "Ignorovat",
@@ -394,6 +378,7 @@
     "Images": "Obr\u00e1zky",
     "Import Members": "Importovat \u010dleny",
     "Import Users": "Importovat u\u017eivatele",
+    "Import users": "Importovat u\u017eivatele",
     "Import users from a .xlsx file": "Importovat u\u017eivatele z XLSX souboru",
     "In all libraries": "Ve v\u0161ech knihovn\u00e1ch",
     "Inactive": "Neaktivn\u00ed",
@@ -417,7 +402,6 @@
     "Invitations": "Pozv\u00e1nky",
     "Invite Guest": "Pozvat hosta",
     "Invite Time": "\u010cas pozv\u00e1n\u00ed",
-    "Invite user": "Pozvat u\u017eivatele",
     "Invited at": "Pozv\u00e1n v",
     "Inviter": "Hostilel",
     "It is required.": "Vy\u017eadov\u00e1no.",
@@ -441,7 +425,6 @@
     "Less than or equal to {maxDays_placeholder} days": "Men\u0161\u00ed nebo rovno {maxDays_placeholder} dn\u00ed",
     "Libraries": "Knihovny",
     "Library": "Knihovna",
-    "Library Name": "N\u00e1zev knihovny",
     "Library Type": "Typ knihovny",
     "Library can not be shared to owner.": "Knihovna nem\u016f\u017ee b\u00fdt sd\u00edlena jej\u00edmu vlastn\u00edkovi.",
     "Limits": "Limity",
@@ -455,6 +438,7 @@
     "Loading failed": "Nahr\u00e1v\u00e1n\u00ed selhalo",
     "Loading...": "Nahr\u00e1v\u00e1m...",
     "Local draft": "M\u00edstn\u00ed koncept",
+    "Local draft saved": "M\u00edstn\u00ed koncept byl ulo\u017een",
     "Location": "Um\u00edst\u011bn\u00ed",
     "Lock": "Z\u00e1mek",
     "Log out": "Odhl\u00e1stit",
@@ -464,7 +448,6 @@
     "Manage Members": "Spravovat \u010dleny",
     "Manage group members": "Spravovat \u010dleny skupiny",
     "Mark all read": "Ozna\u010dit v\u0161e jako p\u0159e\u010dten\u00e9",
-    "Mark as resolved": "Ozna\u010dit jako vy\u0159e\u0161en\u00e9",
     "Max number of files exceeded": "Maxim\u00e1ln\u00ed po\u010det soubor\u016f p\u0159ekro\u010den",
     "Member": "\u010clen",
     "Members": "\u010clenov\u00e9",
@@ -523,9 +506,9 @@
     "New passwords don't match": "Zad\u00e1n\u00ed nov\u00e9ho hesla se neshoduj\u00ed",
     "Next": "Dal\u0161\u00ed",
     "Next (Right arrow key)": "N\u00e1sleduj\u00edc\u00ed (\u0161ipkou vpravo)",
+    "No": "Ne",
     "No Admin login logs": "\u017d\u00e1dn\u00e9 z\u00e1znamy o p\u0159ihl\u00e1\u0161en\u00edch spr\u00e1vce",
     "No Admin operation logs": "\u017d\u00e1dn\u00e9 protokoly operac\u00ed spr\u00e1vce",
-    "No comment yet.": "\u017d\u00e1dn\u00e9 koment\u00e1\u0159e",
     "No connected devices": "\u017d\u00e1dn\u00e1 p\u0159ipojen\u00e1 za\u0159\u00edzen\u00ed",
     "No deleted libraries": "\u017d\u00e1dn\u00e9 smazan\u00e9 knihovny",
     "No departments": "\u017d\u00e1dn\u00e9 odd\u011blen\u00ed",
@@ -556,7 +539,6 @@
     "No published libraries": "\u017d\u00e1dn\u00e9 zve\u0159ejn\u011bn\u00e9 knihovny",
     "No result": "\u017d\u00e1dn\u00fd v\u00fdsledek",
     "No results matching.": "\u017d\u00e1dn\u00fd v\u00fdsledek",
-    "No reviewer yet.": "Zat\u00edm bez kontroln\u00edho u\u017eivatele.",
     "No share links": "\u017d\u00e1dn\u00e9 odkazy pro sd\u00edlen\u00ed",
     "No shared libraries": "\u017d\u00e1dn\u00e9 sd\u00edlen\u00e9 knihovny",
     "No sub-departments": "\u017d\u00e1dn\u00e9 pododd\u011blen\u00ed",
@@ -567,7 +549,6 @@
     "Note: Settings via web interface are saved in database table (seahub-db/constance_config). They have a higher priority over the settings in config files.": "Pozn\u00e1mka: nastaven\u00ed p\u0159es webov\u00e9 rozhran\u00ed jsou ulo\u017eena v datab\u00e1zi, v tabulce (seahub-db/constance_config). Maj\u00ed vy\u0161\u0161\u00ed prioritu ne\u017e nastaven\u00ed v konfigura\u010dn\u00edch souborech.",
     "Notification Detail": "Detail upozorn\u011bn\u00ed",
     "Notifications": "Upozorn\u011bn\u00ed",
-    "Number of changes:": "Po\u010det zm\u011bn:",
     "Number of days that keep user sign in.": "Po\u010det dn\u00ed po, kter\u00e9 z\u016fstanete p\u0159ihl\u00e1\u0161en.",
     "Number of groups": "Po\u010det skupin",
     "Off": "Vypnuto",
@@ -594,7 +575,6 @@
     "Organization": "Organizace",
     "Organization Admin": "Spr\u00e1vce organizace",
     "Organizations": "Organizace",
-    "Original file has been deleted.": "P\u016fvodn\u00ed soubor byl smaz\u00e1n.",
     "Other": "Ostatn\u00ed",
     "Other Libraries": "Ostatn\u00ed knihovny",
     "Out of quota.": "Nedostatek \u00falo\u017en\u00e9ho prostoru - mimo kv\u00f3tu.",
@@ -602,7 +582,6 @@
     "Owner": "Vlastn\u00edk",
     "Owner can use admin panel in an organization, must be a new account.": "Vlastn\u00edk m\u016f\u017ee pou\u017e\u00edt panel v organizaci, mus\u00ed b\u00fdt nov\u00fd \u00fa\u010det.",
     "Packaging...": "Balen\u00ed\u2026",
-    "Participants": "\u00da\u010dastn\u00edci",
     "Password": "Heslo",
     "Password again": "Heslo znovu",
     "Password is required.": "Heslo je vy\u017eadov\u00e1no.",
@@ -644,16 +623,13 @@
     "Preview only": "Pouze zobrazit",
     "Previous": "P\u0159edchoz\u00ed",
     "Previous (Left arrow key)": "P\u0159edchoz\u00ed (\u0161ipkou vlevo)",
-    "Private": "Soukrom\u00fd",
     "Processing...": "Zpracov\u00e1v\u00e1m...",
     "Professional Edition": "Komer\u010dn\u00ed vyd\u00e1n\u00ed",
     "Profile": "Profil",
     "Profile Setting": "Nastaven\u00ed profilu",
-    "Public": "Ve\u0159ejn\u00fd",
     "Publish": "Zve\u0159ejnit",
     "Publish a Library": "Zve\u0159ejnit knihovnu",
     "Publish draft": "Zve\u0159ejnit n\u00e1vrh",
-    "Published": "Zve\u0159ejn\u011bn\u00e9",
     "Published Libraries": "Zve\u0159ejn\u011bn\u00e9 knihovny",
     "Quota": "Kv\u00f3ta",
     "Quota is invalid.": "Neplatn\u00e1 kv\u00f3ta.",
@@ -667,7 +643,6 @@
     "Really want to delete your account?": "Opravdu chcete smazat sv\u016fj \u00fa\u010det?",
     "Really want to leave this group?": "Skute\u010dn\u011b chcete opustit tuto skupinu?",
     "Refresh": "Obnovit",
-    "Related Files": "Souvisej\u00edc\u00ed soubory",
     "Remaining": "Zb\u00fdv\u00e1",
     "Remove": "Odstranit",
     "Remove Member": "Odebrat \u010dlena",
@@ -704,8 +679,6 @@
     "Result": "V\u00fdsledek",
     "Retry": "Opakovat",
     "Retry All": "Opakovat v\u0161e",
-    "Review": "Zkontrolovat",
-    "Reviewers": "Kontroln\u00ed u\u017eivatel\u00e9",
     "Revoke": "Zru\u0161it",
     "Revoke Access": "Odebrat p\u0159\u00edstup",
     "Revoke Admin": "Odvolat Admina",
@@ -716,37 +689,28 @@
     "Saving...": "Ukl\u00e1d\u00e1m...",
     "Seafile": "Seafile",
     "Search": "Hledat",
-    "Search Files": "Vyhledat soubory",
     "Search Groups": "Hledat skupiny",
     "Search Libraries": "Hledat knihovny",
     "Search Organizations": "Hledat v organizac\u00edch",
     "Search Users": "Hledat u\u017eivatele",
     "Search files in this library": "Vyhledat soubory v t\u00e9to knihovn\u011b",
+    "Search groups": "Vyhledat skupiny",
     "Search groups by name": "Hledat skupiny podle n\u00e1zvu",
-    "Search libraries by name": "Hledat knihovny podle jm\u00e9na",
     "Search libraries by owner": "Hledat v knihovn\u00e1ch podle vlastn\u00edka",
     "Search organizations": "Hledat organizace",
     "Search users": "Vyhledat u\u017eivatele",
-    "Search users...": "Vyhledat u\u017eivatele...",
-    "Search...": "Hledat...",
     "Searching...": "Vyhled\u00e1v\u00e1m...",
-    "See All Notifications": "Prohl\u00ed\u017eet v\u0161echna upozorn\u011bn\u00ed",
     "Select File": "Vybrat soubor",
     "Select Image": "Vybrat obr\u00e1zek",
     "Select Tags": "Vybrat \u0161t\u00edtky",
     "Select a color": "Vybrat barvu",
     "Select a department": "Vybrat odd\u011blen\u00ed",
     "Select a group": "Vyberte skupinu",
-    "Select a server...": "Vybrat server...",
     "Select a user": "Vybrat u\u017eivatele",
-    "Select a user as admin...": "Vybrat u\u017eivatele jako administr\u00e1tora...",
     "Select groups": "Vyberte skupiny",
-    "Select groups...": "Vybrat skupiny...",
     "Select libraries to share": "Vyberte knihovnu ke sd\u00edlen\u00ed",
-    "Select related file for {placeholder}": "Vyberte souvisej\u00edc\u00ed soubor pro {placeholder}",
     "Send": "Odeslat",
     "Send activation Email after user registration.": "Odes\u00edlat aktiva\u010dn\u00ed e-mail po registraci.",
-    "Send the invitation link to the others, and they will be able to join the organization via scanning the QR code.": "Ode\u0161lete zvac\u00ed odkaz ostatn\u00edm a oni budou schopni se p\u0159ipojit do organizace pomoc\u00ed naskenov\u00e1n\u00ed QR k\u00f3du.",
     "Send to:": "Odeslat na:",
     "Sending new password...": "Odes\u00edl\u00e1n\u00ed nov\u00e9ho hesla...",
     "Sending...": "Odes\u00edl\u00e1m...",
@@ -774,7 +738,6 @@
     "Share Link": "Ve\u0159ejn\u00fd odkaz",
     "Share Link Traffic": "Provoz sd\u00edlec\u00edho odkazu",
     "Share Links": "Ve\u0159ejn\u00e9 odkazy",
-    "Share Links Admin": "Sd\u00edlen\u00e9 odkazy Admin",
     "Share To": "Sd\u00edlet s",
     "Share To:": "Sd\u00edlet s:",
     "Share existing libraries": "Sd\u00edlet existuj\u00edc\u00ed knihovny",
@@ -796,7 +759,6 @@
     "Shared with me": "Sd\u00edleno se mnou",
     "Show": "Zobraz",
     "Show Codes": "Zobrazit k\u00f3dy",
-    "Show resolved comments": "Zobrazit vy\u0159e\u0161en\u00e9 koment\u00e1\u0159e",
     "Side Nav Menu": "Postrann\u00ed naviga\u010dn\u00ed nab\u00eddka",
     "Site name used in email sending": "N\u00e1zev str\u00e1nky pou\u017eit\u00fd v odeslan\u00fdch e-mailech",
     "Site title shown in a browser tab": "Titulek str\u00e1nky je zobrazen v z\u00e1lo\u017ece prohl\u00ed\u017ee\u010de.",
@@ -807,7 +769,6 @@
     "Star": "Hv\u011bzdi\u010dka",
     "Start": "Za\u010d\u00e1tek",
     "Start date": "Po\u010d\u00e1te\u010dn\u00ed datum",
-    "Start review": "Za\u010d\u00edt kontrolu",
     "Statistic": "Statistika",
     "Status": "Stav",
     "Status: enabled": "Stav: zapnuto",
@@ -830,12 +791,11 @@
     "Successfully deleted %(name)s and %(amount)s other items.": "\u00dasp\u011b\u0161n\u011b smaz\u00e1no %(name)s a %(amount)s dal\u0161\u00edch polo\u017eek.",
     "Successfully deleted %(name)s and 1 other item.": "\u00dasp\u011b\u0161n\u011b smaz\u00e1no %(name)s a 1 dal\u0161\u00ed polo\u017eka.",
     "Successfully deleted %(name)s.": "\u00dasp\u011b\u0161n\u011b smaz\u00e1n %(name)s.",
-    "Successfully deleted %s": "\u00dasp\u011b\u0161n\u011b smaz\u00e1no %s",
+    "Successfully deleted 1 item": "\u00dasp\u011b\u0161n\u011b smaz\u00e1na 1 polo\u017eka",
     "Successfully deleted 1 item.": "\u00dasp\u011b\u0161n\u011b smaz\u00e1na 1 polo\u017eka",
     "Successfully deleted 1 user.": "1 u\u017eivatel byl \u00fasp\u011b\u0161n\u011b smaz\u00e1n.",
     "Successfully deleted draft %(draft)s.": "\u00dasp\u011b\u0161n\u011b smazan\u00fd n\u00e1vrh %(draft)s.",
     "Successfully deleted {name}": "\u00dasp\u011b\u0161n\u011b smaz\u00e1n {name}",
-    "Successfully deleted {name} and other {n} items.": "{name} a {n} dal\u0161\u00ed polo\u017eky smaz\u00e1ny.",
     "Successfully deleted {name}.": "\u00dasp\u011b\u0161n\u011b smz\u00e1n {name}.",
     "Successfully deleted {user_number_placeholder} users.": "\u00dasp\u011b\u0161n\u011b smaz\u00e1no {user_number_placeholder} u\u017eivatel\u016f.",
     "Successfully edited labels.": "\u0160t\u00edtky byly \u00fasp\u011b\u0161n\u011b upraveny.",
@@ -861,9 +821,6 @@
     "Successfully set %s as admin.": "U\u017eivatel %s byl \u00fasp\u011b\u0161n\u011b nastaven jako Admin",
     "Successfully set it.": "\u00dasp\u011b\u0161n\u011b nastaveno.",
     "Successfully set library history.": "Nastaven\u00ed historie knihovny bylo \u00fasp\u011b\u0161n\u00e9.",
-    "Successfully set max number of members.": "\u00dasp\u011b\u0161n\u011b nastaven maxim\u00e1ln\u00ed po\u010det \u010dlen\u016f.",
-    "Successfully set name.": "Jm\u00e9no bylo \u00fasp\u011b\u0161n\u011b nastaveno",
-    "Successfully set quota.": "Kv\u00f3ta byla \u00fasp\u011b\u0161n\u011b nastavena.",
     "Successfully starred {library_name_placeholder}.": "\u00dasp\u011b\u0161n\u011b ozna\u010deno hv\u011bzdi\u010dkou {library_name_placeholder}.",
     "Successfully transferred the group.": "Skupina byla \u00fasp\u011b\u0161n\u011b p\u0159esunuta.",
     "Successfully transferred the library.": "Knihovna byla \u00fasp\u011b\u0161n\u011b p\u0159esunuta.",
@@ -894,9 +851,7 @@
     "Text is required.": "Je vy\u017eadov\u00e1n text.",
     "The URL of the server, like https://seafile.example.com or http://192.168.1.2:8000": "URL serveru jako https://seafile.example.com nebo http://192.168.1.2:8000",
     "The file is too large. Allowed maximum size is 1MB.": "Soubor je p\u0159\u00edli\u0161 velk\u00fd. Nejvy\u0161\u0161\u00ed umo\u017en\u011bn\u00e1 velikost je 1MB.",
-    "The image could not be loaded.": "Obr\u00e1zek nejde na\u010d\u00edst.",
     "The internal URL for downloading/uploading files. Users will not be able to download/upload files if this is not set correctly. If you config Seafile behind Nginx/Apache, it should be SERVICE_URL/seafhttp, like https://seafile.example.com/seafhttp .": "Intern\u00ed URL pro nahr\u00e1v\u00e1n\u00ed/stahov\u00e1n\u00ed soubor\u016f. U\u017eivatel\u00e9 nebudou schopni nahr\u00e1vat/stahovat, jestli\u017ee tato mo\u017enost nebude nastavena spr\u00e1vn\u011b. Pokud m\u00e1te Seafile zprovozn\u011bn\u00fd za Nginx/Apache, m\u011blo by to b\u00fdt URL_SLU\u017dBY/seafhttp, jako t\u0159eba https://seafile.example.com/seafhttp .",
-    "The least number of characters a download/upload link password should include.": "Minim\u00e1ln\u00ed po\u010det znak\u016f, kter\u00e9 by heslo pro download/upload odkazy m\u011blo obsahovat.",
     "The least number of characters an account password should include.": "Minim\u00e1ln\u00ed po\u010det znak\u016f, kter\u00e9 by heslo m\u011blo obsahovat.",
     "The least number of characters an encrypted library password should include.": "Minim\u00e1ln\u00ed po\u010det znak\u016f, kter\u00e9 by heslo knihovny m\u011blo obsahovat",
     "The level(1-4) of an account password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols": "\u00darove\u0148 (1-4) s\u00edly hesla. Nap\u0159\u00edklad '3' znamen\u00e1, \u017ee heslo mus\u00ed obsahovat minim\u00e1ln\u011b 3 v\u011bci z n\u00e1sleduj\u00edc\u00edho seznamu: \u010d\u00edslo, velk\u00e9 p\u00edsmeno, mal\u00e9 p\u00edsmeno, speci\u00e1ln\u00ed znaky",
@@ -909,7 +864,6 @@
     "This file has been updated.": "Tento soubor byl aktualizov\u00e1n.",
     "This file is in draft stage.": "Tento soubor je ve f\u00e1zi n\u00e1vrhu.",
     "This folder has no content at this time.": "Tato slo\u017eka aktu\u00e1ln\u011b nic neobsahuje.",
-    "This is a draft": "Toto je n\u00e1vrh",
     "This is a special group representing a department.": "Toto je speci\u00e1ln\u00ed skupina reprezentuj\u00edc\u00ed odd\u011blen\u00ed.",
     "This library has been set to read-only by admin and cannot be updated.": "Tato knihovna byla nastavena spr\u00e1vcem pouze pro \u010dten\u00ed a nelze ji aktualizovat.",
     "This library is password protected": "Tato knihovna je chr\u00e1n\u011bna heslem",
@@ -949,7 +903,6 @@
     "Unlock": "Odemknout",
     "Unpublish": "Zru\u0161it zve\u0159ejn\u011bn\u00ed",
     "Unpublish Library": "Zru\u0161it zve\u0159ejn\u011bn\u00ed knihovny",
-    "Unresolved comments:": "Nevy\u0159e\u0161en\u00e9 koment\u00e1\u0159e:",
     "Unshare": "Zru\u0161it sd\u00edlen\u00ed",
     "Unshare Library": "Zru\u0161it sd\u00edlen\u00ed knihovny",
     "Unstar": "Odebrat z obl\u00edben\u00fdch",
@@ -986,6 +939,7 @@
     "User {user_link} has added you to {group_link}": "U\u017eivatel {user_link} V\u00e1s p\u0159idal do skupiny {group_link}",
     "Username:": "U\u017eivatelsk\u00e9 jm\u00e9no:",
     "Users": "U\u017eivatel\u00e9",
+    "Verify": "Ov\u011b\u0159it",
     "Version": "Verze",
     "Version Number": "\u010c\u00edslo verze",
     "Version Number is required.": "\u010c\u00edslo verze je povinn\u00e9.",
@@ -995,7 +949,7 @@
     "View Draft": "Zobrazit koncept",
     "View Link": "Zobrazit odkaz",
     "View Snapshot": "Prohl\u00e9dnout Snapshot",
-    "View diff": "Zobrazit rozd\u00edl",
+    "View profile and more": "Zobrazit profil a v\u00edce",
     "Virus": "Virus",
     "Virus File": "Naka\u017een\u00fd soubor",
     "Virus Scan": "Virov\u00e1 kontrola",
@@ -1008,6 +962,7 @@
     "WebDav Password": "WebDav heslo",
     "Welcome to {site_name_placeholder}": "V\u00edtejte v {site_name_placeholder}",
     "Wrong password": "Chybn\u00e9 heslo",
+    "Yes": "Ano",
     "You are not in any groups. Groups allow multiple people to collaborate on libraries. Groups you join will be listed here.": "Nejste v \u017e\u00e1dn\u00e9 skupin\u011b. Skupiny umo\u017e\u0148uj\u00ed v\u00edce lidem spolupracovat na knihovn\u00e1ch. Zde budou uvedeny skupiny, ke kter\u00fdm se p\u0159ipoj\u00edte.",
     "You are not in any groups. Groups allow multiple people to collaborate on libraries. You can create a group by clicking the \"New Group\" button in the menu bar.": "Nejste v \u017e\u00e1dn\u00e9 skupin\u011b. Skupiny umo\u017e\u0148uj\u00ed v\u00edce lidem spolupracovat na knihovn\u00e1ch. Skupinu m\u016f\u017eete vytvo\u0159it kliknut\u00edm na tla\u010d\u00edtko \u201eNov\u00e1 skupina\u201c na panelu nab\u00eddek.",
     "You can also add a user as a guest, who will not be allowed to create libraries and groups.": "M\u016f\u017eete tak\u00e9 p\u0159idat u\u017eivatele jako hosta, kter\u00fd nebude opr\u00e1vn\u011bn vytv\u00e1\u0159et knihovny a skupiny.",
@@ -1032,11 +987,8 @@
     "You have only one backup code remaining.": "Zb\u00fdv\u00e1 v\u00e1m pouze jeden z\u00e1lo\u017en\u00ed k\u00f3d.",
     "You have {num} backup codes remaining.": "Zb\u00fdv\u00e1 v\u00e1m {num} z\u00e1lo\u017en\u00edch k\u00f3d\u016f.",
     "Your notifications will be sent to this email.": "Va\u0161e upozorn\u011bn\u00ed bude odesl\u00e1no na tento e-mail.",
+    "ZIP": "ZIP",
     "ZIP Selected Items": "Zkomprimovat vybran\u00e9 polo\u017eky do form\u00e1tu ZIP",
-    "Zoom In": "P\u0159ibl\u00ed\u017eit",
-    "Zoom Out": "Odd\u00e1lit",
-    "Zoom in": "P\u0159ibl\u00ed\u017eit",
-    "Zoom out": "Odd\u00e1lit",
     "activate after registration": "aktivovat po registraci",
     "all": "v\u0161e",
     "all members": "v\u0161ichni \u010dlenov\u00e9",
@@ -1045,11 +997,7 @@
     "days": "dn\u00ed",
     "deleted": "Smaz\u00e1no",
     "details": "detaily",
-    "download/upload link password minimum length": "minim\u00e1ln\u00ed d\u00e9lka heslo pro odkaz download/upload",
-    "draft": "koncept",
     "email is required": "Email je povinn\u00fd",
-    "file": "soubor",
-    "files": "soubory",
     "icon": "ikona",
     "keep sign in": "z\u016fstat p\u0159ihl\u00e1\u0161en",
     "library password minimum length": "minim\u00e1ln\u00ed d\u00e9lka hesla knihovny",
@@ -1062,7 +1010,6 @@
     "password minimum length": "minim\u00e1ln\u00ed d\u00e9lka hesla",
     "password strength level": "\u00farove\u0148 s\u00edly hesla",
     "progress": "postup",
-    "related files": "souvisej\u00edc\u00ed soubory",
     "result": "v\u00fdsledek",
     "results": "v\u00fdsledky",
     "send activation email": "odes\u00edlat aktiva\u010dn\u00ed e-mail",
@@ -1085,7 +1032,6 @@
     "{placeholder} API Token": "{placeholder} API Token",
     "{placeholder} Folder Permission": "Opr\u00e1vn\u011bn\u00ed slo\u017eky {placeholder} ",
     "{placeholder} Modification History": "{placeholder} Historie zm\u011bn",
-    "{placeholder} Share/Upload Links": "{placeholder} Sd\u00edlet/nahr\u00e1t odkazy",
     "{placeholder} Snapshot": "Zachycen\u00fd stav {placeholder}",
     "{placeholder} Trash": "Ko\u0161 na {placeholder}",
     "{share_from} has shared a folder named {repo_link} to group {group_link}.": "{share_from} s Va\u0161\u00ed skupinou {group_link} sd\u00edl\u00ed slo\u017eku {repo_link}.",
@@ -1097,24 +1043,24 @@
     "{userCount} user(s) and {repoCount} libraries of this organization will also be deleted.": " {userCount} u\u017eivatel(\u016f) a {repoCount} knihovnen t\u00e9to organizace bude smaz\u00e1no.",
     "{user} has transfered a library named {repo_link} to you.": "{user} V\u00e1m p\u0159evedl knihovnu {repo_link}."
   };
-  for (var key in newcatalog) {
+  for (const key in newcatalog) {
     django.catalog[key] = newcatalog[key];
   }
   
 
   if (!django.jsi18n_initialized) {
     django.gettext = function(msgid) {
-      var value = django.catalog[msgid];
-      if (typeof(value) == 'undefined') {
+      const value = django.catalog[msgid];
+      if (typeof value === 'undefined') {
         return msgid;
       } else {
-        return (typeof(value) == 'string') ? value : value[0];
+        return (typeof value === 'string') ? value : value[0];
       }
     };
 
     django.ngettext = function(singular, plural, count) {
-      var value = django.catalog[singular];
-      if (typeof(value) == 'undefined') {
+      const value = django.catalog[singular];
+      if (typeof value === 'undefined') {
         return (count == 1) ? singular : plural;
       } else {
         return value.constructor === Array ? value[django.pluralidx(count)] : value;
@@ -1124,16 +1070,16 @@
     django.gettext_noop = function(msgid) { return msgid; };
 
     django.pgettext = function(context, msgid) {
-      var value = django.gettext(context + '\x04' + msgid);
-      if (value.indexOf('\x04') != -1) {
+      let value = django.gettext(context + '\x04' + msgid);
+      if (value.includes('\x04')) {
         value = msgid;
       }
       return value;
     };
 
     django.npgettext = function(context, singular, plural, count) {
-      var value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
-      if (value.indexOf('\x04') != -1) {
+      let value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
+      if (value.includes('\x04')) {
         value = django.ngettext(singular, plural, count);
       }
       return value;
@@ -1157,12 +1103,10 @@
       "%d.%m.%Y %H:%M:%S.%f",
       "%d.%m.%Y %H.%M",
       "%d.%m.%Y %H:%M",
-      "%d.%m.%Y",
       "%d. %m. %Y %H:%M:%S",
       "%d. %m. %Y %H:%M:%S.%f",
       "%d. %m. %Y %H.%M",
       "%d. %m. %Y %H:%M",
-      "%d. %m. %Y",
       "%Y-%m-%d %H.%M",
       "%Y-%m-%d %H:%M:%S",
       "%Y-%m-%d %H:%M:%S.%f",
@@ -1195,8 +1139,8 @@
   };
 
     django.get_format = function(format_type) {
-      var value = django.formats[format_type];
-      if (typeof(value) == 'undefined') {
+      const value = django.formats[format_type];
+      if (typeof value === 'undefined') {
         return format_type;
       } else {
         return value;
@@ -1215,6 +1159,5 @@
 
     django.jsi18n_initialized = true;
   }
-
-}(this));
+};
 
