@@ -1,13 +1,14 @@
 
 
-(function(globals) {
-
-  var django = globals.django || (globals.django = {});
+'use strict';
+{
+  const globals = this;
+  const django = globals.django || (globals.django = {});
 
   
   django.pluralidx = function(n) {
-    var v=(n != 1);
-    if (typeof(v) == 'boolean') {
+    const v = (n != 1);
+    if (typeof v === 'boolean') {
       return v ? 1 : 0;
     } else {
       return v;
@@ -19,8 +20,7 @@
 
   django.catalog = django.catalog || {};
   
-  var newcatalog = {
-    "%curr% of %total%": "%curr% kokonaism\u00e4\u00e4r\u00e4st\u00e4 %total%",
+  const newcatalog = {
     "(If left blank, owner will be admin)": "(jos j\u00e4tetty tyhj\u00e4ksi, omistaja on admin)",
     "(current notification)": "(nykyinen ilmoitus)",
     "(current version)": "(nykyinen versio",
@@ -70,7 +70,6 @@
     "All Public Links": "Kaikki julkiset linkit",
     "All file types": "Kaikki tiedostotyypit",
     "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Salli uusien k\u00e4ytt\u00e4jien rekister\u00f6itymisen. Poistamalla t\u00e4m\u00e4n valinnan est\u00e4\u00e4 uusien tilien luonnin.",
-    "Allow user to add organization libraries. Otherwise, only system admin can add organization libraries.": "Salli k\u00e4ytt\u00e4j\u00e4n lis\u00e4t\u00e4 organisaation tason kirjastoja. Muutoin, vain j\u00e4rjestelm\u00e4nvalvoja voi tehd\u00e4 organisaatio tason kirjastoja.",
     "Allow user to change library history settings": "Salli k\u00e4ytt\u00e4j\u00e4n muuttaa kirjastohistorian asetuksia",
     "Allow user to create encrypted libraries": "Salli k\u00e4ytt\u00e4j\u00e4n luoda salattuja kirjastoja",
     "An integer that is greater than 0 or equal to -2.": "Integer joka on suurempi kuin 0 tai samansuuruinen kuin -2.",
@@ -102,9 +101,6 @@
     "Clear files in trash and history\uff1a": "Poista historia ja tiedostot roskakorista :",
     "Clients": "Asiakasohjelmat",
     "Close": "Sulje",
-    "Close (Esc)": "Sulje (Esc)",
-    "Comment": "Kommentti",
-    "Comments": "Kommentit",
     "Community Edition": "Community versio",
     "Confirm Password": "Vahvista salasana",
     "Contact Email": "Yhteyss\u00e4hk\u00f6posti",
@@ -112,6 +108,7 @@
     "Copy": "Kopioi",
     "Copy selected item(s) to:": "Kopioi valitut kohteet:",
     "Count": "M\u00e4\u00e4r\u00e4",
+    "Create": "Luo",
     "Create Group": "Luo Ryhm\u00e4",
     "Create Library": "Luo Kirjasto",
     "Created": "Luotu",
@@ -155,8 +152,8 @@
     "Deleted user {user}": "Poistettu k\u00e4ytt\u00e4j\u00e4 {user}",
     "Departments": "Osastot",
     "Description": "Kuvaus",
+    "Description is required": "Kuvaus vaaditaan",
     "Desktop": "Desktop",
-    "Detail": "Selite",
     "Details": "Yksityiskohdat",
     "Device": "Laite",
     "Device Name": "Laitteen nimi",
@@ -170,7 +167,6 @@
     "Download": "Lataa",
     "Download an example file": "Lataa esimerkkitiedosto",
     "Edit": "Muokkaa",
-    "Edit failed.": "Muokkaus ep\u00e4onnistui.",
     "Edit labels": "Muokkaa etikettej\u00e4",
     "Edit on cloud and download": "Muokkaa pilvess\u00e4 ja lataa",
     "Edit succeeded": "Muokkaus onnistui",
@@ -217,6 +213,7 @@
     "Guest": "Vieras",
     "Handled": "K\u00e4sitelty",
     "Help": "Tuki",
+    "Hide": "Piilota",
     "History": "Historia",
     "History Setting": "Historian asetukset",
     "IP": "IP",
@@ -225,6 +222,7 @@
     "Image": "Kuva",
     "Images": "Kuvat",
     "Import Members": "Tuo j\u00e4seni\u00e4",
+    "Import users": "Tuo k\u00e4ytt\u00e4ji\u00e4",
     "Import users from a .xlsx file": "Tuo k\u00e4ytt\u00e4ji\u00e4 .xlsx tiedostosta",
     "In all libraries": "Kaikissa kirjastoissa",
     "Inactive": "Ei aktiivinen",
@@ -307,8 +305,7 @@
     "New password is too short": "Uusi salasana on liian lyhyt",
     "New passwords don't match": "Uudet salasanat eiv\u00e4t t\u00e4sm\u00e4\u00e4",
     "Next": "Seuraava",
-    "Next (Right arrow key)": "Seuraava (Oikea nuolin\u00e4pp\u00e4in)",
-    "No comment yet.": "Ei kommentteja viel\u00e4.",
+    "No": "Ei",
     "No connected devices": "Ei yhdistettyj\u00e4 laitteita",
     "No departments": "Ei osastoja",
     "No groups": "Ei ryhmi\u00e4",
@@ -331,7 +328,6 @@
     "Online Preview": "Online esikatselu",
     "Only Show": "N\u00e4yt\u00e4 vain",
     "Only keep a period of history:": "Pid\u00e4 historia ainoastaan tietyn ajan:",
-    "Open in New Tab": "Avaa uudessa v\u00e4lilehdess\u00e4",
     "Open parent folder": "Avaa is\u00e4nt\u00e4kansio",
     "Open via Client": "Avaa asiakasohjelmassa",
     "Operation": "Toimenpide",
@@ -366,7 +362,6 @@
     "Preview and download": "Esikatsele ja lataa",
     "Preview only": "Esikatselu ainoastaan",
     "Previous": "J\u00e4lkimm\u00e4inen",
-    "Previous (Left arrow key)": "Edellinen (Vasen nuolin\u00e4pp\u00e4in)",
     "Professional Edition": "Professional Edition",
     "Profile": "Profiili",
     "Profile Setting": "Profiilin asetus",
@@ -396,11 +391,10 @@
     "Role": "Rooli",
     "Saving...": "Tallennetaan...",
     "Seafile": "Seafile",
-    "Search Files": "Etsi tiedostoja",
     "Search files in this library": "Etsi tiedostoja t\u00e4st\u00e4 kirjastosta",
-    "Search users...": "Etsi k\u00e4ytt\u00e4ji\u00e4...",
-    "See All Notifications": "Katso kaikki ilmoitukset",
+    "Search groups": "Etsi ryhmi\u00e4",
     "Select a group": "Valitse ryhm\u00e4",
+    "Select groups": "Valitse ryhm\u00e4t",
     "Select libraries to share": "Valitse jaettavat kirjastot",
     "Send": "L\u00e4het\u00e4",
     "Send activation Email after user registration.": "L\u00e4het\u00e4 aktivointis\u00e4hk\u00f6posti k\u00e4ytt\u00e4j\u00e4n rekister\u00f6itymisen j\u00e4lkeen.",
@@ -430,6 +424,7 @@
     "Shared with all": "Jaettu kaikille",
     "Shared with groups": "Jaettu ryhmille",
     "Shared with me": "Jaettu minulle",
+    "Show": "N\u00e4yt\u00e4",
     "Show Codes": "N\u00e4yt\u00e4 Koodit",
     "Side Nav Menu": "Sivu Navigointi -valikko",
     "Site name used in email sending": "K\u00e4ytet\u00e4\u00e4n sivuston nime\u00e4 s\u00e4hk\u00f6postin l\u00e4hetyksess\u00e4",
@@ -449,7 +444,7 @@
     "Successfully copied %(name)s and %(amount)s other items.": "Kopioitiin onnistuneesti %(name)s ja %(amount)s muuta kohdetta.",
     "Successfully copied %(name)s and 1 other item.": "Kopioitiin onnistuneesti %(name)s ja 1 muu kohde.",
     "Successfully copied %(name)s.": "%(name)s kopioitiin onnistuneesti.",
-    "Successfully deleted %s": "Poistettu onnistuneesti %s",
+    "Successfully deleted 1 item": "Onnistuneesti tuhottu 1 kohde",
     "Successfully deleted 1 item.": "Onnistuneesti tuhottu 1 kohde.",
     "Successfully edited labels.": "Onnistuneesti muokattu etikettej\u00e4.",
     "Successfully invited %(email) and %(num) other people.": "Onnistuneesti kutsuttu %(email) ja %(num) muuta k\u00e4ytt\u00e4j\u00e4\u00e4.",
@@ -479,7 +474,6 @@
     "Text files": "Tekstitiedostot",
     "The URL of the server, like https://seafile.example.com or http://192.168.1.2:8000": "Palvelimen URL, kuten https://seafile.example.com tai http://192.168.1.2:8000",
     "The internal URL for downloading/uploading files. Users will not be able to download/upload files if this is not set correctly. If you config Seafile behind Nginx/Apache, it should be SERVICE_URL/seafhttp, like https://seafile.example.com/seafhttp .": "Sis\u00e4inen URL latauksia/l\u00e4hetyksi\u00e4 varten. K\u00e4ytt\u00e4j\u00e4t eiv\u00e4t voi ladata/l\u00e4hett\u00e4\u00e4 tiedostoja jos sit\u00e4 ei ole m\u00e4\u00e4ritetty oikein. Jos Seafile on asennettu Nginx/Apache taakse, sen pit\u00e4isi olla SERVICE_URL/seafhttp, kuten https://seafile.example.com/seafhttp .",
-    "The least number of characters a download/upload link password should include.": "V\u00e4himm\u00e4ism\u00e4\u00e4r\u00e4 lataus/l\u00e4hetys linkin salasanan merkeille.",
     "The least number of characters an account password should include.": "V\u00e4himm\u00e4ism\u00e4\u00e4r\u00e4 merkeille k\u00e4ytt\u00e4j\u00e4tunnuksen salasanassa.",
     "The least number of characters an encrypted library password should include.": "V\u00e4himm\u00e4ism\u00e4\u00e4r\u00e4 merkeille salatun kirjaston salasanassa.",
     "The level(1-4) of an account password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols": "Taso(1-4) tilin salasanan vahvuus. Esimerkiksi, '3' tarkoittaa salasanan pit\u00e4\u00e4 sis\u00e4lt\u00e4\u00e4 seuraavat, numero, iso kirjain, pieni kirjain ja muita symboleja.",
@@ -530,30 +524,32 @@
     "User Permission": "K\u00e4ytt\u00e4j\u00e4n oikeudet",
     "Username:": "K\u00e4ytt\u00e4j\u00e4nimi:",
     "Users": "K\u00e4ytt\u00e4j\u00e4t",
+    "Verify": "Vahvista",
     "Version": "Versiot",
     "Version Number": "Versionumero",
     "Video": "Video",
     "View": "Katso",
     "View Snapshot": "Katso tilannekuva",
+    "View profile and more": "Katse profiilia ja muita tietoja",
     "Virus File": "Virustiedosto",
     "Virus Scan": "Virusskannaus",
     "Visited": "Vierailtu",
     "Visits": "Vierailut",
     "Web Traffic": "Web Liikenne",
     "Wrong password": "V\u00e4\u00e4r\u00e4 salasana",
+    "Yes": "Kyll\u00e4",
     "You can also add a user as a guest, who will not be allowed to create libraries and groups.": "Voit my\u00f6s lis\u00e4t\u00e4 k\u00e4ytt\u00e4j\u00e4n vieraaksi jotka eiv\u00e4t voi luoda kirjastoja ja ryhmi\u00e4.",
     "You can create libraries by clicking the \"New Library\" button above.": "Voit luoda kirjastoja painamalla \"Uusi Kirjasto\" nappia ylh\u00e4\u00e4ll\u00e4.",
     "You can use this field at login.": "Voit k\u00e4ytt\u00e4\u00e4 t\u00e4t\u00e4 kentt\u00e4\u00e4 kirjautumisessa.",
     "You don't have any upload links": "Sinulla ei ole yht\u00e4\u00e4n l\u00e4hetyslinkki\u00e4",
     "You have not shared any folders": "Et ole jakanut yht\u00e4\u00e4n hakemistoa",
     "Your notifications will be sent to this email.": "Sinun ilmoitukset l\u00e4hetet\u00e4\u00e4n t\u00e4h\u00e4n s\u00e4hk\u00f6postiin.",
+    "ZIP": "ZIP",
     "activate after registration": "aktivoi rekister\u00f6innin j\u00e4lkeen",
     "all": "kaikki",
     "all members": "kaikki k\u00e4ytt\u00e4j\u00e4t",
     "allow new registrations": "salli uudet rekister\u00f6itymiset",
     "days": "p\u00e4iv\u00e4\u00e4",
-    "download/upload link password minimum length": "lataus/l\u00e4hetys linkin salasanan minimipituus",
-    "file": "tiedosto",
     "icon": "ikoni",
     "keep sign in": "pid\u00e4 sis\u00e4\u00e4nkirjautuneena",
     "library password minimum length": "kirjasto salasanan minimipituus",
@@ -570,24 +566,24 @@
     "you can also press \u2190 ": "voit painaa my\u00f6s \u2190 ",
     "{placeholder} Folder Permission": "{placeholder} Kansion oikeus"
   };
-  for (var key in newcatalog) {
+  for (const key in newcatalog) {
     django.catalog[key] = newcatalog[key];
   }
   
 
   if (!django.jsi18n_initialized) {
     django.gettext = function(msgid) {
-      var value = django.catalog[msgid];
-      if (typeof(value) == 'undefined') {
+      const value = django.catalog[msgid];
+      if (typeof value === 'undefined') {
         return msgid;
       } else {
-        return (typeof(value) == 'string') ? value : value[0];
+        return (typeof value === 'string') ? value : value[0];
       }
     };
 
     django.ngettext = function(singular, plural, count) {
-      var value = django.catalog[singular];
-      if (typeof(value) == 'undefined') {
+      const value = django.catalog[singular];
+      if (typeof value === 'undefined') {
         return (count == 1) ? singular : plural;
       } else {
         return value.constructor === Array ? value[django.pluralidx(count)] : value;
@@ -597,16 +593,16 @@
     django.gettext_noop = function(msgid) { return msgid; };
 
     django.pgettext = function(context, msgid) {
-      var value = django.gettext(context + '\x04' + msgid);
-      if (value.indexOf('\x04') != -1) {
+      let value = django.gettext(context + '\x04' + msgid);
+      if (value.includes('\x04')) {
         value = msgid;
       }
       return value;
     };
 
     django.npgettext = function(context, singular, plural, count) {
-      var value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
-      if (value.indexOf('\x04') != -1) {
+      let value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
+      if (value.includes('\x04')) {
         value = django.ngettext(singular, plural, count);
       }
       return value;
@@ -629,11 +625,9 @@
       "%d.%m.%Y %H.%M.%S",
       "%d.%m.%Y %H.%M.%S.%f",
       "%d.%m.%Y %H.%M",
-      "%d.%m.%Y",
       "%d.%m.%y %H.%M.%S",
       "%d.%m.%y %H.%M.%S.%f",
       "%d.%m.%y %H.%M",
-      "%d.%m.%y",
       "%Y-%m-%d %H:%M:%S",
       "%Y-%m-%d %H:%M:%S.%f",
       "%Y-%m-%d %H:%M",
@@ -665,8 +659,8 @@
   };
 
     django.get_format = function(format_type) {
-      var value = django.formats[format_type];
-      if (typeof(value) == 'undefined') {
+      const value = django.formats[format_type];
+      if (typeof value === 'undefined') {
         return format_type;
       } else {
         return value;
@@ -685,6 +679,5 @@
 
     django.jsi18n_initialized = true;
   }
-
-}(this));
+};
 
