@@ -1,13 +1,14 @@
 
 
-(function(globals) {
-
-  var django = globals.django || (globals.django = {});
+'use strict';
+{
+  const globals = this;
+  const django = globals.django || (globals.django = {});
 
   
   django.pluralidx = function(n) {
-    var v=(n != 1);
-    if (typeof(v) == 'boolean') {
+    const v = (n != 1);
+    if (typeof v === 'boolean') {
       return v ? 1 : 0;
     } else {
       return v;
@@ -19,8 +20,7 @@
 
   django.catalog = django.catalog || {};
   
-  var newcatalog = {
-    "%curr% of %total%": "%curr% / %total%",
+  const newcatalog = {
     "(If left blank, owner will be admin)": "(Ha \u00fcresen marad akkor a tulajdonos lesz az admin)",
     "(current notification)": "(aktu\u00e1lis \u00e9rtes\u00edt\u00e9s)",
     "(current version)": "(aktu\u00e1lis verzi\u00f3)",
@@ -53,6 +53,7 @@
     "Add User": "Felhaszn\u00e1l\u00f3 hozz\u00e1ad\u00e1sa",
     "Add admin": "Adminisztr\u00e1tor hozz\u00e1ad\u00e1sa",
     "Add auto expiration": "Automatikus lej\u00e1rat be\u00e1ll\u00edt\u00e1sa",
+    "Add custom permission": "Egyedi jogosults\u00e1g hozz\u00e1ad\u00e1sa",
     "Add institution": "Int\u00e9zm\u00e9ny hozz\u00e1ad\u00e1sa",
     "Add new notification": "\u00daj \u00e9rtes\u00edt\u00e9s hozz\u00e1ad\u00e1sa",
     "Add password protection": "Jelsz\u00f3 v\u00e9delem hozz\u00e1ad\u00e1sa",
@@ -67,11 +68,11 @@
     "Admins": "Adminisztr\u00e1torok",
     "All": "Mind",
     "All Groups": "Minden csoport",
+    "All Libraries": "\u00d6sszes k\u00f6tet",
     "All Notifications": "\u00d6sszes \u00e9rtes\u00edt\u00e9s",
     "All Public Links": "\u00d6sszes nyilv\u00e1nos link",
     "All file types": "Minden f\u00e1jl t\u00edpus",
     "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Regisztr\u00e1ci\u00f3k enged\u00e9lyez\u00e9se. Vegye ki a pip\u00e1t, hogy megakad\u00e1lyozza \u00faj felhaszn\u00e1l\u00f3k regisztr\u00e1l\u00e1s\u00e1t.",
-    "Allow user to add organization libraries. Otherwise, only system admin can add organization libraries.": "Enged\u00e9lyezi a felhaszn\u00e1l\u00f3k sz\u00e1m\u00e1ra szervezeti k\u00f6tetek l\u00e9trehoz\u00e1s\u00e1t. Egy\u00e9b esetben csak Adminisztr\u00e1tor tud l\u00e9trehozni szervezeti k\u00f6tetet.",
     "Allow user to change library history settings": "Enged\u00e9lyezi a felhaszn\u00e1l\u00f3knak, a k\u00f6tetnapl\u00f3 be\u00e1ll\u00edt\u00e1sainak m\u00f3dos\u00edt\u00e1s\u00e1t.",
     "Allow user to clean library trash": "Enged\u00e9lyezi a felhaszn\u00e1l\u00f3nak a kuka \u00fcr\u00edt\u00e9s\u00e9t",
     "Allow user to create encrypted libraries": "Enged\u00e9lyezi a felhaszn\u00e1l\u00f3knak titkos\u00edtot k\u00f6tet l\u00e9trehoz\u00e1s\u00e1t.",
@@ -83,6 +84,7 @@
     "Are you sure you want to clear trash?": "Biztos, hogy \u00fcr\u00edti a kuk\u00e1t?",
     "Are you sure you want to delete %s ?": "Biztosan t\u00f6rli: %s?",
     "Are you sure you want to delete the selected user(s) ?": "Biztoson t\u00f6r\u00f6lni k\u00edv\u00e1nja a kijelelt felhaszn\u00e1l\u00f3(ka)t?",
+    "Are you sure you want to delete the share link?": "Biztosan t\u00f6rli a megoszt\u00e1si linket?",
     "Are you sure you want to restore this library?": "Biztosan vissza\u00e1ll\u00edtja a k\u00f6tetet?",
     "Are you sure you want to unlink this device?": "Biztosan sz\u00e9tkapcsolja az eszk\u00f6zt?",
     "Audio": "Zene",
@@ -99,16 +101,14 @@
     "Change": "V\u00e1ltoztat\u00e1s",
     "Change Password": "Jelsz\u00f3 v\u00e1ltoztat\u00e1s",
     "Change Password of Library {placeholder}": "Jelsz\u00f3 megv\u00e1ltoztat\u00e1sa a k\u00f6tethez:  {placeholder}",
+    "Changes": "V\u00e1ltoz\u00e1sok",
     "Clean": "T\u00f6r\u00f6l",
     "Clear": "Tiszt\u00edt",
     "Clear Trash": "Kuka \u00fcr\u00edt\u00e9se",
     "Clear files in trash and history\uff1a": "F\u00e1jlok t\u00f6rl\u00e9se a kuk\u00e1b\u00f3l \u00e9s az el\u0151zm\u00e9nyekb\u0151l :",
     "Clients": "Kliensek",
     "Close": "Bez\u00e1r\u00e1s",
-    "Close (Esc)": "Bez\u00e1r (Esc)",
     "Column": "Oszlop",
-    "Comment": "Megjegyz\u00e9s",
-    "Comments": "Megjegyz\u00e9sek",
     "Community Edition": "K\u00f6z\u00f6ss\u00e9gi verzi\u00f3",
     "Confirm Password": "Jelsz\u00f3 meger\u0151s\u00edt\u00e9se",
     "Contact Email": "Kapcsolat email",
@@ -116,11 +116,17 @@
     "Copy": "M\u00e1sol\u00e1s",
     "Copy selected item(s) to:": "Kiv\u00e1lasztott elem(ek) m\u00e1sol\u00e1sa ide:",
     "Count": "Sz\u00e1ml\u00e1l\u00f3",
+    "Create": "L\u00e9trehoz\u00e1s",
     "Create Group": "Csoport l\u00e9trehoz\u00e1sa",
     "Create Library": "K\u00f6tet l\u00e9trehoz\u00e1sa",
     "Create Report": "Jelent\u00e9s k\u00e9sz\u00edt\u00e9se",
+    "Create a draft from this file, instead of editing it directly.": "Piszkozat l\u00e9trehoz\u00e1sa a f\u00e1jlb\u00f3l szerkeszt\u00e9s helyett.",
     "Created": "L\u00e9trehozva",
     "Created At": "L\u00e9trehozva",
+    "Created Files": "L\u00e9trehozott f\u00e1jlok",
+    "Created draft": "L\u00e9trehozott piszkozat",
+    "Created file": "L\u00e9trehozott f\u00e1jl",
+    "Created folder": "L\u00e9trehozott mappa",
     "Created group {group_name}": "Csoport l\u00e9trehozva: {group_name}",
     "Created library": "K\u00f6tet l\u00e9trehozva",
     "Created library {library_name} with {owner} as its owner": "{library_name} l\u00e9trehozva. Tulajdonos: {owner}",
@@ -141,6 +147,8 @@
     "Delete Account": "Fi\u00f3k t\u00f6rl\u00e9se",
     "Delete Department": "Oszt\u00e1ly t\u00f6rl\u00e9se",
     "Delete Expired Invitations": "Lej\u00e1rt megh\u00edvok t\u00f6rl\u00e9se",
+    "Delete File": "F\u00e1jl t\u00f6rl\u00e9se",
+    "Delete Folder": "Mappa t\u00f6rl\u00e9se",
     "Delete Group": "Csoport t\u00f6rl\u00e9se",
     "Delete Institution": "Int\u00e9zm\u00e9ny t\u00f6rl\u00e9se",
     "Delete Library": "K\u00f6tet t\u00f6rl\u00e9se",
@@ -155,19 +163,24 @@
     "Deleted Libraries": "T\u00f6r\u00f6lt k\u00f6tetek",
     "Deleted Time": "T\u00f6rl\u00e9s ideje",
     "Deleted directories": "T\u00f6r\u00f6lt k\u00f6nyvt\u00e1rak",
+    "Deleted draft": "T\u00f6r\u00f6lt piszkozat",
+    "Deleted file": "T\u00f6r\u00f6lt f\u00e1jl",
     "Deleted files": "T\u00f6r\u00f6lt f\u00e1jlok",
+    "Deleted folder": "T\u00f6r\u00f6lt mappa",
     "Deleted group {group_name}": "Csoport t\u00f6r\u00f6lve: {group_name}",
     "Deleted library": "T\u00f6r\u00f6lt k\u00f6tet",
     "Deleted library {library_name}": "{library_name} k\u00f6tet t\u00f6r\u00f6lve",
     "Deleted user {user}": "Felhaszn\u00e1l\u00f3 t\u00f6r\u00f6lve: {user}",
     "Departments": "Oszt\u00e1lyok",
     "Description": "Le\u00edr\u00e1s",
+    "Description is required": "Le\u00edr\u00e1s k\u00f6telez\u0151",
     "Desktop": "Desktop",
-    "Detail": "R\u00e9szletek",
     "Details": "R\u00e9szletek",
     "Device": "Eszk\u00f6z",
     "Device Name": "Eszk\u00f6z neve",
     "Devices": "Eszk\u00f6z\u00f6k",
+    "Direct Download Link:": "K\u00f6zvetlen let\u00f6lt\u00e9si link:",
+    "Direct download link is copied to the clipboard.": "K\u00f6zvetlen let\u00f6lt\u00e9si link v\u00e1g\u00f3lapra m\u00e1solva",
     "Directory": "K\u00f6nyvt\u00e1r",
     "Disable Two-Factor Authentication": "K\u00e9tl\u00e9pcs\u0151s azonos\u00edt\u00e1s kikapcsol\u00e1sa",
     "Document convertion failed.": "Dokumentum \u00e1talak\u00edt\u00e1sa meghi\u00fasult.",
@@ -176,8 +189,11 @@
     "Don't replace": "Ne cser\u00e9lje",
     "Download": "Let\u00f6lt\u00e9s",
     "Download an example file": "Mintaf\u00e1jl let\u00f6lt\u00e9se",
+    "Download and upload": "Let\u00f6lt\u00e9s \u00e9s felt\u00f6lt\u00e9s",
+    "Draft": "Piszkozat",
+    "Drafts": "Piszkozatok",
     "Edit": "Szerkeszt\u00e9s",
-    "Edit failed.": "Szerkeszt\u00e9s meghi\u00fasult.",
+    "Edit File": "F\u00e1jl szerkeszt\u00e9se",
     "Edit labels": "C\u00edmk\u00e9k szerkeszt\u00e9se",
     "Edit on cloud and download": "Szerkeszt\u00e9s a felh\u0151ben \u00e9s let\u00f6lt\u00e9s",
     "Edit succeeded": "Szerkeszt\u00e9s sikeres.",
@@ -193,12 +209,17 @@
     "Errors": "Hib\u00e1k",
     "Exit System Admin": "Admin kil\u00e9p\u00e9s",
     "Expiration": "Lej\u00e1rat",
+    "Expiration Date:": "Lej\u00e1rati d\u00e1tum:",
+    "Expiration days": "Lej\u00e1rati napok sz\u00e1ma",
+    "Expiration time": "Lej\u00e1rat id\u0151pontja",
     "Expired": "Lej\u00e1rt",
     "Expired at": "Lej\u00e1rt",
     "Export Excel": "Export\u00e1l\u00e1s Excelbe",
     "Extensions of text files that can be online previewed, each suffix is separated by a comma.": "Sz\u00f6veg f\u00e1jl kiterjeszt\u00e9sek, melyek online megtek\u00edthet\u0151ek. Minden v\u00e9gz\u0151d\u00e9st ','-vel kell elv\u00e1lasztani.",
     "Failed": "Sikertelen",
     "Failed to copy %(name)s": "%(name)s m\u00e1sol\u00e1sa sikertelen",
+    "Failed to delete draft %(draft)s.": "Piszkozat t\u00f6rl\u00e9se sikertelen %(draft)s.",
+    "Failed to publish draft %(draft)s.": "Piszkozat publik\u00e1l\u00e1sa sikertelen %(draft)s.",
     "Failed. Please check the network.": "Sikertelen. Ellen\u0151rizze a h\u00e1l\u00f3zatot.",
     "Favorites": "Kedvencek",
     "File": "F\u00e1jl",
@@ -207,23 +228,28 @@
     "File Update": "F\u00e1jl friss\u00edt\u00e9s",
     "File Upload": "F\u00e1jl felt\u00f6lt\u00e9s",
     "File Uploading...": "F\u00e1jl felt\u00f6lt\u00e9s ...",
+    "File does not exist.": "A f\u00e1jl nem l\u00e9tezik.",
     "File download is disabled: the share link traffic of owner is used up.": "F\u00e1jl let\u00f6lt\u00e9s letiltva: a megoszt\u00e1si link tulajdonosa el\u00e9rte a forgalmi korl\u00e1tot.",
     "Files": "F\u00e1jlok",
     "Folder": "K\u00f6nyvt\u00e1r",
     "Folder Permission": "K\u00f6nyvt\u00e1r jogosults\u00e1g",
+    "Folder does not exist.": "A mappa nem l\u00e9tezik.",
     "Folders": "K\u00f6nyvt\u00e1rak",
     "Force user to change password when account is newly added or reset by admin": "K\u00e9nyszer\u00edti a felhaszn\u00e1l\u00f3t jelszav\u00e1nak megv\u00e1ltoztat\u00e1s\u00e1ra, \u00faj felhaszn\u00e1l\u00f3i fi\u00f3k l\u00e9trehoz\u00e1sakor, vagy ha egy Adminisztr\u00e1tor alaphelyzetbe \u00e1ll\u00edtja azt.",
     "Force user to use a strong password when sign up or change password.": "Megk\u00f6veteli a felhaszn\u00e1l\u00f3t\u00f3l er\u0151s jelsz\u00f3 haszn\u00e1lat\u00e1t regisztr\u00e1ci\u00f3 vagy jelsz\u00f3v\u00e1lt\u00e1s alkalm\u00e1val.",
     "Freeze user account when failed login attempts exceed limit.": "Felhaszn\u00e1l\u00f3i fi\u00f3k felf\u00fcggeszt\u00e9se, ha a sikertelen bejelentkez\u00e9si k\u00eds\u00e9rletek sz\u00e1ma el\u00e9rte a limitet.",
     "Generate": "Gener\u00e1l",
     "Global Address Book": "Glob\u00e1lis n\u00e9vjegyz\u00e9k",
+    "Greater than or equal to {minDays_placeholder} days": "Legal\u00e1bb {minDays_placeholder} nap",
     "Grid": "R\u00e1cs",
     "Group": "Csoport",
     "Group Permission": "Csoport jogosults\u00e1g",
+    "Group not found": "Csoport nem tal\u00e1lhat\u00f3",
     "Groups": "Csoportok",
     "Guest": "Vend\u00e9g",
     "Handled": "Kezelve",
     "Help": "Seg\u00edts\u00e9g",
+    "Hide": "Elrejt",
     "History": "Napl\u00f3",
     "History Setting": "Napl\u00f3be\u00e1ll\u00edt\u00e1sok",
     "History Versions": "Kor\u00e1bbi verzi\u00f3k",
@@ -233,6 +259,7 @@
     "Image": "K\u00e9p",
     "Images": "K\u00e9pek",
     "Import Members": "Tagok import\u00e1l\u00e1sa",
+    "Import users": "Felhaszn\u00e1l\u00f3k import\u00e1l\u00e1sa",
     "Import users from a .xlsx file": "Felhaszn\u00e1l\u00f3k import\u00e1l\u00e1sa .xlsx f\u00e1jlb\u00f3l",
     "In all libraries": "Minden k\u00f6tetben",
     "Inactive": "Nem akt\u00edv",
@@ -253,6 +280,7 @@
     "Keep full history": "\u00d6sszes v\u00e1ltozat megtart\u00e1sa",
     "LDAP": "LDAP",
     "LDAP(imported)": "LDAP(bet\u00f6ltve)",
+    "Label": "C\u00edmke",
     "Labels": "C\u00edmk\u00e9k",
     "Language": "Nyelv",
     "Language Setting": "Nyelvi be\u00e1ll\u00edt\u00e1sok",
@@ -261,6 +289,7 @@
     "Last Update": "Utols\u00f3 friss\u00edt\u00e9s ",
     "Last modified by": "Utolj\u00e1ra m\u00f3dos\u00edt\u00f3",
     "Leave Share": "Megoszt\u00e1s elhagy\u00e1sa",
+    "Less than or equal to {maxDays_placeholder} days": "Maximum {maxDays_placeholder} nap",
     "Libraries": "K\u00f6tetek",
     "Library": "K\u00f6tet",
     "Library Type": "K\u00f6tet t\u00edpusa",
@@ -270,15 +299,16 @@
     "Links": "Linkek",
     "List": "Lista",
     "List your account in global address book, so that others can find you by typing your name.": "Felhaszn\u00e1l\u00f3i fi\u00f3kja list\u00e1z\u00e1sa a glob\u00e1lis n\u00e9vjegyz\u00e9kben, \u00edgy m\u00e1sik megtal\u00e1lhatj\u00e1k \u00d6nt a nev\u00e9nek b\u00edr\u00e1s\u00e1val.",
-    "Local draft": "Helyi v\u00e1zlat",
+    "Local draft": "Helyi piszkozat",
+    "Local draft saved": "Helyi piszkozat elmentve",
     "Location": "Helysz\u00edn",
     "Lock": "Lez\u00e1r",
     "Log out": "Kijelentkez\u00e9s",
     "Login Background Image": "Bejelentkez\u0151 k\u00e9perny\u0151 h\u00e1tt\u00e9rk\u00e9p",
     "Logs": "Napl\u00f3k",
     "Manage Members": "Tagok kezel\u00e9se",
+    "Manage group members": "Csoporttagok kezel\u00e9se",
     "Mark all read": "Mindet olvasottnak jel\u00f6l",
-    "Mark as resolved": "Megjel\u00f6l\u00e9s megoldottk\u00e9nt",
     "Member": "Tag",
     "Members": "Tagok",
     "Message": "\u00dczenet",
@@ -294,6 +324,8 @@
     "More Operations": "Tov\u00e1bbi m\u0171veletek",
     "Move": "\u00c1thelyez\u00e9s",
     "Move selected item(s) to:": "Kiv\u00e1lasztott elem(ek) mozgat\u00e1sa ide: ",
+    "Moved file": "\u00c1thelyezett f\u00e1jl",
+    "Moved folder": "\u00c1thelyezett mappa",
     "My Groups": "Saj\u00e1t csoportok",
     "My Libraries": "K\u00f6teteim",
     "Name": "N\u00e9v",
@@ -316,17 +348,19 @@
     "New Password Again": "\u00daj jelsz\u00f3 ism\u00e9t",
     "New PowerPoint File": "\u00daj PowerPoint f\u00e1jl",
     "New Sub-department": "\u00daj aloszt\u00e1ly",
+    "New Tag": "\u00daj c\u00edmke",
     "New Wiki": "\u00daj Wiki",
     "New Word File": "\u00daj Word f\u00e1jl",
     "New directories": "\u00daj k\u00f6nyvt\u00e1rak",
+    "New file name": "\u00daj f\u00e1jl neve",
     "New files": "\u00daj f\u00e1jlok",
     "New password is too short": "Az \u00faj jelsz\u00f3 r\u00f6vid",
     "New passwords don't match": "Az \u00faj jelszavak nem egyeznek",
     "Next": "K\u00f6vetkez\u0151",
-    "Next (Right arrow key)": "K\u00f6vetkez\u0151 (Jobbra ny\u00edl)",
-    "No comment yet.": "Nincs m\u00e9g megjegyz\u00e9s",
+    "No": "Nem",
     "No connected devices": "Nincsenek csatlakozott eszk\u00f6z\u00f6k",
     "No departments": "Nincsenek oszt\u00e1lyok",
+    "No draft yet": "Nincsenek piszkozatok",
     "No groups": "Nincs csoport",
     "No libraries": "Nincs k\u00f6tet",
     "No libraries have been shared with you": "Nincsen egyetlen k\u00f6nyvt\u00e1r sem megosztva \u00d6nnel",
@@ -337,6 +371,7 @@
     "No sync errors": "Nincs szinkroniz\u00e1l\u00e1si hiba",
     "None": "Nincs",
     "Note: Settings via web interface are saved in database table (seahub-db/constance_config). They have a higher priority over the settings in config files.": "Megjegyz\u00e9s: a webes fel\u00fcleten megadott be\u00e1ll\u00edt\u00e1sok az adatb\u00e1zisban r\u00f6gz\u00fclnek (seahub-db/constance_config). Ezeknek magasabb a priorit\u00e1suk a config f\u00e1jlban r\u00f6gz\u00edtettekn\u00e9l.",
+    "Notification": "\u00c9rtes\u00edt\u00e9s",
     "Notification Detail": "\u00c9rtes\u00edt\u00e9s r\u00e9szletei",
     "Notifications": "\u00c9rtes\u00edt\u00e9sek",
     "Number of days that keep user sign in.": "Napok sz\u00e1ma, am\u00edg a felhaszn\u00e1l\u00f3 bejelentkezve marad.",
@@ -348,7 +383,6 @@
     "Online view is not applicable to this file format": "Az online el\u0151n\u00e9zet nem lehets\u00e9ges enn\u00e9l a f\u00e1jlform\u00e1tumn\u00e1l",
     "Only Show": "Csak megjelen\u00edt\u00e9s",
     "Only keep a period of history:": "Csak egy id\u0151szak megtart\u00e1sa:",
-    "Open in New Tab": "Megnyit\u00e1s \u00faj f\u00fcl\u00f6n",
     "Open parent folder": "Sz\u00fcl\u0151k\u00f6nyvt\u00e1r megnyit\u00e1sa",
     "Open via Client": "Megnyit\u00e1s kliensben",
     "Operation": "M\u0171velet",
@@ -359,6 +393,7 @@
     "Organizations": "Szervezetek",
     "Other Libraries": "M\u00e1s k\u00f6tetek",
     "Out of quota.": "Kv\u00f3ta t\u00fall\u00e9p\u00e9s.",
+    "Owned Libraries": "Birtokolt k\u00f6tetek",
     "Owner": "Tulajdonos",
     "Owner can use admin panel in an organization, must be a new account.": "A tulajdonos a szervezet be\u00e1ll\u00edt\u00e1sait kezelheti, \u00faj fi\u00f3knak kell lennie.",
     "Packaging...": "Csomagol\u00e1s",
@@ -367,6 +402,7 @@
     "Password is too short": "A jelsz\u00f3 t\u00fal r\u00f6vid",
     "Password:": "Jelsz\u00f3:",
     "Passwords don't match": "Nem egyeznek a megadott jelszavak.",
+    "Path": "El\u00e9r\u00e9si \u00fat",
     "Permission": "Jogosults\u00e1g",
     "Permission denied": "Jogosults\u00e1g megtagadva",
     "Permission:": "Jogosults\u00e1g:",
@@ -382,15 +418,17 @@
     "Please enter the old password": "K\u00e9rem adja meg a r\u00e9gi jelsz\u00f3t",
     "Please enter the password again": "K\u00e9rem adja meg a jelsz\u00f3t \u00fajra",
     "Please input at least an email.": "Adjon meg legal\u00e1bb egy e-mail c\u00edmet",
+    "Please select a library to share.": "V\u00e1lasszon k\u00f6tetet a megoszt\u00e1shoz",
     "Preview and download": "El\u0151n\u00e9zet \u00e9s let\u00f6lt\u00e9s",
     "Preview only": "Csak el\u0151n\u00e9zet",
     "Previous": "El\u0151z\u0151",
-    "Previous (Left arrow key)": "El\u0151z\u0151 (Balra ny\u00edl)",
     "Professional Edition": "Professzion\u00e1lis verzi\u00f3",
     "Profile": "Profil",
     "Profile Setting": "Profilbe\u00e1ll\u00edt\u00e1sok",
     "Publish": "Publik\u00e1l\u00e1s",
+    "Publish draft": "Piszkozat publik\u00e1l\u00e1sa",
     "Quota": "Kv\u00f3ta",
+    "Quota is invalid.": "\u00c9rv\u00e9nytelen kv\u00f3ta",
     "Read-Only": "Csak olvahat\u00f3",
     "Read-Only folder": "Csak olvashat\u00f3 mappa",
     "Read-Only library": "Csak olvashat\u00f3 k\u00f6tet",
@@ -405,6 +443,10 @@
     "Rename": "\u00c1tnevez\u00e9s",
     "Rename File": "F\u00e1jl \u00e1tnevez\u00e9se",
     "Rename Folder": "K\u00f6nyvt\u00e1r \u00e1tnevez\u00e9se",
+    "Rename group to": "Csoport \u00e1tnevez\u00e9se a k\u00f6vetkez\u0151re:",
+    "Renamed file": "\u00c1tnevezett f\u00e1jl",
+    "Renamed folder": "\u00c1tnevezett mappa",
+    "Renamed library": "\u00c1tnevezett k\u00f6tet",
     "Renamed or Moved files": "\u00c1tnevezett/\u00e1thelyezett f\u00e1jlok",
     "Replace": "Csere",
     "Replace file {filename}?": "Fel\u00fcl\u00edrja: {filename}?",
@@ -414,18 +456,24 @@
     "ResetPwd": "\u00daj jelsz\u00f3",
     "Restore": "Vissza\u00e1ll\u00edt\u00e1s",
     "Restore Library": "K\u00f6tet vissza\u00e1ll\u00edt\u00e1sa",
+    "Restored file": "Vissza\u00e1ll\u00edtott f\u00e1jl",
+    "Restored folder": "Vissza\u00e1ll\u00edtott mappa",
+    "Restored library": "Vissza\u00e1ll\u00edtott k\u00f6tet",
     "Result": "Tal\u00e1lat",
     "Revoke Admin": "Admin jog elv\u00e9tele",
     "Role": "Szerep",
     "Save": "Ment\u00e9s",
+    "Save as ...": "Ment\u00e9s m\u00e1sk\u00e9nt...",
+    "Save to:": "Ment\u00e9s ide:",
     "Saving...": "Ment\u00e9s...",
     "Seafile": "Seafile",
     "Search": "Keres",
-    "Search Files": "F\u00e1jlok keres\u00e9se",
     "Search files in this library": "F\u00e1jlok keres\u00e9se ebben a k\u00f6tetben",
-    "Search users...": "Felhaszn\u00e1l\u00f3k keres\u00e9se...",
-    "See All Notifications": "\u00d6sszes \u00e9rtes\u00edt\u00e9s megtekint\u00e9se",
+    "Search groups": "Csoportok keres\u00e9se",
+    "Select File": "F\u00e1jl kiv\u00e1laszt\u00e1sa",
+    "Select Tags": "C\u00edmk\u00e9k kiv\u00e1laszt\u00e1sa",
     "Select a group": "Csoport kiv\u00e1laszt\u00e1sa",
+    "Select groups": "Csoportok kiv\u00e1laszt\u00e1sa",
     "Select libraries to share": "V\u00e1lasszon k\u00f6teteket a megoszt\u00e1shoz",
     "Send": "K\u00fcld\u00e9s",
     "Send activation Email after user registration.": "Aktiv\u00e1l\u00f3 E-mail k\u00fcld\u00e9se regisztr\u00e1ci\u00f3 ut\u00e1n.",
@@ -433,6 +481,7 @@
     "Sending...": "K\u00fcld\u00e9s...",
     "Server Version: ": "Kiszolg\u00e1l\u00f3verzi\u00f3: ",
     "Set Admin": "Admin jog megad\u00e1sa",
+    "Set Password": "Jelsz\u00f3 be\u00e1ll\u00edt\u00e1sa",
     "Set Quota": "Kv\u00f3ta be\u00e1ll\u00edt\u00e1sa",
     "Set permission": "Jogosults\u00e1g be\u00e1ll\u00edt\u00e1sa",
     "Set to current": "Be\u00e1ll\u00edt\u00e1s aktu\u00e1lisnak",
@@ -454,11 +503,14 @@
     "Share to group": "Megoszt\u00e1s csoporttal",
     "Share to user": "Megoszt\u00e1s felhaszn\u00e1l\u00f3val",
     "Shared By": "Megoszt\u00f3:",
+    "Shared Libraries": "Megosztott k\u00f6tetek",
     "Shared Links": "Megoszt\u00e1s linkek",
+    "Shared by:": "Megoszt\u00f3:",
     "Shared by: ": "Megoszt\u00f3: ",
     "Shared with all": "Mindenkivel megosztva",
     "Shared with groups": "Csoporttal megosztva",
     "Shared with me": "Velem megosztva",
+    "Show": "Mutat",
     "Show Codes": "K\u00f3dok mutat\u00e1sa",
     "Side Nav Menu": "Oldals\u00e1vi men\u00fc",
     "Site name used in email sending": "E-mailben megjelen\u0151 oldal neve",
@@ -479,24 +531,29 @@
     "Successfully copied %(name)s and %(amount)s other items.": "%(name)s m\u00e1sol\u00e1sa \u00e9s m\u00e9g %(amount)s m\u00e1sik elem\u00e9 sikeres.",
     "Successfully copied %(name)s and 1 other item.": "%(name)s m\u00e1sol\u00e1sa \u00e9s m\u00e9g 1 m\u00e1sik elem\u00e9 sikeres.",
     "Successfully copied %(name)s.": "%(name)s m\u00e1sol\u00e1sa sikeres.",
-    "Successfully deleted %s": "%s t\u00f6rl\u00e9se sikeres",
+    "Successfully deleted 1 item": "1 elem sikeresen t\u00f6r\u00f6lve.",
     "Successfully deleted 1 item.": "1 elem sikeresen t\u00f6r\u00f6lve.",
+    "Successfully deleted draft %(draft)s.": "Piszkozat t\u00f6r\u00f6lve %(draft)s.",
+    "Successfully deleted {name}": "Sikeresen t\u00f6r\u00f6lve {name}",
     "Successfully edited labels.": "C\u00edmk\u00e9k szerkeszt\u00e9se sikeres",
     "Successfully invited %(email) and %(num) other people.": "%(email) \u00e9s tov\u00e1bbi %(num) ember megh\u00edvva.",
     "Successfully invited %(email).": "%(email) sikeresen megh\u00edvva",
     "Successfully moved %(name)s and %(amount)s other items.": "%(name)s \u00e1thelyez\u00e9se \u00e9s m\u00e9g %(amount)s m\u00e1sik elem\u00e9 sikeres.",
     "Successfully moved %(name)s and 1 other item.": "%(name)s \u00e1thelyez\u00e9se \u00e9s m\u00e9g 1 m\u00e1sik elem\u00e9 sikeres.",
     "Successfully moved %(name)s.": "%(name)s sikeresen \u00e1tmozgatva.",
+    "Successfully published draft %(draft)s.": "Piszkozat publik\u00e1lva %(draft)s.",
     "Successfully reset password to %(passwd)s for user %(user)s.": "%(user)s jelszava sikeresen \u00e1t\u00e1ll\u00edtva erre: %(passwd)s.",
     "Successfully restored 1 item.": "1 elem sikeresen vissza\u00e1ll\u00edtva.",
     "Successfully restored the library.": "K\u00f6nyvt\u00e1r sikeresen vissza\u00e1ll\u00edtva.",
     "Successfully revoke the admin permission of %s": "%s felhaszn\u00e1l\u00f3t\u00f3l az adminisztr\u00e1tori jogok megvon\u00e1sa sikeres",
+    "Successfully saved": "Sikeresen elmentve",
     "Successfully sent to {placeholder}": "Sikeresen elk\u00fcldve ide: {placeholder}",
     "Successfully set %s as admin.": "%s adminisztr\u00e1tornak val\u00f3 be\u00e1ll\u00edt\u00e1sa sikeres.",
     "Successfully set library history.": "K\u00f6tetnapl\u00f3 be\u00e1ll\u00edt\u00e1sa sikeres",
     "Successfully transferred the group.": "Csoport sikeresen \u00e1tadva.",
     "Successfully transferred the library.": "K\u00f6tet \u00e1tad\u00e1sa sikeres.",
     "Successfully unshared library {placeholder}": "{placeholder} megoszt\u00e1sa sikeresen megsz\u00fcntetve",
+    "Suggestion": "Javaslatok",
     "Sync": "Szinkroniz\u00e1l\u00e1s",
     "Sync Download": "Szinkroniz\u00e1ci\u00f3 let\u00f6l\u00e9s",
     "Sync Traffic": "Szinkroniz\u00e1ci\u00f3 forgalom",
@@ -512,12 +569,13 @@
     "Text files": "Sz\u00f6veg f\u00e1jlok",
     "The URL of the server, like https://seafile.example.com or http://192.168.1.2:8000": "Szerver c\u00edme, pl: https://seafile.example.com vagy http://192.168.1.2:8000",
     "The internal URL for downloading/uploading files. Users will not be able to download/upload files if this is not set correctly. If you config Seafile behind Nginx/Apache, it should be SERVICE_URL/seafhttp, like https://seafile.example.com/seafhttp .": "A bels\u0151 URL a f\u00e1jlok le/felt\u00f6lt\u00e9s\u00e9hez. Hib\u00e1s be\u00e1ll\u00edt\u00e1s eset\u00e9n a felhaszn\u00e1l\u00f3k nem lesznek k\u00e9pesek le/felt\u00f6lteni f\u00e1jlokat. Amennyiben Nginx/Apache m\u00f6g\u00f6tt fut a Seafile szerver, SERVICE_URL/seafhttp-nek kell lennie, pl.: https://seafile.example.com/seafhttp.",
-    "The least number of characters a download/upload link password should include.": "Le/Felt\u00f6lt\u00e9si hivatkoz\u00e1s minim\u00e1lis hossza.",
     "The least number of characters an account password should include.": "Felhaszn\u00e1l\u00f3 jelszav\u00e1nak minim\u00e1lis hossza.",
     "The least number of characters an encrypted library password should include.": "Titkos\u00edtott k\u00f6tet jelszav\u00e1nak minim\u00e1lis hossza.",
     "The level(1-4) of an account password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols": "Felhaszn\u00e1l\u00f3 jelszav\u00e1nak er\u0151ss\u00e9ge (1-4). P\u00e9ld\u00e1ul a '3' azt jelenti, hogy a jelsz\u00f3nak legal\u00e1bb h\u00e1rom t\u00edpust kell tartalmaznia a k\u00f6vetkez\u0151kb\u0151l: sz\u00e1m, nagybet\u0171, kisbet\u0171, \u00e9s egy\u00e9b karakterek.",
     "The maximum number of failed login attempts before showing CAPTCHA.": "Maxim\u00e1lis sikertelen bejelentkez\u00e9si k\u00eds\u00e9rletek a CAPTCHA megjelen\u00edt\u00e9se el\u0151tt.",
+    "The name \"{name}\" is already taken. Please choose a different name.": "A n\u00e9v \"{name}\" haszn\u00e1latban van. K\u00e9rem, v\u00e1lasszon egy m\u00e1sikat.",
     "The owner of this library has run out of space.": "A k\u00f6tet tulajdonos\u00e1nak elfogyott a t\u00e1rhelye.",
+    "The password is too short.": "A jelsz\u00f3 t\u00fal r\u00f6vid.",
     "The password will be kept in the server for only 1 hour.": "A jelsz\u00f3 egy \u00f3r\u00e1n \u00e1t lesz t\u00e1rolva a kiszolg\u00e1l\u00f3n.",
     "This file has been updated.": "Ez a f\u00e1jl friss\u00edtve lett.",
     "This file is in draft stage.": "Ez a f\u00e1jl piszkozat \u00e1llapotban van.",
@@ -554,27 +612,33 @@
     "Unstar": "Nem kedvenc",
     "Update": "Friss\u00edt\u00e9s",
     "Update Terms and Conditions": "Felhaszn\u00e1l\u00e1si felt\u00e9telek friss\u00edt\u00e9se",
+    "Updated draft": "M\u00f3dos\u00edtott piszkozat",
+    "Updated file": "Friss\u00edtett f\u00e1jl",
     "Upgrade to Pro Edition": "Friss\u00edt\u00e9s professzion\u00e1lis verzi\u00f3ra",
     "Upload": "Felt\u00f6lt\u00e9s",
     "Upload Files": "F\u00e1jlok felt\u00f6lt\u00e9se",
     "Upload Folder": "K\u00f6nyvt\u00e1r felt\u00f6lt\u00e9se",
     "Upload Link": "Felt\u00f6lt\u00e9si hivatkoz\u00e1s",
+    "Upload Link:": "Felt\u00f6t\u00e9si link:",
     "Upload Links": "Felt\u00f6lt\u00e9si linkek",
     "Upload file": "F\u00e1jl felt\u00f6lt\u00e9se",
     "Use custom CSS": "Egy\u00e9ni CSS haszn\u00e1lata",
-    "Use draft": "V\u00e1zlat haszn\u00e1lata",
+    "Use draft": "Piszkozat haszn\u00e1lata",
     "Used:": "Foglalt:",
     "User": "Felhaszn\u00e1l\u00f3",
     "User Permission": "Felhaszn\u00e1l\u00f3i jogosults\u00e1g",
     "User Storage": "Felhaszn\u00e1l\u00f3i t\u00e1rhely",
+    "User not found": "Felhaszn\u00e1l\u00f3 nem tal\u00e1lhat\u00f3",
     "Username:": "Felhaszn\u00e1l\u00f3n\u00e9v:",
     "Users": "Felhaszn\u00e1l\u00f3k",
+    "Verify": "Meger\u0151s\u00edt",
     "Version": "Verzi\u00f3",
     "Version Number": "Verzi\u00f3sz\u00e1m",
     "Video": "Vide\u00f3",
     "View": "Megtekint\u00e9s",
     "View Draft": "Piszkozat megjelen\u00edt\u00e9se",
     "View Snapshot": "Pillanatk\u00e9p megtekint\u00e9se",
+    "View profile and more": "Profil megtekint\u00e9se",
     "Virus File": "V\u00edrus f\u00e1jl",
     "Virus Scan": "V\u00edruskeres\u0151",
     "Visited": "Megtekintve",
@@ -583,6 +647,7 @@
     "Web Traffic": "Web forgalom",
     "Web Upload": "Web felt\u00f6lt\u00e9s",
     "Wrong password": "Hib\u00e1s jelsz\u00f3",
+    "Yes": "Igen",
     "You can also add a user as a guest, who will not be allowed to create libraries and groups.": "Vend\u00e9g felhaszn\u00e1l\u00f3t is hozz\u00e1adhat, aki nem tud k\u00f6tetet \u00e9s csoportot l\u00e9trehozni.",
     "You can create libraries by clicking the \"New Library\" button above.": "K\u00f6teteket a fenti \"\u00daj K\u00f6tet\" gombra kattintva hozhat l\u00e9tre.",
     "You can use this field at login.": "Ezt a mez\u0151t haszn\u00e1lhatja a bejelentkez\u00e9shez.",
@@ -590,13 +655,13 @@
     "You have an unsaved draft. Do you like to use it?": "Egy el nem mentett piszkozatot is l\u00e9tezik. Szeretn\u00e9 azt haszn\u00e1lni?",
     "You have not shared any folders": "Nem osztott meg egyetlen k\u00f6nyvt\u00e1rat sem",
     "Your notifications will be sent to this email.": "Az \u00e9rtes\u00edt\u0151 erre az email c\u00edmre lesz elk\u00fcldve.",
+    "ZIP": "ZIP",
     "activate after registration": "Aktiv\u00e1l\u00e1s regisztr\u00e1ci\u00f3 ut\u00e1n",
     "all": "\u00f6sszes",
     "all members": "minden tag",
     "allow new registrations": "Regisztr\u00e1ci\u00f3 enged\u00e9lyez\u00e9se",
     "days": "nap",
-    "download/upload link password minimum length": "Le/Felt\u00f6lt\u00e9si hivatkoz\u00e1s jelsz\u00f3 minim\u00e1lis hossza",
-    "file": "f\u00e1jl",
+    "deleted": "t\u00f6r\u00f6lve",
     "icon": "ikon",
     "keep sign in": "Bejelentkezve maradok",
     "library password minimum length": "K\u00f6tetjelsz\u00f3 minim\u00e1lis hossza",
@@ -604,34 +669,39 @@
     "name": "n\u00e9v",
     "password minimum length": "Jelsz\u00f3 minim\u00e1lis hossza",
     "password strength level": "Jelsz\u00f3 er\u0151ss\u00e9ge",
-    "related files": "kapcsol\u00f3d\u00f3 f\u00e1jlok",
     "send activation email": "Aktiv\u00e1l\u00f3 E-mail k\u00fcld\u00e9se",
     "shared by:": "megoszt\u00f3:",
+    "show more": "t\u00f6bb mutat\u00e1sa",
     "starred": "kedvenc",
+    "state": "\u00e1llapot",
+    "successfully added user %s.": "%s hozz\u00e1ad\u00e1sa sikeres.",
     "text file extensions": "Sz\u00f6vegf\u00e1jl kiterjeszt\u00e9sek",
     "to": "ide:",
     "unstarred": "nem kedvenc",
     "you can also press \u2190 ": "A \u2190 gombot is haszn\u00e1lhatja",
+    "you can also press \u2192": "a \u2192 gombot is haszn\u00e1lhatja ",
+    "{file} and {n} other files": "{file} \u00e9s {n} egy\u00e9b f\u00e1jl",
+    "{number_placeholder} / Page": "{number_placeholder} / Oldal",
     "{placeholder} Folder Permission": "{placeholder} k\u00f6nyvt\u00e1r jogosults\u00e1ga"
   };
-  for (var key in newcatalog) {
+  for (const key in newcatalog) {
     django.catalog[key] = newcatalog[key];
   }
   
 
   if (!django.jsi18n_initialized) {
     django.gettext = function(msgid) {
-      var value = django.catalog[msgid];
-      if (typeof(value) == 'undefined') {
+      const value = django.catalog[msgid];
+      if (typeof value === 'undefined') {
         return msgid;
       } else {
-        return (typeof(value) == 'string') ? value : value[0];
+        return (typeof value === 'string') ? value : value[0];
       }
     };
 
     django.ngettext = function(singular, plural, count) {
-      var value = django.catalog[singular];
-      if (typeof(value) == 'undefined') {
+      const value = django.catalog[singular];
+      if (typeof value === 'undefined') {
         return (count == 1) ? singular : plural;
       } else {
         return value.constructor === Array ? value[django.pluralidx(count)] : value;
@@ -641,16 +711,16 @@
     django.gettext_noop = function(msgid) { return msgid; };
 
     django.pgettext = function(context, msgid) {
-      var value = django.gettext(context + '\x04' + msgid);
-      if (value.indexOf('\x04') != -1) {
+      let value = django.gettext(context + '\x04' + msgid);
+      if (value.includes('\x04')) {
         value = msgid;
       }
       return value;
     };
 
     django.npgettext = function(context, singular, plural, count) {
-      var value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
-      if (value.indexOf('\x04') != -1) {
+      let value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
+      if (value.includes('\x04')) {
         value = django.ngettext(singular, plural, count);
       }
       return value;
@@ -673,7 +743,6 @@
       "%Y.%m.%d. %H:%M:%S",
       "%Y.%m.%d. %H:%M:%S.%f",
       "%Y.%m.%d. %H:%M",
-      "%Y.%m.%d.",
       "%Y-%m-%d %H:%M:%S",
       "%Y-%m-%d %H:%M:%S.%f",
       "%Y-%m-%d %H:%M",
@@ -701,8 +770,8 @@
   };
 
     django.get_format = function(format_type) {
-      var value = django.formats[format_type];
-      if (typeof(value) == 'undefined') {
+      const value = django.formats[format_type];
+      if (typeof value === 'undefined') {
         return format_type;
       } else {
         return value;
@@ -721,6 +790,5 @@
 
     django.jsi18n_initialized = true;
   }
-
-}(this));
+};
 
