@@ -1,13 +1,14 @@
 
 
-(function(globals) {
-
-  var django = globals.django || (globals.django = {});
+'use strict';
+{
+  const globals = this;
+  const django = globals.django || (globals.django = {});
 
   
   django.pluralidx = function(n) {
-    var v=(n != 1);
-    if (typeof(v) == 'boolean') {
+    const v = (n != 1);
+    if (typeof v === 'boolean') {
       return v ? 1 : 0;
     } else {
       return v;
@@ -19,8 +20,7 @@
 
   django.catalog = django.catalog || {};
   
-  var newcatalog = {
-    "%curr% of %total%": "%curr% van %total%",
+  const newcatalog = {
     "(current notification)": "(huidige melding)",
     "(current version)": "(huidige versie)",
     "1 Year": "1 jaar",
@@ -46,7 +46,6 @@
     "Add": "Toevoegen",
     "Add Admin": "Admin toevoegen",
     "Add Admins": "Admins toevoegen",
-    "Add File": "Bestand toevoegen",
     "Add Library": "Voeg bibliotheek toe",
     "Add Member": "Lid toevoegen",
     "Add Organization": "Organisatie toevoegen",
@@ -95,10 +94,7 @@
     "Clear files in trash and history\uff1a": "Schoon bestanden in prullenbak en geschiedenis:",
     "Clients": "Clients",
     "Close": "Sluiten",
-    "Close (Esc)": "Sluiten (Esc)",
     "Column": "Kolom",
-    "Comment": "Opmerking",
-    "Comments": "Opmerkingen",
     "Community Edition": "Community editie",
     "Confirm": "Bevestigen",
     "Confirm Password": "Bevestig Wachtwoord",
@@ -109,6 +105,7 @@
     "Copy": "Kopi\u00ebren ",
     "Copy selected item(s) to:": "Geselecteerde item(s) kopi\u00ebren naar:",
     "Count": "Teller",
+    "Create": "Aanmaken",
     "Create Group": "Groep aanmaken",
     "Create Library": "Bibliotheek aanmaken",
     "Create a new tag": "Nieuwe tag aanmaken",
@@ -156,8 +153,8 @@
     "Deleted user {user}": "Gebruiker {user} verwijderd",
     "Departments": "Afdelingen",
     "Description": "Beschrijving",
+    "Description is required": "Omschrijving is verplicht",
     "Desktop": "Desktop",
-    "Detail": "Detailweergave",
     "Details": "Details",
     "Device": "Apparaat",
     "Device Name": "Apparaatnaam",
@@ -173,7 +170,6 @@
     "Draft": "Concept",
     "Drafts": "Concepten",
     "Edit": "Aanpassen",
-    "Edit failed.": "Wijzigen mislukt",
     "Edit labels": "Labels bewerken",
     "Edit succeeded": "Wijzigen gelukt",
     "Email": "E-mail",
@@ -213,6 +209,7 @@
     "Guest": "Gast",
     "Handled": "Behandeld",
     "Help": "Help",
+    "Hide": "Verbergen",
     "History": "Geschiedenis",
     "History Setting": "Geschiedenis-instellingen",
     "History Versions": "Versiehistorie",
@@ -220,6 +217,7 @@
     "Image": "Afbeelding",
     "Images": "Afbeeldingen",
     "Import Members": "Leden importeren",
+    "Import users": "Importeer gebruikers",
     "In all libraries": "In alle bibliotheken",
     "Inactive": "Inactief",
     "Info": "Informatie",
@@ -232,7 +230,6 @@
     "Invitations": "Uitnodigingen",
     "Invite Guest": "Gast uitnodigen",
     "Invite Time": "Tijdstip uitnodiging",
-    "Invite user": "Gebruiker uitnodigen",
     "Invited at": "Uitgenodigd op",
     "Inviter": "Uitgenodigd door",
     "It is required.": "Het is verplicht.",
@@ -248,7 +245,6 @@
     "Leave Share": "Gedeelde folder verlaten",
     "Libraries": "Bibliotheken",
     "Library": "Bibliotheek",
-    "Library Name": "Naam bibliotheek",
     "Library Type": "Soort bibliotheek",
     "Limits": "Limieten",
     "Link": "Link",
@@ -262,7 +258,6 @@
     "Logs": "Logbestanden",
     "Manage Members": "Leden beheren",
     "Mark all read": "Alles als gelezen markeren",
-    "Mark as resolved": "Markeren als opgelost",
     "Member": "Lid",
     "Members": "Leden",
     "Message": "Bericht",
@@ -309,8 +304,7 @@
     "New password is too short": "Nieuwe wachtwoord is te kort",
     "New passwords don't match": "Nieuwe wachtwoorden komen niet overeen",
     "Next": "Volgende",
-    "Next (Right arrow key)": "Volgende (rechter pijltjestoets)",
-    "No comment yet.": "Nog geen opmerkingen.",
+    "No": "Nee",
     "No connected devices": "Geen apparaten verbonden",
     "No departments": "Geen afdelingen",
     "No groups": "Geen groepen",
@@ -328,7 +322,6 @@
     "Old Password": "Oude wachtwoord",
     "On": "Aan",
     "Only keep a period of history:": "Bewaar alleen geschiedenis over been bepaalde periode:",
-    "Open in New Tab": "Open in nieuw tabblad",
     "Open via Client": "Openen via programma",
     "Operation": "Acties",
     "Operation succeeded.": "Handeling gelukt.",
@@ -341,7 +334,6 @@
     "Owner": "Eigenaar",
     "Owner can use admin panel in an organization, must be a new account.": "Beheerder kan het beheerpaneel in een organisatie gebruiken, moet een nieuw account zijn.",
     "Packaging...": "Aan het inpakken...",
-    "Participants": "Deelnemers",
     "Password": "Wachtwoord",
     "Password again": "Wachtwoord nogmaals",
     "Password is too short": "Wachtwoord is te kort",
@@ -369,12 +361,9 @@
     "Preview and download": "Voorbeeld en download",
     "Preview only": "Alleen voorbeeld",
     "Previous": "Vorige",
-    "Previous (Left arrow key)": "Vorige (linker pijltjestoets)",
-    "Private": "Priv\u00e9",
     "Professional Edition": "Professionele editie",
     "Profile": "Profiel",
     "Profile Setting": "Profielinstelling",
-    "Public": "Openbaar",
     "Publish": "Publiceren",
     "Read-Only": "Alleen lezen",
     "Read-Only library": "Alleen-lezen bibliotheek",
@@ -413,15 +402,13 @@
     "Saving...": "Opslaan...",
     "Seafile": "Seafile",
     "Search": "Zoek",
-    "Search Files": "Zoek Bestanden",
     "Search files in this library": "Zoek bestanden in deze bibliotheek",
-    "Search users...": "Zoek gebruikers...",
-    "Search...": "Zoeken...",
-    "See All Notifications": "Bekijk alle meldingen",
+    "Search groups": "Zoek groepen",
     "Select Image": "Afbeelding selecteren",
     "Select Tags": "Tags selecteren",
     "Select a color": "Kies een kleur",
     "Select a group": "Selecteer een groep",
+    "Select groups": "Selecteer groepen",
     "Select libraries to share": "Selecteer bibliotheken om te delen",
     "Send": "Verzend",
     "Send activation Email after user registration.": "Stuur activatiemail na gebruikersregistratie.",
@@ -452,6 +439,7 @@
     "Shared with all": "Gedeeld met iedereen",
     "Shared with groups": "Gedeeld met groepen",
     "Shared with me": "Gedeeld met mij",
+    "Show": "Toon",
     "Show Codes": "Codes tonen",
     "Size": "Grootte",
     "Space Used": "Ruimte Gebruikt",
@@ -466,7 +454,7 @@
     "Successfully copied %(name)s and %(amount)s other items.": "Kopi\u00ebren van %(name)s en %(amount)s andere items gelukt.",
     "Successfully copied %(name)s and 1 other item.": "Kopi\u00ebren van %(name)s en 1 ander item gelukt.",
     "Successfully copied %(name)s.": "Kopi\u00ebren van %(name)s gelukt.",
-    "Successfully deleted %s": "%s verwijderd.",
+    "Successfully deleted 1 item": "Succesvol 1 item verwijderd.",
     "Successfully deleted 1 item.": "Succesvol 1 item verwijderd.",
     "Successfully moved %(name)s and %(amount)s other items.": "Verplaatsen van %(name)s en %(amount)s andere items gelukt.",
     "Successfully moved %(name)s and 1 other item.": "Verplaatsen van %(name)s en 1 ander item gelukt.",
@@ -490,7 +478,6 @@
     "Text files": "Tekstbestanden",
     "The owner of this library has run out of space.": "De eigenaar van deze bibliotheek heeft geen ruimte meer.",
     "The password will be kept in the server for only 1 hour.": "Het wachtwoord wordt maar 1 uur op de server bewaard.",
-    "This is a draft": "Dit is een concept",
     "This library is password protected": "Deze bibliotheek is beveiligd met een wachtwoord",
     "This operation will not be reverted. Please think twice!": "Deze handeling kan niet ongedaan gemaakt worden",
     "Time": "Tijd:",
@@ -539,6 +526,7 @@
     "View": "Bekijken",
     "View Draft": "Concept bekijken",
     "View Snapshot": "Bekijk Snapshot",
+    "View profile and more": "Profiel en meer weergeven",
     "Virus": "Virus",
     "Virus File": "Virusbestand",
     "Virus Scan": "Virusscan",
@@ -546,23 +534,18 @@
     "Web Download": "Webdownload",
     "Web Upload": "Webupload",
     "Wrong password": "Verkeerd wachtwoord",
+    "Yes": "Ja",
     "You can also add a user as a guest, who will not be allowed to create libraries and groups.": "Je kunt ook een gebruiker als gast toevoegen die geen permissies heeft om gebruikers en bibliotheken aan te maken.",
     "You can use this field at login.": "Je kunt dit veld tijdens het aanmelden gebruiken",
     "You have not shared any folders": "Je hebt geen mappen gedeeld",
     "Your notifications will be sent to this email.": "Je meldingen zullen naar dit e-mailadres worden verzonden.",
-    "Zoom In": "Inzoomen",
-    "Zoom Out": "Uitzoomen",
-    "Zoom in": "Inzoomen",
-    "Zoom out": "Uitzoomen",
+    "ZIP": "ZIP",
     "all": "alle",
     "all members": "alle leden",
     "allow new registrations": "nieuwe registraties toestaan",
     "days": "dagen",
     "deleted": "verwijderd",
-    "draft": "concept",
     "email is required": "e-mail is verplicht",
-    "file": "bestand",
-    "files": "bestanden",
     "icon": "icoon",
     "locked": "Geblokkeerd",
     "name": "naam",
@@ -576,24 +559,24 @@
     "you can also press \u2190 ": "je kan ook drukken op...",
     "{placeholder} Folder Permission": "{placeholder} Map toegangsrechten"
   };
-  for (var key in newcatalog) {
+  for (const key in newcatalog) {
     django.catalog[key] = newcatalog[key];
   }
   
 
   if (!django.jsi18n_initialized) {
     django.gettext = function(msgid) {
-      var value = django.catalog[msgid];
-      if (typeof(value) == 'undefined') {
+      const value = django.catalog[msgid];
+      if (typeof value === 'undefined') {
         return msgid;
       } else {
-        return (typeof(value) == 'string') ? value : value[0];
+        return (typeof value === 'string') ? value : value[0];
       }
     };
 
     django.ngettext = function(singular, plural, count) {
-      var value = django.catalog[singular];
-      if (typeof(value) == 'undefined') {
+      const value = django.catalog[singular];
+      if (typeof value === 'undefined') {
         return (count == 1) ? singular : plural;
       } else {
         return value.constructor === Array ? value[django.pluralidx(count)] : value;
@@ -603,16 +586,16 @@
     django.gettext_noop = function(msgid) { return msgid; };
 
     django.pgettext = function(context, msgid) {
-      var value = django.gettext(context + '\x04' + msgid);
-      if (value.indexOf('\x04') != -1) {
+      let value = django.gettext(context + '\x04' + msgid);
+      if (value.includes('\x04')) {
         value = msgid;
       }
       return value;
     };
 
     django.npgettext = function(context, singular, plural, count) {
-      var value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
-      if (value.indexOf('\x04') != -1) {
+      let value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
+      if (value.includes('\x04')) {
         value = django.ngettext(singular, plural, count);
       }
       return value;
@@ -662,12 +645,7 @@
       "%d-%m-%y %H.%M",
       "%d/%m/%Y %H.%M",
       "%d/%m/%y %H.%M",
-      "%d-%m-%Y",
-      "%d-%m-%y",
-      "%Y-%m-%d",
-      "%d/%m/%Y",
-      "%d/%m/%y",
-      "%Y/%m/%d"
+      "%Y-%m-%d"
     ],
     "DATE_FORMAT": "j F Y",
     "DATE_INPUT_FORMATS": [
@@ -675,6 +653,7 @@
       "%d-%m-%y",
       "%d/%m/%Y",
       "%d/%m/%y",
+      "%Y/%m/%d",
       "%Y-%m-%d"
     ],
     "DECIMAL_SEPARATOR": ",",
@@ -697,8 +676,8 @@
   };
 
     django.get_format = function(format_type) {
-      var value = django.formats[format_type];
-      if (typeof(value) == 'undefined') {
+      const value = django.formats[format_type];
+      if (typeof value === 'undefined') {
         return format_type;
       } else {
         return value;
@@ -717,6 +696,5 @@
 
     django.jsi18n_initialized = true;
   }
-
-}(this));
+};
 
