@@ -4,7 +4,7 @@ from io import BytesIO
 from openpyxl import load_workbook
 
 from django.http import HttpResponse
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from rest_framework.authentication import SessionAuthentication
 from rest_framework.permissions import IsAuthenticated
@@ -28,6 +28,7 @@ from seahub.base.accounts import User
 from seahub.group.signals import add_user_to_group
 from seahub.group.utils import is_group_member, is_group_admin, \
     is_group_owner, is_group_admin_or_owner, get_group_member_info
+from seahub.profile.models import Profile
 
 from .utils import api_check_group
 
@@ -133,10 +134,42 @@ class GroupMembers(APIView):
         return Response(member_info, status=status.HTTP_201_CREATED)
 
 
+class GroupSearchMember(APIView):
+
+    authentication_classes = (TokenAuthentication, SessionAuthentication)
+    permission_classes = (IsAuthenticated,)
+    throttle_classes = (UserRateThrottle,)
+
+    @api_check_group
+    def get(self, request, group_id, format=None):
+        """
+        Search group member by email.
+        """
+
+        q = request.GET.get('q', '')
+        if not q:
+            error_msg = 'q invalid.'
+            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+        if not is_group_member(group_id, request.user.username):
+            error_msg = 'Permission denied.'
+            return api_error(status.HTTP_403_FORBIDDEN, error_msg)
+
+        group_members = []
+        members = ccnet_api.search_group_members(group_id, q)
+        for member in members:
+
+            member_info = get_group_member_info(request, group_id, member.user_name)
+
+            group_members.append(member_info)
+
+        return Response(group_members)
+
+
 class GroupMember(APIView):
     authentication_classes = (TokenAuthentication, SessionAuthentication)
     permission_classes = (IsAuthenticated,)
-    throttle_classes = (UserRateThrottle, )
+    throttle_classes = (UserRateThrottle,)
 
     @api_check_group
     def get(self, request, group_id, email):
@@ -424,17 +457,33 @@ class GroupMembersImport(APIView):
             org_id = request.user.org.org_id
 
         for email in emails_list:
-            email_name = email2nickname(email)
+
+            email_from_excel = email
+
+            user_not_found = False
+
             try:
                 User.objects.get(email=email)
             except User.DoesNotExist:
+                user_not_found = True
+
+            if user_not_found:
+                email = Profile.objects.get_username_by_contact_email(email)
+                try:
+                    User.objects.get(email=email)
+                    user_not_found = False
+                except User.DoesNotExist:
+                    user_not_found = True
+
+            if user_not_found:
                 result['failed'].append({
-                    'email': email,
-                    'email_name': email_name,
-                    'error_msg': 'User %s not found.' % email_name
+                    'email': email_from_excel,
+                    'email_name': email2nickname(email_from_excel),
+                    'error_msg': 'User %s not found.' % email2nickname(email_from_excel)
                     })
                 continue
 
+            email_name = email2nickname(email)
             if is_group_member(group_id, email, in_structure=False):
                 result['failed'].append({
                     'email': email,
