@@ -14,7 +14,7 @@ from seahub.api2.utils import api_error
 
 from seahub.api2.endpoints.group_owned_libraries import get_group_id_by_repo_owner
 
-from seahub.base.models import UserStarredFiles
+from seahub.base.models import UserStarredFiles, UserMonitoredRepos
 from seahub.base.templatetags.seahub_tags import email2nickname, \
         email2contact_email
 from seahub.signals import repo_deleted
@@ -24,7 +24,7 @@ from seahub.group.utils import group_id_to_name
 from seahub.utils import is_org_context, is_pro_version
 from seahub.utils.timeutils import timestamp_to_isoformat_timestr
 from seahub.utils.repo import get_repo_owner, is_repo_admin, \
-        repo_has_been_shared_out, get_related_users_by_repo, normalize_repo_status_code
+        repo_has_been_shared_out, normalize_repo_status_code
 
 from seahub.settings import ENABLE_STORAGE_CLASSES
 
@@ -36,7 +36,7 @@ logger = logging.getLogger(__name__)
 class ReposView(APIView):
 
     authentication_classes = (TokenAuthentication, SessionAuthentication)
-    permission_classes = (IsAuthenticated, )
+    permission_classes = (IsAuthenticated,)
     throttle_classes = (UserRateThrottle,)
 
     def get(self, request):
@@ -84,10 +84,11 @@ class ReposView(APIView):
 
             if org_id:
                 owned_repos = seafile_api.get_org_owned_repo_list(org_id,
-                        email, ret_corrupted=True)
+                                                                  email,
+                                                                  ret_corrupted=True)
             else:
                 owned_repos = seafile_api.get_owned_repo_list(email,
-                        ret_corrupted=True)
+                                                              ret_corrupted=True)
 
             # Reduce memcache fetch ops.
             modifiers_set = {x.last_modifier for x in owned_repos}
@@ -97,6 +98,15 @@ class ReposView(APIView):
                 if e not in nickname_dict:
                     nickname_dict[e] = email2nickname(e)
 
+            owned_repo_ids = [item.repo_id for item in owned_repos]
+            try:
+                monitored_repos = UserMonitoredRepos.objects.filter(repo_id__in=owned_repo_ids)
+                monitored_repos = monitored_repos.filter(email=email)
+                monitored_repo_id_list = [item.repo_id for item in monitored_repos]
+            except Exception as e:
+                logger.error(e)
+                monitored_repo_id_list = []
+
             owned_repos.sort(key=lambda x: x.last_modify, reverse=True)
             for r in owned_repos:
 
@@ -119,6 +129,7 @@ class ReposView(APIView):
                     "encrypted": r.encrypted,
                     "permission": 'rw',  # Always have read-write permission to owned repo
                     "starred": r.repo_id in starred_repo_id_list,
+                    "monitored": r.repo_id in monitored_repo_id_list,
                     "status": normalize_repo_status_code(r.status),
                     "salt": r.salt if r.enc_version >= 3 else '',
                 }
@@ -133,13 +144,11 @@ class ReposView(APIView):
 
             if org_id:
                 shared_repos = seafile_api.get_org_share_in_repo_list(org_id,
-                        email, -1, -1)
+                                                                      email, -1, -1)
             else:
-                shared_repos = seafile_api.get_share_in_repo_list(
-                        email, -1, -1)
+                shared_repos = seafile_api.get_share_in_repo_list(email, -1, -1)
 
-            repos_with_admin_share_to = ExtraSharePermission.objects.\
-                    get_repos_with_admin_permission(email)
+            repos_with_admin_share_to = ExtraSharePermission.objects.get_repos_with_admin_permission(email)
 
             # Reduce memcache fetch ops.
             owners_set = {x.user for x in shared_repos}
@@ -150,6 +159,15 @@ class ReposView(APIView):
                 if e not in nickname_dict:
                     nickname_dict[e] = email2nickname(e)
 
+            shared_repo_ids = [item.repo_id for item in shared_repos]
+            try:
+                monitored_repos = UserMonitoredRepos.objects.filter(repo_id__in=shared_repo_ids)
+                monitored_repos = monitored_repos.filter(email=email)
+                monitored_repo_id_list = [item.repo_id for item in monitored_repos]
+            except Exception as e:
+                logger.error(e)
+                monitored_repo_id_list = []
+
             shared_repos.sort(key=lambda x: x.last_modify, reverse=True)
             for r in shared_repos:
 
@@ -160,12 +178,10 @@ class ReposView(APIView):
                 if '@seafile_group' in owner_email:
                     is_group_owned_repo = True
                     group_id = get_group_id_by_repo_owner(owner_email)
-                    group_name= group_id_to_name(group_id)
+                    group_name = group_id_to_name(group_id)
 
-                owner_name = group_name if is_group_owned_repo else \
-                        nickname_dict.get(owner_email, '')
-                owner_contact_email = '' if is_group_owned_repo else \
-                        contact_email_dict.get(owner_email, '')
+                owner_name = group_name if is_group_owned_repo else nickname_dict.get(owner_email, '')
+                owner_contact_email = '' if is_group_owned_repo else contact_email_dict.get(owner_email, '')
 
                 repo_info = {
                     "type": "shared",
@@ -182,6 +198,7 @@ class ReposView(APIView):
                     "encrypted": r.encrypted,
                     "permission": r.permission,
                     "starred": r.repo_id in starred_repo_id_list,
+                    "monitored": r.repo_id in monitored_repo_id_list,
                     "status": normalize_repo_status_code(r.status),
                     "salt": r.salt if r.enc_version >= 3 else '',
                 }
@@ -211,6 +228,15 @@ class ReposView(APIView):
                 if e not in nickname_dict:
                     nickname_dict[e] = email2nickname(e)
 
+            group_repo_ids = [item.repo_id for item in group_repos]
+            try:
+                monitored_repos = UserMonitoredRepos.objects.filter(repo_id__in=group_repo_ids)
+                monitored_repos = monitored_repos.filter(email=email)
+                monitored_repo_id_list = [item.repo_id for item in monitored_repos]
+            except Exception as e:
+                logger.error(e)
+                monitored_repo_id_list = []
+
             for r in group_repos:
                 repo_info = {
                     "type": "group",
@@ -226,6 +252,7 @@ class ReposView(APIView):
                     "encrypted": r.encrypted,
                     "permission": r.permission,
                     "starred": r.repo_id in starred_repo_id_list,
+                    "monitored": r.repo_id in monitored_repo_id_list,
                     "status": normalize_repo_status_code(r.status),
                     "salt": r.salt if r.enc_version >= 3 else '',
                 }
@@ -290,8 +317,8 @@ class ReposView(APIView):
 class RepoView(APIView):
 
     authentication_classes = (TokenAuthentication, SessionAuthentication)
-    permission_classes = (IsAuthenticated, )
-    throttle_classes = (UserRateThrottle, )
+    permission_classes = (IsAuthenticated,)
+    throttle_classes = (UserRateThrottle,)
 
     def get(self, request, repo_id):
         """ Return repo info
@@ -395,3 +422,79 @@ class RepoView(APIView):
                           repo_name=repo.name)
 
         return Response('success', status=status.HTTP_200_OK)
+
+
+class RepoShareInfoView(APIView):
+
+    authentication_classes = (TokenAuthentication, SessionAuthentication)
+    permission_classes = (IsAuthenticated,)
+    throttle_classes = (UserRateThrottle,)
+
+    def get(self, request, repo_id):
+        """ Return repo share info
+
+        Permission checking:
+        1. all authenticated user can perform this action.
+        """
+
+        # resource check
+        repo = seafile_api.get_repo(repo_id)
+        if not repo:
+            error_msg = 'Library %s not found.' % repo_id
+            return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+
+        # permission check
+        permission = check_folder_permission(request, repo_id, '/')
+        if not permission:
+            error_msg = 'Permission denied.'
+            return api_error(status.HTTP_403_FORBIDDEN, error_msg)
+
+        folder_path = request.GET.get('path', '/')
+        if folder_path != '/':
+            dir_id = seafile_api.get_dir_id_by_path(repo_id, folder_path)
+            if not dir_id:
+                error_msg = 'Folder %s not found.' % folder_path
+                return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+
+        if is_org_context(request):
+            org_id = request.user.org.org_id
+            repo_owner = seafile_api.get_org_repo_owner(repo_id)
+            if folder_path == '/':
+                shared_users = seafile_api.list_org_repo_shared_to(repo_owner, repo_id)
+                shared_groups = seafile_api.list_org_repo_shared_group(org_id, repo_owner, repo_id)
+            else:
+                shared_users = seafile_api.get_org_shared_users_for_subdir(org_id,
+                                                                           repo_id,
+                                                                           folder_path,
+                                                                           repo_owner)
+                shared_groups = seafile_api.get_org_shared_groups_for_subdir(org_id,
+                                                                             repo_id,
+                                                                             folder_path,
+                                                                             repo_owner)
+        else:
+            repo_owner = seafile_api.get_repo_owner(repo_id)
+            if folder_path == '/':
+                shared_users = seafile_api.list_repo_shared_to(repo_owner, repo_id)
+                shared_groups = seafile_api.list_repo_shared_group_by_user(repo_owner, repo_id)
+            else:
+                shared_users = seafile_api.get_shared_users_for_subdir(repo_id,
+                                                                       folder_path,
+                                                                       repo_owner)
+                shared_groups = seafile_api.get_shared_groups_for_subdir(repo_id,
+                                                                         folder_path,
+                                                                         repo_owner)
+
+        group_id = ''
+        if '@seafile_group' in repo_owner:
+            group_id = get_group_id_by_repo_owner(repo_owner)
+
+        shared_group_ids = [item.group_id for item in shared_groups]
+        if group_id and group_id in shared_group_ids:
+            shared_group_ids.remove(group_id)
+
+        result = {
+            "shared_user_emails": [item.user for item in shared_users],
+            "shared_group_ids": shared_group_ids,
+        }
+
+        return Response(result)
