@@ -1,5 +1,7 @@
 # Copyright (c) 2012-2016 Seafile Ltd.
 import os
+import posixpath
+import json
 import logging
 
 from pysearpc import SearpcError
@@ -8,7 +10,7 @@ from rest_framework.authentication import SessionAuthentication
 from rest_framework.permissions import IsAuthenticated
 from rest_framework.response import Response
 from rest_framework.views import APIView
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 import seaserv
 from seaserv import seafile_api, ccnet_api
@@ -21,19 +23,21 @@ from seahub.api2.views import HTTP_443_ABOVE_QUOTA
 from seahub.group.utils import is_group_member
 from seahub.base.accounts import User
 from seahub.share.utils import is_repo_admin, \
-        check_user_share_out_permission, check_group_share_out_permission
+        check_user_share_out_permission, check_group_share_out_permission, \
+        normalize_custom_permission_name
 from seahub.share.models import ExtraSharePermission, ExtraGroupsSharePermission
 from seahub.share.signals import share_repo_to_user_successful, \
         share_repo_to_group_successful
 from seahub.utils import is_org_context, send_perm_audit_msg, \
         normalize_dir_path, get_folder_permission_recursively, \
-        normalize_file_path, check_filename_with_rename
+        normalize_file_path, check_filename_with_rename, get_file_type_and_ext
 from seahub.utils.repo import get_repo_owner, get_available_repo_perms, \
         parse_repo_perm, get_locked_files_by_dir, get_sub_folder_permission_by_dir
 
 from seahub.views import check_folder_permission
 from seahub.settings import MAX_PATH
-from seahub.constants import PERMISSION_READ_WRITE, PERMISSION_READ
+from seahub.utils.file_types import SEADOC
+from seahub.seadoc.utils import copy_sdoc_images_to_different_repo, move_sdoc_images_to_different_repo
 
 logger = logging.getLogger(__name__)
 
@@ -72,10 +76,11 @@ class ReposBatchView(APIView):
         if is_org_context(request):
             org_id = request.user.org.org_id
             share_items = seafile_api.list_org_repo_shared_group(org_id,
-                    username, repo_id)
+                                                                 username,
+                                                                 repo_id)
         else:
-            share_items = seafile_api.list_repo_shared_group_by_user(
-                    username, repo_id)
+            share_items = seafile_api.list_repo_shared_group_by_user(username,
+                                                                     repo_id)
 
         ret = []
         for item in share_items:
@@ -148,8 +153,10 @@ class ReposBatchView(APIView):
 
             permission = request.data.get('permission', 'rw')
             if permission not in get_available_repo_perms():
-                error_msg = 'permission invalid.'
-                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+                permission = normalize_custom_permission_name(permission)
+                if not permission:
+                    error_msg = 'permission invalid.'
+                    return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
 
             # share repo to user
             if share_type == 'user':
@@ -197,10 +204,15 @@ class ReposBatchView(APIView):
                         if is_org_context(request):
                             org_id = request.user.org.org_id
                             seaserv.seafserv_threaded_rpc.org_add_share(org_id,
-                                    repo_id, username, to_username, permission)
+                                                                        repo_id,
+                                                                        username,
+                                                                        to_username,
+                                                                        permission)
                         else:
-                            seafile_api.share_repo(
-                                    repo_id, username, to_username, permission)
+                            seafile_api.share_repo(repo_id,
+                                                   username,
+                                                   to_username,
+                                                   permission)
 
                         # send a signal when sharing repo successful
                         repo = seafile_api.get_repo(repo_id)
@@ -323,10 +335,13 @@ class ReposBatchView(APIView):
                     try:
                         # get share permission before unshare operation
                         permission = check_user_share_out_permission(repo_id,
-                                '/', to_username, is_org_context(request))
+                                                                     '/',
+                                                                     to_username,
+                                                                     is_org_context(request))
 
                         if is_org_context(request):
-                            # when calling seafile API to share authority related functions, change the uesrname to repo owner.
+                            # when calling seafile API to share authority related functions,
+                            # change the uesrname to repo owner.
                             org_id = request.user.org.org_id
                             seafile_api.org_remove_share(org_id, repo_id, repo_owner, to_username)
                         else:
@@ -334,11 +349,11 @@ class ReposBatchView(APIView):
 
                         # Delete share permission at ExtraSharePermission table.
                         ExtraSharePermission.objects.delete_share_permission(repo_id,
-                                to_username)
+                                                                             to_username)
 
                         # send message
                         send_perm_audit_msg('delete-repo-perm', username,
-                                to_username, repo_id, '/', permission)
+                                            to_username, repo_id, '/', permission)
 
                         result['success'].append({
                             "repo_id": repo_id,
@@ -378,7 +393,9 @@ class ReposBatchView(APIView):
                     try:
                         # get share permission before unshare operation
                         permission = check_group_share_out_permission(repo_id,
-                                '/', to_group_id, is_org_context(request))
+                                                                      '/',
+                                                                      to_group_id,
+                                                                      is_org_context(request))
 
                         org_id = None
                         if is_org_context(request):
@@ -390,11 +407,11 @@ class ReposBatchView(APIView):
 
                         # Delete share permission at ExtraSharePermission table.
                         ExtraGroupsSharePermission.objects.delete_share_permission(repo_id,
-                                to_group_id)
+                                                                                   to_group_id)
 
                         # send message
                         send_perm_audit_msg('delete-repo-perm', username,
-                                to_group_id, repo_id, '/', permission)
+                                            to_group_id, repo_id, '/', permission)
 
                         result['success'].append({
                             "repo_id": repo_id,
@@ -565,8 +582,11 @@ class ReposBatchCopyDirView(APIView):
 
             try:
                 # need_progress=0, synchronous=1
-                seafile_api.copy_file(src_repo_id, src_parent_dir, src_obj_name,
-                        dst_repo_id, dst_parent_dir, dst_obj_name, username, 0, 1)
+                seafile_api.copy_file(src_repo_id, src_parent_dir,
+                                      json.dumps([src_obj_name]),
+                                      dst_repo_id, dst_parent_dir,
+                                      json.dumps([dst_obj_name]),
+                                      username, 0, 1)
             except Exception as e:
                 logger.error(e)
                 error_dict = {
@@ -816,11 +836,11 @@ class ReposBatchCopyItemView(APIView):
                 continue
 
             # src resource check
-            ## as we don't know if `src_path` stands for a file or a folder,
-            ## so we check both
+            # as we don't know if `src_path` stands for a file or a folder,
+            # so we check both
             src_dir_id = seafile_api.get_dir_id_by_path(src_repo_id, src_path)
             src_file_id = seafile_api.get_file_id_by_path(src_repo_id,
-                    normalize_file_path(src_path))
+                                                          normalize_file_path(src_path))
 
             if not src_dir_id and not src_file_id:
                 error_dict = {
@@ -859,10 +879,14 @@ class ReposBatchCopyItemView(APIView):
 
             try:
                 dst_obj_name = check_filename_with_rename(dst_repo_id,
-                        dst_parent_dir, dst_obj_name)
+                                                          dst_parent_dir,
+                                                          dst_obj_name)
                 # need_progress=0, synchronous=1
-                seafile_api.copy_file(src_repo_id, src_parent_dir, src_obj_name,
-                        dst_repo_id, dst_parent_dir, dst_obj_name, username, 0, 1)
+                seafile_api.copy_file(src_repo_id, src_parent_dir,
+                                      json.dumps([src_obj_name]),
+                                      dst_repo_id, dst_parent_dir,
+                                      json.dumps([dst_obj_name]),
+                                      username, 0, 1)
             except Exception as e:
                 logger.error(e)
                 error_dict = {
@@ -988,11 +1012,11 @@ class ReposBatchMoveItemView(APIView):
                 continue
 
             # src resource check
-            ## as we don't know if `src_path` stands for a file or a folder,
-            ## so we check both
+            # as we don't know if `src_path` stands for a file or a folder,
+            # so we check both
             src_dir_id = seafile_api.get_dir_id_by_path(src_repo_id, src_path)
             src_file_id = seafile_api.get_file_id_by_path(src_repo_id,
-                    normalize_file_path(src_path))
+                                                          normalize_file_path(src_path))
 
             if not src_dir_id and not src_file_id:
                 error_dict = {
@@ -1031,11 +1055,13 @@ class ReposBatchMoveItemView(APIView):
 
             try:
                 dst_obj_name = check_filename_with_rename(dst_repo_id,
-                        dst_parent_dir, dst_obj_name)
-                # replace=False, username=username, need_progress=0, synchronous=1
-                seafile_api.move_file(src_repo_id, src_parent_dir, src_obj_name,
-                        dst_repo_id, dst_parent_dir, dst_obj_name,
-                        False, username, 0, 1)
+                                                          dst_parent_dir,
+                                                          dst_obj_name)
+                seafile_api.move_file(src_repo_id, src_parent_dir,
+                                      json.dumps([src_obj_name]),
+                                      dst_repo_id, dst_parent_dir,
+                                      json.dumps([dst_obj_name]),
+                                      False, username, 0, 1)
             except Exception as e:
                 logger.error(e)
                 error_dict = {
@@ -1118,29 +1144,24 @@ class ReposAsyncBatchCopyItemView(APIView):
             return api_error(status.HTTP_404_NOT_FOUND, error_msg)
 
         # permission check
-        # 1. User must has `r/rw` permission for src parent dir.
-        src_parent_permission = check_folder_permission(request, src_repo_id, src_parent_dir)
-        if src_parent_permission not in (PERMISSION_READ_WRITE,
-                PERMISSION_READ):
+        # 1. User must has `r/rw` or `copy` permission for src parent dir.
+        if parse_repo_perm(check_folder_permission(request, src_repo_id, src_parent_dir)).can_copy is False:
             error_msg = 'Permission denied.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
         # 2. User must has `rw` permission for dst parent dir.
         dst_parent_permission = check_folder_permission(request, dst_repo_id, dst_parent_dir)
-        if dst_parent_permission != PERMISSION_READ_WRITE:
+        if parse_repo_perm(dst_parent_permission).can_edit_on_web is False:
             error_msg = 'Permission denied.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
         result = {}
         username = request.user.username
-
-        formated_src_dirents = [dirent.strip('/') for dirent in src_dirents]
-        src_multi = "\t".join(formated_src_dirents)
-        dst_multi = "\t".join(formated_src_dirents)
-
         try:
-            res = seafile_api.copy_file(src_repo_id, src_parent_dir, src_multi,
-                                        dst_repo_id, dst_parent_dir, dst_multi,
+            res = seafile_api.copy_file(src_repo_id, src_parent_dir,
+                                        json.dumps(src_dirents),
+                                        dst_repo_id, dst_parent_dir,
+                                        json.dumps(src_dirents),
                                         username=username, need_progress=1,
                                         synchronous=0)
         except Exception as e:
@@ -1150,6 +1171,23 @@ class ReposAsyncBatchCopyItemView(APIView):
 
         result = {}
         result['task_id'] = res.task_id if res.background else ''
+
+        # sdoc image
+        try:
+            sdoc_dirents = []
+            if src_repo_id != dst_repo_id:
+                for dirent in src_dirents:
+                    filetype, fileext = get_file_type_and_ext(dirent)
+                    if filetype == SEADOC:
+                        sdoc_dirents.append(dirent)
+            for sdoc_dirent in sdoc_dirents:
+                src_path = posixpath.join(src_parent_dir, sdoc_dirent)
+                dst_path = posixpath.join(dst_parent_dir, sdoc_dirent)
+                copy_sdoc_images_to_different_repo(
+                    src_repo_id, src_path, dst_repo_id, dst_path, username, is_async=True)
+        except Exception as e:
+            logger.error(e)
+
         return Response(result)
 
 
@@ -1220,13 +1258,13 @@ class ReposAsyncBatchMoveItemView(APIView):
             return api_error(status.HTTP_404_NOT_FOUND, error_msg)
 
         # permission check
-        # 1. User must has `rw` permission for src parent dir.
-        if check_folder_permission(request, src_repo_id, src_parent_dir) != PERMISSION_READ_WRITE:
+        # 1. User must has `rw` or `modify` permission for src parent dir.
+        if parse_repo_perm(check_folder_permission(request, src_repo_id, src_parent_dir)).can_edit_on_web is False:
             error_msg = 'Permission denied.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
-        # 2. User must has `rw` permission for dst parent dir.
-        if check_folder_permission(request, dst_repo_id, dst_parent_dir) != PERMISSION_READ_WRITE:
+        # 2. User must has `rw` or `modify` permission for dst parent dir.
+        if parse_repo_perm(check_folder_permission(request, dst_repo_id, dst_parent_dir)).can_edit_on_web is False:
             error_msg = 'Permission denied.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
@@ -1242,22 +1280,21 @@ class ReposAsyncBatchMoveItemView(APIView):
 
         # check sub folder permission
         folder_permission_dict = get_sub_folder_permission_by_dir(request,
-                src_repo_id, src_parent_dir)
+                                                                  src_repo_id,
+                                                                  src_parent_dir)
         for dirent in src_dirents:
             if dirent in list(folder_permission_dict.keys()) and \
-                    folder_permission_dict[dirent] != 'rw':
+                    parse_repo_perm(folder_permission_dict[dirent]).can_edit_on_web is False:
                 error_msg = _("Can't move folder %s, please check its permission.") % dirent
                 return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
         # move file
         result = {}
-        formated_src_dirents = [dirent.strip('/') for dirent in src_dirents]
-        src_multi = "\t".join(formated_src_dirents)
-        dst_multi = "\t".join(formated_src_dirents)
-
         try:
-            res = seafile_api.move_file(src_repo_id, src_parent_dir, src_multi,
-                                        dst_repo_id, dst_parent_dir, dst_multi,
+            res = seafile_api.move_file(src_repo_id, src_parent_dir,
+                                        json.dumps(src_dirents),
+                                        dst_repo_id, dst_parent_dir,
+                                        json.dumps(src_dirents),
                                         replace=False, username=username,
                                         need_progress=1, synchronous=0)
         except Exception as e:
@@ -1267,6 +1304,23 @@ class ReposAsyncBatchMoveItemView(APIView):
 
         result = {}
         result['task_id'] = res.task_id if res.background else ''
+
+        # sdoc image
+        try:
+            sdoc_dirents = []
+            if src_repo_id != dst_repo_id:
+                for dirent in src_dirents:
+                    filetype, fileext = get_file_type_and_ext(dirent)
+                    if filetype == SEADOC:
+                        sdoc_dirents.append(dirent)
+            for sdoc_dirent in sdoc_dirents:
+                src_path = posixpath.join(src_parent_dir, sdoc_dirent)
+                dst_path = posixpath.join(dst_parent_dir, sdoc_dirent)
+                move_sdoc_images_to_different_repo(
+                    src_repo_id, src_path, dst_repo_id, dst_path, username, is_async=True)
+        except Exception as e:
+            logger.error(e)
+
         return Response(result)
 
 
@@ -1337,29 +1391,24 @@ class ReposSyncBatchCopyItemView(APIView):
             return api_error(status.HTTP_404_NOT_FOUND, error_msg)
 
         # permission check
-        # 1. User must has `r/rw` permission for src parent dir.
-        src_parent_permission = check_folder_permission(request, src_repo_id, src_parent_dir)
-        if src_parent_permission not in (PERMISSION_READ_WRITE,
-                PERMISSION_READ):
+        # 1. User must has `r/rw` or `copy` permission for src parent dir.
+        if parse_repo_perm(check_folder_permission(request, src_repo_id, src_parent_dir)).can_copy is False:
             error_msg = 'Permission denied.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
         # 2. User must has `rw` permission for dst parent dir.
         dst_parent_permission = check_folder_permission(request, dst_repo_id, dst_parent_dir)
-        if dst_parent_permission != PERMISSION_READ_WRITE:
+        if parse_repo_perm(dst_parent_permission).can_edit_on_web is False:
             error_msg = 'Permission denied.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
         result = {}
         username = request.user.username
-
-        formated_src_dirents = [dirent.strip('/') for dirent in src_dirents]
-        src_multi = "\t".join(formated_src_dirents)
-        dst_multi = "\t".join(formated_src_dirents)
-
         try:
-            seafile_api.copy_file(src_repo_id, src_parent_dir, src_multi,
-                                  dst_repo_id, dst_parent_dir, dst_multi,
+            seafile_api.copy_file(src_repo_id, src_parent_dir,
+                                  json.dumps(src_dirents),
+                                  dst_repo_id, dst_parent_dir,
+                                  json.dumps(src_dirents),
                                   username=username, need_progress=0,
                                   synchronous=1)
         except Exception as e:
@@ -1369,6 +1418,23 @@ class ReposSyncBatchCopyItemView(APIView):
 
         result = {}
         result['success'] = True
+
+        # sdoc image
+        try:
+            sdoc_dirents = []
+            if src_repo_id != dst_repo_id:
+                for dirent in src_dirents:
+                    filetype, fileext = get_file_type_and_ext(dirent)
+                    if filetype == SEADOC:
+                        sdoc_dirents.append(dirent)
+            for sdoc_dirent in sdoc_dirents:
+                src_path = posixpath.join(src_parent_dir, sdoc_dirent)
+                dst_path = posixpath.join(dst_parent_dir, sdoc_dirent)
+                copy_sdoc_images_to_different_repo(
+                    src_repo_id, src_path, dst_repo_id, dst_path, username, is_async=False)
+        except Exception as e:
+            logger.error(e)
+
         return Response(result)
 
 
@@ -1439,13 +1505,13 @@ class ReposSyncBatchMoveItemView(APIView):
             return api_error(status.HTTP_404_NOT_FOUND, error_msg)
 
         # permission check
-        # 1. User must has `rw` permission for src parent dir.
-        if check_folder_permission(request, src_repo_id, src_parent_dir) != PERMISSION_READ_WRITE:
+        # 1. User must has `rw` or `modify` permission for src parent dir.
+        if parse_repo_perm(check_folder_permission(request, src_repo_id, src_parent_dir)).can_edit_on_web is False:
             error_msg = 'Permission denied.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
-        # 2. User must has `rw` permission for dst parent dir.
-        if check_folder_permission(request, dst_repo_id, dst_parent_dir) != PERMISSION_READ_WRITE:
+        # 2. User must has `rw` or `modify` permission for dst parent dir.
+        if parse_repo_perm(check_folder_permission(request, dst_repo_id, dst_parent_dir)).can_edit_on_web is False:
             error_msg = 'Permission denied.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
@@ -1461,22 +1527,21 @@ class ReposSyncBatchMoveItemView(APIView):
 
         # check sub folder permission
         folder_permission_dict = get_sub_folder_permission_by_dir(request,
-                src_repo_id, src_parent_dir)
+                                                                  src_repo_id,
+                                                                  src_parent_dir)
         for dirent in src_dirents:
             if dirent in list(folder_permission_dict.keys()) and \
-                    folder_permission_dict[dirent] != 'rw':
+                    parse_repo_perm(folder_permission_dict[dirent]).can_edit_on_web is False:
                 error_msg = _("Can't move folder %s, please check its permission.") % dirent
                 return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
         # move file
         result = {}
-        formated_src_dirents = [dirent.strip('/') for dirent in src_dirents]
-        src_multi = "\t".join(formated_src_dirents)
-        dst_multi = "\t".join(formated_src_dirents)
-
         try:
-            seafile_api.move_file(src_repo_id, src_parent_dir, src_multi,
-                                  dst_repo_id, dst_parent_dir, dst_multi,
+            seafile_api.move_file(src_repo_id, src_parent_dir,
+                                  json.dumps(src_dirents),
+                                  dst_repo_id, dst_parent_dir,
+                                  json.dumps(src_dirents),
                                   replace=False, username=username,
                                   need_progress=0, synchronous=1)
         except Exception as e:
@@ -1486,6 +1551,23 @@ class ReposSyncBatchMoveItemView(APIView):
 
         result = {}
         result['success'] = True
+
+        # sdoc image
+        try:
+            sdoc_dirents = []
+            if src_repo_id != dst_repo_id:
+                for dirent in src_dirents:
+                    filetype, fileext = get_file_type_and_ext(dirent)
+                    if filetype == SEADOC:
+                        sdoc_dirents.append(dirent)
+            for sdoc_dirent in sdoc_dirents:
+                src_path = posixpath.join(src_parent_dir, sdoc_dirent)
+                dst_path = posixpath.join(dst_parent_dir, sdoc_dirent)
+                move_sdoc_images_to_different_repo(
+                    src_repo_id, src_path, dst_repo_id, dst_path, username, is_async=False)
+        except Exception as e:
+            logger.error(e)
+
         return Response(result)
 
 
@@ -1524,7 +1606,8 @@ class ReposBatchDeleteItemView(APIView):
             return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
 
         # resource check
-        if not seafile_api.get_repo(repo_id):
+        repo = seafile_api.get_repo(repo_id)
+        if not repo:
             error_msg = 'Library %s not found.' % repo_id
             return api_error(status.HTTP_404_NOT_FOUND, error_msg)
 
@@ -1534,7 +1617,7 @@ class ReposBatchDeleteItemView(APIView):
 
         # permission check
         # User must has `rw` permission for parent dir.
-        if check_folder_permission(request, repo_id, parent_dir) != PERMISSION_READ_WRITE:
+        if parse_repo_perm(check_folder_permission(request, repo_id, parent_dir)).can_delete is False:
             error_msg = 'Permission denied.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
@@ -1552,17 +1635,16 @@ class ReposBatchDeleteItemView(APIView):
         folder_permission_dict = get_sub_folder_permission_by_dir(request, repo_id, parent_dir)
         for dirent in dirents:
             if dirent in list(folder_permission_dict.keys()) and \
-                    folder_permission_dict[dirent] != 'rw':
+                    folder_permission_dict[dirent] not in ('rw', 'cloud-edit'):
                 error_msg = _("Can't delete folder %s, please check its permission.") % dirent
                 return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
         # delete file
         result = {}
-        formated_dirents = [dirent.strip('/') for dirent in dirents]
-        multi_dirents_str = "\t".join(formated_dirents)
-
         try:
-            seafile_api.del_file(repo_id, parent_dir, multi_dirents_str, username)
+            seafile_api.del_file(repo_id, parent_dir,
+                                 json.dumps(dirents),
+                                 username)
         except Exception as e:
             logger.error(e)
             error_msg = 'Internal Server Error'
@@ -1570,4 +1652,5 @@ class ReposBatchDeleteItemView(APIView):
 
         result = {}
         result['success'] = True
+        result['commit_id'] = repo.head_cmmt_id
         return Response(result)
