@@ -8,6 +8,7 @@ import posixpath
 from constance import config
 from dateutil.relativedelta import relativedelta
 import dateutil.parser
+from collections import defaultdict
 
 from rest_framework.authentication import SessionAuthentication
 from rest_framework.permissions import IsAuthenticated
@@ -17,8 +18,8 @@ from rest_framework import status
 
 from django.utils import timezone
 from django.utils.timezone import get_current_timezone
-from django.utils.translation import ugettext as _
-from django.utils.http import urlquote
+from django.utils.translation import gettext as _
+from urllib.parse import quote
 
 from seaserv import seafile_api
 from pysearpc import SearpcError
@@ -30,11 +31,14 @@ from seahub.api2.permissions import CanGenerateShareLink, IsProVersion
 from seahub.constants import PERMISSION_READ_WRITE, PERMISSION_READ, \
         PERMISSION_PREVIEW_EDIT, PERMISSION_PREVIEW
 from seahub.share.models import FileShare, UploadLinkShare, check_share_link_access
+from seahub.share.decorators import check_share_link_count
 from seahub.utils import gen_shared_link, is_org_context, normalize_file_path, \
         normalize_dir_path, is_pro_version, get_file_type_and_ext, \
-        check_filename_with_rename, gen_file_upload_url
+        check_filename_with_rename, gen_file_upload_url, \
+        get_password_strength_level, is_valid_password
 from seahub.utils.file_op import if_locked_by_online_office
 from seahub.utils.file_types import IMAGE, VIDEO, XMIND
+from seahub.utils.file_tags import get_tagged_files, get_files_tags_in_dir
 from seahub.utils.timeutils import datetime_to_isoformat_timestr, \
         timestamp_to_isoformat_timestr
 from seahub.utils.repo import parse_repo_perm
@@ -48,6 +52,7 @@ from seahub.wiki.models import Wiki
 from seahub.views.file import can_edit_file
 from seahub.views import check_folder_permission
 from seahub.signals import upload_file_successful
+from seahub.repo_tags.models import RepoTags
 
 logger = logging.getLogger(__name__)
 
@@ -69,6 +74,16 @@ def get_share_link_info(fileshare):
     else:
         obj_name = ''
 
+    if repo:
+        if fileshare.s_type == 'd':
+            folder_path = normalize_dir_path(fileshare.path)
+            obj_id = seafile_api.get_dir_id_by_path(repo_id, folder_path)
+        else:
+            file_path = normalize_file_path(fileshare.path)
+            obj_id = seafile_api.get_file_id_by_path(repo_id, file_path)
+    else:
+        obj_id = ''
+
     if fileshare.expire_date:
         expire_date = datetime_to_isoformat_timestr(fileshare.expire_date)
     else:
@@ -85,6 +100,7 @@ def get_share_link_info(fileshare):
 
     data['path'] = path
     data['obj_name'] = obj_name
+    data['obj_id'] = obj_id or ""
     data['is_dir'] = True if fileshare.s_type == 'd' else False
 
     data['token'] = token
@@ -94,6 +110,7 @@ def get_share_link_info(fileshare):
     data['expire_date'] = expire_date
     data['is_expired'] = fileshare.is_expired()
     data['permissions'] = fileshare.get_permissions()
+    data['password'] = fileshare.get_password()
 
     data['can_edit'] = False
     if repo and path != '/' and not data['is_dir']:
@@ -203,32 +220,68 @@ class ShareLinks(APIView):
                                           .filter(repo_id=repo_id) \
                                           .filter(path=path)
 
+        repo_object_dict = {}
         repo_folder_permission_dict = {}
+
         for fileshare in fileshares:
 
-            if fileshare.s_type == 'd':
-                folder_path = normalize_dir_path(fileshare.path)
-            else:
-                file_path = normalize_file_path(fileshare.path)
-                folder_path = os.path.dirname(file_path)
-
             repo_id = fileshare.repo_id
-            if repo_id not in repo_folder_permission_dict:
+            path = fileshare.path
 
+            if repo_id not in repo_object_dict:
+                repo = seafile_api.get_repo(repo_id)
+                repo_object_dict[repo_id] = repo
+
+            tmp_key = f"{repo_id}_{path}"
+            if tmp_key not in repo_folder_permission_dict:
                 try:
                     permission = seafile_api.check_permission_by_path(repo_id,
-                                                                      folder_path,
-                                                                      fileshare.username)
-                except Exception as e:
-                    logger.error(e)
-                    permission = ''
-
-                repo_folder_permission_dict[repo_id] = permission
+                                                                      path,
+                                                                      username)
+                    repo_folder_permission_dict[tmp_key] = permission
+                except Exception:
+                    repo_folder_permission_dict[tmp_key] = ''
 
         links_info = []
         for fs in fileshares:
-            link_info = get_share_link_info(fs)
-            link_info['repo_folder_permission'] = repo_folder_permission_dict.get(link_info['repo_id'], '')
+
+            link_info = {}
+
+            token = fs.token
+            repo_id = fs.repo_id
+            path = fs.path
+            s_type = fs.s_type
+
+            link_info['username'] = username
+            link_info['repo_id'] = repo_id
+
+            repo_object = repo_object_dict.get(repo_id, '')
+            if repo_object:
+                repo_name = repo_object.repo_name
+            else:
+                repo_name = ''
+
+            if path:
+                obj_name = '/' if path == '/' else os.path.basename(path.rstrip('/'))
+            else:
+                obj_name = ''
+
+            link_info['repo_name'] = repo_name
+            link_info['path'] = path
+            link_info['obj_name'] = obj_name
+            link_info['is_dir'] = True if s_type == 'd' else False
+            link_info['token'] = token
+            link_info['link'] = gen_shared_link(token, s_type)
+            link_info['view_cnt'] = fs.view_cnt
+            link_info['ctime'] = datetime_to_isoformat_timestr(fs.ctime) if fs.ctime else ''
+            link_info['expire_date'] = datetime_to_isoformat_timestr(fs.expire_date) if fs.expire_date else ''
+            link_info['is_expired'] = fs.is_expired()
+            link_info['permissions'] = fs.get_permissions()
+            link_info['password'] = fs.get_password()
+
+            tmp_key = f"{repo_id}_{path}"
+            link_info['repo_folder_permission'] = repo_folder_permission_dict.get(tmp_key, "")
+
             links_info.append(link_info)
 
         if len(links_info) == 1:
@@ -244,6 +297,7 @@ class ShareLinks(APIView):
 
         return Response(result)
 
+    @check_share_link_count
     def post(self, request):
         """ Create share link.
 
@@ -263,10 +317,25 @@ class ShareLinks(APIView):
             return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
 
         password = request.data.get('password', None)
-        if password and len(password) < config.SHARE_LINK_PASSWORD_MIN_LENGTH:
-            error_msg = _('Password is too short.')
+
+        if config.SHARE_LINK_FORCE_USE_PASSWORD and not password:
+            error_msg = _('Password is required.')
             return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
 
+        if password:
+
+            if len(password) < config.SHARE_LINK_PASSWORD_MIN_LENGTH:
+                error_msg = _('Password is too short.')
+                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            if get_password_strength_level(password) < config.SHARE_LINK_PASSWORD_STRENGTH_LEVEL:
+                error_msg = _('Password is too weak.')
+                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            if not is_valid_password(password):
+                error_msg = _('Password can only contain number, upper letter, lower letter and other symbols.')
+                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
         expire_days = request.data.get('expire_days', '')
         expiration_time = request.data.get('expiration_time', '')
         if expire_days and expiration_time:
@@ -411,6 +480,71 @@ class ShareLinks(APIView):
         link_info = get_share_link_info(fs)
         return Response(link_info)
 
+    def delete(self, request):
+        """ Delete share links.
+
+        Permission checking:
+        1. default(NOT guest) user;
+        2. link owner;
+        """
+
+        token_list = request.data.get('tokens')
+        if not token_list:
+            error_msg = 'token invalid.'
+            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+        result = {}
+        result['failed'] = []
+        result['success'] = []
+
+        username = request.user.username
+        for token in token_list:
+
+            try:
+                fs = FileShare.objects.get(token=token)
+            except FileShare.DoesNotExist:
+                result['success'].append({
+                    'token': token,
+                })
+                continue
+
+            has_published_library = False
+            if fs.path == '/':
+                try:
+                    Wiki.objects.get(repo_id=fs.repo_id)
+                    has_published_library = True
+                except Wiki.DoesNotExist:
+                    pass
+
+            if not fs.is_owner(username):
+                result['failed'].append({
+                    'token': token,
+                    'error_msg': 'Permission denied.'
+                    })
+                continue
+
+            if has_published_library:
+                result['failed'].append({
+                    'token': token,
+                    'error_msg': _('There is an associated published library.')
+                    })
+                continue
+
+            try:
+                fs.delete()
+                result['success'].append({
+                    'token': token,
+                })
+            except Exception as e:
+                logger.error(e)
+                result['failed'].append({
+                    'token': token,
+                    'error_msg': 'Internal Server Error'
+                    })
+                continue
+
+        return Response(result)
+
 
 class ShareLink(APIView):
 
@@ -435,19 +569,12 @@ class ShareLink(APIView):
         return Response(link_info)
 
     def put(self, request, token):
-        """ Update share link, currently only available for permission.
+        """ Update share link's permission and expiration.
 
         Permission checking:
         share link creater
         """
 
-        # argument check
-        try:
-            perm = check_permissions_arg(request)
-        except Exception:
-            error_msg = 'permissions invalud.'
-            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
-
         # resource check
         try:
             fs = FileShare.objects.get(token=token)
@@ -488,26 +615,102 @@ class ShareLink(APIView):
             error_msg = 'Permission denied.'
             return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
-        if repo_folder_permission in (PERMISSION_PREVIEW_EDIT, PERMISSION_PREVIEW) \
-                and perm != FileShare.PERM_VIEW_ONLY:
-            error_msg = 'Permission denied.'
-            return api_error(status.HTTP_403_FORBIDDEN, error_msg)
+        # argument check
+        permissions = request.data.get('permissions', '')
+        if permissions:
+            try:
+                perm = check_permissions_arg(request)
+            except Exception:
+                error_msg = 'permissions invalid.'
+                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
 
-        if repo_folder_permission in (PERMISSION_READ) \
-                and perm not in (FileShare.PERM_VIEW_DL, FileShare.PERM_VIEW_ONLY):
-            error_msg = 'Permission denied.'
-            return api_error(status.HTTP_403_FORBIDDEN, error_msg)
-
-        if fs.s_type == 'f':
-            file_name = os.path.basename(fs.path.rstrip('/'))
-            can_edit, error_msg = can_edit_file(file_name, dirent.size, repo)
-            if not can_edit and perm in (FileShare.PERM_EDIT_DL, FileShare.PERM_EDIT_ONLY):
+            if repo_folder_permission in (PERMISSION_PREVIEW_EDIT, PERMISSION_PREVIEW) \
+                    and perm != FileShare.PERM_VIEW_ONLY:
                 error_msg = 'Permission denied.'
                 return api_error(status.HTTP_403_FORBIDDEN, error_msg)
 
-        # update share link permission
-        fs.permission = perm
-        fs.save()
+            if repo_folder_permission in (PERMISSION_READ) \
+                    and perm not in (FileShare.PERM_VIEW_DL, FileShare.PERM_VIEW_ONLY):
+                error_msg = 'Permission denied.'
+                return api_error(status.HTTP_403_FORBIDDEN, error_msg)
+
+            if fs.s_type == 'f':
+                file_name = os.path.basename(fs.path.rstrip('/'))
+                can_edit, error_msg = can_edit_file(file_name, dirent.size, repo)
+                if not can_edit and perm in (FileShare.PERM_EDIT_DL, FileShare.PERM_EDIT_ONLY):
+                    error_msg = 'Permission denied.'
+                    return api_error(status.HTTP_403_FORBIDDEN, error_msg)
+
+            # update share link permission
+            fs.permission = perm
+            fs.save()
+
+        expire_days = request.data.get('expire_days', '')
+        expiration_time = request.data.get('expiration_time', '')
+
+        if expire_days and expiration_time:
+            error_msg = 'Can not pass expire_days and expiration_time at the same time.'
+            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+        if expire_days:
+
+            try:
+                expire_days = int(expire_days)
+            except ValueError:
+                error_msg = 'expire_days invalid.'
+                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            if expire_days <= 0:
+                error_msg = 'expire_days invalid.'
+                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            if SHARE_LINK_EXPIRE_DAYS_MIN > 0:
+                if expire_days < SHARE_LINK_EXPIRE_DAYS_MIN:
+                    error_msg = _('Expire days should be greater or equal to %s') % \
+                            SHARE_LINK_EXPIRE_DAYS_MIN
+                    return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            if SHARE_LINK_EXPIRE_DAYS_MAX > 0:
+                if expire_days > SHARE_LINK_EXPIRE_DAYS_MAX:
+                    error_msg = _('Expire days should be less than or equal to %s') % \
+                            SHARE_LINK_EXPIRE_DAYS_MAX
+                    return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            expire_date = timezone.now() + relativedelta(days=expire_days)
+            fs.expire_date = expire_date
+            fs.save()
+
+        if expiration_time:
+
+            try:
+                expire_date = dateutil.parser.isoparse(expiration_time)
+            except Exception as e:
+                logger.error(e)
+                error_msg = 'expiration_time invalid, should be iso format, for example: 2020-05-17T10:26:22+08:00'
+                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            expire_date = expire_date.astimezone(get_current_timezone()).replace(tzinfo=None)
+
+            if SHARE_LINK_EXPIRE_DAYS_MIN > 0:
+                expire_date_min_limit = timezone.now() + relativedelta(days=SHARE_LINK_EXPIRE_DAYS_MIN)
+                expire_date_min_limit = expire_date_min_limit.replace(hour=0).replace(minute=0).replace(second=0)
+
+                if expire_date < expire_date_min_limit:
+                    error_msg = _('Expiration time should be later than %s.') % \
+                            expire_date_min_limit.strftime("%Y-%m-%d %H:%M:%S")
+                    return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            if SHARE_LINK_EXPIRE_DAYS_MAX > 0:
+                expire_date_max_limit = timezone.now() + relativedelta(days=SHARE_LINK_EXPIRE_DAYS_MAX)
+                expire_date_max_limit = expire_date_max_limit.replace(hour=23).replace(minute=59).replace(second=59)
+
+                if expire_date > expire_date_max_limit:
+                    error_msg = _('Expiration time should be earlier than %s.') % \
+                            expire_date_max_limit.strftime("%Y-%m-%d %H:%M:%S")
+                    return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            fs.expire_date = expire_date
+            fs.save()
 
         link_info = get_share_link_info(fs)
         return Response(link_info)
@@ -708,6 +911,12 @@ class ShareLinkDirents(APIView):
             error_msg = 'Internal Server Error'
             return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
 
+        try:
+            files_tags_in_dir = get_files_tags_in_dir(repo_id, path)
+        except Exception as e:
+            logger.error(e)
+            files_tags_in_dir = {}
+
         result = []
         for dirent in dirent_list:
 
@@ -730,12 +939,19 @@ class ShareLinkDirents(APIView):
 
                 file_type, file_ext = get_file_type_and_ext(dirent.obj_name)
                 if file_type in (IMAGE, XMIND) or \
-                        file_type == VIDEO and ENABLE_VIDEO_THUMBNAIL:
+                        (file_type == VIDEO and ENABLE_VIDEO_THUMBNAIL):
 
                     if os.path.exists(os.path.join(THUMBNAIL_ROOT, str(thumbnail_size), dirent.obj_id)):
                         req_image_path = posixpath.join(request_path, dirent.obj_name)
                         src = get_share_link_thumbnail_src(token, thumbnail_size, req_image_path)
-                        dirent_info['encoded_thumbnail_src'] = urlquote(src)
+                        dirent_info['encoded_thumbnail_src'] = quote(src)
+
+                # get tag info
+                file_tags = files_tags_in_dir.get(dirent.obj_name, [])
+                if file_tags:
+                    dirent_info['file_tags'] = []
+                    for file_tag in file_tags:
+                        dirent_info['file_tags'].append(file_tag)
 
             result.append(dirent_info)
 
@@ -1033,8 +1249,233 @@ class ShareLinkSaveFileToRepo(APIView):
                                                      src_dirent_name)
 
         username = request.user.username
-        seafile_api.copy_file(src_repo_id, src_parent_dir, src_dirent_name,
-                              dst_repo_id, dst_parent_dir, dst_dirent_name,
+        seafile_api.copy_file(src_repo_id, src_parent_dir,
+                              json.dumps([src_dirent_name]),
+                              dst_repo_id, dst_parent_dir,
+                              json.dumps([dst_dirent_name]),
                               username, need_progress=0)
 
         return Response({'success': True})
+
+
+class ShareLinkSaveItemsToRepo(APIView):
+
+    authentication_classes = (TokenAuthentication, SessionAuthentication)
+    permission_classes = (IsAuthenticated,)
+    throttle_classes = (UserRateThrottle,)
+
+    def post(self, request, token):
+
+        # argument check
+        dst_repo_id = request.POST.get('dst_repo_id', '')
+        if not dst_repo_id:
+            error_msg = 'dst_repo_id invalid.'
+            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+        dst_parent_dir = request.POST.get('dst_parent_dir', '')
+        if not dst_parent_dir:
+            error_msg = 'dst_parent_dir invalid.'
+            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+        # resource check
+        try:
+            share_link = FileShare.objects.get(token=token)
+        except FileShare.DoesNotExist:
+            error_msg = 'Share link %s not found.' % token
+            return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+
+        if not seafile_api.get_repo(dst_repo_id):
+            error_msg = 'Library %s not found.' % dst_repo_id
+            return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+
+        if not seafile_api.get_dir_id_by_path(dst_repo_id, dst_parent_dir):
+            error_msg = 'Folder %s not found.' % dst_parent_dir
+            return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+
+        # permission check
+        share_link_permission = share_link.get_permissions()
+        if not share_link_permission.get('can_download', False):
+            error_msg = 'Permission denied.'
+            return api_error(status.HTTP_403_FORBIDDEN, error_msg)
+
+        if check_folder_permission(request,
+                                   dst_repo_id,
+                                   dst_parent_dir) != 'rw':
+            error_msg = 'Permission denied.'
+            return api_error(status.HTTP_403_FORBIDDEN, error_msg)
+
+        # save items
+        username = request.user.username
+        src_repo_id = share_link.repo_id
+
+        # save file in file share link
+        if share_link.s_type == 'f':
+
+            src_dirent_path = share_link.path
+            src_parent_dir = os.path.dirname(src_dirent_path)
+            src_dirent_name = os.path.basename(src_dirent_path)
+
+            check_filename_with_rename(dst_repo_id,
+                                       dst_parent_dir,
+                                       src_dirent_name)
+        else:
+            # save items in folder share link
+            src_parent_dir = request.POST.get('src_parent_dir', '')
+            if not src_parent_dir:
+                error_msg = 'src_parent_dir invalid.'
+                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            src_dirents = request.POST.getlist('src_dirents', [])
+            if not src_dirents:
+                error_msg = 'src_dirents invalid.'
+                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            src_parent_dir = posixpath.join(share_link.path, src_parent_dir.strip('/'))
+        try:
+            res = seafile_api.copy_file(src_repo_id, src_parent_dir,
+                                        json.dumps(src_dirents),
+                                        dst_repo_id, dst_parent_dir,
+                                        json.dumps(src_dirents),
+                                        username, need_progress=1, synchronous=0)
+        except Exception as e:
+            logger.error(e)
+            error_msg = 'Internal Server Error'
+            return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
+
+        if not res:
+            error_msg = 'Internal Server Error'
+            return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
+
+        result = {}
+        if res.background:
+            result['task_id'] = res.task_id
+
+        return Response(result)
+
+
+class ShareLinkRepoTags(APIView):
+
+    throttle_classes = (UserRateThrottle,)
+
+    def get(self, request, token):
+        """get all repo_tags by share link token.
+        """
+
+        try:
+            share_link = FileShare.objects.get(token=token)
+        except FileShare.DoesNotExist:
+            error_msg = 'Token %s not found.' % token
+            return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+
+        repo_id = share_link.repo_id
+        repo = seafile_api.get_repo(repo_id)
+        if not repo:
+            error_msg = 'Library %s not found.' % repo_id
+            return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+
+        # get all tags in repo
+        repo_tags = RepoTags.objects.filter(repo_id=repo_id)
+
+        # get tagged files by tag id
+        tag_id_file_list_dict = defaultdict(list)
+        for repo_tag in repo_tags:
+            tagged_files = get_tagged_files(repo, repo_tag.pk)['tagged_files']
+            tagged_files = [item for item in tagged_files if item.get('parent_path') and item.get('parent_path').startswith(share_link.path.rstrip('/'))]
+            tag_id_file_list_dict[repo_tag.pk] = tagged_files
+
+        # generate response
+        result = {
+            "repo_tags": []
+        }
+
+        for repo_tag in repo_tags:
+
+            repo_tag_info = repo_tag.to_dict()
+            repo_tag_id = repo_tag_info["repo_tag_id"]
+            repo_tag_info["files_count"] = len(tag_id_file_list_dict.get(repo_tag_id, []))
+
+            result['repo_tags'].append(repo_tag_info)
+
+        return Response(result)
+
+
+class ShareLinkRepoTagsTaggedFiles(APIView):
+
+    throttle_classes = (UserRateThrottle,)
+
+    def get(self, request, token, tag_id):
+        """get tagged files by share link token and tag id.
+        """
+
+        try:
+            share_link = FileShare.objects.get(token=token)
+        except FileShare.DoesNotExist:
+            error_msg = 'Token %s not found.' % token
+            return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+
+        repo_id = share_link.repo_id
+        repo = seafile_api.get_repo(repo_id)
+        if not repo:
+            error_msg = 'Library %s not found.' % repo_id
+            return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+
+        repo_tag = RepoTags.objects.get_repo_tag_by_id(tag_id)
+        if not repo_tag:
+            error_msg = 'repo_tag %s not found.' % tag_id
+            return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+
+        share_link_path = share_link.path.rstrip('/') if share_link.path != '/' else '/'
+
+        filtered_tagged_files = []
+        tagged_files = get_tagged_files(repo, tag_id)
+        for tagged_file in tagged_files.get('tagged_files', []):
+
+            if tagged_file.get('file_deleted', False):
+                continue
+
+            tagged_file_parent_path = tagged_file.get('parent_path', '')
+            if share_link_path == '/':
+                filtered_tagged_files.append(tagged_file)
+            elif tagged_file_parent_path.startswith(share_link_path):
+                tagged_file['parent_path'] = '/' + tagged_file_parent_path.lstrip(share_link_path)
+                filtered_tagged_files.append(tagged_file)
+
+        return Response({'tagged_files': filtered_tagged_files})
+
+
+class ShareLinksCleanInvalid(APIView):
+
+    authentication_classes = (TokenAuthentication, SessionAuthentication)
+    permission_classes = (IsAuthenticated, CanGenerateShareLink)
+    throttle_classes = (UserRateThrottle,)
+
+    def delete(self, request):
+        """ Clean invalid share links.
+        """
+
+        username = request.user.username
+        share_links = FileShare.objects.filter(username=username)
+
+        for share_link in share_links:
+
+            if share_link.is_expired():
+                share_link.delete()
+                continue
+
+            repo_id = share_link.repo_id
+            if not seafile_api.get_repo(repo_id):
+                share_link.delete()
+                continue
+
+            if share_link.s_type == 'd':
+                folder_path = normalize_dir_path(share_link.path)
+                obj_id = seafile_api.get_dir_id_by_path(repo_id, folder_path)
+            else:
+                file_path = normalize_file_path(share_link.path)
+                obj_id = seafile_api.get_file_id_by_path(repo_id, file_path)
+
+            if not obj_id:
+                share_link.delete()
+                continue
+
+        return Response({'success': True})
