@@ -14,7 +14,7 @@ from rest_framework import status
 
 from django.utils import timezone
 from django.utils.timezone import get_current_timezone
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from seaserv import seafile_api
 from pysearpc import SearpcError
@@ -26,7 +26,8 @@ from seahub.api2.permissions import CanGenerateUploadLink
 
 from seahub.share.models import UploadLinkShare, check_share_link_common
 from seahub.utils import gen_shared_upload_link, gen_file_upload_url, \
-        is_pro_version
+        is_pro_version, get_password_strength_level, is_valid_password
+
 from seahub.views import check_folder_permission
 from seahub.utils.timeutils import datetime_to_isoformat_timestr
 
@@ -54,6 +55,11 @@ def get_upload_link_info(uls):
     else:
         obj_name = ''
 
+    if repo:
+        obj_id = seafile_api.get_dir_id_by_path(repo_id, path)
+    else:
+        obj_id = ''
+
     if uls.ctime:
         ctime = datetime_to_isoformat_timestr(uls.ctime)
     else:
@@ -68,6 +74,7 @@ def get_upload_link_info(uls):
     data['repo_name'] = repo.repo_name if repo else ''
     data['path'] = path
     data['obj_name'] = obj_name
+    data['obj_id'] = obj_id or ""
     data['view_cnt'] = uls.view_cnt
     data['ctime'] = ctime
     data['link'] = gen_shared_upload_link(token)
@@ -75,6 +82,7 @@ def get_upload_link_info(uls):
     data['username'] = uls.username
     data['expire_date'] = expire_date
     data['is_expired'] = uls.is_expired()
+    data['password'] = uls.get_password()
 
     return data
 
@@ -157,10 +165,25 @@ class UploadLinks(APIView):
             return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
 
         password = request.data.get('password', None)
-        if password and len(password) < config.SHARE_LINK_PASSWORD_MIN_LENGTH:
-            error_msg = _('Password is too short')
+
+        if config.SHARE_LINK_FORCE_USE_PASSWORD and not password:
+            error_msg = _('Password is required.')
             return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
 
+        if password:
+
+            if len(password) < config.SHARE_LINK_PASSWORD_MIN_LENGTH:
+                error_msg = _('Password is too short.')
+                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            if get_password_strength_level(password) < config.SHARE_LINK_PASSWORD_STRENGTH_LEVEL:
+                error_msg = _('Password is too weak.')
+                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            if not is_valid_password(password):
+                error_msg = _('Password can only contain number, upper letter, lower letter and other symbols.')
+                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
         expire_days = request.data.get('expire_days', '')
         expiration_time = request.data.get('expiration_time', '')
         if expire_days and expiration_time:
@@ -282,6 +305,88 @@ class UploadLink(APIView):
         link_info = get_upload_link_info(uls)
         return Response(link_info)
 
+    def put(self, request, token):
+        """ Update upload link's expiration.
+
+        Permission checking:
+        upload link creater
+        """
+
+        try:
+            uls = UploadLinkShare.objects.get(token=token)
+        except UploadLinkShare.DoesNotExist:
+            error_msg = 'token %s not found.' % token
+            return api_error(status.HTTP_404_NOT_FOUND, error_msg)
+
+        expire_days = request.data.get('expire_days', '')
+        expiration_time = request.data.get('expiration_time', '')
+        if expire_days and expiration_time:
+            error_msg = 'Can not pass expire_days and expiration_time at the same time.'
+            return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+        expire_date = None
+        if expire_days:
+            try:
+                expire_days = int(expire_days)
+            except ValueError:
+                error_msg = 'expire_days invalid.'
+                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            if expire_days <= 0:
+                error_msg = 'expire_days invalid.'
+                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            if UPLOAD_LINK_EXPIRE_DAYS_MIN > 0:
+                if expire_days < UPLOAD_LINK_EXPIRE_DAYS_MIN:
+                    error_msg = _('Expire days should be greater or equal to %s') % \
+                            UPLOAD_LINK_EXPIRE_DAYS_MIN
+                    return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            if UPLOAD_LINK_EXPIRE_DAYS_MAX > 0:
+                if expire_days > UPLOAD_LINK_EXPIRE_DAYS_MAX:
+                    error_msg = _('Expire days should be less than or equal to %s') % \
+                            UPLOAD_LINK_EXPIRE_DAYS_MAX
+                    return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            expire_date = timezone.now() + relativedelta(days=expire_days)
+            uls.expire_date = expire_date
+            uls.save()
+
+        elif expiration_time:
+
+            try:
+                expire_date = dateutil.parser.isoparse(expiration_time)
+            except Exception as e:
+                logger.error(e)
+                error_msg = 'expiration_time invalid, should be iso format, for example: 2020-05-17T10:26:22+08:00'
+                return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            expire_date = expire_date.astimezone(get_current_timezone()).replace(tzinfo=None)
+
+            if UPLOAD_LINK_EXPIRE_DAYS_MIN > 0:
+                expire_date_min_limit = timezone.now() + relativedelta(days=UPLOAD_LINK_EXPIRE_DAYS_MIN)
+                expire_date_min_limit = expire_date_min_limit.replace(hour=0).replace(minute=0).replace(second=0)
+
+                if expire_date < expire_date_min_limit:
+                    error_msg = _('Expiration time should be later than %s.') % \
+                            expire_date_min_limit.strftime("%Y-%m-%d %H:%M:%S")
+                    return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            if UPLOAD_LINK_EXPIRE_DAYS_MAX > 0:
+                expire_date_max_limit = timezone.now() + relativedelta(days=UPLOAD_LINK_EXPIRE_DAYS_MAX)
+                expire_date_max_limit = expire_date_max_limit.replace(hour=23).replace(minute=59).replace(second=59)
+
+                if expire_date > expire_date_max_limit:
+                    error_msg = _('Expiration time should be earlier than %s.') % \
+                            expire_date_max_limit.strftime("%Y-%m-%d %H:%M:%S")
+                    return api_error(status.HTTP_400_BAD_REQUEST, error_msg)
+
+            uls.expire_date = expire_date
+            uls.save()
+
+        link_info = get_upload_link_info(uls)
+        return Response(link_info)
+
     def delete(self, request, token):
         """ Delete upload link.
 
@@ -356,19 +461,29 @@ class UploadLinkUpload(APIView):
         if is_pro_version() and ENABLE_UPLOAD_LINK_VIRUS_CHECK:
             check_virus = True
 
-        if check_virus:
-            token = seafile_api.get_fileserver_access_token(repo_id,
-                                                            obj_id,
-                                                            'upload-link',
-                                                            uls.username,
-                                                            use_onetime=False,
-                                                            check_virus=check_virus)
-        else:
-            token = seafile_api.get_fileserver_access_token(repo_id,
-                                                            obj_id,
-                                                            'upload-link',
-                                                            uls.username,
-                                                            use_onetime=False)
+        try:
+            if check_virus:
+                token = seafile_api.get_fileserver_access_token(repo_id,
+                                                                obj_id,
+                                                                'upload-link',
+                                                                uls.username,
+                                                                use_onetime=False,
+                                                                check_virus=check_virus)
+            else:
+                token = seafile_api.get_fileserver_access_token(repo_id,
+                                                                obj_id,
+                                                                'upload-link',
+                                                                uls.username,
+                                                                use_onetime=False)
+        except Exception as e:
+            if str(e) == 'Too many files in library.':
+                error_msg = _("The number of files in library exceeds the limit")
+                from seahub.api2.views import HTTP_442_TOO_MANY_FILES_IN_LIBRARY
+                return api_error(HTTP_442_TOO_MANY_FILES_IN_LIBRARY, error_msg)
+            else:
+                logger.error(e)
+                error_msg = 'Internal Server Error'
+                return api_error(status.HTTP_500_INTERNAL_SERVER_ERROR, error_msg)
 
         if not token:
             error_msg = 'Internal Server Error'
@@ -377,3 +492,34 @@ class UploadLinkUpload(APIView):
         result = {}
         result['upload_link'] = gen_file_upload_url(token, 'upload-api')
         return Response(result)
+
+
+class UploadLinksCleanInvalid(APIView):
+    authentication_classes = (TokenAuthentication, SessionAuthentication)
+    permission_classes = (IsAuthenticated, CanGenerateUploadLink)
+    throttle_classes = (UserRateThrottle, )
+
+    def delete(self, request):
+        """ Clean invalid upload links.
+        """
+
+        username = request.user.username
+        upload_links = UploadLinkShare.objects.filter(username=username)
+
+        for upload_link in upload_links:
+
+            if upload_link.is_expired():
+                upload_link.delete()
+                continue
+
+            repo_id = upload_link.repo_id
+            if not seafile_api.get_repo(repo_id):
+                upload_link.delete()
+                continue
+
+            obj_id = seafile_api.get_dir_id_by_path(repo_id, upload_link.path)
+            if not obj_id:
+                upload_link.delete()
+                continue
+
+        return Response({'success': True})
