@@ -4,7 +4,7 @@ import json
 import logging
 import posixpath
 from django.http import HttpResponse
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from rest_framework import status
 from rest_framework.authentication import SessionAuthentication
 from rest_framework.permissions import IsAuthenticated
@@ -123,7 +123,8 @@ class ViaRepoDirView(APIView):
 
         # get dir/file list recursively
         # username = request.user.username
-        username = seafile_api.get_repo_owner(repo_id)
+        # Get username by repo_id. Can not use is_org_context, because 'AnonymousUser' object has no attribute 'org'.
+        username = seafile_api.get_repo_owner(repo_id) or seafile_api.get_org_repo_owner(repo_id)
         if recursive == '1':
 
             try:
