@@ -11,10 +11,12 @@ from django.shortcuts import render
 from django.contrib.sites.shortcuts import get_current_site
 from django.http import HttpResponseRedirect, Http404
 
-from django.utils.http import urlquote, base36_to_int, is_safe_url
-from django.utils.translation import ugettext as _
+from urllib.parse import quote
+from django.utils.http import base36_to_int, url_has_allowed_host_and_scheme
+from django.utils.translation import gettext as _
 from django.views.decorators.cache import never_cache
-from seaserv import seafile_api
+from saml2.ident import decode
+from seaserv import seafile_api, ccnet_api
 
 from seahub.auth import REDIRECT_FIELD_NAME, get_backends
 from seahub.auth import login as auth_login
@@ -31,24 +33,27 @@ from seahub.base.accounts import User, UNUSABLE_PASSWORD
 from seahub.options.models import UserOptions
 from seahub.profile.models import Profile
 from seahub.two_factor.views.login import is_device_remembered
-from seahub.utils import is_ldap_user, get_site_name
+from seahub.utils import is_ldap_user, get_site_name, is_valid_email
 from seahub.utils.ip import get_remote_ip
 from seahub.utils.file_size import get_quota_from_string
 from seahub.utils.two_factor_auth import two_factor_auth_enabled, handle_two_factor_auth
 from seahub.utils.user_permissions import get_user_role
 from seahub.utils.auth import get_login_bg_image_path
+from seahub.organizations.models import OrgSAMLConfig
 
 from constance import config
 
 from seahub.password_session import update_session_auth_hash
 
+from seahub.onlyoffice.settings import ONLYOFFICE_DESKTOP_EDITOR_HTTP_USER_AGENT
+
 # Get an instance of a logger
 logger = logging.getLogger(__name__)
 
 
 def log_user_in(request, user, redirect_to):
     # Ensure the user-originating redirection url is safe.
-    if not is_safe_url(url=redirect_to, allowed_hosts=request.get_host()):
+    if not url_has_allowed_host_and_scheme(url=redirect_to, allowed_hosts=request.get_host()):
         redirect_to = settings.LOGIN_REDIRECT_URL
 
     if request.session.test_cookie_worked():
@@ -93,7 +98,7 @@ def login(request, template_name='registration/login.html',
 
     redirect_to = request.GET.get(redirect_field_name, '')
     if request.user.is_authenticated:
-        if redirect_to:
+        if redirect_to and url_has_allowed_host_and_scheme(redirect_to, allowed_hosts=request.get_host()):
             return HttpResponseRedirect(redirect_to)
         else:
             return HttpResponseRedirect(reverse(redirect_if_logged_in))
@@ -202,7 +207,9 @@ def login(request, template_name='registration/login.html',
         'remember_days': config.LOGIN_REMEMBER_DAYS,
         'signup_url': signup_url,
         'enable_sso': enable_sso,
+        'enable_multi_adfs': getattr(settings, 'ENABLE_MULTI_ADFS', False),
         'login_bg_image_path': login_bg_image_path,
+        'enable_change_password': settings.ENABLE_CHANGE_PASSWORD,
     })
 
 def login_simple_check(request):
@@ -233,7 +240,7 @@ def login_simple_check(request):
         # Ensure the user-originating redirection url is safe.
         if REDIRECT_FIELD_NAME in request.GET:
             next_page = request.GET[REDIRECT_FIELD_NAME]
-            if not is_safe_url(url=next_page, host=request.get_host()):
+            if not url_has_allowed_host_and_scheme(url=next_page, allowed_hosts=request.get_host()):
                 next_page = settings.LOGIN_REDIRECT_URL
         else:
             next_page = settings.SITE_ROOT
@@ -247,6 +254,19 @@ def logout(request, next_page=None,
            template_name='registration/logged_out.html',
            redirect_field_name=REDIRECT_FIELD_NAME):
     "Logs out the user and displays 'You are logged out' message."
+
+    if getattr(settings, 'ENABLE_MULTI_ADFS', False):
+        from seahub.utils import is_org_context
+        try:
+            saml_subject_id = decode(request.saml_session["_saml2_subject_id"])
+        except Exception as e:
+            logger.warning(e)
+            saml_subject_id = None
+        if saml_subject_id and is_org_context(request):
+            org_id = request.user.org.org_id
+            org = ccnet_api.get_org_by_id(org_id)
+            return HttpResponseRedirect('/org/custom/%s/saml2/logout/' % org.url_prefix)
+
     from seahub.auth import logout
     logout(request)
 
@@ -275,7 +295,7 @@ def logout(request, next_page=None,
     if redirect_field_name in request.GET:
         next_page = request.GET[redirect_field_name]
         # Security check -- don't allow redirection to a different host.
-        if not is_safe_url(url=next_page, allowed_hosts=request.get_host()):
+        if not url_has_allowed_host_and_scheme(url=next_page, allowed_hosts=request.get_host()):
             next_page = request.path
 
     if next_page is None:
@@ -284,7 +304,8 @@ def logout(request, next_page=None,
             response = HttpResponseRedirect(redirect_to)
         else:
             response = render(request, template_name, {
-                'title': _('Logged out')
+                'title': _('Logged out'),
+                'request_from_onlyoffice_desktop_editor': ONLYOFFICE_DESKTOP_EDITOR_HTTP_USER_AGENT in request.headers.get('user-agent', ''),
             })
     else:
         # Redirect to this page until the session has been cleared.
@@ -303,7 +324,7 @@ def redirect_to_login(next, login_url=None, redirect_field_name=REDIRECT_FIELD_N
     "Redirects the user to the login page, passing the given 'next' page"
     if not login_url:
         login_url = settings.LOGIN_URL
-    return HttpResponseRedirect('%s?%s=%s' % (login_url, urlquote(redirect_field_name), urlquote(next)))
+    return HttpResponseRedirect('%s?%s=%s' % (login_url, quote(redirect_field_name), quote(next)))
 
 # 4 views for password reset:
 # - password_reset sends the mail
@@ -326,7 +347,7 @@ def password_reset(request, is_admin_site=False, template_name='registration/pas
             opts['use_https'] = request.is_secure()
             opts['token_generator'] = token_generator
             if is_admin_site:
-                opts['domain_override'] = request.META['HTTP_HOST']
+                opts['domain_override'] = request.headers['host']
             else:
                 opts['email_template_name'] = email_template_name
                 opts['domain_override'] = get_current_site(request).domain
@@ -432,3 +453,47 @@ def password_change(request, template_name='registration/password_change_form.ht
 
 def password_change_done(request, template_name='registration/password_change_done.html'):
     return render(request, template_name)
+
+
+def multi_adfs_sso(request):
+    if not getattr(settings, 'ENABLE_MULTI_ADFS', False):
+        return HttpResponseRedirect(settings.LOGIN_URL)
+
+    template_name = 'registration/multi_adfs_sso.html'
+    render_data = {'login_bg_image_path': get_login_bg_image_path()}
+
+    if request.method == "POST":
+        request.session['is_sso_user'] = True
+        login_email = request.POST.get('login', '')
+        if not is_valid_email(login_email):
+            render_data['error_msg'] = 'Email invalid.'
+            return render(request, template_name, render_data)
+
+        domain = login_email.split('@')[-1]
+        if not domain:
+            render_data['error_msg'] = 'Email invalid.'
+            return render(request, template_name, render_data)
+
+        try:
+            org_saml_config = OrgSAMLConfig.objects.get_config_by_domain(domain)
+            if not org_saml_config:
+                render_data['error_msg'] = "Cannot find a SAML/ADFS config for the organization related to domain %s." % domain
+                return render(request, template_name, render_data)
+            if not org_saml_config.domain_verified:
+                render_data['error_msg'] = "The domain %s has not been verified ownership, please login after verification." % domain
+                return render(request, template_name, render_data)
+            org_id = org_saml_config.org_id
+            org = ccnet_api.get_org_by_id(org_id)
+            if not org:
+                render_data['error_msg'] = 'Cannot find an organization related to domain %s.' % domain
+                return render(request, template_name, render_data)
+            url_prefix = org.url_prefix
+        except Exception as e:
+            logger.error(e)
+            render_data['error_msg'] = 'Error, please contact administrator.'
+            return render(request, template_name, render_data)
+
+        return HttpResponseRedirect('/org/custom/%s/saml2/login/' % url_prefix)
+
+    if request.method == "GET":
+        return render(request, template_name, render_data)
