@@ -10,14 +10,14 @@ from django.core.management.base import BaseCommand
 from django.urls import reverse
 from django.utils.html import escape
 from django.utils import translation
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from seaserv import seafile_api, ccnet_api
-from seahub.base.models import CommandsLastCheck
-from seahub.notifications.models import UserNotification
+from seahub.notifications.models import UserNotification, MSG_TYPE_FILE_COMMENT
 from seahub.utils import send_html_email, get_site_scheme_and_netloc
 from seahub.avatar.templatetags.avatar_tags import avatar
 from seahub.avatar.util import get_default_avatar_url
+from seahub.base.accounts import User
 from seahub.base.templatetags.seahub_tags import email2nickname
 from seahub.invitations.models import Invitation
 from seahub.profile.models import Profile
@@ -25,6 +25,10 @@ from seahub.constants import HASH_URLS
 from seahub.utils import get_site_name
 from seahub.options.models import UserOptions, KEY_COLLABORATE_EMAIL_INTERVAL, \
     KEY_COLLABORATE_LAST_EMAILED_TIME, DEFAULT_COLLABORATE_EMAIL_INTERVAL
+from seahub.seadoc.models import SeadocNotification
+from seahub.tags.models import FileUUIDMap
+from seahub.notifications.utils import gen_sdoc_smart_link
+from seahub.utils.auth import VIRTUAL_ID_EMAIL_DOMAIN
 
 # Get an instance of a logger
 logger = logging.getLogger(__name__)
@@ -176,7 +180,7 @@ class Command(BaseCommand):
         notice.notice_from = escape(email2nickname(group_staff))
         notice.avatar_src = self.get_avatar_src(group_staff)
         notice.group_staff_profile_url = reverse('user_profile',
-                                                  args=[group_staff])
+                                                 args=[group_staff])
         notice.group_url = reverse('group', args=[group.id])
         notice.group_name = group.group_name
         return notice
@@ -206,6 +210,70 @@ class Command(BaseCommand):
         notice.inv_accept_at = inv.accept_time.strftime("%Y-%m-%d %H:%M:%S")
         return notice
 
+    def format_deleted_files_msg(self, notice):
+        d = json.loads(notice.detail)
+        repo_id = d['repo_id']
+        repo = seafile_api.get_repo(repo_id)
+        repo_url = reverse('lib_view', args=[repo.id, repo.name, ''])
+
+        notice.repo_url = repo_url
+        notice.repo_name = repo.name
+        notice.avatar_src = self.get_avatar_src(notice.to_user)
+        return notice
+
+    def format_repo_monitor_msg(self, notice):
+
+        d = json.loads(notice.detail)
+
+        op_user_email = d['op_user']
+        notice.user_url = reverse('user_profile', args=[op_user_email])
+        notice.user_name = email2nickname(op_user_email)
+        notice.avatar_src = self.get_avatar_src(op_user_email)
+
+        notice.op_type = d['op_type']
+
+        repo_id = d['repo_id']
+        repo_name = d['repo_name']
+        notice.repo_url = reverse('lib_view', args=[repo_id, repo_name, ''])
+        notice.repo_name = d['repo_name']
+
+        obj_type = d['obj_type']
+        obj_path_list = d['obj_path_list']
+        notice.obj_type = obj_type
+        notice.obj_path_count = len(obj_path_list)
+        notice.obj_path_count_minus_one = len(obj_path_list) - 1
+        notice.obj_name = os.path.basename(d['obj_path_list'][0])
+
+        old_obj_path_list = d.get('old_obj_path_list', [])
+        if old_obj_path_list:
+            notice.old_obj_name = os.path.basename(d['old_obj_path_list'][0])
+        else:
+            notice.old_obj_name = ''
+
+        if obj_type == 'file':
+            notice.obj_url = reverse('view_lib_file', args=[repo_id, obj_path_list[0]])
+        else:
+            notice.obj_url = reverse('lib_view',
+                                     args=[repo_id, repo_name, obj_path_list[0].strip('/')])
+
+        return notice
+
+    def format_sdoc_msg(self, sdoc_queryset, sdoc_notice):
+        sdoc_obj = sdoc_queryset.filter(uuid=sdoc_notice.doc_uuid).first()
+        if not sdoc_obj:
+            return None
+        notice = UserNotification()
+        notice.msg_type = MSG_TYPE_FILE_COMMENT
+        notice.to_user = sdoc_notice.username
+        notice.timestamp = sdoc_notice.created_at
+        notice.file_url = gen_sdoc_smart_link(sdoc_notice.doc_uuid, with_service_url=False)
+        notice.file_name = str(sdoc_obj.filename)[:-5]
+        detail = json.loads(sdoc_notice.detail)
+        author = email2nickname(detail.get('author'))
+        notice.author = author
+        notice.avatar_src = self.get_avatar_src(author)
+        return notice
+
     def get_user_language(self, username):
         return Profile.objects.get_user_language(username)
 
@@ -219,14 +287,23 @@ class Command(BaseCommand):
 
         all_unseen_notices = UserNotification.objects.get_all_notifications(
             seen=False, time_since=last_longest_interval_time).order_by('-timestamp')
+        all_unseen_sdoc_notices = SeadocNotification.objects.filter(
+            seen=False, created_at__gt=last_longest_interval_time).order_by('-created_at')
+        sdoc_queryset = FileUUIDMap.objects.filter(uuid__in=[item.doc_uuid for item in all_unseen_sdoc_notices])
 
         results = {}
         for notice in all_unseen_notices:
             if notice.to_user not in results:
-                results[notice.to_user] = {'notices': [notice], 'interval': DEFAULT_COLLABORATE_EMAIL_INTERVAL}
+                results[notice.to_user] = {'notices': [notice], 'sdoc_notices': [] , 'interval': DEFAULT_COLLABORATE_EMAIL_INTERVAL}
             else:
                 results[notice.to_user]['notices'].append(notice)
 
+        for sdoc_notice in all_unseen_sdoc_notices:
+            if sdoc_notice.username not in results:
+                results[sdoc_notice.username] = {'notices': [], 'sdoc_notices': [sdoc_notice], 'interval': DEFAULT_COLLABORATE_EMAIL_INTERVAL}
+            else:
+                results[sdoc_notice.username]['sdoc_notices'].append(sdoc_notice)
+
         user_options = UserOptions.objects.filter(
             email__in=results.keys(), option_key=KEY_COLLABORATE_EMAIL_INTERVAL)
         for option in user_options:
@@ -241,17 +318,40 @@ class Command(BaseCommand):
             else:
                 results[email]['interval'] = interval
 
-        return [(key, value['interval'], value['notices']) for key, value in results.items()]
-
+        return [(key, value['interval'], value['notices'], value['sdoc_notices'], sdoc_queryset) for key, value in results.items()]
 
     def do_action(self):
+
         user_interval_notices = self.get_user_intervals_and_notices()
         last_emailed_list = UserOptions.objects.filter(option_key=KEY_COLLABORATE_LAST_EMAILED_TIME).values_list('email', 'option_val')
         user_last_emailed_time_dict = {le[0]: datetime.datetime.strptime(le[1], "%Y-%m-%d %H:%M:%S") for le in last_emailed_list}
 
+        # check if to_user active
+        user_active_dict = {}
+        for (to_user, interval_val, notices, sdoc_notices, sdoc_queryset) in user_interval_notices:
+
+            if to_user in user_active_dict:
+                continue
+            else:
+                try:
+                    to_user_obj = User.objects.get(email=to_user)
+                except User.DoesNotExist:
+                    user_active_dict[to_user] = False
+                    continue
+
+                user_active_dict[to_user] = to_user_obj.is_active
+
         # save current language
         cur_language = translation.get_language()
-        for (to_user, interval_val, notices) in user_interval_notices:
+        for (to_user, interval_val, notices, sdoc_notices, sdoc_queryset) in user_interval_notices:
+
+            if not user_active_dict[to_user]:
+                continue
+
+            contact_email = Profile.objects.get_contact_email_by_user(to_user)
+            if not contact_email or VIRTUAL_ID_EMAIL_DOMAIN in contact_email:
+                continue
+
             # get last_emailed_time if any, defaults to today 00:00:00.0
             last_emailed_time = user_last_emailed_time_dict.get(to_user, None)
             now = datetime.datetime.now().replace(microsecond=0)
@@ -263,7 +363,8 @@ class Command(BaseCommand):
                     continue
 
             user_notices = list(filter(lambda notice: notice.timestamp > last_emailed_time, notices))
-            if not user_notices:
+            user_sdoc_notices = list(filter(lambda sdoc_notice: sdoc_notice.created_at > last_emailed_time, sdoc_notices))
+            if not user_notices and not user_sdoc_notices:
                 continue
 
             # get and active user language
@@ -314,18 +415,31 @@ class Command(BaseCommand):
                 elif notice.is_guest_invitation_accepted_msg():
                     notice = self.format_guest_invitation_accepted_msg(notice)
 
+                elif notice.is_deleted_files_msg():
+                    notice = self.format_deleted_files_msg(notice)
+
+                elif notice.is_repo_monitor_msg():
+                    notice = self.format_repo_monitor_msg(notice)
+
                 if notice is None:
                     continue
 
                 notices.append(notice)
 
+            for sdoc_notice in user_sdoc_notices:
+                if sdoc_notice.username != to_user:
+                    continue
+                notice = self.format_sdoc_msg(sdoc_queryset, sdoc_notice)
+                if notice is None:
+                    continue
+                notices.append(notice)
+
             if not notices:
                 continue
+
             user_name = email2nickname(to_user)
-            contact_email = Profile.objects.get_contact_email_by_user(to_user)
-            to_user = contact_email  # use contact email if any
             c = {
-                'to_user': to_user,
+                'to_user': contact_email,
                 'notice_count': len(notices),
                 'notices': notices,
                 'user_name': user_name,
@@ -334,15 +448,14 @@ class Command(BaseCommand):
             try:
                 send_html_email(_('New notice on %s') % get_site_name(),
                                 'notifications/notice_email.html', c,
-                                None, [to_user])
+                                None, [contact_email])
                 # set new last_emailed_time
-                UserOptions.objects.set_collaborate_last_emailed_time(
-                    to_user, now)
-                logger.info('Successfully sent email to %s' % to_user)
-                self.stdout.write('[%s] Successfully sent email to %s' % (str(datetime.datetime.now()), to_user))
+                UserOptions.objects.set_collaborate_last_emailed_time(to_user, now)
+                logger.info('Successfully sent email to %s' % contact_email)
+                self.stdout.write('[%s] Successfully sent email to %s' % (str(datetime.datetime.now()), contact_email))
             except Exception as e:
-                logger.error('Failed to send email to %s, error detail: %s' % (to_user, e))
-                self.stderr.write('[%s] Failed to send email to %s, error detail: %s' % (str(datetime.datetime.now()), to_user, e))
+                logger.error('Failed to send email to %s, error detail: %s' % (contact_email, e))
+                self.stderr.write('[%s] Failed to send email to %s, error detail: %s' % (str(datetime.datetime.now()), contact_email, e))
 
             # restore current language
             translation.activate(cur_language)
