@@ -10,19 +10,16 @@ from django.db import models
 from django.conf import settings
 from django.forms import ModelForm, Textarea
 from django.utils.html import escape
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.core.cache import cache
 from django.template.loader import render_to_string
 
-import seaserv
 from seaserv import seafile_api, ccnet_api
 
 from seahub.base.fields import LowerCaseCharField
 from seahub.base.templatetags.seahub_tags import email2nickname
 from seahub.invitations.models import Invitation
-from seahub.utils.repo import get_repo_shared_users
 from seahub.utils import normalize_cache_key
-from seahub.utils.timeutils import datetime_to_isoformat_timestr
 from seahub.constants import HASH_URLS
 from seahub.drafts.models import DraftReviewer
 from seahub.file_participants.utils import list_file_participants
@@ -77,6 +74,8 @@ MSG_TYPE_DRAFT_COMMENT = 'draft_comment'
 MSG_TYPE_DRAFT_REVIEWER = 'draft_reviewer'
 MSG_TYPE_GUEST_INVITATION_ACCEPTED = 'guest_invitation_accepted'
 MSG_TYPE_REPO_TRANSFER = 'repo_transfer'
+MSG_TYPE_REPO_MINOTOR = 'repo_monitor'
+MSG_TYPE_DELETED_FILES = 'deleted_files'
 
 USER_NOTIFICATION_COUNT_CACHE_PREFIX = 'USER_NOTIFICATION_COUNT_'
 
@@ -406,6 +405,12 @@ class UserNotification(models.Model):
     def is_repo_transfer_msg(self):
         return self.msg_type == MSG_TYPE_REPO_TRANSFER
 
+    def is_repo_monitor_msg(self):
+        return self.msg_type == MSG_TYPE_REPO_MINOTOR
+
+    def is_deleted_files_msg(self):
+        return self.msg_type == MSG_TYPE_DELETED_FILES
+
     def user_message_detail_to_dict(self):
         """Parse user message detail, returns dict contains ``message`` and
         ``msg_from``.
