@@ -6,14 +6,19 @@ import sys
 import os
 import re
 
-from seaserv import FILE_SERVER_ROOT, FILE_SERVER_PORT, SERVICE_URL
+from seaserv import FILE_SERVER_PORT
 
 PROJECT_ROOT = os.path.join(os.path.dirname(__file__), os.pardir)
 
 DEBUG = False
 
+SERVICE_URL = 'http://127.0.0.1:8000'
+FILE_SERVER_ROOT = 'http://127.0.0.1:' + FILE_SERVER_PORT
+
 CLOUD_MODE = False
 
+MULTI_TENANCY = False
+
 ADMINS = [
     # ('Your Name', 'your_email@domain.com'),
 ]
@@ -22,8 +27,8 @@ MANAGERS = ADMINS
 
 DATABASES = {
     'default': {
-        'ENGINE': 'django.db.backends.sqlite3', # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.
-        'NAME': '%s/seahub/seahub.db' % PROJECT_ROOT, # Or path to database file if using sqlite3.
+        'ENGINE': 'django.db.backends.sqlite3',  # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.
+        'NAME': '%s/seahub/seahub.db' % PROJECT_ROOT,  # Or path to database file if using sqlite3.
         'USER': '',                      # Not used with sqlite3.
         'PASSWORD': '',                  # Not used with sqlite3.
         'HOST': '',                      # Set to empty string for localhost. Not used with sqlite3.
@@ -31,6 +36,10 @@ DATABASES = {
     }
 }
 
+# New in Django 3.2
+# Default primary key field type to use for models that don’t have a field with primary_key=True.
+DEFAULT_AUTO_FIELD = 'django.db.models.AutoField'
+
 # Local time zone for this installation. Choices can be found here:
 # http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
 # although not all choices may be available on all operating systems.
@@ -50,7 +59,6 @@ USE_I18N = True
 
 # If you set this to False, Django will not format dates, numbers and
 # calendars according to the current locale.
-USE_L10N = True
 
 # If you set this to False, Django will not use timezone-aware datetimes.
 USE_TZ = False
@@ -90,7 +98,12 @@ WEBPACK_LOADER = {
     }
 }
 
-STATICFILES_STORAGE = 'django.contrib.staticfiles.storage.ManifestStaticFilesStorage'
+DEFAULT_FILE_STORAGE = 'django.core.files.storage.FileSystemStorage'
+# STORAGES = {
+#     "staticfiles": {
+#         "BACKEND": 'django.contrib.staticfiles.storage.ManifestStaticFilesStorage',
+#     },
+# }
 
 # StaticI18N config
 STATICI18N_ROOT = '%s/static/scripts' % PROJECT_ROOT
@@ -124,7 +137,8 @@ MIDDLEWARE = [
     'termsandconditions.middleware.TermsAndConditionsRedirectMiddleware',
     'seahub.two_factor.middleware.OTPMiddleware',
     'seahub.two_factor.middleware.ForceTwoFactorAuthMiddleware',
-    'seahub.trusted_ip.middleware.LimitIpMiddleware'
+    'seahub.trusted_ip.middleware.LimitIpMiddleware',
+    'seahub.organizations.middleware.RedirectMiddleware',
 ]
 
 SITE_ROOT_URLCONF = 'seahub.urls'
@@ -220,6 +234,7 @@ INSTALLED_APPS = [
     'constance.backends.database',
     'termsandconditions',
     'webpack_loader',
+    'djangosaml2',
 
     'seahub.api2',
     'seahub.avatar',
@@ -254,11 +269,18 @@ INSTALLED_APPS = [
     'seahub.abuse_reports',
     'seahub.repo_auto_delete',
     'seahub.ocm',
+    'seahub.ocm_via_webdav',
+    'seahub.search',
+    'seahub.sysadmin_extra',
+    'seahub.organizations',
+    'seahub.krb5_auth',
+    'seahub.django_cas_ng',
+    'seahub.seadoc',
 ]
 
 
 # Enable or disable view File Scan
-# ENABLE_FILE_SCAN = True
+ENABLE_FILE_SCAN = False
 
 # Enable or disable multiple storage backends.
 ENABLE_STORAGE_CLASSES = False
@@ -275,6 +297,12 @@ AUTHENTICATION_BACKENDS = (
     'seahub.base.accounts.AuthBackend',
 )
 
+ENABLE_CAS = False
+
+ENABLE_ADFS_LOGIN = False
+
+ENABLE_MULTI_ADFS = False
+
 ENABLE_OAUTH = False
 ENABLE_WATERMARK = False
 
@@ -289,6 +317,21 @@ ENABLE_WEIXIN = False
 # enable dingtalk
 ENABLE_DINGTALK = False
 
+# enable ldap
+ENABLE_LDAP = False
+LDAP_USER_FIRST_NAME_ATTR = ''
+LDAP_USER_LAST_NAME_ATTR = ''
+LDAP_USER_NAME_REVERSE = False
+LDAP_FILTER = ''
+LDAP_CONTACT_EMAIL_ATTR = ''
+LDAP_USER_ROLE_ATTR = ''
+ACTIVATE_USER_WHEN_IMPORT = True
+
+# enable ldap sasl auth
+ENABLE_SASL = False
+SASL_MECHANISM = ''
+SASL_AUTHC_ID_ATTR = ''
+
 # allow user to clean library trash
 ENABLE_USER_CLEAN_TRASH = True
 
@@ -299,10 +342,13 @@ LOGOUT_REDIRECT_URL = None
 
 ACCOUNT_ACTIVATION_DAYS = 7
 
-# allow seafile amdin view user's repo
+# allow seafile admin view user's repo
 ENABLE_SYS_ADMIN_VIEW_REPO = False
 
-#allow search from LDAP directly during auto-completion (not only search imported users)
+# allow seafile admin generate user auth token
+ENABLE_SYS_ADMIN_GENERATE_USER_AUTH_TOKEN = False
+
+# allow search from LDAP directly during auto-completion (not only search imported users)
 ENABLE_SEARCH_FROM_LDAP_DIRECTLY = False
 
 # show traffic on the UI
@@ -334,6 +380,9 @@ REPO_PASSWORD_MIN_LENGTH = 8
 # token length for the share link
 SHARE_LINK_TOKEN_LENGTH = 20
 
+# max link number for creating share links in batch
+SHARE_LINK_MAX_NUMBER = 200
+
 # if limit only authenticated user can view preview share link
 SHARE_LINK_LOGIN_REQUIRED = False
 
@@ -353,8 +402,17 @@ UPLOAD_LINK_EXPIRE_DAYS_MAX = 0 # 0 means no limit
 # greater than or equal to MIN and less than or equal to MAX
 UPLOAD_LINK_EXPIRE_DAYS_DEFAULT = 0
 
-# mininum length for the password of a share link
-SHARE_LINK_PASSWORD_MIN_LENGTH = 8
+# force use password when generate a share/upload link
+SHARE_LINK_FORCE_USE_PASSWORD = False
+
+# mininum length for the password of a share/upload link
+SHARE_LINK_PASSWORD_MIN_LENGTH = 10
+
+# LEVEL for the password of a share/upload link
+# based on four types of input:
+# num, upper letter, lower letter, other symbols
+# '3' means password must have at least 3 types of the above.
+SHARE_LINK_PASSWORD_STRENGTH_LEVEL = 1
 
 # enable or disable share link audit
 ENABLE_SHARE_LINK_AUDIT = False
@@ -402,9 +460,6 @@ ENABLE_UPDATE_USER_INFO = True
 # Enable or disable repo history setting
 ENABLE_REPO_HISTORY_SETTING = True
 
-# Enable or disable org repo creation by user
-ENABLE_USER_CREATE_ORG_REPO = True
-
 DISABLE_SYNC_WITH_ANY_FOLDER = False
 
 ENABLE_TERMS_AND_CONDITIONS = False
@@ -424,6 +479,9 @@ ENABLE_FILE_COMMENT = True
 # Enable seafile docs
 ENABLE_SEAFILE_DOCS = False
 
+# enable integration seatbale
+ENABLE_SEATABLE_INTEGRATION = False
+
 # File preview
 FILE_PREVIEW_MAX_SIZE = 30 * 1024 * 1024
 FILE_ENCODING_LIST = ['auto', 'utf-8', 'gbk', 'ISO-8859-1', 'ISO-8859-5']
@@ -521,6 +579,9 @@ INIT_PASSWD = genpassword
 # browser tab title
 SITE_TITLE = 'Private Seafile'
 
+# html head meta tag for search engine preview text
+SITE_DESCRIPTION = ''
+
 # Base name used in email sending
 SITE_NAME = 'Seafile'
 
@@ -532,7 +593,8 @@ LOGIN_BG_IMAGE_PATH = 'img/login-bg.jpg'
 
 # Path to the favicon file (relative to the media path)
 # tip: use a different name when modify it.
-FAVICON_PATH = 'img/favicon.ico'
+FAVICON_PATH = 'favicons/favicon.png'
+APPLE_TOUCH_ICON_PATH = 'favicons/favicon.png'
 
 # Path to the Logo Imagefile (relative to the media path)
 LOGO_PATH = 'img/seafile-logo.png'
@@ -564,6 +626,8 @@ SHOW_LOGOUT_ICON = False
 PRIVACY_POLICY_LINK = ''
 TERMS_OF_SERVICE_LINK = ''
 
+FILE_CONVERTER_SERVER_URL = 'http://127.0.0.1:8888'
+
 # For security consideration, please set to match the host/domain of your site, e.g., ALLOWED_HOSTS = ['.example.com'].
 # Please refer https://docs.djangoproject.com/en/dev/ref/settings/#allowed-hosts for details.
 ALLOWED_HOSTS = ['*']
@@ -662,9 +726,6 @@ CAPTCHA_IMAGE_SIZE = (90, 42)
 # Image Thumbnail #
 ###################
 
-# Enable or disable thumbnail
-ENABLE_THUMBNAIL = True
-
 # Absolute filesystem path to the directory that will hold thumbnail files.
 SEAHUB_DATA_ROOT = os.path.join(PROJECT_ROOT, '../../seahub-data')
 if os.path.exists(SEAHUB_DATA_ROOT):
@@ -691,19 +752,26 @@ THUMBNAIL_VIDEO_FRAME_TIME = 5  # use the frame at 5 second as thumbnail
 OFFICE_TEMPLATE_ROOT = os.path.join(MEDIA_ROOT, 'office-template')
 
 ENABLE_WEBDAV_SECRET = False
+WEBDAV_SECRET_MIN_LENGTH = 1
+WEBDAV_SECRET_STRENGTH_LEVEL = 1
+
 ENABLE_USER_SET_CONTACT_EMAIL = False
 
+# SSO to thirdparty website
+ENABLE_SSO_TO_THIRDPART_WEBSITE = False
+THIRDPART_WEBSITE_SECRET_KEY = ''
+THIRDPART_WEBSITE_URL = ''
+
+# client sso
+CLIENT_SSO_VIA_LOCAL_BROWSER = False
+CLIENT_SSO_TOKEN_EXPIRATION = 5 * 60
+
 #####################
 # Global AddressBook #
 #####################
 ENABLE_GLOBAL_ADDRESSBOOK = True
 ENABLE_ADDRESSBOOK_OPT_IN = False
 
-#####################
-# Folder Permission #
-#####################
-ENABLE_FOLDER_PERM = False
-
 ####################
 # Guest Invite     #
 ####################
@@ -740,6 +808,15 @@ SEAFILE_COLLAB_SERVER = ''
 
 DTABLE_WEB_SERVER = ''
 
+##########################
+# Settings for seadoc    #
+##########################
+
+ENABLE_SEADOC = False
+SEADOC_PRIVATE_KEY = ''
+SEADOC_SERVER_URL = 'http://127.0.0.1:7070'
+
+
 ############################
 # Settings for Seahub Priv #
 ############################
@@ -767,6 +844,10 @@ ENABLE_REPO_SNAPSHOT_LABEL = False
 #  Repo wiki mode
 ENABLE_REPO_WIKI_MODE = True
 
+SEAFILE_AI_SECRET_KEY = ''
+SEAFILE_AI_SERVER_URL = ''
+ENABLE_SEAFILE_AI = False
+
 ############################
 # HU berlin additional #
 ############################
@@ -797,6 +878,13 @@ if os.environ.get('SEAFILE_DOCS', None):
     LOGO_WIDTH = ''
     ENABLE_WIKI = True
 
+#######################
+# extended properties #
+#######################
+SEATABLE_EX_PROPS_BASE_API_TOKEN = ''
+EX_PROPS_TABLE = ''
+EX_EDITABLE_COLUMNS = []
+
 d = os.path.dirname
 EVENTS_CONFIG_FILE = os.environ.get(
     'EVENTS_CONFIG_FILE',
@@ -834,16 +922,6 @@ def load_local_settings(module):
         elif re.search('^[A-Z]', attr):
             globals()[attr] = getattr(module, attr)
 
-
-# Load seahub_extra_settings.py
-try:
-    from seahub_extra import seahub_extra_settings
-except ImportError:
-    pass
-else:
-    load_local_settings(seahub_extra_settings)
-    del seahub_extra_settings
-
 # Load local_settings.py
 try:
     import seahub.local_settings
@@ -889,8 +967,6 @@ CONSTANCE_CONFIG = {
     'LOGIN_ATTEMPT_LIMIT': (LOGIN_ATTEMPT_LIMIT, ''),
     'FREEZE_USER_ON_LOGIN_FAILED': (FREEZE_USER_ON_LOGIN_FAILED, ''),
 
-    'ENABLE_USER_CREATE_ORG_REPO': (ENABLE_USER_CREATE_ORG_REPO, ''),
-
     'ENABLE_ENCRYPTED_LIBRARY': (ENABLE_ENCRYPTED_LIBRARY, ''),
     'REPO_PASSWORD_MIN_LENGTH': (REPO_PASSWORD_MIN_LENGTH, ''),
     'ENABLE_REPO_HISTORY_SETTING': (ENABLE_REPO_HISTORY_SETTING, ''),
@@ -901,7 +977,9 @@ CONSTANCE_CONFIG = {
     'USER_PASSWORD_STRENGTH_LEVEL': (USER_PASSWORD_STRENGTH_LEVEL, ''),
 
     'SHARE_LINK_TOKEN_LENGTH': (SHARE_LINK_TOKEN_LENGTH, ''),
+    'SHARE_LINK_FORCE_USE_PASSWORD': (SHARE_LINK_FORCE_USE_PASSWORD, ''),
     'SHARE_LINK_PASSWORD_MIN_LENGTH': (SHARE_LINK_PASSWORD_MIN_LENGTH, ''),
+    'SHARE_LINK_PASSWORD_STRENGTH_LEVEL': (SHARE_LINK_PASSWORD_STRENGTH_LEVEL, ''),
     'ENABLE_TWO_FACTOR_AUTH': (ENABLE_TWO_FACTOR_AUTH, ''),
 
     'TEXT_PREVIEW_EXT': (TEXT_PREVIEW_EXT, ''),
@@ -915,6 +993,9 @@ CONSTANCE_CONFIG = {
 
     'ENABLE_TERMS_AND_CONDITIONS': (ENABLE_TERMS_AND_CONDITIONS, ''),
     'ENABLE_USER_CLEAN_TRASH': (ENABLE_USER_CLEAN_TRASH, ''),
+
+    'CLIENT_SSO_VIA_LOCAL_BROWSER': (CLIENT_SSO_VIA_LOCAL_BROWSER, ''),
+    'CLIENT_SSO_TOKEN_EXPIRATION': (CLIENT_SSO_TOKEN_EXPIRATION, ''),
 }
 
 # if Seafile admin enable remote user authentication in conf/seahub_settings.py
@@ -927,6 +1008,17 @@ if ENABLE_REMOTE_USER_AUTHENTICATION:
 if ENABLE_OAUTH or ENABLE_WORK_WEIXIN or ENABLE_WEIXIN or ENABLE_DINGTALK:
     AUTHENTICATION_BACKENDS += ('seahub.oauth.backends.OauthRemoteUserBackend',)
 
+if ENABLE_CAS:
+    AUTHENTICATION_BACKENDS += ('seahub.django_cas_ng.backends.CASBackend',)
+
+if ENABLE_ADFS_LOGIN or ENABLE_MULTI_ADFS:
+    MIDDLEWARE.append('djangosaml2.middleware.SamlSessionMiddleware')
+    AUTHENTICATION_BACKENDS += ('seahub.adfs_auth.backends.Saml2Backend',)
+    SAML_CONFIG_LOADER = 'seahub.adfs_auth.utils.config_settings_loader'
+
+if ENABLE_LDAP:
+    AUTHENTICATION_BACKENDS += ('seahub.base.accounts.CustomLDAPBackend',)
+
 #####################
 # Custom Nav Items  #
 #####################
@@ -938,4 +1030,8 @@ if ENABLE_OAUTH or ENABLE_WORK_WEIXIN or ENABLE_WEIXIN or ENABLE_DINGTALK:
 #      },
 # ]
 
-SEAFILE_VERSION = "8.0.7"
+# settings.py
+
+
+
+SEAFILE_VERSION = "11.0.3"
