@@ -1,13 +1,13 @@
 # Copyright (c) 2012-2016 Seafile Ltd.
 # encoding: utf-8
 import os
-import logging
 import json
+import logging
 
 from django.core.cache import cache
 from django.http import HttpResponse, HttpResponseRedirect, Http404, \
     HttpResponseBadRequest
-from django.utils.translation import ugettext as _, activate
+from django.utils.translation import gettext as _, activate
 from django.contrib import messages
 from django.utils.html import escape
 
@@ -25,8 +25,10 @@ from seahub.contacts.signals import mail_sended
 from seahub.views import is_registered_user, check_folder_permission
 from seahub.utils import string2list, IS_EMAIL_CONFIGURED, check_filename_with_rename, \
     is_valid_username, is_valid_email, send_html_email, is_org_context, \
-    gen_token, normalize_cache_key, get_site_name
+    gen_token, normalize_cache_key, get_site_name, gen_shared_link
 from seahub.utils.mail import send_html_email_with_dj_template
+from seahub.utils.ms_excel import write_xls
+from seahub.utils.timeutils import datetime_to_isoformat_timestr
 from seahub.settings import SITE_ROOT, REPLACE_FROM_EMAIL, \
         ADD_REPLY_TO_HEADER, SHARE_LINK_EMAIL_LANGUAGE, \
         SHARE_LINK_AUDIT_CODE_TIMEOUT
@@ -219,7 +221,7 @@ def save_shared_link(request):
     dst_repo_id = request.POST.get('dst_repo', '')
     dst_path = request.POST.get('dst_path', '')
 
-    next_page = request.META.get('HTTP_REFERER', None)
+    next_page = request.headers.get('referer', None)
     if not next_page:
         next_page = SITE_ROOT
 
@@ -242,14 +244,97 @@ def save_shared_link(request):
 
     new_obj_name = check_filename_with_rename(dst_repo_id, dst_path, obj_name)
 
-    seafile_api.copy_file(src_repo_id, src_path, obj_name,
-                          dst_repo_id, dst_path, new_obj_name, username,
-                          need_progress=0)
+    seafile_api.copy_file(src_repo_id, src_path,
+                          json.dumps([obj_name]),
+                          dst_repo_id, dst_path,
+                          json.dumps([new_obj_name]),
+                          username, need_progress=0)
 
     messages.success(request, _('Successfully saved.'))
     return HttpResponseRedirect(next_page)
 
 
+# share link
+@login_required
+def export_shared_link(request):
+    """
+    Export shared links to excel.
+    """
+
+    def get_share_link_info(fileshare):
+
+        if fileshare.expire_date:
+            expire_date = datetime_to_isoformat_timestr(fileshare.expire_date)
+        else:
+            expire_date = ''
+
+        info = {}
+        info['username'] = fileshare.username
+        info['link'] = gen_shared_link(fileshare.token, fileshare.s_type)
+        info['expire_date'] = expire_date
+        info['password'] = fileshare.get_password()
+
+        can_edit = fileshare.get_permissions().get('can_edit')
+        can_download = fileshare.get_permissions().get('can_download')
+        can_upload = fileshare.get_permissions().get('can_upload')
+        permission_str = f"{can_edit} {can_download} {can_upload}".lower()
+
+        permission_dict = {
+            "false true false": _('Preview and download'),
+            "false false false": _('Preview only'),
+            "false true true": _('Download and upload'),
+            "true true false": _('Edit on cloud and download'),
+            "true false false": _('Edit on cloud only')
+        }
+
+        info['permission'] = permission_dict.get(permission_str, '')
+
+        return info
+
+    token_list = request.GET.getlist('token')
+    if not token_list:
+        data = json.dumps({'error': _('Argument missing')})
+        return HttpResponse(data,
+                            status=400,
+                            content_type='application/json; charset=utf-8')
+
+    data_list = []
+    username = request.user.username
+    share_links = FileShare.objects.filter(token__in=token_list)
+
+    for link in share_links:
+
+        if link.username != username:
+            continue
+
+        link_info = get_share_link_info(link)
+        row = [link_info.get('link'), link_info.get('username'),
+               link_info.get('password') or '--',
+               link_info.get('permission'),
+               link_info.get('expire_date')]
+
+        data_list.append(row)
+
+    excel_name = 'Share Links'
+    head = [_("Share Link"), _("Creator"),
+            _('Password'), _("Permission"), _("Expiration")]
+
+    try:
+        wb = write_xls(excel_name, head, data_list)
+    except Exception as e:
+        logger.error(e)
+        data = json.dumps({'error': _('Internal Server Error')})
+        return HttpResponse(data,
+                            status=500,
+                            content_type='application/json; charset=utf-8')
+
+    response = HttpResponse(content_type='application/ms-excel')
+    response['Content-Disposition'] = 'attachment; filename="%s.xlsx"' % excel_name
+    wb.save(response)
+
+    return response
+
+
 @login_required_ajax
 def send_shared_upload_link(request):
     """
