@@ -9,4 +9,8 @@ VIDEO = 'Video'
 AUDIO = 'Audio'
 SPREADSHEET = 'SpreadSheet'
 XMIND = 'XMind'
-CDOC = 'cdoc'
+SEADOC = 'SDoc'
+
+
+MARKDOWN_SUPPORT_CONVERT_TYPES = ['sdoc']
+SDOC_SUPPORT_CONVERT_TYPES = ['markdown']
