@@ -14,9 +14,9 @@ from django.contrib import messages
 from django.http import HttpResponse, Http404, \
     HttpResponseRedirect
 from django.shortcuts import render, redirect
-from django.utils.http import urlquote
+from urllib.parse import quote
 from django.utils.html import escape
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 from django.views.decorators.http import condition
 
 import seaserv
@@ -36,35 +36,37 @@ from seahub.options.models import UserOptions, CryptoOptionNotSetError
 from seahub.profile.models import Profile
 from seahub.share.models import FileShare, UploadLinkShare
 from seahub.revision_tag.models import RevisionTags
+from seahub.tags.models import FileUUIDMap
 from seahub.utils import render_permission_error, render_error, \
     gen_shared_upload_link, is_org_context, \
     gen_dir_share_link, gen_file_share_link, get_file_type_and_ext, \
     get_user_repos, EMPTY_SHA1, gen_file_get_url, \
     new_merge_with_no_conflict, get_max_upload_file_size, \
     is_pro_version, FILE_AUDIT_ENABLED, is_valid_dirent_name, \
-    is_windows_operating_system, seafevents_api, IS_EMAIL_CONFIGURED
+    is_windows_operating_system, get_file_history_suffix, IS_EMAIL_CONFIGURED, \
+    normalize_file_path
 from seahub.utils.star import get_dir_starred_files
 from seahub.utils.repo import get_library_storages, parse_repo_perm
 from seahub.utils.file_op import check_file_lock
 from seahub.utils.timeutils import utc_to_local
 from seahub.utils.auth import get_login_bg_image_path
 import seahub.settings as settings
-from seahub.settings import AVATAR_FILE_STORAGE, \
-    ENABLE_FOLDER_PERM, ENABLE_REPO_SNAPSHOT_LABEL, \
+from seahub.settings import AVATAR_FILE_STORAGE, ENABLE_REPO_SNAPSHOT_LABEL, \
     UNREAD_NOTIFICATIONS_REQUEST_INTERVAL, SHARE_LINK_EXPIRE_DAYS_MIN, \
     SHARE_LINK_EXPIRE_DAYS_MAX, SHARE_LINK_EXPIRE_DAYS_DEFAULT, \
     UPLOAD_LINK_EXPIRE_DAYS_MIN, UPLOAD_LINK_EXPIRE_DAYS_MAX, UPLOAD_LINK_EXPIRE_DAYS_DEFAULT, \
     SEAFILE_COLLAB_SERVER, ENABLE_RESET_ENCRYPTED_REPO_PASSWORD, \
     ADDITIONAL_SHARE_DIALOG_NOTE, ADDITIONAL_APP_BOTTOM_LINKS, ADDITIONAL_ABOUT_DIALOG_LINKS, \
-    DTABLE_WEB_SERVER
+    DTABLE_WEB_SERVER, EX_PROPS_TABLE, SEATABLE_EX_PROPS_BASE_API_TOKEN, EX_EDITABLE_COLUMNS
 
 from seahub.wopi.settings import ENABLE_OFFICE_WEB_APP
-from seahub.onlyoffice.settings import ONLYOFFICE_DESKTOP_EDITORS_PORTAL_LOGIN
 from seahub.ocm.settings import ENABLE_OCM, OCM_REMOTE_SERVERS
+from seahub.ocm_via_webdav.settings import ENABLE_OCM_VIA_WEBDAV
 from seahub.constants import HASH_URLS, PERMISSION_READ
 from seahub.group.settings import GROUP_IMPORT_MEMBERS_EXTRA_MSG
 
 from seahub.weixin.settings import ENABLE_WEIXIN
+from seahub.onlyoffice.settings import ONLYOFFICE_DESKTOP_EDITOR_HTTP_USER_AGENT
 
 LIBRARY_TEMPLATES = getattr(settings, 'LIBRARY_TEMPLATES', {})
 CUSTOM_NAV_ITEMS = getattr(settings, 'CUSTOM_NAV_ITEMS', '')
@@ -120,6 +122,22 @@ def check_folder_permission(request, repo_id, path):
     username = request.user.username
     return seafile_api.check_permission_by_path(repo_id, path, username)
 
+def get_seadoc_file_uuid(repo, path):
+    repo_id = repo.repo_id
+    if repo.is_virtual:
+        repo_id = repo.origin_repo_id
+        path = posixpath.join(repo.origin_path, path.strip('/'))
+
+    path = normalize_file_path(path)
+    parent_dir = os.path.dirname(path)
+    filename = os.path.basename(path)
+
+    uuid_map = FileUUIDMap.objects.get_or_create_fileuuidmap(
+        repo_id, parent_dir, filename, is_dir=False)
+
+    file_uuid = str(uuid_map.uuid)  # 36 chars str
+    return file_uuid
+
 def gen_path_link(path, repo_name):
     """
     Generate navigate paths and links in repo page.
@@ -154,7 +172,7 @@ def get_file_download_link(repo_id, obj_id, path):
     - `filename`:
     """
     return reverse('download_file', args=[repo_id, obj_id]) + '?p=' + \
-        urlquote(path)
+        quote(path)
 
 def get_repo_dirents(request, repo, commit, path, offset=-1, limit=-1):
     """List repo dirents based on commit id and path. Use ``offset`` and
@@ -212,8 +230,8 @@ def get_repo_dirents(request, repo, commit, path, offset=-1, limit=-1):
                         dirent.uploadtoken = link.token
                         break
                 p_dpath = posixpath.join(path, dirent.obj_name)
-                dirent.view_link = view_dir_base + '?p=' + urlquote(p_dpath)
-                dirent.dl_link = dl_dir_base + '?p=' + urlquote(p_dpath)
+                dirent.view_link = view_dir_base + '?p=' + quote(p_dpath)
+                dirent.dl_link = dl_dir_base + '?p=' + quote(p_dpath)
                 dir_list.append(dirent)
             else:
                 file_list.append(dirent)
@@ -227,7 +245,7 @@ def get_repo_dirents(request, repo, commit, path, offset=-1, limit=-1):
                 dirent.view_link = reverse('view_lib_file', args=[repo.id, p_fpath])
                 dirent.dl_link = get_file_download_link(repo.id, dirent.obj_id,
                                                         p_fpath)
-                dirent.history_link = file_history_base + '?p=' + urlquote(p_fpath)
+                dirent.history_link = file_history_base + '?p=' + quote(p_fpath)
                 if fpath in starred_files:
                     dirent.starred = True
                 for share in fileshares:
@@ -303,7 +321,7 @@ def render_recycle_dir(request, repo_id, commit_id, referer):
         commit = seafserv_threaded_rpc.get_commit(repo.id, repo.version, commit_id)
     except SearpcError as e:
         logger.error(e)
-        referer = request.META.get('HTTP_REFERER', None)
+        referer = request.headers.get('referer', None)
         next_page = settings.SITE_ROOT if referer is None else referer
         return HttpResponseRedirect(next_page)
 
@@ -365,7 +383,7 @@ def render_dir_recycle_dir(request, repo_id, commit_id, dir_path, referer):
         commit = seafserv_threaded_rpc.get_commit(repo.id, repo.version, commit_id)
     except SearpcError as e:
         logger.error(e)
-        referer = request.META.get('HTTP_REFERER', None)
+        referer = request.headers.get('referer', None)
         next_page = settings.SITE_ROOT if referer is None else referer
         return HttpResponseRedirect(next_page)
 
@@ -551,7 +569,7 @@ def repo_history(request, repo_id):
 @require_POST
 def repo_revert_history(request, repo_id):
 
-    next_page = request.META.get('HTTP_REFERER', None)
+    next_page = request.headers.get('referer', None)
     if not next_page:
         next_page = settings.SITE_ROOT
 
@@ -677,8 +695,11 @@ def create_default_library(request):
         dirents = seafile_api.list_dir_by_path(sys_repo_id, '/')
         for e in dirents:
             obj_name = e.obj_name
-            seafile_api.copy_file(sys_repo_id, '/', obj_name,
-                                  default_repo, '/', obj_name, username, 0)
+            seafile_api.copy_file(sys_repo_id, '/',
+                                  json.dumps([obj_name]),
+                                  default_repo, '/',
+                                  json.dumps([obj_name]),
+                                  username, 0)
     except SearpcError as e:
         logger.error(e)
         return
@@ -748,8 +769,8 @@ def file_revisions(request, repo_id):
 
     u_filename = os.path.basename(path)
 
-    filetype, file_ext = [x.lower() for x in get_file_type_and_ext(u_filename)]
-    if filetype == 'text' or filetype == 'markdown':
+    file_type, file_ext = [x.lower() for x in get_file_type_and_ext(u_filename)]
+    if file_type == 'text' or file_type == 'markdown' or file_type == 'sdoc':
         can_compare = True
     else:
         can_compare = False
@@ -775,15 +796,29 @@ def file_revisions(request, repo_id):
     if repo_perm != 'rw' or (is_locked and not locked_by_me):
         can_revert_file = False
 
+    if file_type == 'sdoc':
+        file_uuid = get_seadoc_file_uuid(repo, path)
+        return render(request, 'sdoc_file_revisions.html', {
+            'repo': repo,
+            'path': path,
+            'u_filename': u_filename,
+            'file_uuid': file_uuid,
+            'zipped': zipped,
+            'is_owner': is_owner,
+            'can_compare': can_compare,
+            'can_revert_file': can_revert_file,
+            'assets_url': '/api/v2.1/seadoc/download-image/' + file_uuid
+        })
+
     # Whether use new file history API which read file history from db.
-    suffix_list = seafevents_api.get_file_history_suffix()
+    suffix_list = get_file_history_suffix()
     if suffix_list and isinstance(suffix_list, list):
         suffix_list = [x.lower() for x in suffix_list]
     else:
         suffix_list = []
 
     use_new_api = True if file_ext in suffix_list else False
-    use_new_style = True if use_new_api and filetype == 'markdown' else False
+    use_new_style = True if use_new_api and file_type == 'markdown' else False
 
     if use_new_style:
         return render(request, 'file_revisions_new.html', {
@@ -850,7 +885,7 @@ def i18n(request):
 
     """
     from django.conf import settings
-    next_page = request.META.get('HTTP_REFERER', settings.SITE_ROOT)
+    next_page = request.headers.get('referer', settings.SITE_ROOT)
 
     lang = request.GET.get('lang', settings.LANGUAGE_CODE)
     if lang not in [e[0] for e in settings.LANGUAGES]:
@@ -931,7 +966,7 @@ def group_events_data(events):
         e.time = utc_to_local(e.timestamp)
         e.date = e.time.strftime("%Y-%m-%d")
         if e.etype == 'repo-update':
-            e.author = e.commit.creator_name
+            e.author = getattr(e.commit, 'creator_name', '')
         elif e.etype == 'repo-create':
             e.author = e.creator
         else:
@@ -1120,7 +1155,10 @@ def react_fake_view(request, **kwargs):
     if resolve(request.path).url_name == 'lib_view':
 
         repo_id = kwargs.get('repo_id', '')
+        repo_name = kwargs.get('repo_name', '')
         path = kwargs.get('path', '')
+        if repo_id and repo_name and not path:
+            path = '/'
 
         if repo_id and path and \
                 not check_folder_permission(request, repo_id, path):
@@ -1139,7 +1177,8 @@ def react_fake_view(request, **kwargs):
                 return render_error(request, error_msg)
 
             converted_path = repo_path_dict['path']
-            if not seafile_api.get_dirent_by_path(converted_repo_id, converted_path):
+            if converted_path != '/' and not seafile_api.get_dirent_by_path(converted_repo_id, converted_path):
+
                 error_msg = 'Dirent %s not found.' % converted_path
                 return render_error(request, error_msg)
 
@@ -1162,8 +1201,6 @@ def react_fake_view(request, **kwargs):
         logger.error(e)
         expire_days = -1
 
-    folder_perm_enabled = True if is_pro_version() and ENABLE_FOLDER_PERM else False
-
     try:
         max_upload_file_size = seafile_api.get_server_config_int('fileserver', 'max_upload_size')
     except Exception as e:
@@ -1171,7 +1208,6 @@ def react_fake_view(request, **kwargs):
         max_upload_file_size = -1
 
     return render(request, "react_app.html", {
-        "onlyoffice_desktop_editors_portal_login": ONLYOFFICE_DESKTOP_EDITORS_PORTAL_LOGIN,
         "guide_enabled": guide_enabled,
         'trash_repos_expire_days': expire_days if expire_days > 0 else 30,
         'dtable_web_server': DTABLE_WEB_SERVER,
@@ -1194,15 +1230,20 @@ def react_fake_view(request, **kwargs):
         'enableFileComment': settings.ENABLE_FILE_COMMENT,
         'is_email_configured': IS_EMAIL_CONFIGURED,
         'can_add_public_repo': request.user.permissions.can_add_public_repo(),
-        'folder_perm_enabled': folder_perm_enabled,
+        'folder_perm_enabled': is_pro_version(),
         'file_audit_enabled': FILE_AUDIT_ENABLED,
         'custom_nav_items': json.dumps(CUSTOM_NAV_ITEMS),
         'enable_show_contact_email_when_search_user': settings.ENABLE_SHOW_CONTACT_EMAIL_WHEN_SEARCH_USER,
         'additional_share_dialog_note': ADDITIONAL_SHARE_DIALOG_NOTE,
         'additional_app_bottom_links': ADDITIONAL_APP_BOTTOM_LINKS,
         'additional_about_dialog_links': ADDITIONAL_ABOUT_DIALOG_LINKS,
+        'enable_ocm_via_webdav': ENABLE_OCM_VIA_WEBDAV,
         'enable_ocm': ENABLE_OCM,
         'ocm_remote_servers': OCM_REMOTE_SERVERS,
         'enable_share_to_department': settings.ENABLE_SHARE_TO_DEPARTMENT,
+        'enable_video_thumbnail': settings.ENABLE_VIDEO_THUMBNAIL,
         'group_import_members_extra_msg': GROUP_IMPORT_MEMBERS_EXTRA_MSG,
+        'request_from_onlyoffice_desktop_editor': ONLYOFFICE_DESKTOP_EDITOR_HTTP_USER_AGENT in request.headers.get('user-agent', ''),
+        'enable_sso_to_thirdpart_website': settings.ENABLE_SSO_TO_THIRDPART_WEBSITE,
+        'can_set_ex_props': DTABLE_WEB_SERVER and SEATABLE_EX_PROPS_BASE_API_TOKEN and EX_PROPS_TABLE and EX_EDITABLE_COLUMNS
     })
