@@ -1,13 +1,14 @@
 
 
-(function(globals) {
-
-  var django = globals.django || (globals.django = {});
+'use strict';
+{
+  const globals = this;
+  const django = globals.django || (globals.django = {});
 
   
   django.pluralidx = function(n) {
-    var v=(n != 1);
-    if (typeof(v) == 'boolean') {
+    const v = n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;
+    if (typeof v === 'boolean') {
       return v ? 1 : 0;
     } else {
       return v;
@@ -19,10 +20,8 @@
 
   django.catalog = django.catalog || {};
   
-  var newcatalog = {
-    "%curr% of %total%": "%curr% de %total%",
+  const newcatalog = {
     "(If left blank, owner will be admin)": "(Si queda en blanco, el propietario ser\u00e1 admin)",
-    "(at least {passwordLength} characters)": "(al menos{passwordLength} caracteres)",
     "(at least {placeholder} characters)": "(al menos {placeholder} caracteres)",
     "(current notification)": "(notificaci\u00f3n actual)",
     "(current version)": "(versi\u00f3n actual)",
@@ -55,21 +54,18 @@
     "Add": "Agregar",
     "Add Admin": "Agregar Admin",
     "Add Admins": "Agregar Administradores",
-    "Add File": "Agregar Archivo",
     "Add Institution": "Agregar Instituci\u00f3n",
     "Add Library": "Agregar Biblioteca",
     "Add Member": "Agregar Miembro",
     "Add Organization": "Agregar Organizaci\u00f3n",
     "Add Terms and Conditions": "Agregar T\u00e9rminos y Condiciones",
     "Add User": "Agregar Usuario",
-    "Add a comment.": "Agregar un comentario",
     "Add admin": "Agregar admin",
     "Add auto expiration": "Agregar vencimiento autom\u00e1tico",
     "Add group member": "Agregar miembro al grupo",
     "Add institution": "Agregar Instituci\u00f3n",
     "Add new notification": "Agregar nueva notificaci\u00f3n",
     "Add new reviewer": "Agregar un revisor",
-    "Add participants": "Agregar participantes",
     "Add password protection": "Agregar protecci\u00f3n por contrase\u00f1a",
     "Add user": "Agregar usuario",
     "Added": "Agregado",
@@ -86,8 +82,8 @@
     "All Notifications": "Todas las notificaciones",
     "All Public Links": "Enlaces P\u00fablicos",
     "All file types": "Todos los tipos",
+    "All files uploaded": "Todos los archivos subidos",
     "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Permitir que nuevos usuarios se registren. Desmarcar \u00e9sto para que nadie pueda crear una nueva cuenta.",
-    "Allow user to add organization libraries. Otherwise, only system admin can add organization libraries.": "Permitir al usuario crear bibliotecas de la organizaci\u00f3n. De otra manera s\u00f3lo un administrador puede hacerlo.",
     "Allow user to change library history settings": "Permitir al usuario modificar la configuraci\u00f3n del historial de la biblioteca",
     "Allow user to clean library trash": "Permitir al usuario vaciar la papelera de la biblioteca",
     "Allow user to create encrypted libraries": "Permitir al usuario crear bibliotecas encriptadas",
@@ -118,7 +114,6 @@
     "At server": "En el servidor",
     "Audio": "Audio",
     "Audit Admin": "Administrador auditor",
-    "Author": "Autor",
     "Auto deletion": "Eliminaci\u00f3n autom\u00e1tica",
     "Automatically delete files that are not modified within certain days:": "Eliminar autom\u00e1ticamente los archivos que no se modifican en determinado lapso de d\u00edas:",
     "Avatar": "Avatar",
@@ -136,7 +131,6 @@
     "By time descending": "Por fecha descendente",
     "Can not copy directory %(src)s to its subdirectory %(des)s": "No se pudo copiar la carpeta %(src)s a la subcarpeta %(des)s",
     "Can not move directory %(src)s to its subdirectory %(des)s": "No se pudo mover la carpeta %(src)s a la subcarpeta %(des)s",
-    "Can not select self as a related file.": "No se puede seleccionar el mismo archivo como relacionado.",
     "Cancel": "Cancelar",
     "Cancel All": "Cancelar Todo",
     "Change": "Cambiar",
@@ -152,10 +146,7 @@
     "Clear files in trash and history\uff1a": "Limpiar archivos en la papelera y en el historial :",
     "Clients": "Clientes",
     "Close": "Cerrar",
-    "Close (Esc)": "Cerrar (Esc)",
     "Column": "Columna",
-    "Comment": "Comentar",
-    "Comments": "Comentarios",
     "Community Edition": "Versi\u00f3n Community",
     "Confirm": "Confirmar",
     "Confirm Password": "Confirmar contrase\u00f1a",
@@ -165,13 +156,13 @@
     "Contact Information": "Informaci\u00f3n de contacto",
     "Contact information is required.": "Se requiere informaci\u00f3n de contacto.",
     "Content Scan Records": "Registros de An\u00e1lisis de Contenido",
-    "Contents": "Contenido",
     "Copy": "Copiar",
     "Copy selected item(s) to:": "Copiar item(s) seleccionados a:",
     "Copy {num} items": "Copiar {num} items",
     "Copy {placeholder} to": "Copiar {placeholder} a",
     "Copyright Infringement": "Violaci\u00f3n de derechos de autor",
     "Count": "Cuenta",
+    "Create": "Crear",
     "Create Group": "Crear Grupo",
     "Create Library": "Crear Biblioteca",
     "Create Report": "Crear Informe",
@@ -201,7 +192,6 @@
     "Date Invalid.": "Fecha inv\u00e1lida.",
     "Default": "Predeterminado",
     "Default Admin": "Administrador predeterminado",
-    "Default Size": "Tama\u00f1o predeterminado",
     "Delete": "Borrar",
     "Delete Account": "Eliminar Cuenta",
     "Delete Department": "Eliminar Departamento",
@@ -234,8 +224,8 @@
     "Deleted user {user}": "Usuario {user} eliminado",
     "Departments": "Departmentos",
     "Description": "Descripci\u00f3n",
+    "Description is required": "Descripci\u00f3n requerida",
     "Desktop": "Escritorio",
-    "Detail": "Detalles",
     "Details": "Detalles",
     "Device": "Dispositivo",
     "Device Name": "Nombre de dispositivo",
@@ -257,15 +247,11 @@
     "Download an example file": "Descargar un archivo de ejemplo",
     "Download and upload": "Descargar y subir",
     "Draft": "Borrador",
-    "Draft has been deleted.": "El borrador ha sido eliminado.",
     "Draft is a way to let you collaborate with others on files. You can create a draft from a file, edit the draft and then ask for a review. The original file will be updated only after the draft has been reviewed.": "Un borrador es una manera de colaborar con otros en archivos. Puedes crear un borrador a partir de un archivo, editarlo y luego solicitar su revisi\u00f3n. El archivo original  ser\u00e1 actualizado s\u00f3lo despu\u00e9s que el borrador haya sido revisado.",
     "Drafts": "Borradores",
     "Drag and drop files or folders here.": "Arrastrar y soltar archivos aqu\u00ed.",
     "Edit": "Editar",
-    "Edit Draft": "Editar Borrador",
     "Edit File": "Editar Archivo",
-    "Edit Tag": "Editar Etiqueta",
-    "Edit failed.": "Fallo al editar.",
     "Edit labels": "Editar etiquetas",
     "Edit on cloud and download": "Editar en la nube y descargar",
     "Edit on cloud only": "Editar s\u00f3lo en la nube",
@@ -306,7 +292,6 @@
     "Failed to delete %(virus_file) from library %(library): %(error_msg)": "Fallo al eliminar %(virus_file) de la biblioteca %(library): %(error_msg)",
     "Failed to delete draft %(draft)s.": "Fallo al eliminar %(draft)s.",
     "Failed to delete {name}": "Fallo al eliminar {name}",
-    "Failed to delete {name} and other {n} items.": "Fallo al eliminar {name} y otros {n} items.",
     "Failed to delete {name}.": "Fallo al eliminar {name}.",
     "Failed to ignore %(virus_file) from library %(library): %(error_msg)": "Fallo al ignorar %(virus_file) de la biblioteca %(library): %(error_msg)",
     "Failed to move %(name)s and %(amount)s other item(s).": "Fallo al mover %(name)s y %(amount)s otros item(s).",
@@ -316,6 +301,7 @@
     "Failed to publish draft %(draft)s.": "Fallo al publicar el borrador %(draft)s.",
     "Failed to send to {email_placeholder}: {errorMsg_placeholder}": "Failo al enviar a {email_placeholder}: {errorMsg_placeholder}",
     "Failed to unshare {name}": "Fallo al dejar de compartir {name}",
+    "Failed to upload {file_name}.": "Fallo al subir {file_name}.",
     "Failed. Please check the network.": "Fallo. Por favor, verifica la red.",
     "Favorites": "Favoritos",
     "File": "Archivo",
@@ -333,7 +319,7 @@
     "File is locked by others.": "El archivo est\u00e1 bloqueado por otros.",
     "File size is too large.": "El tama\u00f1o de archivo es demasiado grande.",
     "File size should be smaller than {max_size_placeholder}.": "El tama\u00f1o debe ser menor que {max_size_placeholder}.",
-    "File {file_link} has a new comment form user {author}.": "El archivo {file_link} tiene un nuevo comentario del usuario {author}.",
+    "File upload started": "Subida de archivo iniciada",
     "Files": "Archivos",
     "Folder": "Carpeta",
     "Folder Permission": "Permiso de Carpeta",
@@ -342,6 +328,7 @@
     "Folders": "Carpetas",
     "Force user to change password when account is newly added or reset by admin": "Forzar a que el usuario cambie la contrase\u00f1a cuando se crea la cuenta o reestablecida por un administrador",
     "Force user to use a strong password when sign up or change password.": "Forzar a que el usuario utilice una contrase\u00f1a segura al registrarse o al cambiar la contrase\u00f1a.",
+    "Force user use password when generating share/upload link.": "Forzar al usuario a utilizar una contrase\u00f1a al generar un recurso compartido/enlace de subida",
     "Freeze user account when failed login attempts exceed limit.": "Inmovilizar la cuenta del usuario cuando el n\u00famero de intentos de acceso fallidos exceda el l\u00edmite.",
     "Generate": "Generar",
     "Global Address Book": "Libreta de direcciones global",
@@ -355,12 +342,12 @@
     "Guest": "Invitado",
     "Handled": "Manejado",
     "Help": "Ayuda",
+    "Hide": "Ocultar",
     "History": "Historial",
     "History Setting": "Configuraci\u00f3n de historial",
     "History Versions": "Historial de Versiones",
     "IP": "IP",
     "If notifications have not been read within one hour, they will be sent to your mailbox.": "Si las notificaciones no han sido le\u00eddas en el plazo de una hora, ser\u00e1n enviadas a su casilla de correo.",
-    "If the share link is deleted, no one will be able to access it any more.": "Si el enlace de compartir es eliminado, nadie podr\u00e1 accederlo.",
     "If turn on, the desktop clients will not be able to sync a folder outside the default Seafile folder.": "Si est\u00e1 activado el cliente de escritorio no podr\u00e1 sincronizar una carpeta fuera de la carpeta Seafile preestablecida.",
     "If you don't have any device with you, you can access your account using backup codes.": "Si no posse ning\u00fan dispositivo consigo, puede acceder a su cuenta utilizando c\u00f3digos de respaldo.",
     "Ignore": "Ignorar",
@@ -370,6 +357,7 @@
     "Import Members": "Importar Miembros",
     "Import Users": "Importar Usuarios",
     "Import members from a .xlsx file": "Importar miembros desde un archivo .xlsx",
+    "Import users": "Importar usuarios",
     "Import users from a .xlsx file": "importar usuarios desde un archivo .xlsx",
     "In all libraries": "En todas las bibliotecas",
     "Inactive": "Inactivo",
@@ -389,7 +377,6 @@
     "Invitations": "Invitaciones",
     "Invite Guest": "Convocar Invitado",
     "Invite Time": "Fecha de Invitaci\u00f3n",
-    "Invite user": "Invitar usuario",
     "Invited at": "Invita en",
     "Inviter": "Invita",
     "It is required.": "Es requerido.",
@@ -412,7 +399,6 @@
     "Less than or equal to {maxDays_placeholder} days": "Menor o igual que {maxDays_placeholder} d\u00edas",
     "Libraries": "Bibliotecas",
     "Library": "Biblioteca",
-    "Library Name": "Nombre de Biblioteca",
     "Library Type": "Tipo de Biblioteca",
     "Library can not be shared to owner.": "La biblioteca no puede ser compartida con su propietario.",
     "Limits": "L\u00edmites",
@@ -424,6 +410,7 @@
     "List": "Lista",
     "List your account in global address book, so that others can find you by typing your name.": "Incluya su cuenta en la libreta de direcciones global, de manera que otros puedan encontrarlo tipeando su nombre.",
     "Local draft": "Borrador local",
+    "Local draft saved": "Borrador local guardado",
     "Location": "Ubicaci\u00f3n",
     "Lock": "Bloquear",
     "Log out": "Desconectarse",
@@ -433,7 +420,6 @@
     "Manage Members": "Administrar Miembros",
     "Manage group members": "Administrar miembros del grupo",
     "Mark all read": "Marcar todo le\u00eddo",
-    "Mark as resolved": "Marcar como resuelto",
     "Member": "Miembro",
     "Members": "Miembros",
     "Message": "Mensaje",
@@ -487,10 +473,9 @@
     "New password is too short": "La nueva contrase\u00f1a es demasiado corta",
     "New passwords don't match": "Las contrase\u00f1as no coinciden",
     "Next": "Siguiente",
-    "Next (Right arrow key)": "Siguiente (Flecha derecha)",
+    "No": "No",
     "No Admin login logs": "No hay registros de ingreso de Admin",
     "No Admin operation logs": "No hay registros de operaciones de Admin",
-    "No comment yet.": "No hay comentarios.",
     "No connected devices": "No hay dispositivos conectados",
     "No deleted libraries": "No hay bibliotecas eliminadas",
     "No departments": "No hay departamentos",
@@ -520,7 +505,6 @@
     "No published libraries": "No hay bibliotecas publicadas",
     "No result": "No hay resultados",
     "No results matching.": "No hay resultados que coincidan.",
-    "No reviewer yet.": "Todav\u00eda no hay revisor.",
     "No share links": "No hay enlaces de compartir",
     "No shared libraries": "No hay bibliotecas compartidas",
     "No sub-departments": "No hay sub-departamentos",
@@ -529,11 +513,11 @@
     "No upload links": "No hay enlaces de subida",
     "None": "Ninguna",
     "Note: Settings via web interface are saved in database table (seahub-db/constance_config). They have a higher priority over the settings in config files.": "Nota: las configuraciones via la interfaz web se guardan en una tabla de la base de datos (seahub-db/constance_config). Tienen prioridad sobre las configuraciones en los archivos.",
+    "Notification": "Notificaci\u00f3n",
     "Notification Detail": "Detalles de notificaciones",
     "Notifications": "Notificaciones",
     "Notifications of collaboration": "Notificaciones de colaboraci\u00f3n",
     "Notifications of file changes": "Notificaciones de modificaciones en archivos",
-    "Number of changes:": "N\u00famero de cambios:",
     "Number of days that keep user sign in.": "N\u00famero de d\u00edas que el usuario permanece identificado",
     "Number of groups": "N\u00famero de grupos",
     "Off": "No",
@@ -549,7 +533,6 @@
     "Online view is not applicable to this file format": "La visualizaci\u00f3n en l\u00ednea no se aplica a este tipo de archivo",
     "Only Show": "S\u00f3lo Mostrar",
     "Only keep a period of history:": "S\u00f3lo mantener el historial por:",
-    "Open in New Tab": "Abrir en una nueva pesta\u00f1a",
     "Open parent directory": "Abrir carpeta contenedora",
     "Open parent folder": "Abrir carpeta contenedora",
     "Open via Client": "Abrir via el Cliente",
@@ -559,7 +542,6 @@
     "Organization": "Organizaci\u00f3n",
     "Organization Admin": "Administrador de la Organizaci\u00f3n",
     "Organizations": "Organizaciones",
-    "Original file has been deleted.": "El archivo original ha sido eliminado.",
     "Other": "Otro",
     "Other Libraries": "Otras bibliotecas",
     "Out of quota.": "Cuota agotada.",
@@ -567,7 +549,6 @@
     "Owner": "Propietario",
     "Owner can use admin panel in an organization, must be a new account.": "El propietario puede utilizar el panel de admin en una organizaci\u00f3n, debe ser una cuenta nueva.",
     "Packaging...": "Empaquetando...",
-    "Participants": "Participantes",
     "Password": "Contrase\u00f1a ",
     "Password again": "Repetir contrase\u00f1a",
     "Password is too short": "Contrase\u00f1a demasiado corta",
@@ -604,16 +585,12 @@
     "Preview and download": "Vista previa y descargar",
     "Preview only": "Vista previa solamente",
     "Previous": "Anterior",
-    "Previous (Left arrow key)": "Anterior (Flecha izquierda)",
-    "Private": "Privado",
     "Professional Edition": "Versi\u00f3n Profesional",
     "Profile": "Perfil",
     "Profile Setting": "Configuraci\u00f3n del perfil",
-    "Public": "P\u00fablico",
     "Publish": "Publicar",
     "Publish a Library": "Publicar una biblioteca",
     "Publish draft": "Publicar borrador",
-    "Published": "Publicado",
     "Published Libraries": "Bibliotecas publicadas",
     "Quota": "Cuota",
     "Quota is invalid.": "La cuota es inv\u00e1lida.",
@@ -627,7 +604,6 @@
     "Really want to delete your account?": "\u00bfSeguro que deseas eliminar tu cuenta?",
     "Really want to leave this group?": "\u00bfSeguro que deseas abandorar este grupo?",
     "Refresh": "Refrescar",
-    "Related Files": "Archivos Relacionados",
     "Remaining": "Restante",
     "Remove": "Remover",
     "Remove Member": "Eliminar Miembro",
@@ -665,8 +641,6 @@
     "Result": "Resultado",
     "Retry": "Reintentar",
     "Retry All": "Reintentar Todo",
-    "Review": "Revisar",
-    "Reviewers": "Revisores",
     "Revoke": "Revocar",
     "Revoke Access": "Revocar Acceso",
     "Revoke Admin": "Revocar Privilegios",
@@ -678,35 +652,28 @@
     "Scan the QR code to view the shared content directly": "Escanear el c\u00f3digo QR para ver el contenido compartido directamente",
     "Seafile": "Seafile",
     "Search": "Buscar",
-    "Search Files": "Buscar Archivos",
     "Search Groups": "Buscar Grupos",
     "Search Libraries": "Buscar Bibliotecas",
     "Search Organizations": "Buscar Organizaciones",
     "Search Users": "Buscar Usuarios",
     "Search files in this library": "Buscar archivos en esta biblioteca",
+    "Search group members": "Buscar miembros del grupo",
+    "Search groups": "Buscar grupos",
     "Search groups by name": "Buscar grupos por nombre",
-    "Search libraries by name": "Buscar bibliotecas por nombre",
     "Search libraries by owner": "Buscar bibliotecas por propietario",
     "Search organizations": "Buscar organizaciones",
     "Search users": "Buscar usuarios",
-    "Search users...": "Buscar usuarios...",
-    "Search...": "Buscar...",
-    "See All Notifications": "Ver Todas las Notificaciones",
     "Select File": "Seleccionar Archivo",
     "Select Image": "Seleccionar Imagen",
     "Select Tags": "Seleccionar etiquetas",
     "Select a color": "Seleccionar un color",
     "Select a department": "Seleccionar un departamento",
     "Select a group": "Seleccione un grupo",
-    "Select a server...": "Seleccione un servidor...",
     "Select a user": "Seleccionar un usuario",
-    "Select a user as admin...": "Selccione un usuario como administrador...",
-    "Select groups...": "Seleccionar grupos...",
+    "Select groups": "Seleccionar grupos",
     "Select libraries to share": "Seleccionar bibliotecas para compartir",
-    "Select related file for {placeholder}": "Seleccionar archivo relacionado para {placeholder}",
     "Send": "Enviar",
     "Send activation Email after user registration.": "Enviar email de activaci\u00f3n despu\u00e9s del registro del usuario.",
-    "Send the invitation link to the others, and they will be able to join the organization via scanning the QR code.": "Env\u00eda el enlace de invitaci\u00f3n a los otros, y ellos podr\u00e1n unirse a la organizaci\u00f3n escanendo el c\u00f3digo QR.",
     "Send to:": "Enviar a:",
     "Sending new password...": "Enviando la nueva contrase\u00f1a...",
     "Sending...": "Enviando\u2026",
@@ -734,7 +701,6 @@
     "Share Link": "Compartir enlace",
     "Share Link Traffic": "Tr\u00e1fico de enlaces compartidos",
     "Share Links": "Enlaces Compartidos",
-    "Share Links Admin": "Admin de Enlaces de Compartir",
     "Share To": "Compartir con",
     "Share To:": "Compartir con:",
     "Share existing libraries": "Compartir bibliotecas existentes",
@@ -753,8 +719,8 @@
     "Shared with all": "Compartido con todos",
     "Shared with groups": "Compartido con grupos",
     "Shared with me": "Compartido conmigo",
+    "Show": "Mostrar",
     "Show Codes": "Mostrar C\u00f3digos",
-    "Show resolved comments": "Mostrar comentarios resueltos",
     "Side Nav Menu": "Men\u00fa Lateral de Navegaci\u00f3n",
     "Site name used in email sending": "Nombre del sitio utilizado en el env\u00edo de email",
     "Site title shown in a browser tab": "T\u00edtulo del sitio mostrado en una pesta\u00f1a del navegador",
@@ -764,7 +730,6 @@
     "Space Used / Quota": "Espacio utilizado / Cuota",
     "Star": "Marcar",
     "Start date": "Fecha Inicio",
-    "Start review": "Iniciar revisi\u00f3n",
     "Statistic": "Estad\u00edstica",
     "Status": "Estado",
     "Status: enabled": "Status: habilitado",
@@ -783,12 +748,11 @@
     "Successfully copied %(name)s and 1 other item.": "%(name)s y 1 otro \u00edtem copiados con \u00e9xito.",
     "Successfully copied %(name)s.": "%(name)s copiados con \u00e9xito.",
     "Successfully copied files to another library.": "Archivos copiados con \u00e9xito a otra biblioteca.",
-    "Successfully deleted %s": "Borrado con \u00e9xito %s",
+    "Successfully deleted 1 item": "1 \u00edtem eliminado con \u00e9xito",
     "Successfully deleted 1 item.": "1 \u00edtem eliminado con \u00e9xito",
     "Successfully deleted 1 user.": "1 usuario eliminado con \u00e9xito.",
     "Successfully deleted draft %(draft)s.": "Borrador %(draft)seliminado con \u00e9xito.",
     "Successfully deleted {name}": "Eliminado con \u00e9xito {name}",
-    "Successfully deleted {name} and other {n} items.": "{name} y otros {n} items eliminados con \u00e9xito.",
     "Successfully deleted {name}.": "{name} eliminado con \u00e9xito.",
     "Successfully deleted {user_number_placeholder} users.": "{user_number_placeholder} usuarios eliminados con \u00e9xito.",
     "Successfully edited labels.": "Etiquetas editadas con \u00e9xito",
@@ -814,9 +778,6 @@
     "Successfully set %s as admin.": "%s asignado como administrador.",
     "Successfully set it.": "Establecido con \u00e9xito",
     "Successfully set library history.": "Historial de biblioteca establecido con \u00e9xito.",
-    "Successfully set max number of members.": "M\u00e1ximo n\u00famero de miembros establecido con \u00e9xito.",
-    "Successfully set name.": "Nombre establecido con  \u00e9xito.",
-    "Successfully set quota.": "Cuota establecida con  \u00e9xito.",
     "Successfully starred {library_name_placeholder}.": "Marcado con \u00e9xito {library_name_placeholder}.",
     "Successfully transferred the group.": "Grupo transferido con \u00e9xito.",
     "Successfully transferred the library.": "Biblioteca transferida con \u00e9xito.",
@@ -846,11 +807,11 @@
     "Text is required.": "Se requiere texto.",
     "The URL of the server, like https://seafile.example.com or http://192.168.1.2:8000": "El URL del servidor, como https://seafile.example.com o http://192.168.1.2:8000",
     "The file is too large. Allowed maximum size is 1MB.": "El archivo es demasiado grande. El tama\u00f1o m\u00e1ximo admitido es 1MB.",
-    "The image could not be loaded.": "La imagen no pudo ser cargada.",
     "The internal URL for downloading/uploading files. Users will not be able to download/upload files if this is not set correctly. If you config Seafile behind Nginx/Apache, it should be SERVICE_URL/seafhttp, like https://seafile.example.com/seafhttp .": "El URL interno para descargar/subir archivos. Los usuarios no podr\u00e1n descargar/subir archivos si \u00e9sto no es correcto. Si configuras Seafile utilizando Nginx/Apache, deber\u00eda ser SERVICE_URL/seafhttp, como https://seafile.example.com/seafhttp .",
-    "The least number of characters a download/upload link password should include.": "El m\u00ednimo n\u00famero de caracteres que deber\u00eda contener la contrase\u00f1a de un enlace de descarga/subida.",
+    "The least number of characters a share/upload link password should include.": "El m\u00ednimo n\u00famero de caracteres que deber\u00eda incluir una contrase\u00f1a de compartir/enlace de subida.",
     "The least number of characters an account password should include.": "El m\u00ednimo n\u00famero de caracteres que deber\u00eda contener la contrase\u00f1a de una cuenta.",
     "The least number of characters an encrypted library password should include.": "El m\u00ednimo n\u00famero de caracteres que deber\u00eda contener la contrase\u00f1a de una biblioteca encriptada.",
+    "The level(1-4) of a share/upload link password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols": "El nivel (1-4) de seguridad de una contrase\u00f1a de compartir/enlace de subida. Por ejemplo, '3' significa que la contrase\u00f1a debe contener al menos 3 de los siguientes: n\u00fameros, may\u00fasculas, min\u00fasculas y otros s\u00edmbolos",
     "The level(1-4) of an account password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols": "El nivel (1-4) de seguridad de la contrase\u00f1a de una cuenta. Por ejemplo, '3' significa que la contrase\u00f1a debe tener por lo menos 3 de los siguientes: n\u00fameros, letras may\u00fasculas, letras min\u00fasculas y otros s\u00edmbolos",
     "The link is copied to the clipboard.": "Enlace copiado al portapapeles.",
     "The list of added, deleted and modified files will be sent to your mailbox.": "La lista de archivos agregados, eliminados y modificados ser\u00e1 enviada a su casilla de correo.",
@@ -861,7 +822,6 @@
     "This file has been updated.": "Este archivo ha sido actualizado.",
     "This file is in draft stage.": "Este archivo est\u00e1 en la etapa de borrador",
     "This folder has no content at this time.": "Esta carpeta no tiene contenido en este momento.",
-    "This is a draft": "Este es un borrador",
     "This is a special group representing a department.": "Este es un grupo especial que representa a un departamento.",
     "This library has been set to read-only by admin and cannot be updated.": "Esta biblioteca ha sido configurada como de s\u00f3lo lectura, y no puede ser actualizada.",
     "This library is password protected": "Esta biblioteca est\u00e1 protegida por contrase\u00f1a",
@@ -874,6 +834,7 @@
     "Tip: libraries deleted {trashReposExpireDays} days ago will be cleaned automatically.": "Consejo: bibliotecas eliminadas hace {trashReposExpireDays} d\u00edas ser\u00e1n removidas autom\u00e1ticamente.",
     "Tip: you can search by keyword in name.": "Consejo: puede buscar por palabra clave en el nombre.",
     "Token": "Identificador",
+    "Token:": "Identificador:",
     "Tools": "Herramientas",
     "Total Devices": "Total de Dispositivos",
     "Total Storage": "Almacenamiento Total",
@@ -901,7 +862,6 @@
     "Unlock": "Desbloquear",
     "Unpublish": "Dejar de publicar",
     "Unpublish Library": "Dejar de publicar Biblioteca",
-    "Unresolved comments:": "Comentarios sin resolver\u00d1",
     "Unshare": "Dejar de compartir",
     "Unshare Library": "Dejar de compartir Biblioteca",
     "Unstar": "Desmarcar",
@@ -937,6 +897,7 @@
     "User {user_link} has added you to {group_link}": "El usuario {user_link} te ha agregado a {group_link}",
     "Username:": "Nombre de usuario:",
     "Users": "Usuarios",
+    "Verify": "Verificar",
     "Version": "Versi\u00f3n",
     "Version Number": "N\u00famero de Versi\u00f3n",
     "Version Number is required.": "Se requiere N\u00famero de Versi\u00f3n.",
@@ -946,7 +907,7 @@
     "View Draft": "Ver Borrador",
     "View Link": "Ver Enlace",
     "View Snapshot": "Ver inst\u00e1ntanea",
-    "View diff": "Ver diferencias",
+    "View profile and more": "Ver perfil y m\u00e1s",
     "Virus": "Virus",
     "Virus File": "Archivo de Virus",
     "Virus Scan": "An\u00e1lisis de Virus",
@@ -960,6 +921,7 @@
     "Welcome to {site_name_placeholder}": "Bienvenido a {site_name_placeholder}",
     "Whether the notifications of collaboration such as sharing library or joining group should be sent to your mailbox.": "Si las notificaciones de colaboraci\u00f3n como compartir bibliotecas o unirse a un grupo deben ser enviadas a su casilla de correo.",
     "Wrong password": "Contrase\u00f1a incorrecta",
+    "Yes": "S\u00ed",
     "You are not in any groups. Groups allow multiple people to collaborate on libraries. Groups you join will be listed here.": "No est\u00e1s en ning\u00fan grupo. Los grupos permiten que varias personas colaboren en bibliotecas. Los grupos a los que te unas estar\u00e1n listados aqu\u00ed.",
     "You are not in any groups. Groups allow multiple people to collaborate on libraries. You can create a group by clicking the \"New Group\" button in the menu bar.": "No est\u00e1s en ning\u00fan grupo. Los grupos permiten que varias personas colaboren en bibliotecas. Puedes crear un grupo haciendo click en l bot\u00f3n \"Nuevo Grupo\" en la barra del men\u00fa.",
     "You can also add a user as a guest, who will not be allowed to create libraries and groups.": "Tambi\u00e9n puedes agregar un usuario como invitado, que no podr\u00e1 crear bibliotecas ni grupos.",
@@ -984,11 +946,8 @@
     "You have only one backup code remaining.": "Le queda solamente un c\u00f3digo de resguardo.",
     "You have {num} backup codes remaining.": "Le quedan  {num} c\u00f3digos de resguardo.",
     "Your notifications will be sent to this email.": "Las notificaciones ser\u00e1n enviadas a esta direcci\u00f3n.",
+    "ZIP": "ZIP",
     "ZIP Selected Items": "ZIP elementos seleccionados",
-    "Zoom In": "Acercar",
-    "Zoom Out": "Alejar",
-    "Zoom in": "Acercar",
-    "Zoom out": "Alejar",
     "activate after registration": "activar despu\u00e9s del registro",
     "all": "todos",
     "all members": "todos los miembros",
@@ -996,11 +955,7 @@
     "days": "d\u00edas",
     "deleted": "eliminado",
     "details": "detalles",
-    "download/upload link password minimum length": "m\u00edmima longitud de contrase\u00f1a de un enlace de descarga/subida",
-    "draft": "borrador",
     "email is required": "direcci\u00f3n de correo requerida",
-    "file": "archivo",
-    "files": "archivos",
     "icon": "icono",
     "keep sign in": "permanecer identificado",
     "library password minimum length": "m\u00edmima longitud de contrase\u00f1a de biblioteca",
@@ -1013,10 +968,12 @@
     "password minimum length": "m\u00edmima longitud de contrase\u00f1a",
     "password strength level": "nivel de seguridad de la contrase\u00f1a",
     "progress": "progreso",
-    "related files": "archivos relacionados",
     "result": "resultado",
     "results": "resultados",
     "send activation email": "enviar email de activaci\u00f3n",
+    "share/upload link force password": "forzar contrase\u00f1a en compartir/enlace de subida",
+    "share/upload link password minimum length": "longitud m\u00ednima de la contrase\u00f1a de compartir/enlace de subida",
+    "share/upload link password strength level": "nivel de seguridad de la contrase\u00f1a de compartir/enlace de subida",
     "shared by:": "compartido por:",
     "show more": "ver m\u00e1s",
     "size": "tama\u00f1o",
@@ -1035,7 +992,6 @@
     "{placeholder} API Token": "{placeholder} API Token",
     "{placeholder} Folder Permission": "{placeholder} Permiso de Carpeta",
     "{placeholder} Modification History": "Historial de Cambios de {placeholder}",
-    "{placeholder} Share/Upload Links": "{placeholder} Enlaces de Compartir/Subir",
     "{placeholder} Snapshot": "{placeholder} Instant\u00e1nea",
     "{placeholder} Trash": "{placeholder} Papelera",
     "{share_from} has shared a folder named {repo_link} to group {group_link}.": "{share_from} ha compartido una carpeta llamada {repo_link} al grupo {group_link}.",
@@ -1047,24 +1003,24 @@
     "{userCount} user(s) and {repoCount} libraries of this organization will also be deleted.": "{userCount} usuario(s) y {repoCount} bibliotecas de esta organizaci\u00f3n tambi\u00e9n ser\u00e1n eliminados.",
     "{user} has transfered a library named {repo_link} to you.": "{user} te ha transferido una biblioteca llamada {repo_link}."
   };
-  for (var key in newcatalog) {
+  for (const key in newcatalog) {
     django.catalog[key] = newcatalog[key];
   }
   
 
   if (!django.jsi18n_initialized) {
     django.gettext = function(msgid) {
-      var value = django.catalog[msgid];
-      if (typeof(value) == 'undefined') {
+      const value = django.catalog[msgid];
+      if (typeof value === 'undefined') {
         return msgid;
       } else {
-        return (typeof(value) == 'string') ? value : value[0];
+        return (typeof value === 'string') ? value : value[0];
       }
     };
 
     django.ngettext = function(singular, plural, count) {
-      var value = django.catalog[singular];
-      if (typeof(value) == 'undefined') {
+      const value = django.catalog[singular];
+      if (typeof value === 'undefined') {
         return (count == 1) ? singular : plural;
       } else {
         return value.constructor === Array ? value[django.pluralidx(count)] : value;
@@ -1074,16 +1030,16 @@
     django.gettext_noop = function(msgid) { return msgid; };
 
     django.pgettext = function(context, msgid) {
-      var value = django.gettext(context + '\x04' + msgid);
-      if (value.indexOf('\x04') != -1) {
+      let value = django.gettext(context + '\x04' + msgid);
+      if (value.includes('\x04')) {
         value = msgid;
       }
       return value;
     };
 
     django.npgettext = function(context, singular, plural, count) {
-      var value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
-      if (value.indexOf('\x04') != -1) {
+      let value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
+      if (value.includes('\x04')) {
         value = django.ngettext(singular, plural, count);
       }
       return value;
@@ -1137,8 +1093,8 @@
   };
 
     django.get_format = function(format_type) {
-      var value = django.formats[format_type];
-      if (typeof(value) == 'undefined') {
+      const value = django.formats[format_type];
+      if (typeof value === 'undefined') {
         return format_type;
       } else {
         return value;
@@ -1157,6 +1113,5 @@
 
     django.jsi18n_initialized = true;
   }
-
-}(this));
+};
 
