@@ -1,13 +1,14 @@
 
 
-(function(globals) {
-
-  var django = globals.django || (globals.django = {});
+'use strict';
+{
+  const globals = this;
+  const django = globals.django || (globals.django = {});
 
   
   django.pluralidx = function(n) {
-    var v=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);
-    if (typeof(v) == 'boolean') {
+    const v = (n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);
+    if (typeof v === 'boolean') {
       return v ? 1 : 0;
     } else {
       return v;
@@ -19,8 +20,7 @@
 
   django.catalog = django.catalog || {};
   
-  var newcatalog = {
-    "%curr% of %total%": "%curr% no %total%",
+  const newcatalog = {
     "(current notification)": "(pa\u0161reiz\u0113jais pazi\u0146ojums)",
     "(current version)": "(pa\u0161reiz\u0113j\u0101 versija)",
     "1 Year": "1 gads",
@@ -82,9 +82,6 @@
     "Clear files in trash and history\uff1a": "T\u012br\u012bt datnes atkritn\u0113 un v\u0113stur\u0113: ",
     "Clients": "Klienti",
     "Close": "Aizv\u0113rt",
-    "Close (Esc)": "Aizv\u0113rt (Esc)",
-    "Comment": "Koment\u0101rs",
-    "Comments": "Koment\u0101ri",
     "Community Edition": "Community Edition",
     "Confirm Password": "Apstiprin\u0101t paroli",
     "Contact Email": "Kontaktpersonas e-pasts:",
@@ -92,6 +89,7 @@
     "Copy": "Kop\u0113t",
     "Copy selected item(s) to:": "Kop\u0113t atlas\u012bto(s) ierakstu(s) uz:",
     "Count": "Skait\u012bt",
+    "Create": "Izveidot",
     "Created": "Izveidoja",
     "Created At": "Izveidoja",
     "Created library": "Kr\u0101tuve izveidota",
@@ -123,8 +121,8 @@
     "Deleted files": "Dz\u0113st datnes",
     "Deleted library": "Dz\u0113st\u0101s bibliot\u0113kas",
     "Description": "Apraksts",
+    "Description is required": "Nepiecie\u0161ams apraksts",
     "Desktop": "Darbvirsma",
-    "Detail": "Deta\u013cas",
     "Details": "Deta\u013cas",
     "Device": "Ier\u012bce",
     "Device Name": "Ier\u012bces nosaukums",
@@ -137,7 +135,6 @@
     "Don't replace": "Neaizst\u0101t",
     "Download": "Lejupl\u0101d\u0113t",
     "Edit": "Main\u012bt",
-    "Edit failed.": "Redi\u0123\u0113\u0161ana neizdev\u0101s.",
     "Edit succeeded": "Redi\u0123\u0113\u0161ana izdev\u0101s",
     "Email": "E-pasts",
     "Enable Two-Factor Authentication": "Aktiviz\u0113t divfaktoru autentifik\u0101cija",
@@ -168,12 +165,14 @@
     "Guest": "Viesis",
     "Handled": "Apstr\u0101d\u0101ts",
     "Help": "Pal\u012bdz\u012bba",
+    "Hide": "Sl\u0113pt",
     "History": "V\u0113sture",
     "History Setting": "V\u0113stures iestat\u012bjumi",
     "IP": "IP adrese",
     "Image": "Att\u0113ls",
     "Images": "Att\u0113ls",
     "Import Members": "Import\u0113t dal\u012bbniekus",
+    "Import users": "Import\u0113t lietot\u0101jus",
     "In all libraries": "vis\u0101s bibliot\u0113k\u0101s",
     "Inactive": "Neakt\u012bvs",
     "Info": " Inform\u0101cija",
@@ -240,8 +239,7 @@
     "New password is too short": "Jaun\u0101 parole par \u012bsu",
     "New passwords don't match": "Jaun\u0101 parole nesakr\u012bt",
     "Next": "N\u0101kamais",
-    "Next (Right arrow key)": "N\u0101kamais (bulti\u0146a pa labi)",
-    "No comment yet.": "Nav koment\u0101ru.",
+    "No": "N\u0113",
     "No connected devices": "Nav savienotas ier\u012bces",
     "No groups": "Nav grupas",
     "No libraries": "Bibliot\u0113kas nav",
@@ -256,7 +254,6 @@
     "Old Password": "Vec\u0101 parole",
     "On": "Iesl\u0113gt",
     "Only keep a period of history:": "Glab\u0101t v\u0113sturi par periodu:",
-    "Open in New Tab": "Atv\u0113rt jaun\u0101 ciln\u0113",
     "Open via Client": "Atv\u0113rt ar klientu",
     "Operation": "Darb\u012bbas",
     "Operation succeeded.": "Darb\u012bba veiksm\u012bga",
@@ -265,6 +262,7 @@
     "Organization Admin": "Organiz\u0101cijas administrators",
     "Organizations": "Organiz\u0101cijas",
     "Other Libraries": "Cita bibliot\u0113ka",
+    "Out of quota.": "P\u0101rsniegts apjoms",
     "Owner": "\u012apa\u0161nieks",
     "Packaging...": "Pakoju...",
     "Password": "Parole",
@@ -286,7 +284,6 @@
     "Please enter the password again": "L\u016bdzu ievad\u012bt paroli v\u0113lreiz",
     "Please input at least an email.": "L\u016bdzu, ievadiet vismaz e-pastu.",
     "Previous": "Iepriek\u0161\u0113jais",
-    "Previous (Left arrow key)": "Iepriek\u0161\u0113jais (bulti\u0146a pa kreisi)",
     "Professional Edition": "Profesion\u0101lais izdevums",
     "Profile": "Profils",
     "Profile Setting": "Profila iestat\u012bjumi",
@@ -312,11 +309,10 @@
     "Role": "Loma",
     "Saving...": "Saglab\u0101...",
     "Seafile": "Seafile",
-    "Search Files": "Mekl\u0113t datnes",
     "Search files in this library": "Mekl\u0113t datnes bibliot\u0113k\u0101",
-    "Search users...": "Mekl\u0113t lietot\u0101jus...",
-    "See All Notifications": "Skat\u012bt visus pazi\u0146ojumus",
+    "Search groups": "Mekl\u0113t grupas",
     "Select a group": "Atlas\u012bt grupu",
+    "Select groups": "Atlas\u012bt grupas",
     "Select libraries to share": "Atlas\u012bt koplieto\u0161anas bibliot\u0113kas ",
     "Send": "S\u016bt\u012bt",
     "Send to:": "S\u016bt\u012bt uz:",
@@ -340,6 +336,7 @@
     "Shared with all": "Koplietot visiem",
     "Shared with groups": "Koplietot grupai",
     "Shared with me": "Man koplietot\u0101s ",
+    "Show": "R\u0101d\u012bt",
     "Show Codes": "R\u0101d\u012bt kodu",
     "Size": "Izm\u0113rs ",
     "Space Used": "Izlietots",
@@ -354,7 +351,7 @@
     "Successfully copied %(name)s and %(amount)s other items.": "Veiksm\u012bgi kop\u0113ts %(name)s un %(amount)s citi ieraksti.",
     "Successfully copied %(name)s and 1 other item.": "Veiksm\u012bgi kop\u0113ts %(name)s un 1 cits ieraksts.",
     "Successfully copied %(name)s.": "Veiksm\u012bgi kop\u0113ts %(name)s.",
-    "Successfully deleted %s": "Veiksm\u012bgi dz\u0113sts %s",
+    "Successfully deleted 1 item": "Veiksm\u012bgi izdz\u0113sts 1 objekts",
     "Successfully deleted 1 item.": "Veiksm\u012bgi izdz\u0113sts 1 objekts",
     "Successfully moved %(name)s and %(amount)s other items.": "Veiksm\u012bgi p\u0101rs\u016bt\u012bts %(name)s un %(amount)s citi ieraksti.",
     "Successfully moved %(name)s and 1 other item.": "Veiksm\u012bgi p\u0101rs\u016bt\u012bts %(name)s un 1 cits ieraksts",
@@ -409,20 +406,23 @@
     "User Permission": "Lietot\u0101ja ties\u012bbas",
     "Username:": "Lietot\u0101jv\u0101rds:",
     "Users": "Lietot\u0101ji",
+    "Verify": "P\u0101rbaud\u012bt",
     "Version": "Versija",
     "Version Number": "Versijas numurs",
     "Video": "Video",
     "View": "Skat\u012bt",
     "View Snapshot": "Skat\u012bt momentuz\u0146\u0113mumu",
+    "View profile and more": "Skat\u012bt profilu",
     "Virus File": "V\u012brusa datne",
     "Virus Scan": "V\u012brusu sken\u0113\u0161ana",
     "Visits": "Apmekl\u0113jumi",
     "Wrong password": "K\u013c\u016bdaina parole",
+    "Yes": "J\u0101",
     "You can also add a user as a guest, who will not be allowed to create libraries and groups.": "Varat pievienot lietot\u0101ju k\u0101 viesi, kuram netiks at\u013cauts izveidot bibliot\u0113kas vai grupas.",
+    "ZIP": "ZIP",
     "all": "visi",
     "all members": "visi dal\u012bbnieki",
     "days": "dienas",
-    "file": "datne",
     "icon": "ikona",
     "locked": "blo\u0137\u0113ts",
     "name": "v\u0101rds",
@@ -433,24 +433,24 @@
     "you can also press \u2190 ": "var spiest ar\u012b  \u2190 ",
     "{placeholder} Folder Permission": "{placeholder} Mapes at\u013caujas"
   };
-  for (var key in newcatalog) {
+  for (const key in newcatalog) {
     django.catalog[key] = newcatalog[key];
   }
   
 
   if (!django.jsi18n_initialized) {
     django.gettext = function(msgid) {
-      var value = django.catalog[msgid];
-      if (typeof(value) == 'undefined') {
+      const value = django.catalog[msgid];
+      if (typeof value === 'undefined') {
         return msgid;
       } else {
-        return (typeof(value) == 'string') ? value : value[0];
+        return (typeof value === 'string') ? value : value[0];
       }
     };
 
     django.ngettext = function(singular, plural, count) {
-      var value = django.catalog[singular];
-      if (typeof(value) == 'undefined') {
+      const value = django.catalog[singular];
+      if (typeof value === 'undefined') {
         return (count == 1) ? singular : plural;
       } else {
         return value.constructor === Array ? value[django.pluralidx(count)] : value;
@@ -460,16 +460,16 @@
     django.gettext_noop = function(msgid) { return msgid; };
 
     django.pgettext = function(context, msgid) {
-      var value = django.gettext(context + '\x04' + msgid);
-      if (value.indexOf('\x04') != -1) {
+      let value = django.gettext(context + '\x04' + msgid);
+      if (value.includes('\x04')) {
         value = msgid;
       }
       return value;
     };
 
     django.npgettext = function(context, singular, plural, count) {
-      var value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
-      if (value.indexOf('\x04') != -1) {
+      let value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
+      if (value.includes('\x04')) {
         value = django.ngettext(singular, plural, count);
       }
       return value;
@@ -495,14 +495,12 @@
       "%d.%m.%Y %H:%M:%S",
       "%d.%m.%Y %H:%M:%S.%f",
       "%d.%m.%Y %H:%M",
-      "%d.%m.%Y",
       "%d.%m.%y %H:%M:%S",
       "%d.%m.%y %H:%M:%S.%f",
       "%d.%m.%y %H:%M",
       "%d.%m.%y %H.%M.%S",
       "%d.%m.%y %H.%M.%S.%f",
       "%d.%m.%y %H.%M",
-      "%d.%m.%y",
       "%Y-%m-%d"
     ],
     "DATE_FORMAT": "Y. \\g\\a\\d\\a j. F",
@@ -531,8 +529,8 @@
   };
 
     django.get_format = function(format_type) {
-      var value = django.formats[format_type];
-      if (typeof(value) == 'undefined') {
+      const value = django.formats[format_type];
+      if (typeof value === 'undefined') {
         return format_type;
       } else {
         return value;
@@ -551,6 +549,5 @@
 
     django.jsi18n_initialized = true;
   }
-
-}(this));
+};
 
