@@ -1,13 +1,14 @@
 
 
-(function(globals) {
-
-  var django = globals.django || (globals.django = {});
+'use strict';
+{
+  const globals = this;
+  const django = globals.django || (globals.django = {});
 
   
   django.pluralidx = function(n) {
-    var v=(n != 1);
-    if (typeof(v) == 'boolean') {
+    const v = (n != 1);
+    if (typeof v === 'boolean') {
       return v ? 1 : 0;
     } else {
       return v;
@@ -19,10 +20,8 @@
 
   django.catalog = django.catalog || {};
   
-  var newcatalog = {
-    "%curr% of %total%": "%curr% av %total%",
+  const newcatalog = {
     "(If left blank, owner will be admin)": "(Om det l\u00e4mnas blankt, kommer \u00e4garen bli admin)",
-    "(at least {passwordLength} characters)": "(\u00e5tminstone {passwordLength} tecken)",
     "(at least {placeholder} characters)": "(\u00e5tminstone {placeholder} tecken)",
     "(current notification)": "aktuellt systemmeddelande",
     "(current version)": "(nuvarande version)",
@@ -55,21 +54,18 @@
     "Add": "L\u00e4gg till",
     "Add Admin": "L\u00e4gg till Admin",
     "Add Admins": "L\u00e4gg till administrat\u00f6rer",
-    "Add File": "L\u00e4gg till Filer",
     "Add Institution": "L\u00e4gg till Institution",
     "Add Library": "L\u00e4gg till bibliotek",
     "Add Member": "L\u00e4gg till medlem",
     "Add Organization": "L\u00e4gg till Organisation",
     "Add Terms and Conditions": "L\u00e4gg till villkor",
     "Add User": "L\u00e4gg till anv\u00e4ndare",
-    "Add a comment.": "L\u00e4gg till kommentar.",
     "Add admin": "L\u00e4gg till admin",
     "Add auto expiration": "L\u00e4gg till automatisk utg\u00e5ngsdatum",
     "Add group member": "L\u00e4gg till gruppmedlem",
     "Add institution": "L\u00e4gg till institution",
     "Add new notification": "Skapa nytt systemmeddelande",
     "Add new reviewer": "L\u00e4gg till granskare",
-    "Add participants": "L\u00e4gg till deltagare",
     "Add password protection": "L\u00e4gg till l\u00f6senordsskydd",
     "Add user": "L\u00e4gg till anv\u00e4ndare",
     "Added": "Tillagd",
@@ -87,7 +83,6 @@
     "All Public Links": "Alla Publika L\u00e4nkar",
     "All file types": "Alla filtyper",
     "Allow new user registrations. Uncheck this to prevent anyone from creating a new account.": "Till\u00e5t nya anv\u00e4ndarregistreringar. Kryssa ur f\u00f6r att hindra att vem som helst skapar ett nytt konto.",
-    "Allow user to add organization libraries. Otherwise, only system admin can add organization libraries.": "Till\u00e5t anv\u00e4ndare att skapa organisationskataloger. Annars kan enbart systemadministrat\u00f6rer skapa organisationskataloger.",
     "Allow user to change library history settings": "Till\u00e5t anv\u00e4ndare till att \u00e4ndra bibliotekets historikinst\u00e4llningar",
     "Allow user to clean library trash": "Till\u00e5t anv\u00e4ndare att rensa katalogskr\u00e4p",
     "Allow user to create encrypted libraries": "Till\u00e5t anv\u00e4ndare att skapa krypterade kataloger",
@@ -118,7 +113,6 @@
     "At server": "P\u00e5 server",
     "Audio": "Audio",
     "Audit Admin": "Anv\u00e4ndaradmin",
-    "Author": "F\u00f6rfattare",
     "Auto deletion": "Auto borttagning",
     "Automatically delete files that are not modified within certain days:": "Ta bort filer automatiskt som inte har \u00e4ndrats inom antal dagar:",
     "Avatar": "Avatar",
@@ -136,7 +130,6 @@
     "By time descending": "P\u00e5 tid fallande",
     "Can not copy directory %(src)s to its subdirectory %(des)s": "Kan inte kopiera katalog %(src)s till dess underkatalog %(des)s",
     "Can not move directory %(src)s to its subdirectory %(des)s": "Kan inte flytta katalog %(src)s till dess underkatalog %(des)s",
-    "Can not select self as a related file.": "Kan inte v\u00e4lja en sj\u00e4lv som relaterad fil.",
     "Cancel": "Avbryt",
     "Cancel All": "Avbryt alla",
     "Change": "\u00c4ndra",
@@ -152,10 +145,7 @@
     "Clear files in trash and history\uff1a": "Rensa filer i skr\u00e4pkorgen och historik:",
     "Clients": "Klienter",
     "Close": "St\u00e4ng",
-    "Close (Esc)": "St\u00e4ng (Esc)",
     "Column": "Kolumn",
-    "Comment": "Kommentar",
-    "Comments": "Kommentarer",
     "Community Edition": "Community Edition",
     "Confirm": "Bekr\u00e4fta",
     "Confirm Password": "Bekr\u00e4fta l\u00f6senord",
@@ -165,13 +155,13 @@
     "Contact Information": "Kontaktinformation",
     "Contact information is required.": "Kontaktinformation kr\u00e4vs.",
     "Content Scan Records": "Inneh\u00e5ll Skanrapporter",
-    "Contents": "Inneh\u00e5ll",
     "Copy": "Kopiera",
     "Copy selected item(s) to:": "Kopiera valda objekt till:",
     "Copy {num} items": "Kopiera {num} objekt",
     "Copy {placeholder} to": "Kopiera {placeholder} till",
     "Copyright Infringement": "Upphovsr\u00e4ttsintr\u00e5ng",
     "Count": "Antal",
+    "Create": "Skapa",
     "Create Group": "Skapa grupp",
     "Create Library": "Skapa Katalog",
     "Create Report": "Skapa rapport",
@@ -201,7 +191,6 @@
     "Date Invalid.": "Datum Ogiltig.",
     "Default": "Standard",
     "Default Admin": "Standardadmin",
-    "Default Size": "Standard Storlek",
     "Delete": "Ta bort",
     "Delete Account": "Ta bort konto",
     "Delete Department": "Ta bort Avdelning",
@@ -234,8 +223,8 @@
     "Deleted user {user}": "Tog bort anv\u00e4ndare {user}",
     "Departments": "Avdelningar",
     "Description": "Beskrivning",
+    "Description is required": "Beskrivning kr\u00e4vs",
     "Desktop": "Skrivbord",
-    "Detail": "Detaljer",
     "Details": "Detaljer",
     "Device": "Enhet",
     "Device Name": "Enhetsnamn",
@@ -257,15 +246,11 @@
     "Download an example file": "Ladda ner en exempelfil",
     "Download and upload": "Ladda ner och ladda upp",
     "Draft": "Utkast",
-    "Draft has been deleted.": "Utkasten har tagits bort.",
     "Draft is a way to let you collaborate with others on files. You can create a draft from a file, edit the draft and then ask for a review. The original file will be updated only after the draft has been reviewed.": "Utkast \u00e4r ett s\u00e4tt g\u00f6r dig att samarbeta med andra i filer. Du kan skapa utkast av en fil, \u00e4ndra ett utkast och sedan efterfr\u00e5ga en granskning. Orginalfilen kommer d\u00e5 att uppdateras endast efter att utkast blivit granskad.",
     "Drafts": "F\u00f6rslag",
     "Drag and drop files or folders here.": "Dra och sl\u00e4pp filer eller mappar h\u00e4r.",
     "Edit": "\u00c4ndra",
-    "Edit Draft": "\u00c4ndra Utkast",
     "Edit File": "Redigera Fil",
-    "Edit Tag": "\u00c4ndra Tagg",
-    "Edit failed.": "\u00c4ndring misslyckades",
     "Edit labels": "\u00c4ndra markeringar",
     "Edit on cloud and download": "\u00c4ndra i molnet och ladda ner",
     "Edit on cloud only": "Redigera i molnet enbart",
@@ -306,7 +291,6 @@
     "Failed to delete %(virus_file) from library %(library): %(error_msg)": "Misslyckades ta bort %(virus_file) fr\u00e5n katalog %(library): %(error_msg)",
     "Failed to delete draft %(draft)s.": "Misslyckades ta bort utkast %(draft)s.",
     "Failed to delete {name}": "Misslyckades ta bort {name}",
-    "Failed to delete {name} and other {n} items.": "Misslyckades ta bort {name} och {n} andra objekt.",
     "Failed to delete {name}.": "Misslyckades ta bort {name}.",
     "Failed to ignore %(virus_file) from library %(library): %(error_msg)": "Misslyckade ignorera %(virus_file) fr\u00e5n katalog %(library): %(error_msg)",
     "Failed to move %(name)s and %(amount)s other item(s).": "Misslyckades flytta %(name)s och %(amount)s andra objekt.",
@@ -332,7 +316,6 @@
     "File extensions can only be {placeholder}.": "Fil\u00e4ndelser kan enbart vara {placeholder}.",
     "File is locked by others.": "Filer l\u00e5sta av andra.",
     "File size is too large.": "Filstorleken \u00e4r f\u00f6r stor.",
-    "File {file_link} has a new comment form user {author}.": "Filen {file_link} har en ny kommentar fr\u00e5n anv\u00e4ndaren {author}.",
     "Files": "Filer",
     "Folder": "Mapp",
     "Folder Permission": "Mappr\u00e4ttigheter",
@@ -354,11 +337,11 @@
     "Guest": "G\u00e4st",
     "Handled": "Hanterad",
     "Help": "Hj\u00e4lp",
+    "Hide": "D\u00f6lj",
     "History": "Historik",
     "History Setting": "Historik Inst\u00e4llning",
     "History Versions": "Versionshistorik",
     "IP": "IP",
-    "If the share link is deleted, no one will be able to access it any more.": "Om delningsl\u00e4nken \u00e4r borttagen, s\u00e5 kommer ingen kunna komma \u00e5t den l\u00e4ngre.",
     "If turn on, the desktop clients will not be able to sync a folder outside the default Seafile folder.": "Om detta \u00e4r p\u00e5slaget kommer desktop-klienten inte kunna synka mappar utanf\u00f6r standard Seafile-mappen.",
     "If you don't have any device with you, you can access your account using backup codes.": "Om du inte har din enhet med dig s\u00e5 kan du komma \u00e5t ditt konto med backup koder.",
     "Ignore": "Ignorera",
@@ -367,6 +350,7 @@
     "Images": "Bilder",
     "Import Members": "Importera Medlemmar",
     "Import Users": "Importera Anv\u00e4ndare",
+    "Import users": "Importera anv\u00e4ndare",
     "Import users from a .xlsx file": "Importera anv\u00e4ndare fr\u00e5n en .xlsx fil",
     "In all libraries": "I alla kataloger",
     "Inactive": "Inaktiv",
@@ -386,7 +370,6 @@
     "Invitations": "Inbjudningar",
     "Invite Guest": "Bjud in G\u00e4st",
     "Invite Time": "Inbjudningstid",
-    "Invite user": "Bjud in anv\u00e4ndare",
     "Invited at": "Inbjuden vid",
     "Inviter": "Inbjudaren",
     "It is required.": "Det kr\u00e4vs.",
@@ -409,7 +392,6 @@
     "Less than or equal to {maxDays_placeholder} days": "Mindre \u00e4n eller lika med {maxDays_placeholder} dagar",
     "Libraries": "Kataloger",
     "Library": "Katalog",
-    "Library Name": "Katalogs Namn",
     "Library Type": "Katalogstyp",
     "Library can not be shared to owner.": "Katalogen kan inte delas till \u00e4garen.",
     "Limits": "Begr\u00e4nsningar",
@@ -421,6 +403,7 @@
     "List": "Lista",
     "List your account in global address book, so that others can find you by typing your name.": "Lista dina konton i den globala adresslistan, s\u00e5 att andra kan hitta dig genom att s\u00f6ka efter ditt namn.",
     "Local draft": "Lokalt utkast",
+    "Local draft saved": "Lokalt utkast sparat",
     "Location": "Lokation",
     "Lock": "L\u00e5s",
     "Log out": "Logga ut",
@@ -430,7 +413,6 @@
     "Manage Members": "Managera medlemmar",
     "Manage group members": "Hantera gruppmedlemmar",
     "Mark all read": "Markera alla l\u00e4sta",
-    "Mark as resolved": "Markera som l\u00f6st",
     "Member": "Medlem",
     "Members": "Medlemmar",
     "Message": "Meddelande",
@@ -484,10 +466,9 @@
     "New password is too short": "Det nya l\u00f6senordet \u00e4r f\u00f6r kort",
     "New passwords don't match": "De nya l\u00f6senorden \u00f6verensst\u00e4mmer inte",
     "Next": "N\u00e4sta",
-    "Next (Right arrow key)": "N\u00e4sta (H\u00f6ger piltangent)",
+    "No": "Nej",
     "No Admin login logs": "Inga Admin login loggar",
     "No Admin operation logs": "Inga Admin \u00e5tg\u00e4rdsloggar",
-    "No comment yet.": "Inga kommentarer \u00e4nnu.",
     "No connected devices": "Inga anslutna enheter",
     "No deleted libraries": "Inga borttagna kataloger",
     "No departments": "Inga avdelningar",
@@ -517,7 +498,6 @@
     "No published libraries": "Inga publicerade kataloger",
     "No result": "Inget resultat",
     "No results matching.": "Inga resultat matchar.",
-    "No reviewer yet.": "Inga granskare \u00e4nnu.",
     "No share links": "Inga delningsl\u00e4nkar",
     "No shared libraries": "Inga delade kataloger",
     "No sub-departments": "Inga underavdelningar",
@@ -528,7 +508,6 @@
     "Note: Settings via web interface are saved in database table (seahub-db/constance_config). They have a higher priority over the settings in config files.": "Not: Inst\u00e4llningar via webbgr\u00e4nssnittet \u00e4r sparade i databastabellen (seahub-db/constance_config). De har h\u00f6gre prioritet \u00f6ver inst\u00e4llningar i konfigurationsfiler.",
     "Notification Detail": "Detaljer",
     "Notifications": "Meddelanden",
-    "Number of changes:": "Antal \u00e4ndringar:",
     "Number of days that keep user sign in.": "Antal dagar som anv\u00e4ndaren h\u00e5lls inloggad.",
     "Number of groups": "Antal grupper",
     "Off": "Av",
@@ -544,7 +523,6 @@
     "Online view is not applicable to this file format": "Online-visning \u00e4r inte tillg\u00e4ngligt f\u00f6r detta filformat",
     "Only Show": "Visa Enbart",
     "Only keep a period of history:": "Spara endast historiken ",
-    "Open in New Tab": "\u00d6ppna i ny flik",
     "Open parent directory": "\u00d6ppna f\u00f6r\u00e4ldermapp",
     "Open parent folder": "\u00d6ppna huvudmapp",
     "Open via Client": "\u00d6ppna via Klient",
@@ -554,7 +532,6 @@
     "Organization": "Organisation",
     "Organization Admin": "Organisationsadmin",
     "Organizations": "Organisationer",
-    "Original file has been deleted.": "Original filen har tagits bort.",
     "Other": "Annat",
     "Other Libraries": "Andra Kataloger",
     "Out of quota.": "Slut p\u00e5 kvoten.",
@@ -562,7 +539,6 @@
     "Owner": "\u00c4gare",
     "Owner can use admin panel in an organization, must be a new account.": "\u00c4gare kan inte anv\u00e4nda adminpanelen i en organisation. M\u00e5ste vara ett nytt konto.",
     "Packaging...": "Paketerar...",
-    "Participants": "Deltagare",
     "Password": "L\u00f6senord",
     "Password again": "L\u00f6senord igen",
     "Password is too short": "L\u00f6senordet \u00e4r f\u00f6r kort",
@@ -599,16 +575,12 @@
     "Preview and download": "F\u00f6rhandsgranska och ladda ner",
     "Preview only": "F\u00f6rhandsgranska enbart",
     "Previous": "Tidigare",
-    "Previous (Left arrow key)": "F\u00f6reg\u00e5ende (V\u00e4nster piltangent)",
-    "Private": "Privat",
     "Professional Edition": "Professional Edition",
     "Profile": "Profil",
     "Profile Setting": "Profilinst\u00e4llningar",
-    "Public": "Publik",
     "Publish": "Publicera",
     "Publish a Library": "Publicera Katalog",
     "Publish draft": "Publicera utkast",
-    "Published": "Publicerad",
     "Published Libraries": "Publicerade Kataloger",
     "Quota": "Kvot",
     "Quota is invalid.": "Kvot \u00e4r inte giltig.",
@@ -622,7 +594,6 @@
     "Really want to delete your account?": "Vill du verkligen ta bort ditt konto? ",
     "Really want to leave this group?": "Vill du verkligen l\u00e4mna denna grupp?",
     "Refresh": "Uppdatera",
-    "Related Files": "Relaterade Filer",
     "Remaining": "\u00c5terst\u00e5r",
     "Remove": "Ta bort",
     "Remove Member": "Ta bort Medlem",
@@ -659,8 +630,6 @@
     "Result": "Resultat",
     "Retry": "F\u00f6rs\u00f6k igen",
     "Retry All": "F\u00f6rs\u00f6k igen med Alla",
-    "Review": "Granska",
-    "Reviewers": "Granskare",
     "Revoke": "Degradera",
     "Revoke Access": "Ta bort Tilltr\u00e4de",
     "Revoke Admin": "Degradera admin",
@@ -671,35 +640,27 @@
     "Saving...": "Sparar...",
     "Seafile": "Seafile",
     "Search": "S\u00f6k",
-    "Search Files": "S\u00f6k filer",
     "Search Groups": "S\u00f6k Grupper",
     "Search Libraries": "S\u00f6k Kataloger",
     "Search Organizations": "S\u00f6k Organisationer",
     "Search Users": "S\u00f6k Anv\u00e4ndare",
     "Search files in this library": "S\u00f6k efter filer i denna katalog",
+    "Search groups": "S\u00f6k grupper",
     "Search groups by name": "S\u00f6k grupper med namn",
-    "Search libraries by name": "S\u00f6k kataloger med namn",
     "Search libraries by owner": "S\u00f6k kataloger med \u00e4gare",
     "Search organizations": "S\u00f6k organisationer",
     "Search users": "S\u00f6k anv\u00e4ndare",
-    "Search users...": "S\u00f6k anv\u00e4ndare...",
-    "Search...": "S\u00f6k...",
-    "See All Notifications": "Se Alla Notifikationer",
     "Select File": "V\u00e4lj Fil",
     "Select Image": "V\u00e4lj Bild",
     "Select Tags": "V\u00e4lj Taggar",
     "Select a color": "V\u00e4lj en f\u00e4rg",
     "Select a department": "V\u00e4lj en avdelning",
     "Select a group": "V\u00e4lj en grupp",
-    "Select a server...": "V\u00e4lj en server...",
     "Select a user": "V\u00e4lj en anv\u00e4ndare",
-    "Select a user as admin...": "V\u00e4lj en anv\u00e4ndare som admin...",
-    "Select groups...": "V\u00e4lj grupper...",
+    "Select groups": "V\u00e4lj grupper",
     "Select libraries to share": "V\u00e4lj kataloger att dela",
-    "Select related file for {placeholder}": "V\u00e4lj relaterad fil f\u00f6r {placeholder}",
     "Send": "Skicka",
     "Send activation Email after user registration.": "Skicka aktiverings-mejl efter anv\u00e4ndarregistrering.",
-    "Send the invitation link to the others, and they will be able to join the organization via scanning the QR code.": "Skicka en inbjudningsk\u00f6nk till andra, och de kommer att kunna g\u00e5 med i organisationen genom att skanna QR koden.",
     "Send to:": "Skicka till:",
     "Sending new password...": "Skickar nytt l\u00f6senord...",
     "Sending...": "Skickar...",
@@ -727,7 +688,6 @@
     "Share Link": "Dela L\u00e4nk",
     "Share Link Traffic": "Delningsl\u00e4nk Trafik",
     "Share Links": "Delningsl\u00e4nkar",
-    "Share Links Admin": "Delningsl\u00e4nkar Admin",
     "Share To": "Dela med",
     "Share To:": "Dela Till:",
     "Share existing libraries": "Dela existerande kataloger",
@@ -746,8 +706,8 @@
     "Shared with all": "Delade med alla",
     "Shared with groups": "Delade med grupper",
     "Shared with me": "Delade med mig",
+    "Show": "Visa",
     "Show Codes": "Visa Koder",
-    "Show resolved comments": "Visa l\u00f6sta kommentarer",
     "Side Nav Menu": "Sidomeny",
     "Site name used in email sending": "Sidnamn som anv\u00e4nds i mejlutskick",
     "Site title shown in a browser tab": "Sidtiteln som visas i en webbl\u00e4sartabb",
@@ -757,7 +717,6 @@
     "Space Used / Quota": "Utrymme Anv\u00e4nt / Kvot",
     "Star": "Favorit",
     "Start date": "Startdatum",
-    "Start review": "Starta granskning",
     "Statistic": "Statistik",
     "Status": "Status",
     "Status: enabled": "Status: aktiverad",
@@ -776,12 +735,11 @@
     "Successfully copied %(name)s and 1 other item.": "Lyckades kopiera %(name)s och 1 annan fil.",
     "Successfully copied %(name)s.": "Lyckades kopiera %(name)s.",
     "Successfully copied files to another library.": "Lyckades kopiera filer till en annan katalog.",
-    "Successfully deleted %s": "Tog bort %s",
+    "Successfully deleted 1 item": "Lyckades ta bort 1 sak",
     "Successfully deleted 1 item.": "Lyckades ta bort 1 sak.",
     "Successfully deleted 1 user.": "Lyckades ta bort 1 anv\u00e4ndare.",
     "Successfully deleted draft %(draft)s.": "Lyckades ta bort utkast %(draft)s.",
     "Successfully deleted {name}": "Lyckades ta bort {name}",
-    "Successfully deleted {name} and other {n} items.": "Lyckades ta bort {name} och {n} andra objekt.",
     "Successfully deleted {name}.": "Lyckades ta bort {name}.",
     "Successfully deleted {user_number_placeholder} users.": "Lyckades ta bort {user_number_placeholder} anv\u00e4ndare.",
     "Successfully edited labels.": "Lyckades \u00e4ndra markeringar.",
@@ -807,9 +765,6 @@
     "Successfully set %s as admin.": "Lyckades s\u00e4tta %s som admin.",
     "Successfully set it.": "Lyckades s\u00e4tta den.",
     "Successfully set library history.": "Satte katalogens historik.",
-    "Successfully set max number of members.": "Lyckades s\u00e4tta max antal medlemmar.",
-    "Successfully set name.": "Lyckades s\u00e4tta namn.",
-    "Successfully set quota.": "Lyckades s\u00e4tta kvot.",
     "Successfully starred {library_name_placeholder}.": "{library_name_placeholder} las till favoriter.",
     "Successfully transferred the group.": "Gruppen \u00f6verf\u00f6rd.",
     "Successfully transferred the library.": "Biblioteket \u00f6verf\u00f6rdes.",
@@ -839,9 +794,7 @@
     "Text is required.": "Text kr\u00e4vs.",
     "The URL of the server, like https://seafile.example.com or http://192.168.1.2:8000": "Serverns URL. T.ex. https://seafile.example.com eller http://192.168.1.2:8000",
     "The file is too large. Allowed maximum size is 1MB.": "Denna fil \u00e4r f\u00f6r stor. Till\u00e5ten maxstorlek \u00e4r 1MB.",
-    "The image could not be loaded.": "Bilden kunde inte laddas.",
     "The internal URL for downloading/uploading files. Users will not be able to download/upload files if this is not set correctly. If you config Seafile behind Nginx/Apache, it should be SERVICE_URL/seafhttp, like https://seafile.example.com/seafhttp .": "Intern URL f\u00f6r att ladda ner/upp filer. Anv\u00e4ndare kommer inte kunna ladda ner/upp filer om detta inte \u00e4r r\u00e4tt inst\u00e4llt. Om du anv\u00e4nder Seafile bakom Nginx/Apache detta ska vara SERVICE_URL/seafhttp. T.ex. https://seafile.example.com/seafhttp .",
-    "The least number of characters a download/upload link password should include.": "Det l\u00e4gsta antal tecken som en nerladdnings-/uppladdningsl\u00e4nks l\u00f6senord ska inneh\u00e5lla.",
     "The least number of characters an account password should include.": "Det l\u00e4gsta antal tecken som ett kontos l\u00f6senord ska inneh\u00e5lla.",
     "The least number of characters an encrypted library password should include.": "Det l\u00e4gsta antal tecken som ett krypterat biblioteks l\u00f6senord ska inneh\u00e5lla.",
     "The level(1-4) of an account password's strength. For example, '3' means password must have at least 3 of the following: num, upper letter, lower letter and other symbols": "Styrkeniv\u00e5 (1-4) f\u00f6r ett kontos l\u00f6senord. Exempelvis betyder '3' att ett l\u00f6senord m\u00e5ste ha minst 3 av f\u00f6ljande: siffra, versal, gemen och andra symboler.",
@@ -854,7 +807,6 @@
     "This file has been updated.": "Denna fil har blivit uppdaterad.",
     "This file is in draft stage.": "Denna fil \u00e4r i ett utkast l\u00e4ge.",
     "This folder has no content at this time.": "Denna mapp har inget inneh\u00e5ll just nu.",
-    "This is a draft": "Detta \u00e4r ett utkast",
     "This is a special group representing a department.": "Detta \u00e4r en speciell grupp som representerar en avdelning.",
     "This library has been set to read-only by admin and cannot be updated.": "Denna katalog har satts med enbart l\u00e4s r\u00e4ttigheter av admin och kan inte uppdateras.",
     "This library is password protected": "Katalogen \u00e4r l\u00f6senordsskyddad",
@@ -894,7 +846,6 @@
     "Unlock": "L\u00e5s upp",
     "Unpublish": "Avpublicera",
     "Unpublish Library": "Avpublicera Katalog",
-    "Unresolved comments:": "Ol\u00f6sta kommentarer:",
     "Unshare": "Sluta dela",
     "Unshare Library": "Sluta dela bibliotek",
     "Unstar": "Ta bort favorit",
@@ -930,6 +881,7 @@
     "User {user_link} has added you to {group_link}": "Anv\u00e4ndaren {user_link} har lagt till dig till {group_link}",
     "Username:": "Anv\u00e4ndarnamn:",
     "Users": "Anv\u00e4ndare",
+    "Verify": "Verifiera",
     "Version": "Version",
     "Version Number": "Versions Nummer",
     "Version Number is required.": "Versionsnummer kr\u00e4vs.",
@@ -939,7 +891,7 @@
     "View Draft": "Visa Utkast",
     "View Link": "Visa L\u00e4nk",
     "View Snapshot": "Visa Snapshot",
-    "View diff": "Visa differens",
+    "View profile and more": "Visa profil och mer",
     "Virus": "Virus",
     "Virus File": "Virusfil",
     "Virus Scan": "Virusscan",
@@ -952,6 +904,7 @@
     "WebDav Password": "WebDav L\u00f6senord",
     "Welcome to {site_name_placeholder}": "V\u00e4lkommen till {site_name_placeholder}",
     "Wrong password": "Fel l\u00f6senord",
+    "Yes": "Ja",
     "You are not in any groups. Groups allow multiple people to collaborate on libraries. Groups you join will be listed here.": "Du \u00e4r inte i n\u00e5gon grupp. Grupper till\u00e5ter flera personer att samarbeta med kataloger. Grupper som du g\u00e5r med i kommer listas h\u00e4r.",
     "You are not in any groups. Groups allow multiple people to collaborate on libraries. You can create a group by clicking the \"New Group\" button in the menu bar.": "Du \u00e4r inte i n\u00e5gon grupp. Grupper till\u00e5ter flera personer att samarbeta med kataloger. Du kan skapa en grupp genom att klicka p\u00e5 \"Ny Grupp\" knappen i menyn.",
     "You can also add a user as a guest, who will not be allowed to create libraries and groups.": "Du kan ocks\u00e5 l\u00e4gga till en anv\u00e4ndare som g\u00e4st, som inte kommer kunna skapa kataloger eller grupper.",
@@ -976,11 +929,8 @@
     "You have only one backup code remaining.": "Du har bara en backupkod kvar.",
     "You have {num} backup codes remaining.": "Du har {num} backupkoder kvar.",
     "Your notifications will be sent to this email.": "Dina notifikationer kommer att skickas till denna mejladress.",
+    "ZIP": "ZIP",
     "ZIP Selected Items": "ZIP Valda Objekt",
-    "Zoom In": "Zooma In",
-    "Zoom Out": "Zooma Ut",
-    "Zoom in": "Zooma in",
-    "Zoom out": "Zooma ut",
     "activate after registration": "aktivera efter registrering",
     "all": "alla",
     "all members": "alla medlemmar",
@@ -988,11 +938,7 @@
     "days": "dagar",
     "deleted": "borttagen",
     "details": "detaljer",
-    "download/upload link password minimum length": "minimil\u00e4ngd f\u00f6r nerladdnings-/uppladdningsl\u00e4nks l\u00f6senord",
-    "draft": "utkast",
     "email is required": "mailadress kr\u00e4vs",
-    "file": "fil",
-    "files": "filer",
     "icon": "ikon",
     "keep sign in": "h\u00e5ll inloggad",
     "library password minimum length": "minimil\u00e4ngd f\u00f6r biblioteks l\u00f6senord",
@@ -1004,7 +950,6 @@
     "password minimum length": "l\u00f6senords minimil\u00e4ngd",
     "password strength level": "l\u00f6senords styrkeniv\u00e5",
     "progress": "g\u00e5ng",
-    "related files": "relaterade filer",
     "result": "resultat",
     "results": "resultat",
     "send activation email": "skicka aktiverings-mejl",
@@ -1026,7 +971,6 @@
     "{placeholder} API Token": "{placeholder} API Token",
     "{placeholder} Folder Permission": "{placeholder} Mappr\u00e4ttigheter",
     "{placeholder} Modification History": "{placeholder} \u00c4ndringshistorik",
-    "{placeholder} Share/Upload Links": "{placeholder} Delning/Uppladdningsl\u00e4nkar",
     "{placeholder} Snapshot": "{placeholder} \u00d6gonblicksbild",
     "{placeholder} Trash": "{placeholder} Papperskorg",
     "{share_from} has shared a folder named {repo_link} to group {group_link}.": "{share_from} har delat mappen med namnet {repo_link} till gruppen {group_link}.",
@@ -1038,24 +982,24 @@
     "{userCount} user(s) and {repoCount} libraries of this organization will also be deleted.": "{userCount} anv\u00e4ndare och {repoCount} kataloger i denna organisation kommer ocks\u00e5 att tas bort.",
     "{user} has transfered a library named {repo_link} to you.": "{user} har \u00f6verf\u00f6rt en katalog med namnet {repo_link} till dig."
   };
-  for (var key in newcatalog) {
+  for (const key in newcatalog) {
     django.catalog[key] = newcatalog[key];
   }
   
 
   if (!django.jsi18n_initialized) {
     django.gettext = function(msgid) {
-      var value = django.catalog[msgid];
-      if (typeof(value) == 'undefined') {
+      const value = django.catalog[msgid];
+      if (typeof value === 'undefined') {
         return msgid;
       } else {
-        return (typeof(value) == 'string') ? value : value[0];
+        return (typeof value === 'string') ? value : value[0];
       }
     };
 
     django.ngettext = function(singular, plural, count) {
-      var value = django.catalog[singular];
-      if (typeof(value) == 'undefined') {
+      const value = django.catalog[singular];
+      if (typeof value === 'undefined') {
         return (count == 1) ? singular : plural;
       } else {
         return value.constructor === Array ? value[django.pluralidx(count)] : value;
@@ -1065,16 +1009,16 @@
     django.gettext_noop = function(msgid) { return msgid; };
 
     django.pgettext = function(context, msgid) {
-      var value = django.gettext(context + '\x04' + msgid);
-      if (value.indexOf('\x04') != -1) {
+      let value = django.gettext(context + '\x04' + msgid);
+      if (value.includes('\x04')) {
         value = msgid;
       }
       return value;
     };
 
     django.npgettext = function(context, singular, plural, count) {
-      var value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
-      if (value.indexOf('\x04') != -1) {
+      let value = django.ngettext(context + '\x04' + singular, context + '\x04' + plural, count);
+      if (value.includes('\x04')) {
         value = django.ngettext(singular, plural, count);
       }
       return value;
@@ -1097,15 +1041,13 @@
       "%Y-%m-%d %H:%M:%S",
       "%Y-%m-%d %H:%M:%S.%f",
       "%Y-%m-%d %H:%M",
-      "%Y-%m-%d",
       "%m/%d/%Y %H:%M:%S",
       "%m/%d/%Y %H:%M:%S.%f",
       "%m/%d/%Y %H:%M",
-      "%m/%d/%Y",
       "%m/%d/%y %H:%M:%S",
       "%m/%d/%y %H:%M:%S.%f",
       "%m/%d/%y %H:%M",
-      "%m/%d/%y"
+      "%Y-%m-%d"
     ],
     "DATE_FORMAT": "j F Y",
     "DATE_INPUT_FORMATS": [
@@ -1130,8 +1072,8 @@
   };
 
     django.get_format = function(format_type) {
-      var value = django.formats[format_type];
-      if (typeof(value) == 'undefined') {
+      const value = django.formats[format_type];
+      if (typeof value === 'undefined') {
         return format_type;
       } else {
         return value;
@@ -1150,6 +1092,5 @@
 
     django.jsi18n_initialized = true;
   }
-
-}(this));
+};
 
