@@ -15,9 +15,11 @@ from shibboleth.app_settings import SHIB_ATTRIBUTE_MAP, LOGOUT_SESSION_KEY, SHIB
 
 from seahub import auth
 from seahub.base.accounts import User
+from seahub.auth.models import SocialAuthUser
 from seahub.base.sudo_mode import update_sudo_mode_ts
 from seahub.profile.models import Profile
 from seahub.utils.file_size import get_quota_from_string
+from seahub.role_permissions.utils import get_enabled_role_permissions_by_role
 
 # Get an instance of a logger
 logger = logging.getLogger(__name__)
@@ -33,15 +35,14 @@ try:
 except KeyError:
     CUSTOM_SHIBBOLETH_GET_USER_ROLE = False
 
+SHIBBOLETH_PROVIDER_IDENTIFIER = getattr(settings, 'SHIBBOLETH_PROVIDER_IDENTIFIER', 'shibboleth')
+
 
 class ShibbolethRemoteUserMiddleware(RemoteUserMiddleware):
     """
     Authentication Middleware for use with Shibboleth.  Uses the recommended pattern
     for remote authentication from: http://code.djangoproject.com/svn/django/tags/releases/1.3/django/contrib/auth/middleware.py
     """
-    def __init__(self, *a, **kw):
-        super(ShibbolethRemoteUserMiddleware, self).__init__(*a, **kw)
-
     def process_request(self, request):
         if request.path.rstrip('/') != settings.SITE_ROOT + 'sso':
             return
@@ -66,22 +67,23 @@ class ShibbolethRemoteUserMiddleware(RemoteUserMiddleware):
         # Locate the remote user header.
         # import pprint; pprint.pprint(request.META)
         try:
-            username = request.META[SHIB_USER_HEADER]
+            remote_user = request.META[SHIB_USER_HEADER]
         except KeyError:
             # If specified header doesn't exist then return (leaving
             # request.user set to AnonymousUser by the
             # AuthenticationMiddleware).
             return
 
-        p_id = ccnet_api.get_primary_id(username)
-        if p_id is not None:
-            username = p_id
-
         # If the user is already authenticated and that user is the user we are
         # getting passed in the headers, then the correct user is already
         # persisted in the session and we don't need to continue.
         if request.user.is_authenticated:
-            if request.user.username == username:
+            # If user is already authenticated, the value of request.user.username should be random ID of user,
+            # not the SHIB_USER_HEADER in the request header
+            shib_user = SocialAuthUser.objects.get_by_provider_and_uid(SHIBBOLETH_PROVIDER_IDENTIFIER, remote_user)
+            if shib_user:
+                remote_user = shib_user.username
+            if request.user.username == remote_user:
                 if request.user.is_staff:
                     update_sudo_mode_ts(request)
                 return
@@ -96,7 +98,7 @@ class ShibbolethRemoteUserMiddleware(RemoteUserMiddleware):
 
         # We are seeing this user for the first time in this session, attempt
         # to authenticate the user.
-        user = auth.authenticate(remote_user=username, shib_meta=shib_meta)
+        user = auth.authenticate(remote_user=remote_user, shib_meta=shib_meta)
         if user:
             if not user.is_active:
                 return HttpResponseRedirect(reverse('shib_complete'))
@@ -224,8 +226,9 @@ class ShibbolethRemoteUserMiddleware(RemoteUserMiddleware):
                 return role
 
     def update_user_quota(self, user, user_role):
-        if user.permissions.role_quota():
-            quota = get_quota_from_string(user.permissions.role_quota())
+        role_quota = get_enabled_role_permissions_by_role(user_role)['role_quota']
+        if role_quota:
+            quota = get_quota_from_string(role_quota)
             logger.info('Set quota[%d] for user: %s, role[%s]' % (quota, user.username, user_role))
             seafile_api.set_role_quota(user_role, quota)
         else:
