@@ -1,5 +1,6 @@
 from wsgidav.dav_error import DAVError, HTTP_BAD_REQUEST, HTTP_FORBIDDEN, \
-    HTTP_NOT_FOUND, HTTP_INTERNAL_ERROR
+    HTTP_NOT_FOUND, HTTP_INTERNAL_ERROR, HTTP_TOO_MANY_FILES_IN_LIBRARY
+
 from wsgidav.dav_provider import DAVProvider, DAVCollection, DAVNonCollection
 from threading import Timer, Lock
 
@@ -7,6 +8,7 @@ import wsgidav.util as util
 import os
 import time
 import posixpath
+import unicodedata
 
 import tempfile
 
@@ -256,7 +258,7 @@ class SeafileResource(DAVNonCollection):
                 return True
 
             parent, filename = os.path.split(self.rel_path)
-            seafile_api.del_file(self.repo.id, parent, filename, self.username)
+            seafile_api.del_file(self.repo.id, parent, '[\"'+filename+'\"]', self.username)
         except SearpcError as e:
             raise DAVError(HTTP_INTERNAL_ERROR, e.msg)
 
@@ -289,10 +291,10 @@ class SeafileResource(DAVNonCollection):
             # some clients such as GoodReader requires "overwrite" semantics
             file_id_dest = seafile_api.get_file_id_by_path(dest_repo.id, rel_path)
             if file_id_dest != None:
-                seafile_api.del_file(dest_repo.id, dest_dir, dest_file, self.username)
+                seafile_api.del_file(dest_repo.id, dest_dir, '[\"'+dest_file+'\"]', self.username)
 
-            seafile_api.move_file(self.repo.id, src_dir, src_file,
-                                dest_repo.id, dest_dir, dest_file, 1, self.username, NEED_PROGRESS, SYNCHRONOUS)
+            seafile_api.move_file(self.repo.id, src_dir, '[\"'+src_file+'\"]',
+                                dest_repo.id, dest_dir, '[\"'+dest_file+'\"]', 1, self.username, NEED_PROGRESS, SYNCHRONOUS)
         except SearpcError as e:
             raise DAVError(HTTP_INTERNAL_ERROR, e.msg)
 
@@ -324,8 +326,8 @@ class SeafileResource(DAVNonCollection):
             if not seafile_api.is_valid_filename(dest_repo.id, dest_file):
                 raise DAVError(HTTP_BAD_REQUEST)
 
-            seafile_api.copy_file(self.repo.id, src_dir, src_file,
-                                dest_repo.id, dest_dir, dest_file, self.username, NEED_PROGRESS, SYNCHRONOUS)
+            seafile_api.copy_file(self.repo.id, src_dir, '[\"'+src_file+'\"]',
+                                dest_repo.id, dest_dir, '[\"'+dest_file+'\"]', self.username, NEED_PROGRESS, SYNCHRONOUS)
         except SearpcError as e:
             raise DAVError(HTTP_INTERNAL_ERROR, e.msg)
 
@@ -436,9 +438,11 @@ class SeafDirResource(DAVCollection):
 
         try:
             seafile_api.post_empty_file(self.repo.id, self.rel_path, name, self.username)
-        except SearpcError as e:
+        except Exception as e:
             if e.msg == 'Invalid file name':
                 raise DAVError(HTTP_BAD_REQUEST, e.msg)
+            if e.msg == 'Too many files in library.':
+                raise DAVError(HTTP_TOO_MANY_FILES_IN_LIBRARY, e.msg)
             if e.msg != 'file already exists':
                 raise DAVError(HTTP_INTERNAL_ERROR, e.msg)
 
@@ -492,7 +496,7 @@ class SeafDirResource(DAVCollection):
             if not filename:
                 raise DAVError(HTTP_BAD_REQUEST)
 
-            seafile_api.del_file(self.repo.id, parent, filename, self.username)
+            seafile_api.del_file(self.repo.id, parent, '[\"'+filename+'\"]', self.username)
         except SearpcError as e:
             raise DAVError(HTTP_INTERNAL_ERROR, e.msg)
 
@@ -525,8 +529,8 @@ class SeafDirResource(DAVCollection):
             if not seafile_api.is_valid_filename(dest_repo.id, dest_file):
                 raise DAVError(HTTP_BAD_REQUEST)
 
-            seafile_api.move_file(self.repo.id, src_dir, src_file,
-                                dest_repo.id, dest_dir, dest_file, 0, self.username, NEED_PROGRESS, SYNCHRONOUS)
+            seafile_api.move_file(self.repo.id, src_dir, '[\"'+src_file+'\"]',
+                                dest_repo.id, dest_dir, '[\"'+dest_file+'\"]', 0, self.username, NEED_PROGRESS, SYNCHRONOUS)
         except SearpcError as e:
             raise DAVError(HTTP_INTERNAL_ERROR, e.msg)
 
@@ -559,8 +563,8 @@ class SeafDirResource(DAVCollection):
             if not seafile_api.is_valid_filename(dest_repo.id, dest_file):
                 raise DAVError(HTTP_BAD_REQUEST)
 
-            seafile_api.copy_file(self.repo.id, src_dir, src_file,
-                                dest_repo.id, dest_dir, dest_file, self.username, NEED_PROGRESS, SYNCHRONOUS)
+            seafile_api.copy_file(self.repo.id, src_dir, '[\"'+src_file+'\"]',
+                                dest_repo.id, dest_dir, '[\"'+dest_file+'\"]', self.username, NEED_PROGRESS, SYNCHRONOUS)
         except SearpcError as e:
             raise DAVError(HTTP_INTERNAL_ERROR, e.msg)
 
@@ -738,6 +742,7 @@ class SeafileProvider(DAVProvider):
         return SeafileResource(path, repo, rel_path, obj, environ, self.block_map, self.block_map_lock)
 
 def resolvePath(path, username, org_id, is_guest):
+    path = unicodedata.normalize('NFC', path)
     segments = path.strip("/").split("/")
     if len(segments) == 0:
         raise DAVError(HTTP_BAD_REQUEST)
@@ -767,6 +772,7 @@ def resolvePath(path, username, org_id, is_guest):
     return (repo, rel_path, obj)
 
 def resolveRepoPath(repo, path):
+    path = unicodedata.normalize('NFC', path)
     segments = path.strip("/").split("/")
 
     obj = get_repo_root_seafdir(repo)
