@@ -19,7 +19,7 @@ Configuration is defined like this:
 
     1. Get the name of a configuration file from command line option
        ``--config-file=FILENAME`` (or short ``-cFILENAME``).
-       If this option is omitted, we use ``wsgidav.conf`` in the current
+       If this option is omitted, we use ``wsgidav.yaml`` in the current
        directory.
     2. Set reasonable default settings.
     3. If configuration file exists: read and use it to overwrite defaults.
@@ -32,9 +32,18 @@ Configuration is defined like this:
        ``--root=FOLDER`` option creates a FilesystemProvider that publishes
        FOLDER on the '/' share.
 """
-from __future__ import print_function
-from inspect import isfunction
+import argparse
+import copy
+import logging
+import os
+import platform
+import sys
+import webbrowser
 from pprint import pformat
+from threading import Timer
+
+import yaml
+
 from wsgidav import __version__, util
 from wsgidav.default_conf import DEFAULT_CONFIG, DEFAULT_VERBOSE
 from wsgidav.fs_dav_provider import FilesystemProvider
@@ -43,17 +52,6 @@ from wsgidav.xml_tools import use_lxml
 from wsgidav.dc.domain_controller import SeafileDomainController
 from wsgidav.seafile_dav_provider import SeafileProvider
 
-import argparse
-import copy
-import io
-import logging
-import os
-import platform
-import sys
-import traceback
-import yaml
-
-
 try:
     # Try pyjson5 first because it's faster than json5
     from pyjson5 import load as json_load
@@ -64,26 +62,39 @@ except ImportError:
 __docformat__ = "reStructuredText"
 
 #: Try this config files if no --config=... option is specified
-DEFAULT_CONFIG_FILES = ("wsgidav.yaml", "wsgidav.json", "wsgidav.conf")
+DEFAULT_CONFIG_FILES = ("wsgidav.yaml", "wsgidav.json")
 
 _logger = logging.getLogger("wsgidav")
 
 
-def _get_checked_path(path, config, must_exist=True, allow_none=True):
-    """Convert path to absolute if not None."""
-    if path in (None, ""):
-        if allow_none:
-            return None
-        raise ValueError("Invalid path {!r}".format(path))
-    # Evaluate path relative to the folder of the config file (if any)
-    config_file = config.get("_config_file")
-    if config_file and not os.path.isabs(path):
-        path = os.path.normpath(os.path.join(os.path.dirname(config_file), path))
-    else:
-        path = os.path.abspath(path)
-    if must_exist and not os.path.exists(path):
-        raise ValueError("Invalid path {!r}".format(path))
-    return path
+def _get_common_info(config):
+    """Calculate some common info."""
+    # Support SSL
+    ssl_certificate = util.fix_path(config.get("ssl_certificate"), config)
+    ssl_private_key = util.fix_path(config.get("ssl_private_key"), config)
+    ssl_certificate_chain = util.fix_path(config.get("ssl_certificate_chain"), config)
+    ssl_adapter = config.get("ssl_adapter", "builtin")
+    use_ssl = False
+    if ssl_certificate and ssl_private_key:
+        use_ssl = True
+        # _logger.info("SSL / HTTPS enabled. Adapter: {}".format(ssl_adapter))
+    elif ssl_certificate or ssl_private_key:
+        raise RuntimeError(
+            "Option 'ssl_certificate' and 'ssl_private_key' must be used together."
+        )
+
+    protocol = "https" if use_ssl else "http"
+    url = f"{protocol}://{config['host']}:{config['port']}"
+    info = {
+        "use_ssl": use_ssl,
+        "ssl_cert": ssl_certificate,
+        "ssl_pk": ssl_private_key,
+        "ssl_adapter": ssl_adapter,
+        "ssl_chain": ssl_certificate_chain,
+        "protocol": protocol,
+        "url": url,
+    }
+    return info
 
 
 class FullExpandedPath(argparse.Action):
@@ -96,7 +107,6 @@ class FullExpandedPath(argparse.Action):
 
 def _init_command_line_options():
     """Parse command line options into a dictionary."""
-
     description = """\
 
 Run a WEBDAV server to share file system folders.
@@ -126,13 +136,12 @@ See https://github.com/mar10/wsgidav for additional information.
         prog="wsgidav",
         description=description,
         epilog=epilog,
-        # allow_abbrev=False,  # Py3.5+
+        allow_abbrev=False,
         formatter_class=argparse.RawTextHelpFormatter,
     )
     parser.add_argument(
         "-p",
         "--port",
-        dest="port",
         type=int,
         # default=8080,
         help="port to serve on (default: 8080)",
@@ -140,7 +149,6 @@ See https://github.com/mar10/wsgidav for additional information.
     parser.add_argument(
         "-H",  # '-h' conflicts with --help
         "--host",
-        dest="host",
         help=(
             "host to serve from (default: localhost). 'localhost' is only "
             "accessible from the local computer. Use 0.0.0.0 to make your "
@@ -203,16 +211,20 @@ See https://github.com/mar10/wsgidav for additional information.
         dest="config_file",
         action=FullExpandedPath,
         help=(
-            "configuration file (default: {} in current directory)".format(
-                DEFAULT_CONFIG_FILES
-            )
+            f"configuration file (default: {DEFAULT_CONFIG_FILES} in current directory)"
         ),
     )
+
     qv_group.add_argument(
         "--no-config",
         action="store_true",
-        dest="no_config",
-        help="do not try to load default {}".format(DEFAULT_CONFIG_FILES),
+        help=f"do not try to load default {DEFAULT_CONFIG_FILES}",
+    )
+
+    parser.add_argument(
+        "--browse",
+        action="store_true",
+        help="open browser on start",
     )
 
     parser.add_argument(
@@ -229,14 +241,14 @@ See https://github.com/mar10/wsgidav for additional information.
 
     if args.root_path and not os.path.isdir(args.root_path):
         msg = "{} is not a directory".format(args.root_path)
-        raise parser.error(msg)
+        parser.error(msg)
 
     if args.version:
         if args.verbose >= 4:
             version_info = "WsgiDAV/{} Python/{}({} bit) {}".format(
                 __version__,
                 util.PYTHON_VERSION,
-                "64" if sys.maxsize > 2 ** 32 else "32",
+                "64" if sys.maxsize > 2**32 else "32",
                 platform.platform(aliased=True),
             )
             version_info += "\nPython from: {}".format(sys.executable)
@@ -328,49 +340,29 @@ def _loadSeafileSettings(config):
     config['workers'] = workers
     config['timeout'] = timeout
 
-def _read_config_file(config_file, verbose):
+def _read_config_file(config_file, _verbose):
     """Read configuration file options into a dictionary."""
 
     config_file = os.path.abspath(config_file)
 
     if not os.path.exists(config_file):
-        raise RuntimeError("Couldn't open configuration file '{}'.".format(config_file))
+        raise RuntimeError(f"Couldn't open configuration file '{config_file}'.")
 
     if config_file.endswith(".json"):
-        with io.open(config_file, mode="r", encoding="utf-8") as json_file:
-            conf = json_load(json_file)
+        with open(config_file, mode="rt", encoding="utf-8-sig") as fp:
+            conf = json_load(fp)
 
     elif config_file.endswith(".yaml"):
-        with io.open(config_file, mode="r", encoding="utf-8") as yaml_file:
-            conf = yaml.safe_load(yaml_file)
+        with open(config_file, mode="rt", encoding="utf-8-sig") as fp:
+            conf = yaml.safe_load(fp)
 
     else:
-        try:
-            import imp
-
-            conf = {}
-            configmodule = imp.load_source("configuration_module", config_file)
-
-            for k, v in vars(configmodule).items():
-                if k.startswith("__"):
-                    continue
-                elif isfunction(v):
-                    continue
-                conf[k] = v
-        except Exception:
-            exc_type, exc_value = sys.exc_info()[:2]
-            exc_info_list = traceback.format_exception_only(exc_type, exc_value)
-            exc_text = "\n".join(exc_info_list)
-            print(
-                "Failed to read configuration file: "
-                + config_file
-                + "\nDue to "
-                + exc_text,
-                file=sys.stderr,
-            )
-            raise
+        raise RuntimeError(
+            f"Unsupported config file format (expected yaml or json): {config_file}"
+        )
 
     conf["_config_file"] = config_file
+    conf["_config_root"] = os.path.dirname(config_file)
     return conf
 
 
@@ -381,6 +373,8 @@ def _init_config():
 
     # Set config defaults
     config = copy.deepcopy(DEFAULT_CONFIG)
+    config["_config_file"] = None
+    config["_config_root"] = os.getcwd()
 
     # Configuration file overrides defaults
     config_file = cli_opts.get("config_file")
@@ -424,8 +418,12 @@ def _init_config():
 
     if config["verbose"] >= 5:
         # TODO: remove passwords from user_mapping
-        # config_cleaned = copy.deepcopy(config)
-        print("Configuration({}):\n{}".format(cli_opts["config_file"], pformat(config)))
+        config_cleaned = util.purge_passwords(config)
+        print(
+            "Configuration({}):\n{}".format(
+                cli_opts["config_file"], pformat(config_cleaned)
+            )
+        )
 
     if not config["provider_mapping"]:
         parser.error("No DAV provider defined.")
@@ -438,7 +436,7 @@ def _init_config():
         config["pidfile"] = pid_file
     # Quick-configuration of DomainController
     auth = cli_opts.get("auth")
-    auth_conf = config.get("http_authenticator", {})
+    auth_conf = util.get_dict_value(config, "http_authenticator", as_dict=True)
     if auth and auth_conf.get("domain_controller"):
         parser.error(
             "--auth option can only be used when no domain_controller is configured"
@@ -488,18 +486,18 @@ def _init_config():
         config["pam_dc"] = {"service": "login"}
     # print(config)
 
-    if cli_opts.get("reload"):
-        print("Installing paste.reloader.", file=sys.stderr)
-        from paste import reloader  # @UnresolvedImport
+    # if cli_opts.get("reload"):
+    #     print("Installing paste.reloader.", file=sys.stderr)
+    #     from paste import reloader  # @UnresolvedImport
 
-        reloader.install()
-        if config_file:
-            # Add config file changes
-            reloader.watch_file(config_file)
-        # import pydevd
-        # pydevd.settrace()
+    #     reloader.install()
+    #     if config_file:
+    #         # Add config file changes
+    #         reloader.watch_file(config_file)
+    #     # import pydevd
+    #     # pydevd.settrace()
 
-    return config
+    return cli_opts, config
 
 import gunicorn.app.base
 
@@ -519,118 +517,158 @@ class GunicornApplication(gunicorn.app.base.BaseApplication):
     def load(self):
         return self.application
 
-def _run_gunicorn(app, config, mode):
-    options = {
-        'bind': '%s:%s' % (config.get('host'), config.get('port')),
-        'threads': config.get('workers'),
-        "pidfile": config.get('pidfile'),
-        "timeout": config.get('timeout')
-    }
 
-    GunicornApplication(app, options).run()
-
-
-def _run_paste(app, config, mode):
-    """Run WsgiDAV using paste.httpserver, if Paste is installed.
-
-    See http://pythonpaste.org/modules/httpserver.html for more options
-    """
-    from paste import httpserver
-
-    version = "WsgiDAV/{} {} Python {}".format(
-        __version__, httpserver.WSGIHandler.server_version, util.PYTHON_VERSION
-    )
-    _logger.info("Running {}...".format(version))
-
-    # See http://pythonpaste.org/modules/httpserver.html for more options
-    server = httpserver.serve(
-        app,
-        host=config["host"],
-        port=config["port"],
-        server_version=version,
-        # This option enables handling of keep-alive
-        # and expect-100:
-        protocol_version="HTTP/1.1",
-        start_loop=False,
-    )
-
-    if config["verbose"] >= 5:
-        __handle_one_request = server.RequestHandlerClass.handle_one_request
-
-        def handle_one_request(self):
-            __handle_one_request(self)
-            if self.close_connection == 1:
-                _logger.debug("HTTP Connection : close")
-            else:
-                _logger.debug("HTTP Connection : continue")
-
-        server.RequestHandlerClass.handle_one_request = handle_one_request
-
-        # __handle = server.RequestHandlerClass.handle
-
-        # def handle(self):
-        #     _logger.debug("open HTTP connection")
-        #     __handle(self)
-
-        server.RequestHandlerClass.handle_one_request = handle_one_request
-
-    host, port = server.server_address
-    if host == "0.0.0.0":
-        _logger.info(
-            "Serving on 0.0.0.0:{} view at {}://127.0.0.1:{}".format(port, "http", port)
-        )
-    else:
-        _logger.info("Serving on {}://{}:{}".format("http", host, port))
+def _run_cheroot(app, config, _server):
+    """Run WsgiDAV using cheroot.server (https://cheroot.cherrypy.dev/)."""
     try:
-        server.serve_forever()
+        from cheroot import server, wsgi
+    except ImportError:
+        _logger.exception("Could not import Cheroot (https://cheroot.cherrypy.dev/).")
+        _logger.error("Try `pip install cheroot`.")
+        return False
+
+    version = wsgi.Server.version
+    version = f"WsgiDAV/{__version__} {version} Python {util.PYTHON_VERSION}"
+    wsgi.Server.version = version
+
+    info = _get_common_info(config)
+
+    # Support SSL
+    if info["use_ssl"]:
+        ssl_adapter = info["ssl_adapter"]
+        ssl_adapter = server.get_ssl_adapter_class(ssl_adapter)
+        wsgi.Server.ssl_adapter = ssl_adapter(
+            info["ssl_cert"], info["ssl_pk"], info["ssl_chain"]
+        )
+        _logger.info("SSL / HTTPS enabled. Adapter: {}".format(ssl_adapter))
+
+    _logger.info(f"Running {version}")
+    _logger.info(f"Serving on {info['url']} ...")
+
+    server_args = {
+        "bind_addr": (config["host"], config["port"]),
+        "wsgi_app": app,
+        "server_name": version,
+        # File Explorer needs lot of threads (see issue #149):
+        "numthreads": 50,  # TODO: still required?
+    }
+    # Override or add custom args
+    custom_args = util.get_dict_value(config, "server_args", as_dict=True)
+    server_args.update(custom_args)
+
+    class PatchedServer(wsgi.Server):
+        STARTUP_NOTIFICATION_DELAY = 0.5
+
+        def serve(self, *args, **kwargs):
+            _logger.error("wsgi.Server.serve")
+            if startup_event and not startup_event.is_set():
+                Timer(self.STARTUP_NOTIFICATION_DELAY, startup_event.set).start()
+                _logger.error("wsgi.Server is ready")
+            return super().serve(*args, **kwargs)
+
+    # If the caller passed a startup event, monkey patch the server to set it
+    # when the request handler loop is entered
+    startup_event = config.get("startup_event")
+    if startup_event:
+        server = PatchedServer(**server_args)
+    else:
+        server = wsgi.Server(**server_args)
+
+    try:
+        server.start()
+    except KeyboardInterrupt:
+        _logger.warning("Caught Ctrl-C, shutting down...")
+    finally:
+        server.stop()
+
+    return
+
+
+def _run_ext_wsgiutils(app, config, _server):
+    """Run WsgiDAV using ext_wsgiutils_server from the wsgidav package."""
+    from wsgidav.server import ext_wsgiutils_server
+
+    _logger.warning(
+        "WARNING: This single threaded server (ext-wsgiutils) is not meant for production."
+    )
+    try:
+        ext_wsgiutils_server.serve(config, app)
     except KeyboardInterrupt:
         _logger.warning("Caught Ctrl-C, shutting down...")
     return
 
 
-def _run_gevent(app, config, mode):
-    """Run WsgiDAV using gevent if gevent is installed.
+# def _run_flup(app, config, server):
+#     """Run WsgiDAV using flup.server.fcgi (http://trac.saddi.com/flup/wiki/FlupServers)."""
+#     try:
+#         if server == "flup-fcgi":
+#             from flup.server.fcgi import WSGIServer
+#             from flup.server.fcgi import __version__ as flupver
+#         elif server == "flup-fcgi-fork":
+#             from flup.server.fcgi_fork import WSGIServer
+#             from flup.server.fcgi_fork import __version__ as flupver
+#         else:
+#             raise ValueError
+#     except ImportError:
+#         _logger.exception(f"Could not import {server} (https://gunicorn.org).")
+#         _logger.error("Try `pip install flup`.")
+#         return False
+
+#     version = f"{WSGIServer.__module__}/{flupver}"
+#     version = f"WsgiDAV/{__version__} {version} Python {util.PYTHON_VERSION}"
+#     _logger.info(f"Running {version} ...")
+
+#     server = WSGIServer(
+#         app,
+#         bindAddress=(config["host"], config["port"]),
+#         # debug=True,
+#     )
+#     try:
+#         server.run()
+#     except KeyboardInterrupt:
+#         _logger.warning("Caught Ctrl-C, shutting down...")
+#     return
+
+
+def _run_gevent(app, config, server):
+    """Run WsgiDAV using gevent if gevent (https://www.gevent.org).
 
     See
       https://github.com/gevent/gevent/blob/master/src/gevent/pywsgi.py#L1356
       https://github.com/gevent/gevent/blob/master/src/gevent/server.py#L38
-     for more options
+    for more options.
     """
-    import gevent
-    import gevent.monkey
+    try:
+        import gevent
+        import gevent.monkey
+        from gevent.pywsgi import WSGIServer
+    except ImportError:
+        _logger.exception("Could not import gevent (http://www.gevent.org).")
+        _logger.error("Try `pip install gevent`.")
+        return False
 
     gevent.monkey.patch_all()
-    from gevent.pywsgi import WSGIServer
 
-    server_args = {"bind_addr": (config["host"], config["port"]), "wsgi_app": app}
-
-    server_name = "WsgiDAV/{} gevent/{} Python/{}".format(
-        __version__, gevent.__version__, util.PYTHON_VERSION
-    )
-
-    # Support SSL
-    ssl_certificate = _get_checked_path(config.get("ssl_certificate"), config)
-    ssl_private_key = _get_checked_path(config.get("ssl_private_key"), config)
-    ssl_certificate_chain = _get_checked_path(
-        config.get("ssl_certificate_chain"), config
-    )
+    info = _get_common_info(config)
+    version = f"gevent/{gevent.__version__}"
+    version = f"WsgiDAV/{__version__} {version} Python {util.PYTHON_VERSION}"
 
     # Override or add custom args
-    server_args.update(config.get("server_args", {}))
+    server_args = {
+        "wsgi_app": app,
+        "bind_addr": (config["host"], config["port"]),
+    }
+    custom_args = util.get_dict_value(config, "server_args", as_dict=True)
+    server_args.update(custom_args)
 
-    protocol = "http"
-    if ssl_certificate:
-        assert ssl_private_key
-        protocol = "https"
-        _logger.info("SSL / HTTPS enabled.")
+    if info["use_ssl"]:
         dav_server = WSGIServer(
             server_args["bind_addr"],
             app,
-            keyfile=ssl_private_key,
-            certfile=ssl_certificate,
-            ca_certs=ssl_certificate_chain,
+            keyfile=info["ssl_pk"],
+            certfile=info["ssl_cert"],
+            ca_certs=info["ssl_chain"],
         )
-
     else:
         dav_server = WSGIServer(server_args["bind_addr"], app)
 
@@ -648,10 +686,8 @@ def _run_gevent(app, config, mode):
         org_start = dav_server.start_accepting
         dav_server.start_accepting = _patched_start
 
-    _logger.info("Running {}".format(server_name))
-    _logger.info(
-        "Serving on {}://{}:{} ...".format(protocol, config["host"], config["port"])
-    )
+    _logger.info(f"Running {version}")
+    _logger.info(f"Serving on {info['url']} ...")
     try:
         gevent.spawn(dav_server.serve_forever())
     except KeyboardInterrupt:
@@ -659,214 +695,175 @@ def _run_gevent(app, config, mode):
     return
 
 
-def _run__cherrypy(app, config, mode):
-    """Run WsgiDAV using cherrypy.wsgiserver if CherryPy is installed."""
-    assert mode == "cherrypy-wsgiserver"
-
+def _run_gunicorn(app, config, server):
+    """Run WsgiDAV using Gunicorn (https://gunicorn.org)."""
     try:
-        from cherrypy import wsgiserver
-        from cherrypy.wsgiserver.ssl_builtin import BuiltinSSLAdapter
-
-        _logger.warning("WARNING: cherrypy.wsgiserver is deprecated.")
-        _logger.warning(
-            "         Starting with CherryPy 9.0 the functionality from cherrypy.wsgiserver"
-        )
-        _logger.warning("         was moved to the cheroot project.")
-        _logger.warning("         Consider using --server=cheroot.")
+        import gunicorn.app.base
     except ImportError:
-        _logger.error("*" * 78)
-        _logger.error("ERROR: Could not import cherrypy.wsgiserver.")
-        _logger.error(
-            "Try `pip install cherrypy` or specify another server using the --server option."
-        )
-        _logger.error("Note that starting with CherryPy 9.0, the server was moved to")
-        _logger.error(
-            "the cheroot project, so it is recommended to use `-server=cheroot`"
-        )
-        _logger.error("and run `pip install cheroot` instead.")
-        _logger.error("*" * 78)
-        raise
+        _logger.exception("Could not import Gunicorn (https://gunicorn.org).")
+        _logger.error("Try `pip install gunicorn` (UNIX only).")
+        return False
 
-    server_name = "WsgiDAV/{} {} Python/{}".format(
-        __version__, wsgiserver.CherryPyWSGIServer.version, util.PYTHON_VERSION
-    )
-    wsgiserver.CherryPyWSGIServer.version = server_name
+    info = _get_common_info(config)
 
-    # Support SSL
-    ssl_certificate = _get_checked_path(config.get("ssl_certificate"), config)
-    ssl_private_key = _get_checked_path(config.get("ssl_private_key"), config)
-    ssl_certificate_chain = _get_checked_path(
-        config.get("ssl_certificate_chain"), config
-    )
-    protocol = "http"
-    if ssl_certificate:
-        assert ssl_private_key
-        wsgiserver.CherryPyWSGIServer.ssl_adapter = BuiltinSSLAdapter(
-            ssl_certificate, ssl_private_key, ssl_certificate_chain
-        )
-        protocol = "https"
-        _logger.info("SSL / HTTPS enabled.")
+    class GunicornApplication(gunicorn.app.base.BaseApplication):
+        def __init__(self, app, options=None):
+            self.options = options or {}
+            self.application = app
+            super().__init__()
 
-    _logger.info("Running {}".format(server_name))
-    _logger.info(
-        "Serving on {}://{}:{} ...".format(protocol, config["host"], config["port"])
-    )
+        def load_config(self):
+            config = {
+                key: value
+                for key, value in self.options.items()
+                if key in self.cfg.settings and value is not None
+            }
+            for key, value in config.items():
+                self.cfg.set(key.lower(), value)
 
+        def load(self):
+            return self.application
+
+    # See https://docs.gunicorn.org/en/latest/settings.html
     server_args = {
-        "bind_addr": (config["host"], config["port"]),
-        "wsgi_app": app,
-        "server_name": server_name,
+        "bind": "{}:{}".format(config["host"], config["port"]),
+        'workers': config.get('workers'),
+        "timeout": config.get('timeout'),
+        "pidfile": config.get('pidfile'),
     }
+    if info["use_ssl"]:
+        server_args.update(
+            {
+                "keyfile": info["ssl_pk"],
+                "certfile": info["ssl_cert"],
+                "ca_certs": info["ssl_chain"],
+                # "ssl_version": ssl_version
+                # "cert_reqs": ssl_cert_reqs
+                # "ciphers": ssl_ciphers
+            }
+        )
     # Override or add custom args
-    server_args.update(config.get("server_args", {}))
+    custom_args = util.get_dict_value(config, "server_args", as_dict=True)
+    server_args.update(custom_args)
 
-    server = wsgiserver.CherryPyWSGIServer(**server_args)
+    version = f"gunicorn/{gunicorn.__version__}"
+    version = f"WsgiDAV/{__version__} {version} Python {util.PYTHON_VERSION}"
+    _logger.info(f"Running {version} ...")
 
-    # If the caller passed a startup event, monkey patch the server to set it
-    # when the request handler loop is entered
-    startup_event = config.get("startup_event")
-    if startup_event:
+    GunicornApplication(app, server_args).run()
 
-        def _patched_tick():
-            server.tick = org_tick  # undo the monkey patch
-            org_tick()
-            _logger.info("CherryPyWSGIServer is ready")
-            startup_event.set()
 
-        org_tick = server.tick
-        server.tick = _patched_tick
+def _run_paste(app, config, server):
+    """Run WsgiDAV using paste.httpserver, if Paste is installed.
 
+    See http://pythonpaste.org/modules/httpserver.html for more options
+    """
     try:
-        server.start()
-    except KeyboardInterrupt:
-        _logger.warning("Caught Ctrl-C, shutting down...")
-    finally:
-        server.stop()
-    return
-
-
-def _run_cheroot(app, config, mode):
-    """Run WsgiDAV using cheroot.server if Cheroot is installed."""
-    assert mode == "cheroot"
-    try:
-        from cheroot import server, wsgi
-    #         from cheroot.ssl.builtin import BuiltinSSLAdapter
-    #         import cheroot.ssl.pyopenssl
+        from paste import httpserver
     except ImportError:
-        _logger.error("*" * 78)
-        _logger.error("ERROR: Could not import Cheroot.")
-        _logger.error(
-            "Try `pip install cheroot` or specify another server using the --server option."
+        _logger.exception(
+            "Could not import paste.httpserver (https://github.com/cdent/paste)."
         )
-        _logger.error("*" * 78)
-        raise
+        _logger.error("Try `pip install paste`.")
+        return False
 
-    server_name = "WsgiDAV/{} {} Python/{}".format(
-        __version__, wsgi.Server.version, util.PYTHON_VERSION
-    )
-    wsgi.Server.version = server_name
+    info = _get_common_info(config)
 
-    # Support SSL
-    ssl_certificate = _get_checked_path(config.get("ssl_certificate"), config)
-    ssl_private_key = _get_checked_path(config.get("ssl_private_key"), config)
-    ssl_certificate_chain = _get_checked_path(
-        config.get("ssl_certificate_chain"), config
-    )
-    ssl_adapter = config.get("ssl_adapter", "builtin")
-    protocol = "http"
-    if ssl_certificate and ssl_private_key:
-        ssl_adapter = server.get_ssl_adapter_class(ssl_adapter)
-        wsgi.Server.ssl_adapter = ssl_adapter(
-            ssl_certificate, ssl_private_key, ssl_certificate_chain
-        )
-        protocol = "https"
-        _logger.info("SSL / HTTPS enabled. Adapter: {}".format(ssl_adapter))
-    elif ssl_certificate or ssl_private_key:
-        raise RuntimeError(
-            "Option 'ssl_certificate' and 'ssl_private_key' must be used together."
-        )
-    #     elif ssl_adapter:
-    #         print("WARNING: Ignored option 'ssl_adapter' (requires 'ssl_certificate').")
+    version = httpserver.WSGIHandler.server_version
+    version = f"WsgiDAV/{__version__} {version} Python {util.PYTHON_VERSION}"
 
-    _logger.info("Running {}".format(server_name))
-    _logger.info(
-        "Serving on {}://{}:{} ...".format(protocol, config["host"], config["port"])
-    )
-
-    server_args = {
-        "bind_addr": (config["host"], config["port"]),
-        "wsgi_app": app,
-        "server_name": server_name,
-        # File Explorer needs lot of threads (see issue #149):
-        "numthreads": 50,
-    }
-    # Override or add custom args
-    server_args.update(config.get("server_args", {}))
-
-    server = wsgi.Server(**server_args)
-
-    # If the caller passed a startup event, monkey patch the server to set it
-    # when the request handler loop is entered
-    startup_event = config.get("startup_event")
-    if startup_event:
-
-        def _patched_tick():
-            server.tick = org_tick  # undo the monkey patch
-            _logger.info("wsgi.Server is ready")
-            startup_event.set()
-            org_tick()
-
-        org_tick = server.tick
-        server.tick = _patched_tick
-
-    try:
-        server.start()
-    except KeyboardInterrupt:
-        _logger.warning("Caught Ctrl-C, shutting down...")
-    finally:
-        server.stop()
-
-    return
-
-
-def _run_flup(app, config, mode):
-    """Run WsgiDAV using flup.server.fcgi if Flup is installed."""
-    # http://trac.saddi.com/flup/wiki/FlupServers
-    if mode == "flup-fcgi":
-        from flup.server.fcgi import WSGIServer, __version__ as flupver
-    elif mode == "flup-fcgi-fork":
-        from flup.server.fcgi_fork import WSGIServer, __version__ as flupver
-    else:
-        raise ValueError
-
-    _logger.info(
-        "Running WsgiDAV/{} {}/{}...".format(
-            __version__, WSGIServer.__module__, flupver
-        )
-    )
-    server = WSGIServer(
+    # See http://pythonpaste.org/modules/httpserver.html for more options
+    server = httpserver.serve(
         app,
-        bindAddress=(config["host"], config["port"]),
-        # debug=True,
+        host=config["host"],
+        port=config["port"],
+        server_version=version,
+        # This option enables handling of keep-alive and expect-100:
+        protocol_version="HTTP/1.1",
+        start_loop=False,
     )
+
+    if config["verbose"] >= 5:
+        __handle_one_request = server.RequestHandlerClass.handle_one_request
+
+        def handle_one_request(self):
+            __handle_one_request(self)
+            if self.close_connection == 1:
+                _logger.debug("HTTP Connection : close")
+            else:
+                _logger.debug("HTTP Connection : continue")
+
+        server.RequestHandlerClass.handle_one_request = handle_one_request
+
+    _logger.info(f"Running {version} ...")
+    host, port = server.server_address
+    if host == "0.0.0.0":
+        _logger.info(f"Serving on 0.0.0.0:{port} view at http://127.0.0.1:{port}")
+    else:
+        _logger.info(f"Serving on {info['url']}")
+
     try:
-        server.run()
+        server.serve_forever()
     except KeyboardInterrupt:
         _logger.warning("Caught Ctrl-C, shutting down...")
     return
 
 
-def _run_wsgiref(app, config, mode):
-    """Run WsgiDAV using wsgiref.simple_server, on Python 2.5+."""
-    # http://www.python.org/doc/2.5.2/lib/module-wsgiref.html
-    from wsgiref.simple_server import make_server, software_version
+def _run_uvicorn(app, config, server):
+    """Run WsgiDAV using Uvicorn (https://www.uvicorn.org)."""
+    try:
+        import uvicorn
+    except ImportError:
+        _logger.exception("Could not import Uvicorn (https://www.uvicorn.org).")
+        _logger.error("Try `pip install uvicorn`.")
+        return False
+
+    info = _get_common_info(config)
+
+    # See https://www.uvicorn.org/settings/
+    server_args = {
+        "interface": "wsgi",
+        "host": config["host"],
+        "port": config["port"],
+        # TODO: see _run_cheroot()
+    }
+    if info["use_ssl"]:
+        server_args.update(
+            {
+                "ssl_keyfile": info["ssl_pk"],
+                "ssl_certfile": info["ssl_cert"],
+                "ssl_ca_certs": info["ssl_chain"],
+                # "ssl_keyfile_password": ssl_keyfile_password
+                # "ssl_version": ssl_version
+                # "ssl_cert_reqs": ssl_cert_reqs
+                # "ssl_ciphers": ssl_ciphers
+            }
+        )
+    # Override or add custom args
+    custom_args = util.get_dict_value(config, "server_args", as_dict=True)
+    server_args.update(custom_args)
+
+    version = f"uvicorn/{uvicorn.__version__}"
+    version = f"WsgiDAV/{__version__} {version} Python {util.PYTHON_VERSION}"
+    _logger.info(f"Running {version} ...")
+
+    uvicorn.run(app, **server_args)
+
+
+def _run_wsgiref(app, config, _server):
+    """Run WsgiDAV using wsgiref.simple_server (https://docs.python.org/3/library/wsgiref.html)."""
+    from wsgiref.simple_server import WSGIRequestHandler, make_server
+
+    version = WSGIRequestHandler.server_version
+    version = f"WsgiDAV/{__version__} {version}"  # Python {util.PYTHON_VERSION}"
+    _logger.info(f"Running {version} ...")
 
-    version = "WsgiDAV/{} {}".format(__version__, software_version)
-    _logger.info("Running {}...".format(version))
     _logger.warning(
         "WARNING: This single threaded server (wsgiref) is not meant for production."
     )
+    WSGIRequestHandler.server_version = version
     httpd = make_server(config["host"], config["port"], app)
+    # httpd.RequestHandlerClass.server_version = version
     try:
         httpd.serve_forever()
     except KeyboardInterrupt:
@@ -874,41 +871,27 @@ def _run_wsgiref(app, config, mode):
     return
 
 
-def _run_ext_wsgiutils(app, config, mode):
-    """Run WsgiDAV using ext_wsgiutils_server from the wsgidav package."""
-    from wsgidav.server import ext_wsgiutils_server
-
-    _logger.info(
-        "Running WsgiDAV {} on wsgidav.ext_wsgiutils_server...".format(__version__)
-    )
-    _logger.warning(
-        "WARNING: This single threaded server (ext-wsgiutils) is not meant for production."
-    )
-    try:
-        ext_wsgiutils_server.serve(config, app)
-    except KeyboardInterrupt:
-        _logger.warning("Caught Ctrl-C, shutting down...")
-    return
-
-
 SUPPORTED_SERVERS = {
+    "cheroot": _run_cheroot,
+    # "cherrypy": _run__cherrypy,
+    "ext-wsgiutils": _run_ext_wsgiutils,
+    # "flup-fcgi_fork": _run_flup,
+    # "flup-fcgi": _run_flup,
+    "gevent": _run_gevent,
     "gunicorn": _run_gunicorn,
     "paste": _run_paste,
-    "gevent": _run_gevent,
-    "cheroot": _run_cheroot,
-    "cherrypy": _run__cherrypy,
-    "ext-wsgiutils": _run_ext_wsgiutils,
-    "flup-fcgi": _run_flup,
-    "flup-fcgi_fork": _run_flup,
+    "uvicorn": _run_uvicorn,
     "wsgiref": _run_wsgiref,
 }
 
 
 def run():
-    config = _init_config()
+    cli_opts, config = _init_config()
 
     util.init_logging(config)
 
+    info = _get_common_info(config)
+
     app = WsgiDAVApp(config)
 
     server = config["server"]
@@ -926,7 +909,19 @@ def run():
             "Consider `pip install lxml`(see https://pypi.python.org/pypi/lxml)."
         )
 
+    if cli_opts["browse"]:
+        BROWSE_DELAY = 2.0
+
+        def _worker():
+            url = info["url"]
+            url = url.replace("0.0.0.0", "127.0.0.1")
+            _logger.info(f"Starting browser on {url} ...")
+            webbrowser.open(url)
+
+        Timer(BROWSE_DELAY, _worker).start()
+
     handler(app, config, server)
+    return
 
 
 if __name__ == "__main__":
