@@ -304,6 +304,7 @@ class EnvManager(object):
         self.central_pids_dir = os.path.join(self.top_dir, 'pids')
         self.central_logs_dir = os.path.join(self.top_dir, 'logs')
         Utils.must_mkdir(self.central_config_dir)
+        self.is_pro = os.path.exists(os.path.join(self.install_path, 'pro'))
 
     def check_pre_condiction(self):
         def error_if_not_exists(path):
@@ -327,6 +328,7 @@ class EnvManager(object):
         env = dict(os.environ)
         env['CCNET_CONF_DIR'] = ccnet_config.ccnet_dir
         env['SEAFILE_CONF_DIR'] = seafile_config.seafile_dir
+        env['SEAFES_DIR'] = os.path.join(self.install_path, 'pro', 'python', 'seafes')
         self.setup_python_path(env)
         return env
 
@@ -342,8 +344,8 @@ class EnvManager(object):
 
             os.path.join(install_path, 'seahub', 'thirdpart'),
 
-            os.path.join(install_path, 'seafile/lib/python3.6/site-packages'),
-            os.path.join(install_path, 'seafile/lib64/python3.6/site-packages'),
+            os.path.join(install_path, 'seafile/lib/python3/site-packages'),
+            os.path.join(install_path, 'seafile/lib64/python3/site-packages'),
         ]
 
         for path in extra_python_path:
@@ -806,7 +808,7 @@ class CcnetConfigurator(AbstractConfigurator):
     def generate(self):
         print('Generating ccnet configuration ...\n')
         with open(self.ccnet_conf, 'w') as fp:
-            fp.write('[General]\nSERVICE_URL = http://%s/\n' % self.ip_or_domain)
+            fp.write('[General]')
 
         self.generate_db_conf()
 
@@ -930,6 +932,7 @@ class SeafileConfigurator(AbstractConfigurator):
             fp.write('[fileserver]\nport=%d\n' % self.fileserver_port)
 
         self.generate_db_conf()
+        self.generate_notification_conf()
 
         ## use default seafile-data path: seafile_data_dir=${TOPDIR}/seafile-data
 
@@ -957,6 +960,32 @@ class SeafileConfigurator(AbstractConfigurator):
 
         Utils.write_config(config, self.seafile_conf)
 
+    def generate_notification_conf(self):
+        config = Utils.read_config(self.seafile_conf)
+        # [notification]
+        # enabled=
+        # host=
+        # port=
+        # log_level=
+        # jwt_private_key=
+        script = os.path.join(env_mgr.install_path, 'seahub/tools/secret_key_generator.py')
+        cmd = [
+            Utils.get_python_executable(),
+            script,
+        ]
+        jwt_private_key = Utils.get_command_output(cmd).strip().decode('utf8').replace('%', '')
+
+        db_section = 'notification'
+        if not config.has_section(db_section):
+            config.add_section(db_section)
+        config.set(db_section, 'enabled', 'false')
+        config.set(db_section, 'host', '127.0.0.1')
+        config.set(db_section, 'port', '8083')
+        config.set(db_section, 'log_level', 'info')
+        config.set(db_section, 'jwt_private_key', jwt_private_key)
+
+        Utils.write_config(config, self.seafile_conf)
+
     def validate_seafile_dir(self, path):
         if os.path.exists(path):
             raise InvalidAnswer('%s already exists' % Utils.highlight(path))
@@ -1054,6 +1083,8 @@ class SeahubConfigurator(AbstractConfigurator):
             fp.write('\n')
             self.write_secret_key(fp)
             fp.write('\n')
+            fp.write('SERVICE_URL = "http://%s/"' % ccnet_config.ip_or_domain)
+            fp.write('\n')
             self.write_database_config(fp)
 
     def write_utf8_comment(self, fp):
@@ -1077,7 +1108,8 @@ class SeahubConfigurator(AbstractConfigurator):
         'USER': '%(username)s',
         'PASSWORD': '%(password)s',
         'HOST': '%(host)s',
-        'PORT': '%(port)s'
+        'PORT': '%(port)s',
+        'OPTIONS': {'charset': 'utf8mb4'},
     }
 }
 
@@ -1209,13 +1241,37 @@ class SeafDavConfigurator(AbstractConfigurator):
 [WEBDAV]
 enabled = false
 port = 8080
-fastcgi = false
 share_name = /
 '''
 
         with open(self.seafdav_conf, 'w') as fp:
             fp.write(text)
 
+class ProfessionalConfigurator(AbstractConfigurator):
+    '''Seafile Pro related configuration'''
+    def __init__(self):
+        AbstractConfigurator.__init__(self)
+        self.pro_py = os.path.join(env_mgr.install_path, 'pro', 'pro.py')
+        self.pro_data_dir = os.path.join(env_mgr.top_dir, 'pro-data')
+
+    def ask_questions(self):
+        pass
+
+    def generate(self):
+        argv = [
+            Utils.get_python_executable(),
+            self.pro_py,
+            'setup',
+            '--mysql',
+            '--mysql_host=%s' % db_config.mysql_host,
+            '--mysql_port=%s' % db_config.mysql_port,
+            '--mysql_user=%s' % db_config.seafile_mysql_user,
+            '--mysql_password=%s' % db_config.seafile_mysql_password,
+            '--mysql_db=%s' % db_config.seahub_db_name,
+        ]
+        if Utils.run_argv(argv, env=env_mgr.get_seahub_env()) != 0:
+            Utils.error('Failed to generate seafile pro configuration')
+
 class GunicornConfigurator(AbstractConfigurator):
     def __init__(self):
         AbstractConfigurator.__init__(self)
@@ -1349,6 +1405,8 @@ seafdav_config = SeafDavConfigurator()
 gunicorn_config = GunicornConfigurator()
 seahub_config = SeahubConfigurator()
 user_manuals_handler = UserManualHandler()
+if env_mgr.is_pro:
+    pro_config = ProfessionalConfigurator()
 # Would be created after AbstractDBConfigurator.ask_use_existing_db()
 db_config = None
 need_pause = True
@@ -1494,6 +1552,8 @@ def main():
     ccnet_config.ask_questions()
     seafile_config.ask_questions()
     seahub_config.ask_questions()
+    if env_mgr.is_pro:
+        pro_config.ask_questions()
 
     # pylint: disable=redefined-variable-type
     if not db_config:
@@ -1513,6 +1573,8 @@ def main():
     seafdav_config.generate()
     gunicorn_config.generate()
     seahub_config.generate()
+    if env_mgr.is_pro:
+        pro_config.generate()
 
     ccnet_config.do_syncdb()
     seafile_config.do_syncdb()
