@@ -9,6 +9,8 @@ default_seahub_db=${TOPDIR}/seahub.db
 default_conf_dir=${TOPDIR}/conf
 default_pids_dir=${TOPDIR}/pids
 default_logs_dir=${TOPDIR}/logs
+pro_pylibs_dir=${INSTALLPATH}/pro/python
+IS_PRO_SEAFEVENTS=`awk '/is_pro/{getline;print $2;exit}' ${pro_pylibs_dir}/seafevents/seafevents_api.py`
 
 export SEAFILE_LD_LIBRARY_PATH=${INSTALLPATH}/seafile/lib/:${INSTALLPATH}/seafile/lib64:${LD_LIBRARY_PATH}
 
@@ -16,7 +18,11 @@ server_manual_http='https://download.seafile.com/published/seafile-manual/home.m
 
 function welcome () {
     echo "-----------------------------------------------------------------"
-    echo "This script will guide you to config and setup your seafile server."
+    if [[ $IS_PRO_SEAFEVENTS = "True" ]]; then
+        echo "This script will guide you to config and setup your seafile professional server."
+    else
+        echo "This script will guide you to config and setup your seafile server."
+    fi
     echo -e "\nMake sure you have read seafile server manual at \n\n\t${server_manual_http}\n"
     echo -e "Note: This script will guide your to setup seafile server using sqlite3,"
     echo "which may have problems if your disk is on a NFS/CIFS/USB."
@@ -103,7 +109,7 @@ function check_python_executable() {
             echo
             echo "Can't find a python executable of $PYTHON in PATH"
             echo "Install $PYTHON before continue."
-            echo "Or if you installed it in a non-standard PATH, set the PYTHON enviroment varirable to it"
+            echo "Or if you installed it in a non-standard PATH, set the PYTHON enviroment variable to it"
             echo
             err_and_quit
         fi
@@ -152,6 +158,7 @@ function check_system_dependency () {
     printf "Checking packages needed by seafile ...\n\n"
     check_python;
     check_sqlite3;
+
     printf "Checking Done.\n\n"
 }
 
@@ -290,7 +297,6 @@ function gen_ccnet_conf () {
     ccnet_conf=${default_conf_dir}/ccnet.conf
     if ! $(cat > ${ccnet_conf} <<EOF
 [General]
-SERVICE_URL = http://$ip_or_domain
 EOF
 ); then
     echo "failed to generate ccnet.conf";
@@ -349,8 +355,6 @@ function gen_seafdav_conf () {
 [WEBDAV]
 enabled = false
 port = 8080
-fastcgi = false
-host = 0.0.0.0
 share_name = /
 EOF
 ); then
@@ -427,6 +431,13 @@ function usage() {
 # Main workflow of this script 
 # -------------------------------------------
 
+echo "-----------------------------------------------------------------"
+echo
+echo "[Warning] SQLite database support is deprecated. The support of SQLite database will be removed in version 12 or version 13."
+echo
+echo "-----------------------------------------------------------------"
+echo
+
 for param in $@; do
     if [[ "$param" == "-h" || "$param" == "--help" ]]; then
         usage;
@@ -492,7 +503,9 @@ fi
 
 echo "Generating ccnet configuration in ${default_ccnet_conf_dir}..."
 echo
+
 gen_ccnet_conf;
+
 echo
 
 # -------------------------------------------
@@ -501,17 +514,11 @@ echo
 
 echo "Generating seafile configuration in ${default_seafile_data_dir} ..."
 echo
+
 gen_seafile_conf;
+
 echo
 
-
-# -------------------------------------------
-# Write seafile.ini
-# -------------------------------------------
-
-## use default seafile-data path: seafile_data_dir=${TOPDIR}/seafile-data
-# echo "${seafile_data_dir}" > "${default_ccnet_conf_dir}/seafile.ini"
-
 # -------------------------------------------
 # Generate gunicorn.conf.py
 # -------------------------------------------
@@ -535,6 +542,9 @@ if [[ ! -f ${dest_settings_py} ]]; then
     cat > ${dest_settings_py} <<EOF
 # -*- coding: utf-8 -*-
 SECRET_KEY = "$key"
+
+SERVICE_URL = "http://$ip_or_domain/"
+
 EOF
 fi
 
@@ -711,6 +721,11 @@ chmod 0700 "$default_ccnet_conf_dir"
 chmod 0700 "$default_seafile_data_dir"
 chmod 0700 "$default_conf_dir"
 
+if [[ -d ${INSTALLPATH}/pro ]]; then
+    pro_py=${INSTALLPATH}/pro/pro.py
+    $PYTHON ${pro_py} setup
+fi
+
 # -------------------------------------------
 # copy user manuals to library template
 # -------------------------------------------
