@@ -5,10 +5,9 @@ UPGRADE_DIR=$(dirname "$SCRIPT") # haiwen/seafile-server-1.3.0/upgrade/
 INSTALLPATH=$(dirname "$UPGRADE_DIR") # haiwen/seafile-server-1.3.0/
 TOPDIR=$(dirname "${INSTALLPATH}") # haiwen/
 default_ccnet_conf_dir=${TOPDIR}/ccnet
-default_conf_dir=${TOPDIR}/conf
-default_pids_dir=${TOPDIR}/pids
-default_logs_dir=${TOPDIR}/logs
 default_seafile_data_dir=${TOPDIR}/seafile-data
+default_seahub_db=${TOPDIR}/seahub.db
+default_conf_dir=${TOPDIR}/conf
 seafile_server_symlink=${TOPDIR}/seafile-server-latest
 seahub_data_dir=${TOPDIR}/seahub-data
 seahub_settings_py=${TOPDIR}/seahub_settings.py
@@ -16,13 +15,12 @@ seahub_settings_py=${TOPDIR}/seahub_settings.py
 manage_py=${INSTALLPATH}/seahub/manage.py
 
 export CCNET_CONF_DIR=${default_ccnet_conf_dir}
-export SEAFILE_CONF_DIR=${default_seafile_data_dir}
-export SEAFILE_CENTRAL_CONF_DIR=${default_conf_dir}
-export PYTHONPATH=${INSTALLPATH}/seafile/lib/python3.6/site-packages:${INSTALLPATH}/seafile/lib64/python3.6/site-packages:${INSTALLPATH}/seahub:${INSTALLPATH}/seahub/thirdpart:$PYTHONPATH
+export PYTHONPATH=${INSTALLPATH}/seafile/lib/python2.6/site-packages:${INSTALLPATH}/seafile/lib64/python2.6/site-packages:${INSTALLPATH}/seafile/lib/python2.7/site-packages:${INSTALLPATH}/seahub/thirdpart:$PYTHONPATH
+export PYTHONPATH=${INSTALLPATH}/seafile/lib/python2.7/site-packages:${INSTALLPATH}/seafile/lib64/python2.7/site-packages:$PYTHONPATH
 export SEAFILE_LD_LIBRARY_PATH=${INSTALLPATH}/seafile/lib/:${INSTALLPATH}/seafile/lib64:${LD_LIBRARY_PATH}
 
-prev_version=7.1
-current_version=8.0
+prev_version=4.2
+current_version=4.3
 
 echo
 echo "-------------------------------------------------------------"
@@ -37,33 +35,39 @@ function check_python_executable() {
         return 0
     fi
 
-    if which python3 2>/dev/null 1>&2; then
-        PYTHON=python3
-    elif !(python --version 2>&1 | grep "3\.[0-9]\.[0-9]") 2>/dev/null 1>&2; then
+    if which python2.7 2>/dev/null 1>&2; then
+        PYTHON=python2.7
+    elif which python27 2>/dev/null 1>&2; then
+        PYTHON=python27
+    elif which python2.6 2>/dev/null 1>&2; then
+        PYTHON=python2.6
+    elif which python26 2>/dev/null 1>&2; then
+        PYTHON=python26
+    else
         echo
-        echo "The current version of python is not 3.x.x, please use Python 3.x.x ."
+        echo "Can't find a python executable of version 2.6 or above in PATH"
+        echo "Install python 2.6+ before continue."
+        echo "Or if you installed it in a non-standard PATH, set the PYTHON enviroment variable to it"
         echo
         exit 1
-    else
-        PYTHON="python"$(python --version | cut -b 8-10)
-        if !which $PYTHON 2>/dev/null 1>&2; then
-            echo
-            echo "Can't find a python executable of $PYTHON in PATH"
-            echo "Install $PYTHON before continue."
-            echo "Or if you installed it in a non-standard PATH, set the PYTHON enviroment varirable to it"
-            echo
-            exit 1
-        fi
     fi
 }
 
-function check_seafile_data_dir () {
-    if [[ ! -d ${default_seafile_data_dir} ]]; then
-        echo "Your seafile server data directory \"${default_seafile_data_dir}\" is invalid or doesn't exits."
+function read_seafile_data_dir () {
+    seafile_ini=${default_ccnet_conf_dir}/seafile.ini
+    if [[ ! -f ${seafile_ini} ]]; then
+        echo "${seafile_ini} not found. Now quit"
+        exit 1
+    fi
+    seafile_data_dir=$(cat "${seafile_ini}")
+    if [[ ! -d ${seafile_data_dir} ]]; then
+        echo "Your seafile server data directory \"${seafile_data_dir}\" is invalid or doesn't exits."
         echo "Please check it first, or create this directory yourself."
         echo ""
         exit 1;
     fi
+
+    export SEAFILE_CONF_DIR=$seafile_data_dir
 }
 
 function ensure_server_not_running() {
@@ -74,8 +78,7 @@ function ensure_server_not_running() {
         echo "stop it using scripts before upgrade."
         echo
         exit 1
-    elif pgrep -f "${manage_py} run_gunicorn" 2>/dev/null 1>&2 \
-         || pgrep -f "seahub.wsgi:application" 2>/dev/null 1>&2; then
+    elif pgrep -f "${manage_py} run_gunicorn" 2>/dev/null 1>&2 ; then
         echo
         echo "seahub server is still running !"
         echo "stop it before upgrade."
@@ -118,7 +121,7 @@ function update_database() {
     echo
 
     db_update_helper=${UPGRADE_DIR}/db_update_helper.py
-    if ! $PYTHON "${db_update_helper}" 8.0.0; then
+    if ! $PYTHON "${db_update_helper}" 4.3.0; then
         echo
         echo "Failed to upgrade your database"
         echo
@@ -189,22 +192,48 @@ function move_old_customdir_outside() {
     cp -rf "${old_customdir}" "${seahub_data_dir}/"
 }
 
+function regenerate_secret_key() {
+    regenerate_secret_key_script=$UPGRADE_DIR/regenerate_secret_key.sh
+    if ! $regenerate_secret_key_script ; then
+        echo "Failed to regenerate the seahub secret key"
+        exit 1
+    fi
+}
+
+function remove_es_index() {
+    local es_data_dir=$TOPDIR/pro-data/search/data
+    echo -n "Removing old search index ... "
+    rm -rf $es_data_dir && mkdir -p $es_data_dir
+    echo "Done"
+}
+
+function remove_office_files() {
+    rm -rf /tmp/seafile-office-output/html/*
+}
+
 #################
 # The main execution flow of the script
 ################
 
 check_python_executable;
-check_seafile_data_dir;
+read_seafile_data_dir;
 ensure_server_not_running;
 
+regenerate_secret_key;
+
 update_database;
+
+# We changed elasticsearch index settings in 4.3.0, need to recreate the index.
+remove_es_index;
+remove_office_files;
+
 migrate_avatars;
 
+
 move_old_customdir_outside;
 make_media_custom_symlink;
 upgrade_seafile_server_latest_symlink;
 
-
 echo
 echo "-----------------------------------------------------------------"
 echo "Upgraded your seafile server successfully."
